{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# PlotlyとCufflinks\n",
    "\n",
    ":::{warning}\n",
    "2024/05/09現在，[cufflinks](https://github.com/santosjorge/cufflinks?tab=readme-ov-file)は3年前からメンテナンスが止まっているようです．そのため，このノートを参考にcufflinksを勉強し始める必要はありません．\n",
    "\n",
    "このノートは記録のためだけに公開されています．\n",
    ":::\n",
    "\n",
    "## 可視化プラットフォームPlotlyとpd.DataFrameから簡単にPlotlyを使うためのラッパーcufflinks\n",
    "\n",
    "Plotlyを使うことで，HTML,CSS, Javascriptなどの力を借りたインタラクティブなグラフを作成できます．PlotlyはそのままPythonライブラリとして公開されていますが，PandasのDataFrameから手軽にプロットできるcufflinksというライブラリが別途公開されているので，ここではこれの使い方を確認していきます．\n",
    "\n",
    "\n",
    "## インストール\n",
    "\n",
    "インストールは以下のCommand。\n",
    "```sh\n",
    "pip install plotly\n",
    "pip install cufflinks\n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## データの準備\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "まずはデータを読み込みます。"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "import warnings\n",
    "warnings.filterwarnings('ignore')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax && window.MathJax.Hub && window.MathJax.Hub.Config) {window.MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.31.1.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from sklearn import datasets\n",
    "from sklearn.manifold import TSNE\n",
    "import pandas as pd\n",
    "import cufflinks as cf\n",
    "import numpy as np\n",
    "\n",
    "cf.go_offline()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "(1797, 64)"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "digits = datasets.load_digits()\n",
    "digits.data.shape"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>0</th>\n",
       "      <th>1</th>\n",
       "      <th>2</th>\n",
       "      <th>3</th>\n",
       "      <th>4</th>\n",
       "      <th>5</th>\n",
       "      <th>6</th>\n",
       "      <th>7</th>\n",
       "      <th>8</th>\n",
       "      <th>9</th>\n",
       "      <th>...</th>\n",
       "      <th>55</th>\n",
       "      <th>56</th>\n",
       "      <th>57</th>\n",
       "      <th>58</th>\n",
       "      <th>59</th>\n",
       "      <th>60</th>\n",
       "      <th>61</th>\n",
       "      <th>62</th>\n",
       "      <th>63</th>\n",
       "      <th>label</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>5.0</td>\n",
       "      <td>13.0</td>\n",
       "      <td>9.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>6.0</td>\n",
       "      <td>13.0</td>\n",
       "      <td>10.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>12.0</td>\n",
       "      <td>13.0</td>\n",
       "      <td>5.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>11.0</td>\n",
       "      <td>16.0</td>\n",
       "      <td>10.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>4.0</td>\n",
       "      <td>15.0</td>\n",
       "      <td>12.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>3.0</td>\n",
       "      <td>11.0</td>\n",
       "      <td>16.0</td>\n",
       "      <td>9.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>2</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>7.0</td>\n",
       "      <td>15.0</td>\n",
       "      <td>13.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>8.0</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>7.0</td>\n",
       "      <td>13.0</td>\n",
       "      <td>13.0</td>\n",
       "      <td>9.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>3</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>11.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>2.0</td>\n",
       "      <td>16.0</td>\n",
       "      <td>4.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>4</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>5 rows × 65 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "     0    1    2     3     4     5    6    7    8    9  ...   55   56   57  \\\n",
       "0  0.0  0.0  5.0  13.0   9.0   1.0  0.0  0.0  0.0  0.0  ...  0.0  0.0  0.0   \n",
       "1  0.0  0.0  0.0  12.0  13.0   5.0  0.0  0.0  0.0  0.0  ...  0.0  0.0  0.0   \n",
       "2  0.0  0.0  0.0   4.0  15.0  12.0  0.0  0.0  0.0  0.0  ...  0.0  0.0  0.0   \n",
       "3  0.0  0.0  7.0  15.0  13.0   1.0  0.0  0.0  0.0  8.0  ...  0.0  0.0  0.0   \n",
       "4  0.0  0.0  0.0   1.0  11.0   0.0  0.0  0.0  0.0  0.0  ...  0.0  0.0  0.0   \n",
       "\n",
       "    58    59    60    61   62   63  label  \n",
       "0  6.0  13.0  10.0   0.0  0.0  0.0      0  \n",
       "1  0.0  11.0  16.0  10.0  0.0  0.0      1  \n",
       "2  0.0   3.0  11.0  16.0  9.0  0.0      2  \n",
       "3  7.0  13.0  13.0   9.0  0.0  0.0      3  \n",
       "4  0.0   2.0  16.0   4.0  0.0  0.0      4  \n",
       "\n",
       "[5 rows x 65 columns]"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df = pd.DataFrame(digits.data)\n",
    "df[\"label\"] = digits[\"target\"]\n",
    "df.head()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## cufflinksで2d scatter plot"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 44,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "[t-SNE] Computing 91 nearest neighbors...\n",
      "[t-SNE] Indexed 1797 samples in 0.000s...\n",
      "[t-SNE] Computed neighbors for 1797 samples in 0.019s...\n",
      "[t-SNE] Computed conditional probabilities for sample 1000 / 1797\n",
      "[t-SNE] Computed conditional probabilities for sample 1797 / 1797\n",
      "[t-SNE] Mean sigma: 11.619740\n",
      "[t-SNE] KL divergence after 250 iterations with early exaggeration: 60.883202\n",
      "[t-SNE] KL divergence after 1000 iterations: 0.741748\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>X</th>\n",
       "      <th>Y</th>\n",
       "      <th>number</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>-2.663614</td>\n",
       "      <td>55.667736</td>\n",
       "      <td>0</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>12.658976</td>\n",
       "      <td>-9.017388</td>\n",
       "      <td>1</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>-15.840053</td>\n",
       "      <td>-18.825392</td>\n",
       "      <td>2</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>-37.019611</td>\n",
       "      <td>6.332451</td>\n",
       "      <td>3</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>44.413197</td>\n",
       "      <td>-9.344617</td>\n",
       "      <td>4</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "           X          Y  number\n",
       "0  -2.663614  55.667736       0\n",
       "1  12.658976  -9.017388       1\n",
       "2 -15.840053 -18.825392       2\n",
       "3 -37.019611   6.332451       3\n",
       "4  44.413197  -9.344617       4"
      ]
     },
     "execution_count": 44,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "X2 = TSNE(n_components=2,verbose=True).fit_transform(df.values)\n",
    "\n",
    "embed2d = pd.DataFrame(X2, columns=list(\"XY\"))\n",
    "embed2d[\"label\"] = df[\"label\"]\n",
    "embed2d.head()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 63,
   "metadata": {},
   "outputs": [
    {
     "ename": "AttributeError",
     "evalue": "module 'pandas' has no attribute 'np'",
     "output_type": "error",
     "traceback": [
      "\u001b[0;31m---------------------------------------------------------------------------\u001b[0m",
      "\u001b[0;31mAttributeError\u001b[0m                            Traceback (most recent call last)",
      "Cell \u001b[0;32mIn[63], line 1\u001b[0m\n\u001b[0;32m----> 1\u001b[0m \u001b[43membed2d\u001b[49m\u001b[38;5;241;43m.\u001b[39;49m\u001b[43miplot\u001b[49m\u001b[43m(\u001b[49m\n\u001b[1;32m      2\u001b[0m \u001b[43m    \u001b[49m\u001b[43mkind\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[38;5;124;43mscatter\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[43m,\u001b[49m\u001b[43m \u001b[49m\n\u001b[1;32m      3\u001b[0m \u001b[43m    \u001b[49m\u001b[43mx\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[38;5;124;43mX\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[43m,\u001b[49m\u001b[43m \u001b[49m\u001b[43my\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[38;5;124;43mY\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[43m,\u001b[49m\n\u001b[1;32m      4\u001b[0m \u001b[43m    \u001b[49m\u001b[43mxTitle\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[38;5;124;43mX\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[43m,\u001b[49m\u001b[43m \u001b[49m\u001b[43myTitle\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[38;5;124;43mY\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[43m,\u001b[49m\n\u001b[1;32m      5\u001b[0m \u001b[43m    \u001b[49m\u001b[43mcategories\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[38;5;124;43mlabel\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[43m,\u001b[49m\n\u001b[1;32m      6\u001b[0m \u001b[43m    \u001b[49m\u001b[43mtitle\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[38;5;124;43mT-SNE 2D demo\u001b[39;49m\u001b[38;5;124;43m\"\u001b[39;49m\u001b[43m,\u001b[49m\n\u001b[1;32m      7\u001b[0m \u001b[43m    \u001b[49m\u001b[43mmode\u001b[49m\u001b[38;5;241;43m=\u001b[39;49m\u001b[38;5;124;43m'\u001b[39;49m\u001b[38;5;124;43mmarkers\u001b[39;49m\u001b[38;5;124;43m'\u001b[39;49m\u001b[43m,\u001b[49m\n\u001b[1;32m      8\u001b[0m \u001b[43m    \u001b[49m\u001b[43m)\u001b[49m\n",
      "File \u001b[0;32m~/workspace/prpy/.venv/lib/python3.11/site-packages/cufflinks/plotlytools.py:807\u001b[0m, in \u001b[0;36m_iplot\u001b[0;34m(self, kind, data, layout, filename, sharing, title, xTitle, yTitle, zTitle, theme, colors, colorscale, fill, width, dash, mode, interpolation, symbol, size, barmode, sortbars, bargap, bargroupgap, bins, histnorm, histfunc, orientation, boxpoints, annotations, keys, bestfit, bestfit_colors, mean, mean_colors, categories, x, y, z, text, gridcolor, zerolinecolor, margin, labels, values, secondary_y, secondary_y_title, subplots, shape, error_x, error_y, error_type, locations, lon, lat, asFrame, asDates, asFigure, asImage, dimensions, asPlot, asUrl, online, **kwargs)\u001b[0m\n\u001b[1;32m    802\u001b[0m \t_data\u001b[38;5;241m=\u001b[39mScatter3d(x\u001b[38;5;241m=\u001b[39m_x,y\u001b[38;5;241m=\u001b[39m_y,z\u001b[38;5;241m=\u001b[39m_z,mode\u001b[38;5;241m=\u001b[39mmode,name\u001b[38;5;241m=\u001b[39m_,\n\u001b[1;32m    803\u001b[0m \t\t\tmarker\u001b[38;5;241m=\u001b[39m\u001b[38;5;28mdict\u001b[39m(color\u001b[38;5;241m=\u001b[39mcolors[_],symbol\u001b[38;5;241m=\u001b[39msymbol,size\u001b[38;5;241m=\u001b[39m_size,opacity\u001b[38;5;241m=\u001b[39mopacity,\n\u001b[1;32m    804\u001b[0m \t\t\t\t\t\t\tline\u001b[38;5;241m=\u001b[39m\u001b[38;5;28mdict\u001b[39m(width\u001b[38;5;241m=\u001b[39mwidth)),textfont\u001b[38;5;241m=\u001b[39mtools\u001b[38;5;241m.\u001b[39mgetLayout(theme\u001b[38;5;241m=\u001b[39mtheme)[\u001b[38;5;124m'\u001b[39m\u001b[38;5;124mxaxis\u001b[39m\u001b[38;5;124m'\u001b[39m][\u001b[38;5;124m'\u001b[39m\u001b[38;5;124mtitlefont\u001b[39m\u001b[38;5;124m'\u001b[39m])\n\u001b[1;32m    805\u001b[0m \u001b[38;5;28;01melse\u001b[39;00m:\n\u001b[1;32m    806\u001b[0m \t\u001b[38;5;66;03m#see error 168\u001b[39;00m\n\u001b[0;32m--> 807\u001b[0m \t\u001b[38;5;28;01mif\u001b[39;00m \u001b[38;5;28mtype\u001b[39m(_x)\u001b[38;5;241m==\u001b[39m\u001b[43mpd\u001b[49m\u001b[38;5;241;43m.\u001b[39;49m\u001b[43mnp\u001b[49m\u001b[38;5;241m.\u001b[39mndarray:\n\u001b[1;32m    808\u001b[0m \t\t\u001b[38;5;28;01mif\u001b[39;00m \u001b[38;5;124m'\u001b[39m\u001b[38;5;124m[ns]\u001b[39m\u001b[38;5;124m'\u001b[39m \u001b[38;5;129;01min\u001b[39;00m _x\u001b[38;5;241m.\u001b[39mdtype\u001b[38;5;241m.\u001b[39mstr:\n\u001b[1;32m    809\u001b[0m \t\t\t_x\u001b[38;5;241m=\u001b[39m_x\u001b[38;5;241m.\u001b[39mastype(\u001b[38;5;28mstr\u001b[39m)\n",
      "\u001b[0;31mAttributeError\u001b[0m: module 'pandas' has no attribute 'np'"
     ]
    }
   ],
   "source": [
    "embed2d.iplot(\n",
    "    kind=\"scatter\", \n",
    "    x=\"X\", y=\"Y\",\n",
    "    xTitle=\"X\", yTitle=\"Y\",\n",
    "    categories=\"label\",\n",
    "    title=\"T-SNE 2D demo\",\n",
    "    mode='markers',\n",
    "    )"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## cufflinksで3d scatter plot"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "[t-SNE] Computing 91 nearest neighbors...\n",
      "[t-SNE] Indexed 1797 samples in 0.007s...\n",
      "[t-SNE] Computed neighbors for 1797 samples in 0.516s...\n",
      "[t-SNE] Computed conditional probabilities for sample 1000 / 1797\n",
      "[t-SNE] Computed conditional probabilities for sample 1797 / 1797\n",
      "[t-SNE] Mean sigma: 8.132731\n",
      "[t-SNE] KL divergence after 250 iterations with early exaggeration: 61.700394\n",
      "[t-SNE] Error after 1000 iterations: 0.611338\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>X</th>\n",
       "      <th>Y</th>\n",
       "      <th>Z</th>\n",
       "      <th>label</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>2.644546</td>\n",
       "      <td>22.259514</td>\n",
       "      <td>-1.929261</td>\n",
       "      <td>0</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>-10.827566</td>\n",
       "      <td>-4.184731</td>\n",
       "      <td>8.216836</td>\n",
       "      <td>1</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>-0.487536</td>\n",
       "      <td>-3.023013</td>\n",
       "      <td>13.081998</td>\n",
       "      <td>2</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>7.301555</td>\n",
       "      <td>7.178536</td>\n",
       "      <td>3.457083</td>\n",
       "      <td>3</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>-17.475632</td>\n",
       "      <td>1.376311</td>\n",
       "      <td>-1.810267</td>\n",
       "      <td>4</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "           X          Y          Z  label\n",
       "0   2.644546  22.259514  -1.929261      0\n",
       "1 -10.827566  -4.184731   8.216836      1\n",
       "2  -0.487536  -3.023013  13.081998      2\n",
       "3   7.301555   7.178536   3.457083      3\n",
       "4 -17.475632   1.376311  -1.810267      4"
      ]
     },
     "execution_count": 45,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "X3 = TSNE(n_components=3,verbose=True).fit_transform(df.values)\n",
    "embed3d = pd.DataFrame(X3, columns=list(\"XYZ\"))\n",
    "embed3d[\"label\"] = df[\"label\"]\n",
    "embed3d.head()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "data": [
        {
         "marker": {
          "color": "rgba(255, 153, 51, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 0,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          2.644545555114746,
          0.03308841213583946,
          -1.1813353300094604,
          -1.8606873750686646,
          -2.511894702911377,
          2.9136877059936523,
          3.5985608100891113,
          -1.5059148073196411,
          -0.37507161498069763,
          4.730902194976807,
          2.3637795448303223,
          1.1334855556488037,
          -0.42548826336860657,
          2.0898375511169434,
          -1.010321021080017,
          1.603029727935791,
          -2.150287389755249,
          -0.4557243585586548,
          2.032132148742676,
          -1.231459379196167,
          -0.49044322967529297,
          0.8546522259712219,
          -2.2519729137420654,
          0.7782018780708313,
          1.742220163345337,
          0.5687474608421326,
          -0.3724197447299957,
          0.08703026920557022,
          0.9939014911651611,
          0.30537375807762146,
          1.386106014251709,
          3.045429229736328,
          2.337897777557373,
          1.720536470413208,
          0.9367567300796509,
          0.5722203850746155,
          0.6567646265029907,
          3.533115863800049,
          3.506016492843628,
          1.8850548267364502,
          1.2332979440689087,
          0.9685823917388916,
          -1.5980215072631836,
          1.1206222772598267,
          2.36203932762146,
          1.9457670450210571,
          4.745760917663574,
          -0.991393506526947,
          3.673412561416626,
          2.623690366744995,
          1.0392217636108398,
          2.0958778858184814,
          4.209120273590088,
          3.4068050384521484,
          4.317223072052002,
          4.270819187164307,
          4.827152729034424,
          4.510911464691162,
          3.6158556938171387,
          0.4231966733932495,
          1.9309958219528198,
          5.516477584838867,
          4.472803115844727,
          4.32534646987915,
          4.280980110168457,
          -1.4626933336257935,
          1.5180964469909668,
          -1.533578634262085,
          0.7174404859542847,
          1.2539626359939575,
          -1.4014054536819458,
          1.0087313652038574,
          -2.67923641204834,
          -1.7085020542144775,
          -2.0054633617401123,
          0.9860870242118835,
          0.4405594766139984,
          -1.444814920425415,
          2.799365997314453,
          2.7119829654693604,
          0.8627581000328064,
          2.139770746231079,
          1.5694608688354492,
          3.3068041801452637,
          -0.8770229816436768,
          -1.9512728452682495,
          -1.230717658996582,
          -2.504639148712158,
          3.5486538410186768,
          2.5957884788513184,
          1.6662949323654175,
          4.325659275054932,
          4.418684959411621,
          5.298583984375,
          4.668051242828369,
          3.9108848571777344,
          5.054770469665527,
          2.8771181106567383,
          5.471211910247803,
          4.353833198547363,
          5.344956398010254,
          2.310926675796509,
          2.2371435165405273,
          5.686141490936279,
          5.650480270385742,
          2.6145570278167725,
          5.221519947052002,
          5.321629524230957,
          2.7225825786590576,
          5.2155232429504395,
          2.6549668312072754,
          3.7892539501190186,
          2.4910104274749756,
          4.22224760055542,
          5.366903305053711,
          2.1096179485321045,
          0.5800105929374695,
          2.1149206161499023,
          -1.733886957168579,
          -1.939658761024475,
          -1.7320433855056763,
          2.4193434715270996,
          1.5785276889801025,
          1.7003239393234253,
          2.298651695251465,
          2.7283501625061035,
          1.3125557899475098,
          5.803750038146973,
          1.635360836982727,
          1.9851796627044678,
          3.82065486907959,
          -1.8325811624526978,
          0.23366659879684448,
          0.051943425089120865,
          -1.9094544649124146,
          0.8382778763771057,
          2.592280149459839,
          0.8770537376403809,
          1.4837019443511963,
          -1.1695820093154907,
          4.65665864944458,
          3.6780190467834473,
          2.7248988151550293,
          4.476814270019531,
          4.002392768859863,
          3.5420963764190674,
          3.755396842956543,
          3.8239705562591553,
          2.5800724029541016,
          3.697172164916992,
          3.752075672149658,
          4.631152153015137,
          3.320222854614258,
          -0.422157883644104,
          -0.03288615494966507,
          -0.646160900592804,
          -2.345409870147705,
          2.0882558822631836,
          -1.3978296518325806,
          1.9143792390823364,
          0.4781865179538727,
          -1.195197582244873,
          2.6881978511810303,
          -1.6869139671325684,
          0.7946316599845886,
          3.1751246452331543,
          2.446516275405884,
          0.9900432825088501,
          2.168485641479492,
          -1.6152288913726807,
          -0.27808400988578796,
          2.1292901039123535,
          -1.9773379564285278,
          -0.02765979990363121,
          -0.20242446660995483,
          1.0449535846710205,
          0.8490106463432312,
          -2.3051249980926514
         ],
         "y": [
          22.25951385498047,
          24.176992416381836,
          21.785917282104492,
          21.6221923828125,
          22.031354904174805,
          20.663576126098633,
          22.18168830871582,
          21.353479385375977,
          21.871112823486328,
          24.358537673950195,
          23.859846115112305,
          20.992475509643555,
          21.518888473510742,
          21.987396240234375,
          23.586763381958008,
          21.514801025390625,
          22.300647735595703,
          22.935653686523438,
          24.723316192626953,
          20.681760787963867,
          21.49909782409668,
          22.73981475830078,
          21.190357208251953,
          21.48859977722168,
          24.10454750061035,
          21.8496036529541,
          23.607816696166992,
          25.32268714904785,
          23.357746124267578,
          24.255584716796875,
          24.184267044067383,
          20.775020599365234,
          24.454856872558594,
          24.287187576293945,
          21.94518280029297,
          24.184837341308594,
          22.172443389892578,
          20.0750732421875,
          21.845598220825195,
          24.89164161682129,
          23.971771240234375,
          22.4375,
          23.668365478515625,
          25.217287063598633,
          23.314563751220703,
          22.065385818481445,
          22.657054901123047,
          23.456146240234375,
          22.182384490966797,
          23.060401916503906,
          23.75383186340332,
          23.382192611694336,
          20.340822219848633,
          25.105375289916992,
          20.695077896118164,
          20.183908462524414,
          24.429460525512695,
          19.90261459350586,
          25.93440055847168,
          22.893051147460938,
          18.496692657470703,
          21.518667221069336,
          19.791566848754883,
          20.480581283569336,
          20.689334869384766,
          22.081148147583008,
          21.466463088989258,
          21.804676055908203,
          21.767803192138672,
          23.625791549682617,
          20.070341110229492,
          20.803449630737305,
          20.794973373413086,
          20.401165008544922,
          23.063987731933594,
          21.795438766479492,
          20.691116333007812,
          19.941112518310547,
          24.755348205566406,
          25.666807174682617,
          24.604598999023438,
          24.19566535949707,
          23.756603240966797,
          19.10026741027832,
          23.789737701416016,
          21.877145767211914,
          21.742843627929688,
          21.219993591308594,
          22.576732635498047,
          22.581567764282227,
          19.438962936401367,
          24.7239933013916,
          24.304594039916992,
          21.37442398071289,
          23.674558639526367,
          22.952415466308594,
          24.00343894958496,
          24.740615844726562,
          23.664749145507812,
          22.893613815307617,
          24.750272750854492,
          21.62708282470703,
          22.75641632080078,
          21.91501808166504,
          22.938018798828125,
          21.511615753173828,
          21.74382781982422,
          21.788978576660156,
          25.998085021972656,
          22.07013702392578,
          26.15476417541504,
          25.966556549072266,
          20.82691764831543,
          24.581233978271484,
          21.26730728149414,
          21.776660919189453,
          21.088899612426758,
          21.731582641601562,
          21.903663635253906,
          21.668790817260742,
          21.8953914642334,
          21.437814712524414,
          22.28543472290039,
          21.59790802001953,
          21.597572326660156,
          18.64767837524414,
          21.58429718017578,
          21.842910766601562,
          19.146902084350586,
          20.296953201293945,
          25.649499893188477,
          19.78982162475586,
          20.811487197875977,
          20.94723129272461,
          21.729326248168945,
          22.05788230895996,
          22.012544631958008,
          19.963525772094727,
          19.995195388793945,
          19.612173080444336,
          23.733240127563477,
          23.25984001159668,
          25.124048233032227,
          22.88530158996582,
          22.77019691467285,
          22.925060272216797,
          22.934106826782227,
          25.677261352539062,
          25.210227966308594,
          25.552379608154297,
          22.844675064086914,
          22.99800682067871,
          22.506160736083984,
          21.126319885253906,
          20.274538040161133,
          22.1842041015625,
          19.122529983520508,
          20.39008140563965,
          19.44737434387207,
          19.90376853942871,
          19.80162239074707,
          19.639263153076172,
          25.570632934570312,
          20.693735122680664,
          22.424694061279297,
          23.716524124145508,
          22.889015197753906,
          24.479137420654297,
          22.615829467773438,
          21.601348876953125,
          25.2949275970459,
          23.41631317138672,
          24.186105728149414,
          25.37824249267578,
          25.199295043945312,
          24.524431228637695,
          19.998912811279297,
          22.526391983032227
         ],
         "z": [
          -1.9292606115341187,
          -2.5914926528930664,
          -7.3494720458984375,
          -1.5264109373092651,
          -5.996274948120117,
          -4.520977020263672,
          -7.276357650756836,
          -8.084244728088379,
          -8.63754940032959,
          -6.866645812988281,
          -6.43996000289917,
          -8.826441764831543,
          -8.426254272460938,
          -4.787093639373779,
          -7.119477272033691,
          -8.215618133544922,
          -5.33062744140625,
          -5.462334156036377,
          -5.656154632568359,
          -8.300060272216797,
          -8.51948070526123,
          -7.140420436859131,
          -7.507429599761963,
          -8.88784408569336,
          -6.395082950592041,
          -7.314884185791016,
          -2.2752878665924072,
          -6.363030433654785,
          -2.6778037548065186,
          -1.4142754077911377,
          -0.07165339589118958,
          -4.406280517578125,
          -3.131192445755005,
          -2.744267702102661,
          -3.5837018489837646,
          -2.901963233947754,
          -2.956057071685791,
          -6.68018102645874,
          -5.836273670196533,
          -7.788674354553223,
          -6.482784271240234,
          -7.1286540031433105,
          -6.458746433258057,
          -7.5867204666137695,
          -6.1115593910217285,
          -6.9685139656066895,
          -2.978332042694092,
          -5.420497894287109,
          -2.485715866088867,
          -8.05246353149414,
          -8.481369018554688,
          -3.8719968795776367,
          -2.1112051010131836,
          -2.4325995445251465,
          -1.1351313591003418,
          -1.7650721073150635,
          -3.7392656803131104,
          -3.830408811569214,
          -5.5082807540893555,
          -1.3451792001724243,
          -6.268732070922852,
          -2.3536977767944336,
          -1.544303297996521,
          -0.5138711333274841,
          -2.3502237796783447,
          -3.69229793548584,
          0.8639624118804932,
          -4.143296718597412,
          -2.817782163619995,
          -6.441438674926758,
          -5.060263633728027,
          -0.7109747529029846,
          -7.903613567352295,
          -5.312132358551025,
          -5.221382141113281,
          -4.023004531860352,
          -5.410628318786621,
          -4.939663410186768,
          -0.4147368371486664,
          -3.9236836433410645,
          -1.0299053192138672,
          -2.8502607345581055,
          -2.8419904708862305,
          -7.221343994140625,
          -2.8432812690734863,
          -2.6855814456939697,
          -6.314162254333496,
          -6.605260848999023,
          -3.306826591491699,
          -2.0118699073791504,
          -3.3604657649993896,
          -2.9239821434020996,
          -3.079122543334961,
          -3.961977005004883,
          -2.0969815254211426,
          -3.240055561065674,
          -2.3188059329986572,
          -0.383673757314682,
          -5.168666839599609,
          -2.1128933429718018,
          -2.187486410140991,
          -1.956154227256775,
          -5.977368354797363,
          -6.496505260467529,
          -3.9816174507141113,
          -6.943090915679932,
          -7.944777011871338,
          -7.9180402755737305,
          -4.915209770202637,
          -3.28794264793396,
          -5.013430118560791,
          -5.341499328613281,
          -2.1093246936798096,
          -4.396109104156494,
          -3.9975194931030273,
          -1.1679614782333374,
          -2.4302878379821777,
          0.5975602269172668,
          0.36931952834129333,
          -0.5692277550697327,
          0.3466615378856659,
          0.3113330006599426,
          0.7957611680030823,
          0.808590829372406,
          0.27480655908584595,
          -6.838045597076416,
          1.193999171257019,
          -6.516894340515137,
          -5.765609264373779,
          -5.828574180603027,
          -6.548303127288818,
          -7.029991149902344,
          -5.196873664855957,
          -5.553402423858643,
          -2.086463212966919,
          -1.6483289003372192,
          -1.6013069152832031,
          -4.954973220825195,
          -5.918783664703369,
          -6.90612268447876,
          -2.9889705181121826,
          -6.657566070556641,
          -2.3090152740478516,
          -5.89799165725708,
          -5.582448482513428,
          -4.600179195404053,
          -4.76690673828125,
          -6.36293363571167,
          -6.8597259521484375,
          -6.7194108963012695,
          -4.220125198364258,
          -5.670261383056641,
          -3.0905652046203613,
          -6.059903144836426,
          -6.688298225402832,
          -6.0354156494140625,
          -7.725232124328613,
          -5.200483322143555,
          -8.041502952575684,
          -2.2775235176086426,
          -7.597530841827393,
          -8.215959548950195,
          -4.137556552886963,
          -6.633802890777588,
          -1.6257325410842896,
          -6.5853776931762695,
          -6.886780738830566,
          -8.423072814941406,
          -2.477160930633545,
          -4.975984573364258,
          -6.818063735961914,
          -1.520279049873352,
          -6.5103912353515625,
          -6.389538764953613,
          -4.749855041503906,
          -8.234357833862305,
          -7.900266170501709,
          -5.110470294952393
         ]
        },
        {
         "marker": {
          "color": "rgba(55, 128, 191, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 1,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          -10.827566146850586,
          -11.909122467041016,
          -11.305717468261719,
          -12.903533935546875,
          -12.534194946289062,
          -12.346872329711914,
          -12.307214736938477,
          -11.602080345153809,
          -12.780597686767578,
          -12.966633796691895,
          -10.946525573730469,
          -9.92597770690918,
          -12.905599594116211,
          -12.122573852539062,
          -12.58407211303711,
          -12.6441068649292,
          -11.21564769744873,
          -12.181347846984863,
          -11.21117877960205,
          -13.072080612182617,
          -11.5850248336792,
          -13.467394828796387,
          -12.65672492980957,
          -10.465242385864258,
          -11.917826652526855,
          -10.545066833496094,
          -8.642694473266602,
          -8.828369140625,
          -8.061355590820312,
          -8.110196113586426,
          -6.3602752685546875,
          -13.368795394897461,
          -9.113539695739746,
          -8.548568725585938,
          -8.671355247497559,
          -8.389947891235352,
          -9.568779945373535,
          -9.377766609191895,
          -8.490273475646973,
          -11.696104049682617,
          -10.55137825012207,
          -10.265970230102539,
          -11.469453811645508,
          -10.639190673828125,
          13.748291015625,
          -11.224167823791504,
          -11.033990859985352,
          -10.97247314453125,
          -12.228050231933594,
          -10.267788887023926,
          -10.454047203063965,
          -10.768467903137207,
          14.184226036071777,
          13.449821472167969,
          13.321700096130371,
          13.736357688903809,
          13.599352836608887,
          13.52845573425293,
          14.046616554260254,
          13.2211332321167,
          14.026569366455078,
          12.928370475769043,
          14.04179573059082,
          -5.733801364898682,
          14.552776336669922,
          -7.7613043785095215,
          -7.555898189544678,
          -7.907632827758789,
          -6.491315841674805,
          -6.5335469245910645,
          -7.583098888397217,
          -8.04887866973877,
          -7.495293617248535,
          -8.429256439208984,
          -8.08998966217041,
          -7.456004619598389,
          -8.086626052856445,
          -7.810412406921387,
          -9.89983081817627,
          -8.758214950561523,
          -8.125533103942871,
          -5.3304057121276855,
          -7.033037185668945,
          13.371352195739746,
          -6.0597100257873535,
          -8.248050689697266,
          -8.526755332946777,
          -9.926668167114258,
          -9.042177200317383,
          -8.971946716308594,
          -6.662446975708008,
          13.455527305603027,
          13.466410636901855,
          13.645353317260742,
          14.593564987182617,
          14.332561492919922,
          14.1117525100708,
          14.475223541259766,
          14.308937072753906,
          13.568138122558594,
          14.08556079864502,
          14.274847030639648,
          14.383922576904297,
          14.061666488647461,
          -5.201333522796631,
          -6.280808925628662,
          -9.439273834228516,
          -6.279049873352051,
          -9.390647888183594,
          -8.876214027404785,
          -9.733814239501953,
          -9.206414222717285,
          -9.05965518951416,
          -6.038912296295166,
          -8.249279975891113,
          -10.405864715576172,
          -9.388751029968262,
          -12.059313774108887,
          -12.192066192626953,
          -12.509997367858887,
          -7.131499290466309,
          -12.396586418151855,
          -11.217509269714355,
          -9.362257957458496,
          -9.504068374633789,
          -12.60523509979248,
          -9.6105318069458,
          -9.48205280303955,
          -10.11495590209961,
          -12.875414848327637,
          -11.982316017150879,
          -12.412790298461914,
          -12.810571670532227,
          -11.118916511535645,
          -10.345826148986816,
          -12.061213493347168,
          -9.436575889587402,
          -12.481501579284668,
          -9.037550926208496,
          -10.490727424621582,
          -9.76076889038086,
          -10.477005958557129,
          -11.202588081359863,
          -11.761089324951172,
          -12.092497825622559,
          -11.925593376159668,
          -12.115891456604004,
          -12.305166244506836,
          -12.075262069702148,
          -12.00821590423584,
          -12.035648345947266,
          -11.831503868103027,
          -11.938721656799316,
          -12.271206855773926,
          -12.29833698272705,
          -11.787409782409668,
          -11.179159164428711,
          -10.026984214782715,
          -9.932075500488281,
          -10.646199226379395,
          -11.141708374023438,
          -10.465107917785645,
          -10.321433067321777,
          -11.154510498046875,
          -11.596464157104492,
          -10.807507514953613,
          -10.313669204711914,
          -10.350810050964355,
          -10.559351921081543,
          -6.169316291809082,
          -6.757174491882324,
          -7.51202917098999,
          -5.885586261749268,
          -7.409930229187012,
          -7.318585395812988,
          -6.175550937652588,
          -5.042765140533447,
          -6.081454753875732,
          -6.386892795562744,
          -7.114294528961182,
          -5.375392913818359,
          -5.376293659210205
         ],
         "y": [
          -4.184731483459473,
          -2.4871349334716797,
          -1.2325547933578491,
          -2.1476402282714844,
          -1.8157031536102295,
          -1.4614334106445312,
          -1.9841479063034058,
          -2.1650314331054688,
          -3.050720453262329,
          -2.2791333198547363,
          -4.110365867614746,
          -9.39643383026123,
          -1.392618179321289,
          1.1305358409881592,
          -0.9726213812828064,
          -0.17304782569408417,
          -0.32710108160972595,
          0.09231075644493103,
          -0.4894208312034607,
          -2.16263747215271,
          -0.4459267258644104,
          -2.432382822036743,
          -0.2299826443195343,
          -1.6553964614868164,
          -2.5007309913635254,
          -1.5809317827224731,
          -7.073297500610352,
          -4.885290622711182,
          -5.839223861694336,
          -10.00139331817627,
          -7.683035850524902,
          -2.3967082500457764,
          -7.9815826416015625,
          -5.345093250274658,
          -5.045544624328613,
          -6.247196197509766,
          -8.054810523986816,
          -5.468915939331055,
          -10.607678413391113,
          1.3126368522644043,
          -1.141910433769226,
          -0.9937639832496643,
          -0.542533814907074,
          -1.1897557973861694,
          -7.880704402923584,
          -0.8732361793518066,
          -1.9332401752471924,
          -2.4349889755249023,
          -1.7345863580703735,
          -1.0912736654281616,
          -1.0579053163528442,
          -0.484576016664505,
          -6.895153045654297,
          -8.009840965270996,
          -8.227214813232422,
          -8.68260383605957,
          -8.212570190429688,
          -8.927892684936523,
          -8.160848617553711,
          -8.421318054199219,
          -7.9686479568481445,
          -8.638541221618652,
          -7.059431552886963,
          -9.756778717041016,
          -6.010536193847656,
          -7.676952838897705,
          -10.099018096923828,
          -10.199301719665527,
          -7.34100866317749,
          -7.444638252258301,
          -5.362453460693359,
          -8.926629066467285,
          -5.168266773223877,
          -9.932950973510742,
          -10.37427043914795,
          -9.049175262451172,
          -8.81424617767334,
          -7.797077178955078,
          -6.1078200340271,
          -5.4367499351501465,
          -5.661554336547852,
          -8.863814353942871,
          -8.28874683380127,
          -9.261943817138672,
          -5.922898769378662,
          -10.776016235351562,
          -7.259383201599121,
          -7.530503273010254,
          -8.283665657043457,
          -6.501480579376221,
          -5.504086494445801,
          -9.049112319946289,
          -9.023128509521484,
          -9.501691818237305,
          -5.871133804321289,
          -7.112838268280029,
          -7.6776957511901855,
          -6.25387716293335,
          -7.196028709411621,
          -9.026862144470215,
          -7.366619110107422,
          -6.336265563964844,
          -6.194252014160156,
          -8.06201457977295,
          -7.754131317138672,
          -7.841803073883057,
          -7.307444095611572,
          -7.381941795349121,
          -8.246374130249023,
          -9.600674629211426,
          -7.136697292327881,
          -9.462654113769531,
          -6.87540864944458,
          -6.4388203620910645,
          -6.538257122039795,
          -8.626861572265625,
          -8.777498245239258,
          -2.6072120666503906,
          -1.964064598083496,
          -5.94359016418457,
          -6.755452632904053,
          -4.296993255615234,
          -6.747904300689697,
          -9.097959518432617,
          -6.48012113571167,
          -5.014648914337158,
          -8.38864803314209,
          -8.58858871459961,
          -9.645350456237793,
          -6.946598052978516,
          2.0794358253479004,
          -4.91234016418457,
          0.26123300194740295,
          -7.2413482666015625,
          -6.432297706604004,
          -0.2945283055305481,
          -6.155461311340332,
          -1.8480299711227417,
          -5.860062122344971,
          -5.664259910583496,
          -7.528328895568848,
          -8.121729850769043,
          -8.029393196105957,
          1.6566225290298462,
          1.9948441982269287,
          0.3173580467700958,
          1.4295073747634888,
          1.8614689111709595,
          2.4313676357269287,
          2.4290924072265625,
          2.7162318229675293,
          1.9640926122665405,
          0.3128484785556793,
          1.9365031719207764,
          2.18473744392395,
          2.512389898300171,
          -6.01318359375,
          -10.137521743774414,
          -10.335636138916016,
          -6.179143905639648,
          -7.466185092926025,
          -10.316793441772461,
          -8.169886589050293,
          -7.461458206176758,
          -6.59722375869751,
          -6.503052234649658,
          -6.528499603271484,
          -5.9073686599731445,
          -5.99923849105835,
          -10.520843505859375,
          -8.517810821533203,
          -10.356085777282715,
          -10.008685111999512,
          -7.984958648681641,
          -9.725578308105469,
          -7.501064300537109,
          -8.587014198303223,
          -5.457345485687256,
          -6.555988311767578,
          -9.570831298828125,
          -8.484935760498047,
          -8.185859680175781
         ],
         "z": [
          8.216835975646973,
          2.7501862049102783,
          4.3673272132873535,
          4.214907646179199,
          5.6060872077941895,
          5.090933799743652,
          6.377938270568848,
          4.992412090301514,
          5.092120170593262,
          4.167708873748779,
          8.081120491027832,
          9.250310897827148,
          2.88070011138916,
          2.766906976699829,
          2.6548357009887695,
          2.190154552459717,
          3.078521728515625,
          2.3211910724639893,
          3.8932430744171143,
          2.7041075229644775,
          3.1095476150512695,
          2.0486624240875244,
          2.0879619121551514,
          3.5159075260162354,
          2.7265326976776123,
          3.1176061630249023,
          7.632228374481201,
          5.751526355743408,
          6.026551723480225,
          8.731374740600586,
          9.8975830078125,
          2.1702075004577637,
          8.458090782165527,
          6.318399906158447,
          5.926570892333984,
          8.228814125061035,
          10.680869102478027,
          10.50156021118164,
          7.218724727630615,
          4.657943248748779,
          6.664333820343018,
          4.459747791290283,
          4.735278606414795,
          6.613256931304932,
          10.158440589904785,
          4.646866321563721,
          6.646491527557373,
          6.835513591766357,
          4.510189056396484,
          5.362056732177734,
          5.9895195960998535,
          4.694235324859619,
          8.737723350524902,
          9.7448148727417,
          8.7872314453125,
          8.98465347290039,
          7.641672134399414,
          9.084696769714355,
          7.855481147766113,
          8.078290939331055,
          7.9857025146484375,
          7.988214015960693,
          8.327959060668945,
          8.534163475036621,
          8.3378324508667,
          6.81044864654541,
          8.369301795959473,
          8.09942626953125,
          5.724946975708008,
          5.778990268707275,
          9.798503875732422,
          6.0823140144348145,
          9.703640937805176,
          5.890573501586914,
          6.461719036102295,
          6.5609588623046875,
          5.788365840911865,
          6.047486305236816,
          10.191986083984375,
          11.38203239440918,
          9.675158500671387,
          7.799160480499268,
          7.817317008972168,
          10.409672737121582,
          8.514512062072754,
          8.573502540588379,
          7.318488597869873,
          8.173089027404785,
          9.291983604431152,
          9.2286376953125,
          8.488640785217285,
          10.0855131149292,
          10.349488258361816,
          10.143784523010254,
          8.707046508789062,
          9.855874061584473,
          9.96664810180664,
          8.926997184753418,
          9.748351097106934,
          10.037096977233887,
          9.551153182983398,
          9.160361289978027,
          9.241886138916016,
          9.95088005065918,
          8.408488273620605,
          9.13671588897705,
          10.126965522766113,
          7.458561420440674,
          9.361599922180176,
          6.384341239929199,
          10.346393585205078,
          8.590277671813965,
          10.623109817504883,
          7.689265251159668,
          8.72296142578125,
          7.713599681854248,
          8.993642807006836,
          6.146723747253418,
          5.8919997215271,
          7.051689147949219,
          8.716550827026367,
          6.856541156768799,
          10.67857837677002,
          8.253110885620117,
          9.943920135498047,
          7.13579797744751,
          8.316609382629395,
          8.161541938781738,
          6.802364349365234,
          7.044095516204834,
          5.898270606994629,
          7.011117935180664,
          1.9829432964324951,
          10.381963729858398,
          10.288970947265625,
          5.300385475158691,
          9.435563087463379,
          6.184915065765381,
          11.714577674865723,
          10.75485610961914,
          11.183302879333496,
          9.229645729064941,
          9.285008430480957,
          5.573055744171143,
          4.694080829620361,
          4.574207782745361,
          3.164231061935425,
          3.1227669715881348,
          4.423942565917969,
          4.364450931549072,
          3.8934097290039062,
          5.6128363609313965,
          4.496248722076416,
          3.8342273235321045,
          3.269373893737793,
          4.78983736038208,
          9.356736183166504,
          8.247152328491211,
          7.652048587799072,
          11.502643585205078,
          9.32398796081543,
          8.241077423095703,
          10.171581268310547,
          9.918570518493652,
          11.125935554504395,
          11.590723037719727,
          10.259759902954102,
          11.29261589050293,
          11.539640426635742,
          8.344965934753418,
          6.524571895599365,
          8.9097900390625,
          8.444796562194824,
          7.5806121826171875,
          9.49682331085205,
          7.330178260803223,
          7.740687370300293,
          9.858963966369629,
          7.905205249786377,
          8.362271308898926,
          7.842913627624512,
          8.095987319946289
         ]
        },
        {
         "marker": {
          "color": "rgba(50, 171, 96, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 2,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          -0.48753610253334045,
          9.342896461486816,
          5.920720100402832,
          0.5340273976325989,
          -0.5768459439277649,
          -0.7002596259117126,
          -0.5440384745597839,
          -0.9355037212371826,
          -1.2001891136169434,
          6.799711227416992,
          3.9255945682525635,
          0.16667887568473816,
          0.7469857931137085,
          5.529292106628418,
          3.986828565597534,
          4.822013854980469,
          5.723148822784424,
          4.32041072845459,
          7.230229377746582,
          7.1137166023254395,
          4.877756118774414,
          5.217931270599365,
          5.3250603675842285,
          7.316779613494873,
          7.031344890594482,
          5.750073432922363,
          4.680910110473633,
          5.216151714324951,
          3.757751226425171,
          4.423910140991211,
          3.8926637172698975,
          4.9139909744262695,
          5.351200580596924,
          4.839890003204346,
          3.708493232727051,
          3.5841658115386963,
          3.887220621109009,
          3.5433969497680664,
          5.996980667114258,
          8.694512367248535,
          9.467896461486816,
          9.694934844970703,
          9.705801963806152,
          8.073246002197266,
          8.239194869995117,
          9.094963073730469,
          9.817119598388672,
          8.207430839538574,
          9.057477951049805,
          8.153432846069336,
          9.265279769897461,
          0.15686911344528198,
          7.65172004699707,
          8.604114532470703,
          8.567939758300781,
          7.435904026031494,
          7.733501434326172,
          7.031217098236084,
          7.736171722412109,
          7.789455890655518,
          5.0481767654418945,
          7.415810585021973,
          8.219293594360352,
          5.537779331207275,
          7.69680118560791,
          3.898101329803467,
          4.767670154571533,
          4.634403705596924,
          4.423253536224365,
          4.506598472595215,
          4.1608381271362305,
          4.2346930503845215,
          4.432117938995361,
          5.3253397941589355,
          3.8891544342041016,
          3.622177839279175,
          3.5049526691436768,
          3.617863893508911,
          5.152515411376953,
          6.2199482917785645,
          4.433529376983643,
          4.910932540893555,
          6.647972106933594,
          4.0372209548950195,
          8.423776626586914,
          4.900318622589111,
          6.2963385581970215,
          3.87650465965271,
          5.444586277008057,
          6.146601676940918,
          3.5618555545806885,
          5.618246078491211,
          8.52247428894043,
          6.403207302093506,
          7.13467264175415,
          8.3141508102417,
          7.992909908294678,
          7.501036167144775,
          8.16124439239502,
          7.73394250869751,
          7.5649919509887695,
          8.314526557922363,
          8.750493049621582,
          6.662895202636719,
          4.70881986618042,
          7.691251754760742,
          6.414530277252197,
          7.114837169647217,
          9.045122146606445,
          6.253516674041748,
          7.746669292449951,
          8.563700675964355,
          4.781879425048828,
          7.731500625610352,
          5.756507873535156,
          5.703646659851074,
          4.316622734069824,
          5.1402692794799805,
          4.35775089263916,
          4.095414161682129,
          4.84674596786499,
          3.6314966678619385,
          4.012618541717529,
          2.91635799407959,
          3.9765655994415283,
          3.0923633575439453,
          3.3960349559783936,
          5.993826866149902,
          8.586572647094727,
          6.5414557456970215,
          6.275485038757324,
          6.807520866394043,
          8.053889274597168,
          6.635629177093506,
          7.6771063804626465,
          7.806852340698242,
          7.460266590118408,
          6.594245910644531,
          7.470962047576904,
          6.935745716094971,
          8.406828880310059,
          8.82966423034668,
          8.207500457763672,
          8.038198471069336,
          9.145187377929688,
          8.740948677062988,
          8.919992446899414,
          8.561885833740234,
          8.675537109375,
          7.977952480316162,
          7.792421340942383,
          5.957779884338379,
          8.891460418701172,
          5.806069850921631,
          8.3233003616333,
          9.204745292663574,
          7.910576820373535,
          6.815467834472656,
          8.151593208312988,
          3.9385364055633545,
          8.311202049255371,
          5.760833740234375,
          7.505275726318359,
          5.864363193511963,
          7.884149074554443,
          3.3405802249908447,
          6.41190242767334,
          8.122574806213379,
          7.9350104331970215,
          7.9210286140441895,
          9.411046981811523,
          7.395853042602539,
          5.109996318817139,
          6.391575336456299,
          7.969184875488281,
          9.345258712768555,
          9.788956642150879
         ],
         "y": [
          -3.0230133533477783,
          -5.803776741027832,
          -6.646180152893066,
          -3.1597909927368164,
          -2.4828293323516846,
          -2.3433947563171387,
          -2.937822103500366,
          -2.322186231613159,
          -2.0848731994628906,
          -10.913689613342285,
          -5.759332180023193,
          -2.8852438926696777,
          -3.2230634689331055,
          -10.925117492675781,
          -10.654276847839355,
          -4.499629974365234,
          -9.665587425231934,
          -10.208765983581543,
          -12.334656715393066,
          -9.960440635681152,
          -4.40047550201416,
          -9.822434425354004,
          -10.631241798400879,
          -12.643016815185547,
          -12.849943161010742,
          -9.801929473876953,
          -8.601359367370605,
          -8.804906845092773,
          -9.417587280273438,
          -11.217595100402832,
          -9.524253845214844,
          -8.21703815460205,
          -9.665761947631836,
          -8.435726165771484,
          -10.551716804504395,
          -9.431286811828613,
          -8.66014289855957,
          -10.642617225646973,
          -9.334747314453125,
          -6.32099723815918,
          -4.810490608215332,
          -7.83773946762085,
          -5.001193046569824,
          -6.41934061050415,
          -5.7355427742004395,
          -4.429324150085449,
          -6.187462329864502,
          -8.819232940673828,
          -9.93310260772705,
          -9.424782752990723,
          -8.798408508300781,
          -3.622349500656128,
          -2.381507396697998,
          -4.265542030334473,
          -4.096609592437744,
          -5.662094593048096,
          -5.7116475105285645,
          -5.160619735717773,
          -5.732185363769531,
          -3.613231658935547,
          -8.773444175720215,
          -10.995110511779785,
          -5.2571892738342285,
          -7.393367767333984,
          -5.844871997833252,
          -8.741111755371094,
          -8.377230644226074,
          -7.686216831207275,
          -5.049793720245361,
          -6.750277042388916,
          -4.617552280426025,
          -4.545808792114258,
          -5.7304534912109375,
          -8.945582389831543,
          -12.144099235534668,
          -7.702841758728027,
          -7.377834796905518,
          -8.397455215454102,
          -10.821002006530762,
          -9.754030227661133,
          -11.981307029724121,
          -9.837611198425293,
          -12.935803413391113,
          -11.673752784729004,
          -9.783019065856934,
          -12.61043930053711,
          -12.631281852722168,
          -4.458306312561035,
          -12.721665382385254,
          0.27218011021614075,
          -8.374934196472168,
          -7.964495658874512,
          -11.519248008728027,
          -7.309785842895508,
          -7.067631244659424,
          -3.929759979248047,
          -5.6713409423828125,
          -4.083427906036377,
          -4.278022289276123,
          -8.33504581451416,
          -5.783756256103516,
          -3.567812204360962,
          -7.635630130767822,
          -10.07242202758789,
          -5.443800449371338,
          -3.6675033569335938,
          -3.2658684253692627,
          -4.048700332641602,
          -4.525984764099121,
          -1.7722610235214233,
          -6.292186737060547,
          -7.659564971923828,
          -5.395066738128662,
          -2.6741631031036377,
          -10.629714012145996,
          -7.236163139343262,
          -7.150862693786621,
          -5.637694358825684,
          -7.994674205780029,
          -10.809659004211426,
          -7.881167888641357,
          -7.5290985107421875,
          -4.649866580963135,
          -8.49604606628418,
          -12.201005935668945,
          -10.050792694091797,
          -7.584517478942871,
          -2.929123878479004,
          -2.2800185680389404,
          -2.474308729171753,
          -1.5423648357391357,
          -1.0183888673782349,
          -1.2073591947555542,
          -1.5771859884262085,
          -5.140833854675293,
          -0.6957600116729736,
          -4.486873626708984,
          -1.7786870002746582,
          -3.7313809394836426,
          -2.786655902862549,
          -9.760163307189941,
          -10.548978805541992,
          -9.179364204406738,
          -7.044344425201416,
          -8.926294326782227,
          -8.329384803771973,
          -8.691298484802246,
          -8.864411354064941,
          -8.303722381591797,
          -12.114180564880371,
          -7.721554756164551,
          -4.98110818862915,
          -8.64352035522461,
          -6.423591136932373,
          -1.6374300718307495,
          -3.9323582649230957,
          -0.37985745072364807,
          -7.0665154457092285,
          -0.7088648676872253,
          -9.083423614501953,
          -1.4760186672210693,
          -11.0220947265625,
          -10.075287818908691,
          -2.2343106269836426,
          -7.846498489379883,
          -8.48452377319336,
          -6.319341659545898,
          -12.068151473999023,
          -9.43150520324707,
          -11.897432327270508,
          -10.565208435058594,
          -6.623371124267578,
          -7.179174423217773,
          -6.3657546043396,
          -7.063424587249756,
          -8.10330581665039,
          -9.568429946899414
         ],
         "z": [
          13.081997871398926,
          17.51533317565918,
          18.596454620361328,
          13.791665077209473,
          13.713499069213867,
          13.735552787780762,
          13.188928604125977,
          13.747230529785156,
          13.861645698547363,
          16.760478973388672,
          18.320281982421875,
          13.790016174316406,
          13.892999649047852,
          15.14416790008545,
          14.642023086547852,
          14.828497886657715,
          13.069965362548828,
          14.518391609191895,
          15.796555519104004,
          13.34091567993164,
          14.447178840637207,
          13.82674789428711,
          14.688305854797363,
          15.640652656555176,
          15.57707691192627,
          12.844115257263184,
          17.645322799682617,
          17.311370849609375,
          17.022335052490234,
          16.90280532836914,
          15.13888168334961,
          16.972387313842773,
          17.183530807495117,
          16.26658821105957,
          16.72413444519043,
          15.8154296875,
          17.357946395874023,
          16.77614974975586,
          16.36362648010254,
          17.501197814941406,
          16.020191192626953,
          15.97821044921875,
          16.13930320739746,
          16.169240951538086,
          15.869599342346191,
          15.641743659973145,
          16.66248893737793,
          16.934467315673828,
          15.34618091583252,
          16.991321563720703,
          15.883705139160156,
          13.316110610961914,
          17.7568416595459,
          20.307512283325195,
          20.145545959472656,
          20.058753967285156,
          20.26122283935547,
          18.78605079650879,
          20.243473052978516,
          18.713232040405273,
          18.18583869934082,
          17.398962020874023,
          20.28758430480957,
          16.70880126953125,
          20.274187088012695,
          12.751047134399414,
          12.493386268615723,
          13.942596435546875,
          13.551274299621582,
          12.844311714172363,
          13.112722396850586,
          13.255538940429688,
          13.262901306152344,
          12.45284366607666,
          16.100120544433594,
          13.377217292785645,
          13.290375709533691,
          13.283239364624023,
          16.07564926147461,
          16.11756706237793,
          15.928165435791016,
          14.240092277526855,
          15.66114330291748,
          15.80513858795166,
          14.681000709533691,
          15.930338859558105,
          15.808135986328125,
          15.521710395812988,
          15.868448257446289,
          11.63801383972168,
          14.098136901855469,
          17.899112701416016,
          15.141097068786621,
          16.995393753051758,
          16.77592658996582,
          17.32029914855957,
          17.72783660888672,
          17.111154556274414,
          17.54372787475586,
          16.838876724243164,
          18.22320556640625,
          17.309938430786133,
          15.286474227905273,
          16.86497688293457,
          18.250228881835938,
          18.383949279785156,
          16.916053771972656,
          17.39310073852539,
          15.742141723632812,
          16.9420108795166,
          17.099515914916992,
          15.62519645690918,
          18.2977237701416,
          17.53416633605957,
          16.247251510620117,
          17.80048370361328,
          14.291086196899414,
          15.56667423248291,
          13.704442977905273,
          16.24686622619629,
          16.001611709594727,
          16.74109649658203,
          15.663398742675781,
          16.564952850341797,
          15.936542510986328,
          16.635059356689453,
          16.475513458251953,
          16.433868408203125,
          17.11330795288086,
          16.461660385131836,
          16.778902053833008,
          16.77367401123047,
          16.241485595703125,
          17.12515640258789,
          15.777256965637207,
          16.015546798706055,
          18.034263610839844,
          18.06739616394043,
          16.962717056274414,
          18.064319610595703,
          15.515357971191406,
          14.693791389465332,
          15.360334396362305,
          14.390057563781738,
          15.797721862792969,
          14.361010551452637,
          14.016501426696777,
          15.077579498291016,
          14.502897262573242,
          15.384842872619629,
          15.152931213378906,
          15.771039009094238,
          13.969176292419434,
          18.720535278320312,
          15.410653114318848,
          15.289288520812988,
          15.845248222351074,
          16.941831588745117,
          16.190046310424805,
          13.140289306640625,
          15.54455852508545,
          16.026193618774414,
          13.234776496887207,
          16.65988540649414,
          16.649322509765625,
          13.149500846862793,
          13.453786849975586,
          15.504497528076172,
          15.244528770446777,
          15.473670959472656,
          14.488847732543945,
          13.305045127868652,
          13.7070951461792,
          13.470211029052734,
          14.186084747314453,
          15.330533981323242,
          14.464659690856934
         ]
        },
        {
         "marker": {
          "color": "rgba(128, 0, 128, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 3,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          7.3015546798706055,
          7.413646697998047,
          7.079817771911621,
          9.41799545288086,
          7.8926496505737305,
          9.116058349609375,
          8.641244888305664,
          8.530816078186035,
          8.805084228515625,
          8.285299301147461,
          8.461874008178711,
          8.587034225463867,
          7.770370960235596,
          9.038240432739258,
          8.48620319366455,
          8.037731170654297,
          8.393963813781738,
          8.388808250427246,
          9.901891708374023,
          7.614129543304443,
          9.537302017211914,
          8.875494956970215,
          9.280976295471191,
          9.145796775817871,
          8.079692840576172,
          6.743386268615723,
          6.792569637298584,
          4.669057369232178,
          8.504585266113281,
          4.764706134796143,
          6.141941070556641,
          5.10050630569458,
          5.931851863861084,
          5.940941333770752,
          4.908916473388672,
          6.9559197425842285,
          6.850910663604736,
          6.987812519073486,
          8.250082969665527,
          8.474345207214355,
          5.894638538360596,
          5.125760555267334,
          7.765382289886475,
          4.940516948699951,
          4.465898513793945,
          4.691445827484131,
          4.6430559158325195,
          5.0326762199401855,
          5.137178897857666,
          5.465907096862793,
          6.051137447357178,
          6.333110332489014,
          4.809304237365723,
          0.39993351697921753,
          1.2319936752319336,
          0.5986347198486328,
          1.0111987590789795,
          0.36060038208961487,
          3.6950836181640625,
          -0.16849970817565918,
          0.6116019487380981,
          0.3035270571708679,
          0.6335434317588806,
          0.5618917942047119,
          1.2769150733947754,
          1.2266126871109009,
          4.06983757019043,
          3.6076669692993164,
          4.2194671630859375,
          4.097118377685547,
          4.791540622711182,
          4.271080017089844,
          4.794374942779541,
          5.963459014892578,
          4.087339401245117,
          4.07149076461792,
          6.898747444152832,
          6.849942207336426,
          4.766132831573486,
          6.862674713134766,
          7.272140026092529,
          8.185503959655762,
          9.24951171875,
          9.148548126220703,
          9.293006896972656,
          6.025407791137695,
          6.079094409942627,
          8.214132308959961,
          7.250162601470947,
          7.561081886291504,
          8.512157440185547,
          6.155101299285889,
          8.579785346984863,
          8.379480361938477,
          6.8668694496154785,
          7.507997035980225,
          8.296615600585938,
          8.5652494430542,
          8.624847412109375,
          7.207060813903809,
          8.692774772644043,
          8.642618179321289,
          7.997570991516113,
          9.040600776672363,
          7.261545658111572,
          8.35949993133545,
          8.171317100524902,
          7.158025741577148,
          6.129117965698242,
          6.211386680603027,
          6.556643009185791,
          5.0654296875,
          6.274228572845459,
          8.180363655090332,
          8.325225830078125,
          -5.2500319480896,
          7.966953277587891,
          6.513846397399902,
          5.712750434875488,
          6.547682285308838,
          7.8892011642456055,
          8.602629661560059,
          7.78570556640625,
          8.567706108093262,
          6.688238143920898,
          7.206857681274414,
          7.922371864318848,
          7.3681960105896,
          6.358635902404785,
          8.350835800170898,
          7.963878631591797,
          7.552842140197754,
          6.7603678703308105,
          6.8904852867126465,
          6.523571491241455,
          6.321026802062988,
          5.064694881439209,
          4.876662731170654,
          4.969051361083984,
          6.914379596710205,
          7.962066173553467,
          7.3277587890625,
          4.4863080978393555,
          6.349786281585693,
          6.1473188400268555,
          5.964600563049316,
          6.856779098510742,
          8.907320022583008,
          6.164173126220703,
          8.19694995880127,
          6.458999156951904,
          7.515409469604492,
          7.7584547996521,
          6.4070963859558105,
          9.258638381958008,
          8.656461715698242,
          7.742297172546387,
          6.472586631774902,
          4.975527286529541,
          7.792771339416504,
          7.679525375366211,
          7.563621997833252,
          7.779302597045898,
          8.53715705871582,
          7.360236644744873,
          7.252785682678223,
          6.83721923828125,
          6.148585796356201,
          6.5689167976379395,
          7.037393569946289,
          6.081777572631836,
          8.328965187072754,
          6.31028938293457,
          8.779223442077637,
          8.926855087280273,
          9.299132347106934,
          5.537827968597412,
          8.805577278137207,
          8.64305591583252,
          8.154556274414062,
          5.01324462890625,
          6.297050476074219,
          7.359136581420898
         ],
         "y": [
          7.1785359382629395,
          3.864008903503418,
          1.3133739233016968,
          4.630995273590088,
          2.2634544372558594,
          4.30478572845459,
          3.6939890384674072,
          2.092458724975586,
          2.133413553237915,
          3.210071086883545,
          1.2485584020614624,
          1.7851381301879883,
          -2.5580968856811523,
          0.987450897693634,
          3.796293258666992,
          1.3320999145507812,
          2.302276134490967,
          3.970040798187256,
          2.8655712604522705,
          1.9913325309753418,
          3.089046001434326,
          2.1676244735717773,
          2.236450433731079,
          2.5259580612182617,
          1.719977855682373,
          0.9696843028068542,
          7.097827911376953,
          5.292856693267822,
          7.434632778167725,
          5.4091691970825195,
          5.008094787597656,
          4.865855693817139,
          5.672499656677246,
          5.553225040435791,
          5.394509315490723,
          4.7270660400390625,
          5.058369159698486,
          4.693751811981201,
          7.745229244232178,
          3.719390630722046,
          4.623905181884766,
          8.57890510559082,
          11.08814525604248,
          8.135305404663086,
          8.077716827392578,
          7.736551284790039,
          8.153565406799316,
          7.9978485107421875,
          7.953851699829102,
          7.974357604980469,
          7.091980934143066,
          7.3569746017456055,
          8.862397193908691,
          6.97905969619751,
          6.540913105010986,
          6.278901100158691,
          7.19066047668457,
          7.802128791809082,
          5.940244197845459,
          6.156862258911133,
          6.98833703994751,
          7.825969696044922,
          5.931926250457764,
          6.341174602508545,
          7.101954460144043,
          6.909090042114258,
          5.358790397644043,
          6.213089942932129,
          4.626309871673584,
          4.298932075500488,
          5.955036640167236,
          5.340080261230469,
          6.414392948150635,
          4.984899997711182,
          5.527099132537842,
          6.250779628753662,
          5.1043829917907715,
          5.1283159255981445,
          4.392301559448242,
          4.28283166885376,
          5.054572105407715,
          6.028068542480469,
          5.316318988800049,
          4.782440185546875,
          4.5940728187561035,
          4.127394676208496,
          3.689979076385498,
          5.063234329223633,
          5.7853498458862305,
          6.195620059967041,
          6.1464104652404785,
          2.8238604068756104,
          9.368953704833984,
          8.292845726013184,
          9.069997787475586,
          8.60964584350586,
          7.55056619644165,
          8.318000793457031,
          10.269136428833008,
          10.397805213928223,
          10.769248962402344,
          9.16501522064209,
          10.920327186584473,
          6.821186542510986,
          10.32992172241211,
          8.066303253173828,
          8.522756576538086,
          7.173116207122803,
          6.140641212463379,
          7.6940789222717285,
          5.826387405395508,
          8.025869369506836,
          7.439008712768555,
          7.80825662612915,
          7.6835856437683105,
          -12.01269817352295,
          7.898909091949463,
          8.36392593383789,
          8.244439125061035,
          5.141961574554443,
          7.113368988037109,
          -2.004786491394043,
          6.866845607757568,
          3.1962218284606934,
          1.4604192972183228,
          5.353181838989258,
          0.9971900582313538,
          2.680790662765503,
          8.676675796508789,
          5.23794412612915,
          0.8092613220214844,
          6.060222148895264,
          5.710188865661621,
          9.262499809265137,
          7.39066219329834,
          2.7000203132629395,
          5.687589168548584,
          7.465916156768799,
          7.793002605438232,
          6.952779293060303,
          2.1715011596679688,
          7.536888599395752,
          6.5605998039245605,
          8.180418968200684,
          6.949100494384766,
          8.3487548828125,
          6.215232849121094,
          5.947609901428223,
          8.137346267700195,
          7.896887302398682,
          8.606088638305664,
          6.926698684692383,
          7.155182361602783,
          5.245785236358643,
          6.18391227722168,
          7.633050441741943,
          6.422194480895996,
          2.4297497272491455,
          3.0902750492095947,
          2.1590843200683594,
          -1.7285085916519165,
          -1.5511311292648315,
          -2.4158542156219482,
          -1.6515036821365356,
          -1.1453649997711182,
          1.4924074411392212,
          2.643249750137329,
          1.111543893814087,
          2.510246992111206,
          2.9808223247528076,
          3.688323736190796,
          -0.25383463501930237,
          1.944154977798462,
          -1.8047997951507568,
          -0.0382850207388401,
          -0.2637055814266205,
          3.670882225036621,
          -0.6044549942016602,
          0.41956353187561035,
          2.968255043029785,
          4.68057918548584,
          2.0011773109436035,
          3.9870824813842773
         ],
         "z": [
          3.457082748413086,
          7.813357353210449,
          10.625985145568848,
          8.951018333435059,
          7.202033996582031,
          9.027458190917969,
          9.509380340576172,
          8.508039474487305,
          10.058058738708496,
          9.733043670654297,
          8.575311660766602,
          9.186284065246582,
          5.96522331237793,
          10.05478286743164,
          9.933396339416504,
          10.333454132080078,
          7.640806198120117,
          10.218793869018555,
          9.48549747467041,
          11.274240493774414,
          8.854496002197266,
          9.982268333435059,
          10.093697547912598,
          8.892887115478516,
          10.935257911682129,
          10.966038703918457,
          3.4117183685302734,
          5.760101318359375,
          7.823007106781006,
          6.461649417877197,
          3.705294370651245,
          7.5353007316589355,
          5.406838417053223,
          5.414632797241211,
          6.045984745025635,
          7.275136470794678,
          3.5640647411346436,
          3.3654794692993164,
          7.498910903930664,
          6.760550498962402,
          7.769204139709473,
          3.118394374847412,
          5.502676486968994,
          4.221892833709717,
          4.631917953491211,
          2.954195022583008,
          4.27570915222168,
          2.5102415084838867,
          2.958331346511841,
          2.4414215087890625,
          1.768036961555481,
          2.2810137271881104,
          2.3046460151672363,
          9.590048789978027,
          10.563082695007324,
          11.353801727294922,
          9.805440902709961,
          9.7677583694458,
          11.30720329284668,
          10.213329315185547,
          10.078442573547363,
          9.92353630065918,
          10.341127395629883,
          10.80351448059082,
          10.147517204284668,
          10.224152565002441,
          6.959818363189697,
          7.8176655769348145,
          5.910393238067627,
          9.306009292602539,
          8.305523872375488,
          7.314127445220947,
          8.817092895507812,
          6.337478160858154,
          7.90092134475708,
          8.909493446350098,
          1.9332506656646729,
          1.992470383644104,
          5.418702125549316,
          2.4268975257873535,
          4.580986976623535,
          5.5728230476379395,
          5.379965305328369,
          4.5948405265808105,
          4.61843204498291,
          10.531536102294922,
          10.39426040649414,
          7.162641525268555,
          3.6482954025268555,
          5.001523971557617,
          3.8537964820861816,
          7.211933612823486,
          6.1578803062438965,
          3.6898040771484375,
          2.9432592391967773,
          2.7600600719451904,
          4.8364644050598145,
          3.8751556873321533,
          6.242915630340576,
          4.603460788726807,
          6.289338111877441,
          6.385032653808594,
          5.683082580566406,
          4.873601913452148,
          4.5842108726501465,
          8.143477439880371,
          8.291282653808594,
          8.694341659545898,
          9.463286399841309,
          9.10683536529541,
          9.577226638793945,
          7.882725238800049,
          9.07645034790039,
          8.713706016540527,
          8.847810745239258,
          -3.343414306640625,
          9.151348114013672,
          9.504532814025879,
          7.359191417694092,
          9.048007011413574,
          10.318567276000977,
          5.229144096374512,
          10.506729125976562,
          6.85231351852417,
          9.883637428283691,
          10.106297492980957,
          8.24681568145752,
          9.000930786132812,
          7.063814163208008,
          7.200260639190674,
          8.348262786865234,
          8.129061698913574,
          9.944450378417969,
          2.889303207397461,
          7.299322605133057,
          7.5644850730896,
          8.23703670501709,
          8.841851234436035,
          8.103852272033691,
          7.125003337860107,
          6.456498622894287,
          5.822904586791992,
          7.900754451751709,
          7.253457069396973,
          3.282724618911743,
          3.8693795204162598,
          3.240403175354004,
          5.89702844619751,
          3.410221815109253,
          5.506599426269531,
          3.925466537475586,
          6.7483601570129395,
          4.344146251678467,
          5.498439311981201,
          5.983231544494629,
          6.231650352478027,
          4.34853458404541,
          8.48622989654541,
          9.226417541503906,
          6.629359722137451,
          6.177629470825195,
          5.9769768714904785,
          5.998683929443359,
          7.252555847167969,
          5.992919921875,
          7.322041034698486,
          8.840625762939453,
          6.970469951629639,
          7.833456039428711,
          8.283370018005371,
          2.3362534046173096,
          5.39408540725708,
          2.3070385456085205,
          5.121795177459717,
          5.31194543838501,
          5.044065475463867,
          2.072270631790161,
          5.322558403015137,
          5.844764232635498,
          6.983829498291016,
          4.602605819702148,
          2.2854599952697754,
          5.413284778594971
         ]
        },
        {
         "marker": {
          "color": "rgba(219, 64, 82, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 4,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          -17.475631713867188,
          -16.9200439453125,
          -16.779300689697266,
          -17.3725643157959,
          -18.362926483154297,
          -15.99202823638916,
          -14.958146095275879,
          -17.1932430267334,
          -17.288366317749023,
          -16.64014434814453,
          -16.43488121032715,
          -15.077937126159668,
          -17.483543395996094,
          -16.035764694213867,
          -16.77069854736328,
          -17.181533813476562,
          -17.857561111450195,
          -18.836952209472656,
          -18.860429763793945,
          -17.33972930908203,
          -17.249568939208984,
          -18.888463973999023,
          -17.15690803527832,
          -16.83964729309082,
          -16.815723419189453,
          -16.440338134765625,
          -16.880521774291992,
          -17.93008804321289,
          -19.08321189880371,
          -18.221040725708008,
          -18.948444366455078,
          -17.06877326965332,
          -20.204471588134766,
          -15.401065826416016,
          -21.748117446899414,
          -17.80739402770996,
          -18.635290145874023,
          -17.243412017822266,
          -19.30828857421875,
          -19.847984313964844,
          -18.297382354736328,
          -16.9330997467041,
          -19.21842384338379,
          -18.28573226928711,
          -16.68873405456543,
          -19.48590850830078,
          -18.077537536621094,
          -16.682510375976562,
          -17.856081008911133,
          -16.879377365112305,
          -19.266130447387695,
          -18.948246002197266,
          -17.714859008789062,
          -21.17378807067871,
          -19.904176712036133,
          -19.370073318481445,
          -17.915176391601562,
          -19.148733139038086,
          -19.86643409729004,
          -19.939531326293945,
          -21.923114776611328,
          -19.687210083007812,
          -18.93956184387207,
          -19.149442672729492,
          -17.189393997192383,
          -17.55948829650879,
          -16.163740158081055,
          -16.42409324645996,
          -16.056486129760742,
          -17.855098724365234,
          -17.852113723754883,
          -19.621604919433594,
          -15.297622680664062,
          -22.014265060424805,
          -15.061985969543457,
          -22.280719757080078,
          -15.189435005187988,
          -22.131532669067383,
          -19.860668182373047,
          -21.138683319091797,
          -19.742414474487305,
          -19.085100173950195,
          -20.949913024902344,
          -19.464548110961914,
          -22.037817001342773,
          -22.557777404785156,
          -21.139108657836914,
          -19.356395721435547,
          -22.03240966796875,
          -21.729068756103516,
          -17.879589080810547,
          -17.967140197753906,
          -15.393442153930664,
          -15.172039985656738,
          -14.717047691345215,
          -15.471721649169922,
          -22.4145450592041,
          -14.651443481445312,
          -17.01142120361328,
          -17.254627227783203,
          -14.496809005737305,
          -13.491331100463867,
          -14.884119033813477,
          -14.117115020751953,
          -13.891798973083496,
          -14.872306823730469,
          -14.013284683227539,
          -14.827863693237305,
          -15.07956600189209,
          -14.556427001953125,
          -14.76125431060791,
          -16.6553897857666,
          -17.482324600219727,
          -14.554553031921387,
          -16.807344436645508,
          -14.694486618041992,
          -17.594263076782227,
          -19.02825927734375,
          -18.88616180419922,
          -18.259449005126953,
          -21.367347717285156,
          -17.022502899169922,
          -18.31441307067871,
          -18.328750610351562,
          -20.311399459838867,
          -20.20806312561035,
          -17.71664810180664,
          -19.045501708984375,
          -16.818326950073242,
          -22.154335021972656,
          -22.41827964782715,
          -22.550125122070312,
          -21.742185592651367,
          -21.719758987426758,
          -21.004127502441406,
          -21.05904197692871,
          -21.82407569885254,
          -18.114713668823242,
          -19.710264205932617,
          -19.623271942138672,
          -19.409099578857422,
          -21.020841598510742,
          -18.63784408569336,
          -20.591102600097656,
          -19.317956924438477,
          -18.457120895385742,
          -20.508085250854492,
          -19.25472640991211,
          -20.043235778808594,
          -19.351797103881836,
          -19.422616958618164,
          -19.842121124267578,
          -17.636667251586914,
          -20.140214920043945,
          -19.062105178833008,
          -16.61094093322754,
          -16.964670181274414,
          -17.197771072387695,
          -18.709362030029297,
          -16.68568229675293,
          -0.7213875651359558,
          -0.7671758532524109,
          -19.368436813354492,
          -16.925567626953125,
          -16.805282592773438,
          -17.164466857910156,
          -0.6628260016441345,
          -17.977924346923828,
          -17.40603256225586,
          -19.380779266357422,
          -18.900787353515625,
          -18.99045753479004,
          -16.954164505004883,
          -17.566144943237305,
          -18.21288299560547,
          -20.495525360107422,
          -16.734569549560547,
          -17.36549186706543,
          -20.21017074584961,
          -19.358144760131836,
          -19.08414649963379
         ],
         "y": [
          1.3763108253479004,
          -0.8642842769622803,
          -0.18564866483211517,
          -1.3922797441482544,
          -0.061121173202991486,
          -1.3161226511001587,
          -4.597584247589111,
          -0.25225716829299927,
          0.08347262442111969,
          -2.390944242477417,
          -1.6633461713790894,
          -4.516882419586182,
          -1.405064344406128,
          -5.284055709838867,
          -5.272739410400391,
          -3.8789172172546387,
          -5.00050163269043,
          -3.3332018852233887,
          -4.232583045959473,
          -4.979456424713135,
          -4.631378173828125,
          -4.176174163818359,
          -3.780022382736206,
          -3.053952693939209,
          -5.152273654937744,
          -2.023808479309082,
          -2.8237578868865967,
          -3.266784429550171,
          -0.5571475028991699,
          -2.436776638031006,
          -3.1764023303985596,
          -2.929800510406494,
          -0.4154728949069977,
          -3.640127420425415,
          0.3351626694202423,
          -0.9489519000053406,
          -2.713541030883789,
          -1.2696365118026733,
          -3.5696299076080322,
          -4.661483287811279,
          -3.4086177349090576,
          -3.0434908866882324,
          -3.891988515853882,
          -2.95988392829895,
          -0.7163217067718506,
          -3.893519401550293,
          -3.498169422149658,
          -1.3861767053604126,
          -2.3192665576934814,
          -1.1064105033874512,
          -3.7100021839141846,
          -6.139007091522217,
          -6.170920372009277,
          -4.5376152992248535,
          -4.786737442016602,
          -3.8550446033477783,
          -6.149044036865234,
          -6.556962490081787,
          -5.293094158172607,
          -5.788503170013428,
          -5.1773762702941895,
          -3.509835720062256,
          -6.833011627197266,
          -6.178643703460693,
          -4.005849361419678,
          -4.277078151702881,
          -1.228192687034607,
          -3.7157175540924072,
          -3.68741774559021,
          -3.721937894821167,
          -3.985443115234375,
          -6.111423969268799,
          -6.7680583000183105,
          -5.240442752838135,
          -6.266303539276123,
          -4.375089168548584,
          -6.463327884674072,
          -2.211951494216919,
          -2.2744150161743164,
          -3.326772451400757,
          -0.4755805432796478,
          -3.2801601886749268,
          -3.142165422439575,
          1.67550528049469,
          -2.851680278778076,
          0.5837539434432983,
          -3.331151008605957,
          -1.1768951416015625,
          -2.1842117309570312,
          0.7144724130630493,
          1.511224627494812,
          1.7724709510803223,
          0.913096010684967,
          -0.22552946209907532,
          0.6953033208847046,
          0.9465413689613342,
          2.477287769317627,
          0.674345076084137,
          2.2946889400482178,
          1.4154152870178223,
          -0.44934162497520447,
          -1.311837077140808,
          -2.3257665634155273,
          -1.4681835174560547,
          -1.1016372442245483,
          -1.063894510269165,
          -0.4149930477142334,
          -2.088578224182129,
          -4.383401393890381,
          -1.5421336889266968,
          -3.069019079208374,
          -1.2860041856765747,
          0.46800604462623596,
          -1.4078000783920288,
          -0.9221764802932739,
          -3.3428661823272705,
          -1.503509759902954,
          1.6008810997009277,
          -4.148882865905762,
          1.671847939491272,
          0.6119957566261292,
          -0.26191794872283936,
          -0.07208486646413803,
          -0.819257915019989,
          -0.34821617603302,
          0.7809972763061523,
          0.06000767648220062,
          -0.032093919813632965,
          -2.6986806392669678,
          1.7816420793533325,
          2.0815818309783936,
          2.1119015216827393,
          1.6568992137908936,
          2.007845878601074,
          0.4708136320114136,
          0.5808534026145935,
          2.180819034576416,
          -0.9051434993743896,
          0.542583167552948,
          0.34466391801834106,
          -0.023428848013281822,
          0.5004860162734985,
          -6.272749900817871,
          -4.192598819732666,
          -4.820032596588135,
          -2.4622771739959717,
          -4.7379655838012695,
          -3.8598201274871826,
          -3.459428310394287,
          -4.959980487823486,
          -4.61604118347168,
          -3.8183987140655518,
          -5.6627936363220215,
          -4.345124244689941,
          -3.1010589599609375,
          -2.9748620986938477,
          -2.107071876525879,
          -4.408398151397705,
          -2.4858527183532715,
          -4.562985420227051,
          -8.163947105407715,
          -8.138551712036133,
          -2.2300045490264893,
          -3.0802409648895264,
          -2.598252296447754,
          -5.318418025970459,
          -8.188207626342773,
          -2.1514933109283447,
          2.5414345264434814,
          -0.28545865416526794,
          0.13193055987358093,
          0.48689910769462585,
          0.9127366542816162,
          2.2642884254455566,
          2.2099664211273193,
          0.9889585375785828,
          0.2855018377304077,
          1.410605788230896,
          2.0545413494110107,
          1.5541902780532837,
          -0.6704782247543335
         ],
         "z": [
          -1.8102673292160034,
          -4.0876336097717285,
          -1.3409059047698975,
          -4.68557071685791,
          -3.080174684524536,
          -8.197813034057617,
          -4.852209568023682,
          -2.0293080806732178,
          -1.899247646331787,
          -8.80775260925293,
          -7.933374404907227,
          -4.978802680969238,
          -5.096914768218994,
          -0.5252307057380676,
          0.13911163806915283,
          -0.32341331243515015,
          0.900323212146759,
          -0.09659407287836075,
          1.4098893404006958,
          0.44582197070121765,
          0.3452126681804657,
          1.3113654851913452,
          0.486491322517395,
          0.6469846963882446,
          0.10927528142929077,
          -7.611862659454346,
          -5.847756862640381,
          -7.742164134979248,
          -5.944921016693115,
          -6.823691368103027,
          -7.800638675689697,
          -5.814254283905029,
          -5.4871954917907715,
          -7.030957221984863,
          -4.3130035400390625,
          -6.61550235748291,
          -7.213767051696777,
          -5.002145767211914,
          0.4922327995300293,
          -2.474665641784668,
          -0.6438981890678406,
          -1.7579455375671387,
          -1.651850700378418,
          -0.3866024613380432,
          -0.9151185750961304,
          -1.5652029514312744,
          -1.2974838018417358,
          -0.8628331422805786,
          -0.5724542140960693,
          -1.1272536516189575,
          0.7152950763702393,
          -5.777735233306885,
          -6.694233417510986,
          -4.148437976837158,
          -6.0242018699646,
          -6.131462097167969,
          -6.282955646514893,
          -5.798614978790283,
          -5.705326080322266,
          -6.124820232391357,
          -5.060049533843994,
          -6.394657611846924,
          -5.849935054779053,
          -6.386712551116943,
          -0.8655476570129395,
          -0.7001035809516907,
          -0.09618090838193893,
          -1.8943978548049927,
          -2.431898593902588,
          -0.7882996797561646,
          -1.3157035112380981,
          -6.279134273529053,
          -7.231850624084473,
          -5.001996994018555,
          -7.323042392730713,
          -5.2255859375,
          -7.2808685302734375,
          -3.8305513858795166,
          -3.1171488761901855,
          -4.854804992675781,
          -4.274731636047363,
          -3.704712152481079,
          -3.731288194656372,
          -3.7263221740722656,
          -4.083231449127197,
          -3.630441427230835,
          -4.156848430633545,
          -2.977146625518799,
          -3.881103038787842,
          -3.64558482170105,
          -3.8685598373413086,
          -3.67511248588562,
          -3.732269048690796,
          -6.0128068923950195,
          -4.052994251251221,
          -3.6880834102630615,
          -4.438479423522949,
          -4.072926044464111,
          -2.6184866428375244,
          -3.9791319370269775,
          -5.491838455200195,
          -5.834179878234863,
          -6.682351589202881,
          -6.044618606567383,
          -5.767200946807861,
          -6.083579063415527,
          -5.215037822723389,
          -6.714287757873535,
          -7.6231889724731445,
          -6.415344715118408,
          -6.73353910446167,
          -7.049036026000977,
          -5.738692283630371,
          -6.613891124725342,
          -6.410061836242676,
          -6.63644552230835,
          -5.925558090209961,
          -3.3196167945861816,
          -5.3577117919921875,
          -3.562839984893799,
          -3.3846724033355713,
          -5.829578399658203,
          -4.088128566741943,
          -4.345372676849365,
          -5.336322784423828,
          -4.69972038269043,
          -6.254402160644531,
          -3.001224994659424,
          -8.8432035446167,
          -3.8033640384674072,
          -3.926255464553833,
          -3.850144386291504,
          -3.8240065574645996,
          -3.5494227409362793,
          -5.191485404968262,
          -5.452659606933594,
          -3.6041717529296875,
          -4.9573187828063965,
          -2.1149303913116455,
          -2.2173173427581787,
          -2.0980987548828125,
          -5.301987648010254,
          -5.334067344665527,
          -4.260056018829346,
          -4.87274694442749,
          -3.6605255603790283,
          -4.2109375,
          -4.411825180053711,
          -4.166650295257568,
          -5.067562580108643,
          -4.906900882720947,
          -4.277406215667725,
          -6.447353839874268,
          -4.256455898284912,
          -3.350863456726074,
          -6.57667875289917,
          -7.3807692527771,
          -7.577743053436279,
          -6.939297676086426,
          -7.365035057067871,
          -0.83269864320755,
          -0.8035109043121338,
          -6.996661186218262,
          -6.218621253967285,
          -6.695049285888672,
          -7.162291049957275,
          -0.8496039509773254,
          -7.211385726928711,
          -1.465680718421936,
          -5.984722137451172,
          -5.309928894042969,
          -6.797394752502441,
          -5.157110691070557,
          -2.2588980197906494,
          -2.541815996170044,
          -4.168274879455566,
          -2.529292583465576,
          -1.9942600727081299,
          -3.266576051712036,
          -3.2910678386688232,
          -3.7956504821777344
         ]
        },
        {
         "marker": {
          "color": "rgba(0, 128, 128, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 5,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          -0.08301404863595963,
          -2.685412883758545,
          0.11812525242567062,
          -2.065103769302368,
          -2.0740439891815186,
          -1.9415643215179443,
          -1.7632330656051636,
          -2.3618361949920654,
          0.9039490222930908,
          0.36622196435928345,
          -0.5399121642112732,
          -2.997023105621338,
          -1.367246389389038,
          -2.286656618118286,
          -3.288245677947998,
          -1.578566312789917,
          -2.5331385135650635,
          -1.9881923198699951,
          -2.510267972946167,
          -1.7635242938995361,
          -1.756783366203308,
          -2.030202865600586,
          -2.6245710849761963,
          -1.6635650396347046,
          -2.3962714672088623,
          -1.9413384199142456,
          -2.2913501262664795,
          -4.229553699493408,
          -1.02217698097229,
          -2.1270029544830322,
          1.334639549255371,
          0.5512004494667053,
          -2.5109853744506836,
          -1.5131442546844482,
          -1.9582120180130005,
          -1.5567059516906738,
          -1.0681118965148926,
          -0.29521244764328003,
          -3.871781587600708,
          -3.6050350666046143,
          -2.638490915298462,
          -2.685260772705078,
          -3.923652172088623,
          -1.8278509378433228,
          -4.743711948394775,
          -3.1679635047912598,
          -1.7970341444015503,
          -1.7971936464309692,
          -2.929746389389038,
          -1.9805090427398682,
          -1.008275032043457,
          -2.510981798171997,
          -0.3979075253009796,
          0.7887973785400391,
          -0.6775175929069519,
          -2.3585994243621826,
          -0.12713831663131714,
          -0.3372274935245514,
          -0.3158126175403595,
          -0.7211278080940247,
          1.1280663013458252,
          -0.6121706366539001,
          -0.2599552869796753,
          -0.5415381789207458,
          0.6752017140388489,
          2.9522006511688232,
          0.5318238139152527,
          0.2765246033668518,
          3.6861367225646973,
          0.05322457104921341,
          0.09648960083723068,
          -0.7519342303276062,
          2.9399023056030273,
          3.142392873764038,
          2.2810864448547363,
          -1.1027745008468628,
          -0.5602957010269165,
          -1.0312026739120483,
          -3.9483911991119385,
          -3.704113006591797,
          -2.9973814487457275,
          -4.06766939163208,
          -1.417641520500183,
          -4.155812740325928,
          -2.9504125118255615,
          -3.7995011806488037,
          -3.1028635501861572,
          -3.4725520610809326,
          -2.1726913452148438,
          -3.412452220916748,
          -3.2547852993011475,
          -0.5532779693603516,
          -1.3061474561691284,
          -0.5794751048088074,
          -0.7364785671234131,
          -1.3821651935577393,
          -0.7487194538116455,
          -1.8653740882873535,
          -1.616836667060852,
          -0.9036091566085815,
          -1.3793689012527466,
          -1.2662389278411865,
          -1.0550596714019775,
          -0.6775572896003723,
          -1.4608708620071411,
          -2.8570568561553955,
          -1.3703632354736328,
          -0.7197443246841431,
          -2.171964168548584,
          -0.6757805347442627,
          -1.2362651824951172,
          0.47996610403060913,
          0.05537354201078415,
          0.45838475227355957,
          1.346112847328186,
          -1.7535303831100464,
          1.422371745109558,
          2.032029390335083,
          2.3222949504852295,
          -3.1105005741119385,
          -0.17827466130256653,
          -3.3185434341430664,
          -3.925459146499634,
          2.911428451538086,
          -0.012044054456055164,
          1.328801155090332,
          -4.02610445022583,
          -2.9068996906280518,
          -0.7725733518600464,
          -1.3384082317352295,
          0.9745394587516785,
          -0.08269917964935303,
          1.743085503578186,
          0.5044799447059631,
          1.026587963104248,
          -2.2987101078033447,
          0.5574591755867004,
          2.1890807151794434,
          8.306465148925781,
          1.0656418800354004,
          -1.6651159524917603,
          2.9569315910339355,
          -2.461531400680542,
          0.11348544806241989,
          0.35467529296875,
          0.553004264831543,
          0.34884965419769287,
          0.20930007100105286,
          0.590826153755188,
          -1.1918977499008179,
          1.01048743724823,
          1.170082688331604,
          -1.244591236114502,
          -0.33900654315948486,
          1.019712209701538,
          -0.308161199092865,
          -2.0805859565734863,
          -1.2604767084121704,
          -2.040910005569458,
          -3.9544737339019775,
          -3.666987180709839,
          -1.8537839651107788,
          -2.5605692863464355,
          -2.5662386417388916,
          0.18803484737873077,
          -2.3622665405273438,
          -3.9234251976013184,
          -1.0320810079574585,
          -2.1728572845458984,
          1.5489953756332397,
          1.8714027404785156,
          1.9678151607513428,
          1.3252170085906982,
          -0.658654510974884,
          -2.102800130844116,
          1.9588251113891602,
          -0.23541276156902313,
          1.9602326154708862,
          0.9017851948738098,
          2.1247057914733887,
          1.7088865041732788,
          1.0286864042282104
         ],
         "y": [
          8.477279663085938,
          1.9757733345031738,
          -0.9237343072891235,
          4.598019599914551,
          0.1974790394306183,
          0.16510653495788574,
          -0.7547478079795837,
          5.143782615661621,
          1.5874905586242676,
          1.9343715906143188,
          0.46202367544174194,
          -0.19374212622642517,
          0.18827319145202637,
          -1.1067554950714111,
          0.8215852379798889,
          -2.7442564964294434,
          0.11364280432462692,
          -2.2075932025909424,
          -1.903007984161377,
          -0.07010767608880997,
          -0.5873476266860962,
          -2.7818069458007812,
          -2.21036434173584,
          -2.141915798187256,
          -2.5560083389282227,
          -1.8075737953186035,
          6.366917610168457,
          0.09785566478967667,
          5.095004558563232,
          5.962522983551025,
          4.080295085906982,
          6.3360595703125,
          6.120059967041016,
          3.1250154972076416,
          6.0772223472595215,
          6.991847038269043,
          3.875454902648926,
          4.789083480834961,
          -1.0792672634124756,
          4.093114852905273,
          2.132740020751953,
          2.401906967163086,
          4.411002159118652,
          2.578615188598633,
          4.788196086883545,
          2.6378300189971924,
          7.221619129180908,
          2.6228368282318115,
          3.9670653343200684,
          2.397157907485962,
          0.6064704060554504,
          2.2971842288970947,
          7.920051574707031,
          7.848963737487793,
          7.786123752593994,
          5.586735248565674,
          8.111760139465332,
          8.250167846679688,
          7.505863189697266,
          6.7325439453125,
          8.281481742858887,
          8.198933601379395,
          6.3659491539001465,
          8.16354751586914,
          7.8452935218811035,
          5.320967674255371,
          -0.6293837428092957,
          -0.7078018188476562,
          4.281156539916992,
          1.3387490510940552,
          -1.5030895471572876,
          0.14241650700569153,
          3.4795479774475098,
          3.6074888706207275,
          4.452942848205566,
          0.010821809060871601,
          -0.705488383769989,
          -2.733104944229126,
          1.104385495185852,
          -1.5025237798690796,
          -1.5033526420593262,
          -0.08275897800922394,
          -0.6498454809188843,
          0.8573750257492065,
          0.4385674297809601,
          -0.2801494896411896,
          -0.5776200890541077,
          0.8389964699745178,
          -1.2619118690490723,
          1.9412020444869995,
          -1.172173261642456,
          5.9927520751953125,
          7.921871662139893,
          8.549057006835938,
          7.452877521514893,
          6.682126522064209,
          8.21383285522461,
          8.319872856140137,
          6.717569828033447,
          7.255167484283447,
          5.193469524383545,
          7.6774115562438965,
          7.944188594818115,
          5.667378902435303,
          2.4072604179382324,
          3.5098743438720703,
          6.734063148498535,
          2.938420295715332,
          3.2105960845947266,
          2.9071414470672607,
          4.206096649169922,
          4.674686431884766,
          1.350136399269104,
          1.9583545923233032,
          4.594621181488037,
          2.2688398361206055,
          3.7108664512634277,
          3.4908158779144287,
          4.616276741027832,
          -2.1014010906219482,
          4.367406845092773,
          2.019371271133423,
          1.296053409576416,
          3.5073301792144775,
          -0.8989943265914917,
          3.6299328804016113,
          -1.8225783109664917,
          -2.251286506652832,
          -2.73053240776062,
          -0.6413944363594055,
          6.0080671310424805,
          4.5148701667785645,
          3.2304437160491943,
          3.000117540359497,
          2.424269676208496,
          4.191417694091797,
          2.9551639556884766,
          3.400696277618408,
          -0.7207544445991516,
          1.1551964282989502,
          2.527508020401001,
          3.3322196006774902,
          5.213438987731934,
          6.48717737197876,
          5.844298362731934,
          6.345604419708252,
          5.859102249145508,
          5.668928146362305,
          5.78239631652832,
          7.329810619354248,
          5.215967178344727,
          3.0007247924804688,
          7.426074028015137,
          8.430139541625977,
          5.300679683685303,
          5.094590187072754,
          -0.7239847779273987,
          -0.42214474081993103,
          2.2745883464813232,
          2.1595492362976074,
          -2.582289457321167,
          -0.3243989646434784,
          -2.932546377182007,
          -0.6358117461204529,
          1.6328983306884766,
          2.2416396141052246,
          -0.35265251994132996,
          -0.02009865641593933,
          2.2694971561431885,
          6.722196102142334,
          5.973117351531982,
          6.365815162658691,
          5.248581886291504,
          6.18495512008667,
          5.128190040588379,
          6.262630939483643,
          7.7462544441223145,
          6.577381610870361,
          7.149861812591553,
          5.6691203117370605,
          5.909104347229004,
          7.877176761627197
         ],
         "z": [
          2.638666868209839,
          -13.1295747756958,
          -12.570115089416504,
          -10.626434326171875,
          -9.244645118713379,
          -9.242835998535156,
          -9.738129615783691,
          -11.605634689331055,
          -9.39612865447998,
          -10.615882873535156,
          -11.8826904296875,
          -12.515128135681152,
          -8.947940826416016,
          -12.8359956741333,
          -11.593602180480957,
          -15.225564002990723,
          -11.983981132507324,
          -14.585907936096191,
          -13.575278282165527,
          -12.028617858886719,
          -12.530350685119629,
          -15.132817268371582,
          -13.017965316772461,
          -12.995837211608887,
          -13.431105613708496,
          -12.157633781433105,
          -7.474548816680908,
          -12.04387092590332,
          -8.788961410522461,
          -8.634729385375977,
          -6.761839866638184,
          -3.823632001876831,
          -8.919053077697754,
          -14.348984718322754,
          -8.940908432006836,
          -7.786739349365234,
          -9.961227416992188,
          -6.4460859298706055,
          -13.750614166259766,
          -8.74514102935791,
          -8.700179100036621,
          -8.656865119934082,
          -8.516143798828125,
          -8.499526023864746,
          -8.135307312011719,
          -8.236083030700684,
          -10.386449813842773,
          -8.583449363708496,
          -9.815776824951172,
          -8.758439064025879,
          -12.924365997314453,
          -7.675414562225342,
          -10.099129676818848,
          -7.348390579223633,
          -8.203527450561523,
          -10.228873252868652,
          -7.041338920593262,
          -7.7375688552856445,
          -8.154033660888672,
          -8.59896469116211,
          -7.545482635498047,
          -6.947836399078369,
          -8.543924331665039,
          -10.391666412353516,
          -7.550856113433838,
          -10.25745677947998,
          -12.875212669372559,
          -13.09660816192627,
          -10.524514198303223,
          -14.679059982299805,
          -12.988259315490723,
          -13.096343040466309,
          -9.989843368530273,
          -10.149417877197266,
          -8.411529541015625,
          -13.293327331542969,
          -14.3537015914917,
          -15.410759925842285,
          -12.41807746887207,
          -14.308440208435059,
          -14.246042251586914,
          -10.501265525817871,
          -14.133788108825684,
          -12.4866304397583,
          -12.529155731201172,
          -10.58408260345459,
          -11.154260635375977,
          -10.96519947052002,
          -13.778495788574219,
          -10.754508018493652,
          -13.972305297851562,
          -8.65164566040039,
          -5.809396743774414,
          -4.357920169830322,
          -4.753599166870117,
          -7.032557487487793,
          -4.556517124176025,
          -4.145081520080566,
          -6.774106502532959,
          -5.5294718742370605,
          -8.792222023010254,
          -4.748089790344238,
          -4.635593414306641,
          -5.983297348022461,
          -12.815730094909668,
          -11.731903076171875,
          -9.822376251220703,
          -12.408835411071777,
          -13.669946670532227,
          -12.578861236572266,
          -9.976461410522461,
          -11.246935844421387,
          -14.677328109741211,
          -11.072927474975586,
          -11.021286010742188,
          -13.020500183105469,
          -10.963907241821289,
          -8.032773971557617,
          -8.331586837768555,
          -14.234539985656738,
          -9.872110366821289,
          -10.570356369018555,
          -12.579244613647461,
          -9.716479301452637,
          -13.637505531311035,
          -8.9832763671875,
          -14.118635177612305,
          -13.159001350402832,
          -15.466452598571777,
          -12.254449844360352,
          -6.669647216796875,
          -8.043474197387695,
          -9.680412292480469,
          -8.796931266784668,
          -9.435870170593262,
          -10.50840950012207,
          -8.609429359436035,
          -8.586153030395508,
          -8.386133193969727,
          -11.143800735473633,
          -10.953659057617188,
          -8.3147611618042,
          -11.712831497192383,
          -8.092391967773438,
          -6.319811820983887,
          -3.8066208362579346,
          -6.402787685394287,
          -6.500784873962402,
          -6.436359882354736,
          -6.6068115234375,
          -5.931481838226318,
          -7.9142842292785645,
          -6.655228137969971,
          -4.962485313415527,
          -7.405322551727295,
          -8.590423583984375,
          -14.836255073547363,
          -15.062471389770508,
          -13.156697273254395,
          -14.325615882873535,
          -14.854331016540527,
          -15.221579551696777,
          -15.24837875366211,
          -14.480378150939941,
          -10.428231239318848,
          -14.288919448852539,
          -12.190363883972168,
          -15.108146667480469,
          -14.213895797729492,
          -9.38515567779541,
          -9.836130142211914,
          -10.622176170349121,
          -9.744072914123535,
          -10.558465957641602,
          -11.482954978942871,
          -9.96630573272705,
          -10.123441696166992,
          -10.691003799438477,
          -8.62801456451416,
          -8.905112266540527,
          -10.930227279663086,
          -9.265571594238281
         ]
        },
        {
         "marker": {
          "color": "rgba(255, 255, 51, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 6,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          10.928581237792969,
          14.73205852508545,
          10.616498947143555,
          13.407443046569824,
          11.0814208984375,
          13.82938003540039,
          11.366425514221191,
          12.363516807556152,
          11.124995231628418,
          11.928298950195312,
          9.788389205932617,
          8.649663925170898,
          11.032812118530273,
          11.023523330688477,
          13.388391494750977,
          11.960299491882324,
          11.727598190307617,
          11.306059837341309,
          11.625654220581055,
          11.443159103393555,
          11.413480758666992,
          11.99350643157959,
          13.632010459899902,
          11.275300979614258,
          13.25624942779541,
          12.846925735473633,
          12.930723190307617,
          12.016923904418945,
          13.549726486206055,
          11.167546272277832,
          14.752256393432617,
          14.753996849060059,
          15.708040237426758,
          14.042840003967285,
          12.311342239379883,
          13.629748344421387,
          12.77941608428955,
          15.120826721191406,
          10.305264472961426,
          10.105396270751953,
          11.27318286895752,
          10.554213523864746,
          9.978879928588867,
          11.510895729064941,
          10.246987342834473,
          11.498729705810547,
          10.66536808013916,
          12.761981964111328,
          11.898797035217285,
          11.531963348388672,
          7.558645725250244,
          10.328418731689453,
          9.321782112121582,
          11.046360969543457,
          9.190189361572266,
          8.19082260131836,
          8.477437019348145,
          9.962220191955566,
          8.816391944885254,
          8.476259231567383,
          8.199174880981445,
          10.285454750061035,
          10.457393646240234,
          8.79902458190918,
          13.899377822875977,
          13.583479881286621,
          13.263427734375,
          11.342669486999512,
          12.855134010314941,
          12.753312110900879,
          16.083839416503906,
          12.011197090148926,
          13.465595245361328,
          13.701361656188965,
          12.27675724029541,
          13.576075553894043,
          13.753466606140137,
          12.750475883483887,
          12.742444038391113,
          12.128085136413574,
          11.979413986206055,
          11.513972282409668,
          11.111129760742188,
          11.949187278747559,
          12.798749923706055,
          10.598867416381836,
          12.781291961669922,
          12.619077682495117,
          13.103315353393555,
          12.35090446472168,
          14.191083908081055,
          12.369609832763672,
          13.025566101074219,
          14.017561912536621,
          14.194077491760254,
          13.557043075561523,
          14.285233497619629,
          13.930904388427734,
          13.72063159942627,
          13.962530136108398,
          14.88211727142334,
          12.573196411132812,
          11.849102020263672,
          11.79589557647705,
          12.37200927734375,
          14.710803031921387,
          14.069846153259277,
          10.476723670959473,
          13.968059539794922,
          15.398099899291992,
          14.74520492553711,
          12.849966049194336,
          14.159468650817871,
          15.65445613861084,
          10.003945350646973,
          14.512845993041992,
          12.80517292022705,
          9.836610794067383,
          14.677617073059082,
          14.65211009979248,
          13.189669609069824,
          15.36994457244873,
          11.938821792602539,
          11.923858642578125,
          14.713403701782227,
          15.213513374328613,
          15.351487159729004,
          11.40341854095459,
          15.173064231872559,
          15.10869026184082,
          15.194818496704102,
          16.104053497314453,
          15.653685569763184,
          12.52519702911377,
          12.47620677947998,
          12.982973098754883,
          12.562165260314941,
          14.245780944824219,
          16.049272537231445,
          15.201370239257812,
          14.66342830657959,
          13.674386978149414,
          12.16520881652832,
          12.283397674560547,
          12.43907356262207,
          9.851729393005371,
          13.277972221374512,
          11.935848236083984,
          12.333867073059082,
          12.325150489807129,
          11.757737159729004,
          12.646659851074219,
          12.599878311157227,
          12.547486305236816,
          14.046171188354492,
          15.239639282226562,
          13.059599876403809,
          11.551423072814941,
          12.687994956970215,
          14.219928741455078,
          12.489447593688965,
          12.334845542907715,
          13.9990234375,
          14.312472343444824,
          12.973272323608398,
          15.992984771728516,
          12.283699035644531,
          10.460855484008789,
          10.240951538085938,
          10.978190422058105,
          10.037720680236816,
          10.377548217773438,
          10.864388465881348,
          9.635683059692383,
          10.621908187866211,
          11.633678436279297,
          10.229207038879395,
          12.252172470092773,
          11.241827964782715,
          11.368793487548828,
          11.665700912475586
         ],
         "y": [
          -4.555772304534912,
          -3.0798490047454834,
          -5.07667350769043,
          -2.9969136714935303,
          -4.532172679901123,
          -2.7674264907836914,
          -4.68100643157959,
          -5.484598159790039,
          -4.81699275970459,
          -3.533393144607544,
          -5.0779571533203125,
          -4.171670913696289,
          -4.8468098640441895,
          -2.112997055053711,
          -0.35549023747444153,
          -3.4447615146636963,
          -4.371364116668701,
          -4.5566911697387695,
          -2.6455800533294678,
          -4.6928935050964355,
          -3.6940810680389404,
          -5.436384201049805,
          -3.509286403656006,
          0.39570024609565735,
          0.37298548221588135,
          -1.2760002613067627,
          -2.0995240211486816,
          -4.6942620277404785,
          -2.2965927124023438,
          0.003800175618380308,
          -3.8448472023010254,
          -3.6948208808898926,
          -2.7438266277313232,
          -3.824270248413086,
          -1.1980246305465698,
          -2.001319646835327,
          -2.5418169498443604,
          -4.378009796142578,
          0.5561990737915039,
          1.3399263620376587,
          0.7634656429290771,
          1.84735906124115,
          0.06857366114854813,
          0.6119768023490906,
          0.9307846426963806,
          0.7005715370178223,
          -2.40329647064209,
          0.9796587228775024,
          2.0050415992736816,
          0.0951060876250267,
          -3.9778895378112793,
          -1.75751531124115,
          -0.7366616129875183,
          -1.6234617233276367,
          -2.3193929195404053,
          -2.8552439212799072,
          -1.5980942249298096,
          -1.985949158668518,
          -0.7955102324485779,
          -1.5510621070861816,
          -3.183882474899292,
          -1.6650846004486084,
          -2.391695737838745,
          -2.1215991973876953,
          -4.466310501098633,
          -3.9928088188171387,
          -3.6745173931121826,
          -3.8205299377441406,
          -5.278356552124023,
          -1.979064702987671,
          -2.540736198425293,
          -2.8883445262908936,
          -3.279137134552002,
          -5.319445610046387,
          -1.7346775531768799,
          -4.907657146453857,
          -4.8811187744140625,
          2.855128526687622,
          3.288177967071533,
          1.2584363222122192,
          2.217480182647705,
          -2.0404036045074463,
          -0.17817917466163635,
          2.324289560317993,
          2.946188449859619,
          -0.006329053547233343,
          2.0265846252441406,
          0.5780669450759888,
          -3.0788049697875977,
          -3.429385185241699,
          -3.591782331466675,
          -4.074133396148682,
          -1.4304571151733398,
          -1.5784144401550293,
          -3.603304862976074,
          -1.474019169807434,
          -1.1677937507629395,
          -2.553158760070801,
          -1.7586190700531006,
          -2.6869704723358154,
          -0.508087158203125,
          -1.431227207183838,
          -0.2327839881181717,
          -1.934393286705017,
          1.0321983098983765,
          -1.7993921041488647,
          -3.1064391136169434,
          -2.915008783340454,
          -5.045597076416016,
          -1.6885952949523926,
          -3.2376179695129395,
          -5.170385360717773,
          -4.887719631195068,
          -1.284198522567749,
          -5.195748329162598,
          -0.4236205518245697,
          -0.46665069460868835,
          -3.1534759998321533,
          -1.9469162225723267,
          -2.8477530479431152,
          0.9030784368515015,
          -1.433334231376648,
          -2.060364007949829,
          -2.4282684326171875,
          -0.4243639409542084,
          -0.7112997174263,
          -0.9167152047157288,
          -1.3341442346572876,
          -0.4985508918762207,
          -1.248765230178833,
          -1.8688066005706787,
          0.13925665616989136,
          -0.17047187685966492,
          0.3678939640522003,
          0.9101667404174805,
          1.2531967163085938,
          -0.21617503464221954,
          -0.8370160460472107,
          0.03834408521652222,
          -1.5415815114974976,
          0.7549495697021484,
          1.82317054271698,
          0.3457164168357849,
          0.6869778037071228,
          -0.3029048442840576,
          -0.4437790811061859,
          0.7849535346031189,
          -1.3132591247558594,
          -3.6737706661224365,
          -1.7717258930206299,
          0.5680280327796936,
          0.5210446119308472,
          -0.36929604411125183,
          -0.24235616624355316,
          -1.5204514265060425,
          -1.2865394353866577,
          -1.102216362953186,
          -4.3541259765625,
          -0.7682923078536987,
          -0.9085873961448669,
          -2.683286190032959,
          -3.179900646209717,
          -1.0231866836547852,
          -0.8369622826576233,
          -2.4196906089782715,
          -2.5896382331848145,
          -3.533053398132324,
          -2.428522825241089,
          -4.743182182312012,
          0.41702529788017273,
          -3.792389392852783,
          -3.354996919631958,
          0.2576545476913452,
          -5.385371208190918,
          -3.308063507080078,
          -5.824520111083984,
          -4.856675148010254,
          -4.9417033195495605,
          -4.661458492279053,
          -4.486875057220459,
          -0.7284959554672241
         ],
         "z": [
          -4.404854774475098,
          -3.5896875858306885,
          -4.863114356994629,
          -2.765070676803589,
          -5.570187568664551,
          -5.70928955078125,
          -5.103144645690918,
          -9.223640441894531,
          -4.703556537628174,
          -3.9581363201141357,
          -3.5987842082977295,
          -5.229947566986084,
          -2.8687074184417725,
          -9.098127365112305,
          -4.092918395996094,
          -4.464502811431885,
          -9.749593734741211,
          -8.040881156921387,
          -4.2998480796813965,
          -7.942378520965576,
          -9.159761428833008,
          -8.972823143005371,
          -3.6013951301574707,
          -6.125542163848877,
          -9.66050910949707,
          -9.843951225280762,
          -8.620857238769531,
          -9.973774909973145,
          -7.13043212890625,
          -10.862403869628906,
          -9.227628707885742,
          -9.11330509185791,
          -6.849229335784912,
          -4.586303234100342,
          -10.649145126342773,
          -7.22301721572876,
          -9.082145690917969,
          -9.220341682434082,
          -5.504188060760498,
          -4.785943984985352,
          -3.841313123703003,
          -4.292050361633301,
          -10.179333686828613,
          -3.808116912841797,
          -5.036420822143555,
          -3.573967218399048,
          -5.194639682769775,
          -3.395033597946167,
          -3.7249066829681396,
          -4.44541597366333,
          -5.156561374664307,
          -5.876122951507568,
          -8.600176811218262,
          -7.193210601806641,
          -6.571809768676758,
          -5.912238597869873,
          -7.481404781341553,
          -5.9842424392700195,
          -8.453910827636719,
          -7.486588954925537,
          -5.741471290588379,
          -5.828007221221924,
          -5.973723411560059,
          -5.978321552276611,
          -8.782179832458496,
          -9.023652076721191,
          -9.191444396972656,
          -9.584782600402832,
          -9.382787704467773,
          -10.608541488647461,
          -6.650765895843506,
          -11.281296730041504,
          -9.181797981262207,
          -5.7219390869140625,
          -10.521173477172852,
          -5.193536281585693,
          -5.1956048011779785,
          -5.830892086029053,
          -6.165279865264893,
          -4.536134243011475,
          -8.247842788696289,
          -3.7369585037231445,
          -4.732922554016113,
          -8.246899604797363,
          -5.758356094360352,
          -7.711283206939697,
          -4.78956937789917,
          -7.3056321144104,
          -2.4487855434417725,
          -10.087541580200195,
          -11.71653938293457,
          -10.763004302978516,
          -11.102485656738281,
          -9.165815353393555,
          -11.738966941833496,
          -8.604683876037598,
          -9.630780220031738,
          -10.5607328414917,
          -10.431729316711426,
          -5.761842727661133,
          -7.7440266609191895,
          -10.061111450195312,
          -9.409128189086914,
          -10.91940689086914,
          -9.184904098510742,
          -8.782798767089844,
          -3.7414257526397705,
          -4.729773044586182,
          -7.964292049407959,
          -5.624999046325684,
          -6.950530529022217,
          -5.185450077056885,
          -8.016934394836426,
          -7.070249080657959,
          -4.793490409851074,
          -8.50418758392334,
          -11.061018943786621,
          -6.466702461242676,
          -6.249284267425537,
          -6.9212470054626465,
          -4.057268142700195,
          -5.949678421020508,
          -5.335129737854004,
          -5.50938081741333,
          -6.448243618011475,
          -5.792942523956299,
          -5.639039516448975,
          -5.552145004272461,
          -4.935196876525879,
          -2.885342836380005,
          -3.3594512939453125,
          -4.223737716674805,
          -4.280749797821045,
          -4.231257438659668,
          -4.513515949249268,
          -4.242830276489258,
          -4.277962684631348,
          -3.819173574447632,
          -4.198322772979736,
          -3.9346940517425537,
          -2.9963762760162354,
          -4.478946208953857,
          -9.109329223632812,
          -9.426217079162598,
          -10.48753833770752,
          -8.950920104980469,
          -9.850252151489258,
          -9.776653289794922,
          -11.350913047790527,
          -7.973001956939697,
          -8.959567070007324,
          -8.458429336547852,
          -7.851080417633057,
          -7.973262786865234,
          -6.460412502288818,
          -2.049076795578003,
          -2.256197690963745,
          -2.530614137649536,
          -3.420377254486084,
          -2.5767807960510254,
          -3.44714617729187,
          -2.6247546672821045,
          -3.200066328048706,
          -2.6616392135620117,
          -2.3818743228912354,
          -5.069831371307373,
          -2.177774429321289,
          -3.123662233352661,
          -6.985002040863037,
          -7.545629501342773,
          -7.730307102203369,
          -8.216920852661133,
          -6.912175178527832,
          -5.481332778930664,
          -8.390491485595703,
          -9.385677337646484,
          -5.898719310760498,
          -4.964108943939209,
          -6.861639499664307,
          -3.6063151359558105,
          -8.211865425109863
         ]
        },
        {
         "marker": {
          "color": "rgba(128, 128, 0, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 7,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          -0.0038599050603806973,
          -2.093423843383789,
          -5.1614813804626465,
          -4.203186988830566,
          0.5189491510391235,
          -4.011181354522705,
          -2.3547468185424805,
          -1.1007589101791382,
          -5.268081188201904,
          -0.2506669759750366,
          -3.438760995864868,
          -1.086936593055725,
          -1.9506109952926636,
          0.7475259900093079,
          0.9953192472457886,
          2.3045053482055664,
          -4.0541253089904785,
          -3.053619861602783,
          0.618952751159668,
          3.862091064453125,
          2.117739677429199,
          3.4680979251861572,
          -2.5390865802764893,
          1.7184978723526,
          3.0357730388641357,
          -3.6047608852386475,
          0.54502272605896,
          -3.997831106185913,
          1.3913378715515137,
          -3.7210352420806885,
          -4.55549430847168,
          -4.833897590637207,
          -1.3240302801132202,
          -0.8627880215644836,
          2.2001821994781494,
          2.2114803791046143,
          -0.8493049740791321,
          -3.605269432067871,
          -4.734476566314697,
          -5.112005233764648,
          -5.481454849243164,
          -6.742030143737793,
          -3.252392530441284,
          -4.906854629516602,
          -6.155129909515381,
          -6.75238561630249,
          -3.7238049507141113,
          -4.932497978210449,
          -5.789007186889648,
          -5.3113908767700195,
          -3.8952431678771973,
          2.3484153747558594,
          -0.35650771856307983,
          -4.606544494628906,
          -2.1524064540863037,
          -1.3399558067321777,
          1.7026128768920898,
          -4.9679365158081055,
          0.5880866050720215,
          -0.981328547000885,
          0.6968358159065247,
          -0.4237845242023468,
          3.1439709663391113,
          -1.0807324647903442,
          -0.6166160702705383,
          -5.045203685760498,
          -7.243677139282227,
          -6.988693714141846,
          -6.991338729858398,
          -4.860947132110596,
          -5.23690128326416,
          -5.358004570007324,
          -7.077900409698486,
          -5.522628307342529,
          -5.664846420288086,
          -5.995028495788574,
          -0.8718975186347961,
          -1.3860259056091309,
          0.4139682650566101,
          1.324256420135498,
          3.1274380683898926,
          -1.681803584098816,
          3.717174768447876,
          0.40659648180007935,
          0.36991068720817566,
          -3.1269307136535645,
          3.085686206817627,
          0.3077988028526306,
          0.2916403114795685,
          1.4478094577789307,
          -1.9159818887710571,
          -0.7151064276695251,
          -2.3267018795013428,
          -0.40075796842575073,
          -3.5688891410827637,
          -0.6974485516548157,
          -2.102385997772217,
          -1.3483690023422241,
          -2.0147459506988525,
          -2.6771328449249268,
          -0.31684306263923645,
          -1.3564693927764893,
          0.8902864456176758,
          -0.3964707553386688,
          1.3423476219177246,
          1.1320364475250244,
          0.4861558675765991,
          1.5586110353469849,
          2.4936630725860596,
          2.5940346717834473,
          2.650512456893921,
          0.34077081084251404,
          -0.8815020322799683,
          2.4756155014038086,
          1.6613287925720215,
          1.297466516494751,
          -2.447171926498413,
          -5.284573078155518,
          2.354548454284668,
          0.5602063536643982,
          0.07786351442337036,
          1.0662771463394165,
          2.2315049171447754,
          2.9132258892059326,
          0.5561085343360901,
          2.004347562789917,
          -4.472914218902588,
          -3.3832194805145264,
          2.900848627090454,
          -1.5523601770401,
          0.07704093307256699,
          -1.9240409135818481,
          -0.2420041412115097,
          0.18964052200317383,
          1.0083918571472168,
          0.7061065435409546,
          3.251696825027466,
          -2.7023136615753174,
          0.9018368721008301,
          -3.829488515853882,
          -0.47646626830101013,
          -3.3021438121795654,
          -4.120022773742676,
          -3.2500455379486084,
          -1.9897569417953491,
          -1.758618950843811,
          -4.926741123199463,
          -3.3504562377929688,
          -2.2356157302856445,
          -1.8327134847640991,
          -2.197572708129883,
          -3.002817392349243,
          -3.951279640197754,
          -3.2438719272613525,
          2.7159767150878906,
          2.259892225265503,
          1.8031694889068604,
          4.01847505569458,
          4.63334321975708,
          3.934715986251831,
          2.3184194564819336,
          4.158658504486084,
          3.6760003566741943,
          -1.287140130996704,
          1.7941912412643433,
          3.973771333694458,
          -0.8247756958007812,
          -3.446972131729126,
          -0.8560844659805298,
          -2.94399094581604,
          -4.774163722991943,
          0.6542467474937439,
          -0.1304192692041397,
          2.5079872608184814,
          1.73712956905365,
          -1.0284351110458374,
          1.472805380821228,
          -2.6449522972106934,
          2.0234792232513428
         ],
         "y": [
          -14.87378978729248,
          -14.992799758911133,
          -16.009164810180664,
          -16.07781982421875,
          -15.198847770690918,
          -15.59908676147461,
          -15.320404052734375,
          -16.423019409179688,
          -15.004079818725586,
          -13.746530532836914,
          -15.752281188964844,
          -15.866131782531738,
          -14.832110404968262,
          -15.198366165161133,
          -15.467913627624512,
          -17.314830780029297,
          -14.795953750610352,
          -12.786778450012207,
          -15.726134300231934,
          -17.370845794677734,
          -18.436859130859375,
          -16.935091018676758,
          -14.562360763549805,
          -17.201059341430664,
          -16.917736053466797,
          -14.450419425964355,
          -15.736624717712402,
          -12.466906547546387,
          -15.105735778808594,
          -12.219593048095703,
          -13.5986328125,
          -12.488883018493652,
          -13.70108699798584,
          -14.165482521057129,
          -15.452167510986328,
          -16.88955307006836,
          -14.151620864868164,
          -13.851947784423828,
          -8.05136775970459,
          -7.910179138183594,
          -7.952444553375244,
          -7.326693058013916,
          -8.231036186218262,
          -7.948731899261475,
          -8.074149131774902,
          -7.327517986297607,
          -8.139480590820312,
          -6.958268165588379,
          -8.120327949523926,
          -7.72078800201416,
          -8.093320846557617,
          -18.407934188842773,
          -15.744479179382324,
          -13.943017959594727,
          -15.264066696166992,
          -15.173357009887695,
          -16.451908111572266,
          -13.932562828063965,
          -15.778517723083496,
          -16.091337203979492,
          -15.387688636779785,
          -15.278268814086914,
          -17.145156860351562,
          -15.298505783081055,
          -15.874232292175293,
          -14.118123054504395,
          -13.478314399719238,
          -13.678407669067383,
          -13.5923433303833,
          -14.638111114501953,
          -13.720020294189453,
          -14.66633129119873,
          -13.660449981689453,
          -14.526524543762207,
          -14.676115989685059,
          -14.618999481201172,
          -15.096253395080566,
          -13.32794189453125,
          -16.028505325317383,
          -14.533734321594238,
          -15.50760555267334,
          -13.10110092163086,
          -16.466726303100586,
          -14.387377738952637,
          -14.558728218078613,
          -14.114677429199219,
          -15.879446029663086,
          -16.02851676940918,
          -14.668243408203125,
          -17.939115524291992,
          -10.458918571472168,
          -11.66860294342041,
          -10.769630432128906,
          -11.749162673950195,
          -11.613960266113281,
          -11.67934513092041,
          -11.506993293762207,
          -13.640445709228516,
          -11.444998741149902,
          -10.990805625915527,
          -11.992609024047852,
          -11.051833152770996,
          -12.554625511169434,
          -12.138071060180664,
          -12.215166091918945,
          -11.298348426818848,
          -13.057896614074707,
          -11.802077293395996,
          -11.172024726867676,
          -13.593469619750977,
          -11.1051664352417,
          -12.278803825378418,
          -14.742188453674316,
          -13.624513626098633,
          -11.854788780212402,
          -16.015552520751953,
          -13.95228385925293,
          -13.929598808288574,
          -15.75998306274414,
          -15.300117492675781,
          -15.600991249084473,
          -16.438438415527344,
          -15.962347030639648,
          -17.10924530029297,
          -16.328006744384766,
          -16.25541877746582,
          -14.471693992614746,
          -14.70804500579834,
          -16.297653198242188,
          -12.745055198669434,
          -13.08325481414795,
          -12.264738082885742,
          -13.570121765136719,
          -13.199846267700195,
          -17.23832893371582,
          -16.0325927734375,
          -15.838339805603027,
          -14.449100494384766,
          -17.54448890686035,
          -14.472676277160645,
          -14.369009971618652,
          -11.259127616882324,
          -11.241586685180664,
          -11.16564655303955,
          -11.696975708007812,
          -10.629524230957031,
          -11.718764305114746,
          -12.202559471130371,
          -11.69134521484375,
          -12.518017768859863,
          -11.545552253723145,
          -10.270639419555664,
          -11.722517013549805,
          -10.750029563903809,
          -18.573463439941406,
          -18.30267333984375,
          -14.868929862976074,
          -16.323776245117188,
          -16.986724853515625,
          -16.300466537475586,
          -16.465044021606445,
          -16.121238708496094,
          -15.991500854492188,
          -16.961219787597656,
          -17.36432456970215,
          -15.248392105102539,
          -16.5437068939209,
          -15.720941543579102,
          -16.497047424316406,
          -12.198442459106445,
          -14.895672798156738,
          -16.58143424987793,
          -15.415570259094238,
          -17.468984603881836,
          -16.973941802978516,
          -14.472723960876465,
          -17.721494674682617,
          -13.908499717712402,
          -17.25748062133789
         ],
         "z": [
          -0.48415493965148926,
          -6.933775424957275,
          -5.140028476715088,
          -5.765667915344238,
          -1.026469349861145,
          -4.553251266479492,
          -6.788053035736084,
          -3.338512897491455,
          -6.477664947509766,
          -6.870485782623291,
          -6.312717914581299,
          -4.949681758880615,
          -4.719244480133057,
          -6.714395999908447,
          -6.888797760009766,
          -5.302797794342041,
          -3.603364944458008,
          -5.7620530128479,
          -5.504180431365967,
          -5.451229095458984,
          -1.754773497581482,
          -5.830965042114258,
          -3.334838390350342,
          -4.626461029052734,
          -6.007786273956299,
          -2.24214243888855,
          -3.9203951358795166,
          -8.368672370910645,
          -4.088873386383057,
          -6.252474308013916,
          -4.523413181304932,
          -7.58958625793457,
          -7.32334041595459,
          -7.263733863830566,
          -6.017366886138916,
          -6.602942943572998,
          -7.130037784576416,
          -6.451875686645508,
          -6.263692378997803,
          -6.340020179748535,
          -6.463441371917725,
          -6.330093860626221,
          -6.587779521942139,
          -6.285155773162842,
          -6.604739189147949,
          -6.335838794708252,
          -6.499907493591309,
          -4.253734588623047,
          -6.574897766113281,
          -6.247513771057129,
          -6.461629390716553,
          -1.360728144645691,
          -1.8253527879714966,
          -4.2177414894104,
          -5.2602152824401855,
          -2.281973123550415,
          -1.1998810768127441,
          -3.437190055847168,
          -2.5175812244415283,
          -2.3114118576049805,
          -4.816307544708252,
          -3.56778883934021,
          -3.2365033626556396,
          -2.046691417694092,
          -3.4909121990203857,
          -3.4279778003692627,
          -5.987387180328369,
          -6.217676639556885,
          -6.249998092651367,
          -4.7053117752075195,
          -4.527806282043457,
          -5.136596202850342,
          -6.010014057159424,
          -5.239480972290039,
          -5.20936393737793,
          -5.912710189819336,
          -2.982024908065796,
          -6.1499762535095215,
          -4.547298431396484,
          -5.012302875518799,
          -5.0133957862854,
          -5.494068622589111,
          -5.584421157836914,
          -5.588831901550293,
          -6.043522357940674,
          -2.7521116733551025,
          -5.486516952514648,
          -6.442264556884766,
          -5.8251752853393555,
          -2.0537753105163574,
          -7.682677745819092,
          -8.510226249694824,
          -7.240685939788818,
          -7.73695182800293,
          -7.336568832397461,
          -8.185402870178223,
          -8.256637573242188,
          -5.707413196563721,
          -8.242775917053223,
          -7.669823169708252,
          -7.123222351074219,
          -6.897960662841797,
          -5.946230888366699,
          -7.075456619262695,
          -5.446816444396973,
          -6.427515029907227,
          -7.287545204162598,
          -5.734737873077393,
          -6.4827423095703125,
          -3.6448440551757812,
          -6.5369791984558105,
          -7.414454936981201,
          -0.765368640422821,
          -4.174315929412842,
          -6.053696632385254,
          -1.2099077701568604,
          -3.370213031768799,
          -3.533334732055664,
          -1.8485620021820068,
          -1.1383745670318604,
          -3.1621792316436768,
          -0.611502468585968,
          -1.7197805643081665,
          -2.8500635623931885,
          -3.9067611694335938,
          -0.7987844347953796,
          -3.326378345489502,
          -1.4852861166000366,
          -2.2502706050872803,
          -4.513653755187988,
          -3.8356211185455322,
          -4.882072448730469,
          -2.9797990322113037,
          -4.0274128913879395,
          -1.625738263130188,
          -1.5417221784591675,
          -5.125356674194336,
          -6.103024482727051,
          -4.903584003448486,
          -5.528587341308594,
          -2.6794145107269287,
          -6.418857097625732,
          -6.197110176086426,
          -6.639581680297852,
          -5.897033214569092,
          -6.0745930671691895,
          -6.524253845214844,
          -6.226407527923584,
          -4.941376686096191,
          -6.261125087738037,
          -5.734434604644775,
          -6.47698974609375,
          -6.08341646194458,
          -6.4106855392456055,
          -0.9817137122154236,
          -1.388361930847168,
          -3.4706428050994873,
          -2.784533739089966,
          -2.6779849529266357,
          -3.13222599029541,
          -3.165391445159912,
          -4.640491008758545,
          -2.198925733566284,
          -4.499117851257324,
          -4.591620445251465,
          -3.157543182373047,
          -2.414297580718994,
          -4.912849426269531,
          -2.3170077800750732,
          -8.70190143585205,
          -4.535368919372559,
          -5.381048202514648,
          -7.920151710510254,
          -5.761022090911865,
          -6.712001800537109,
          -4.316093921661377,
          -2.2630138397216797,
          -2.9137978553771973,
          -5.0658392906188965
         ]
        },
        {
         "marker": {
          "color": "rgba(251, 128, 114, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 8,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          -0.16157656908035278,
          0.15423166751861572,
          -0.17687584459781647,
          -1.28054940700531,
          0.21375955641269684,
          -2.5616447925567627,
          -3.0202224254608154,
          -1.4151943922042847,
          -2.863831043243408,
          1.0990471839904785,
          -0.4150402247905731,
          -1.4690122604370117,
          -11.103476524353027,
          -0.1691625416278839,
          -2.4708406925201416,
          -1.5828388929367065,
          -0.2516637146472931,
          3.543043851852417,
          -0.3823775053024292,
          3.325946092605591,
          -0.9141373634338379,
          -1.6292195320129395,
          -1.35783052444458,
          -0.5436268448829651,
          -0.8295237421989441,
          -2.65995192527771,
          -1.7683762311935425,
          -1.23227858543396,
          -1.6341456174850464,
          -1.921139121055603,
          -2.0058372020721436,
          -3.035966634750366,
          -1.8596128225326538,
          -0.7151488065719604,
          -1.6095281839370728,
          0.7338882684707642,
          -2.402966022491455,
          -1.5958341360092163,
          -3.3810296058654785,
          -0.18362490832805634,
          -4.9542460441589355,
          -3.3022751808166504,
          -2.2300944328308105,
          -3.9021189212799072,
          -2.3455810546875,
          -0.6825240850448608,
          -2.674910545349121,
          -0.3550781011581421,
          -1.382484793663025,
          -2.906243085861206,
          -2.6572744846343994,
          -2.43422794342041,
          -1.343428134918213,
          -0.9123102426528931,
          -2.414853572845459,
          -0.8972333073616028,
          -0.3597951829433441,
          -0.6092586517333984,
          -1.0098567008972168,
          -2.835836172103882,
          -2.2843148708343506,
          -0.9595056176185608,
          -0.8233073949813843,
          -2.292461633682251,
          -0.687346875667572,
          -0.9812159538269043,
          -0.6621478199958801,
          -1.8495362997055054,
          -1.7407035827636719,
          -1.689937710762024,
          -2.8370585441589355,
          -2.976701021194458,
          -2.581181049346924,
          -2.4992127418518066,
          -3.714125394821167,
          -0.5891281366348267,
          -2.1158859729766846,
          -0.34822168946266174,
          -12.302939414978027,
          -3.239616870880127,
          -1.8877739906311035,
          -5.771195411682129,
          -6.019748687744141,
          -4.372987270355225,
          -0.27826908230781555,
          -6.866299629211426,
          -6.652362823486328,
          2.256918430328369,
          -6.874943256378174,
          -0.4910142123699188,
          -0.5875145792961121,
          -0.43685799837112427,
          0.10284221917390823,
          -0.6202135682106018,
          -1.9115371704101562,
          -0.3927057981491089,
          -2.514127731323242,
          -3.3847382068634033,
          0.41369277238845825,
          -2.3249218463897705,
          -0.8965171575546265,
          -1.0664514303207397,
          1.6470783948898315,
          2.6218984127044678,
          2.3090240955352783,
          -0.9953585267066956,
          1.65755295753479,
          2.489218235015869,
          2.4156510829925537,
          0.15140517055988312,
          2.812136650085449,
          1.757753849029541,
          2.864362955093384,
          2.679401397705078,
          0.277237206697464,
          -2.1607553958892822,
          -1.496523380279541,
          0.39066916704177856,
          -0.2472631335258484,
          -1.4818799495697021,
          0.3657974600791931,
          0.6293726563453674,
          0.36914902925491333,
          -1.4437462091445923,
          -0.014960494823753834,
          -0.43568870425224304,
          0.29839804768562317,
          -2.7002975940704346,
          -3.1363213062286377,
          -1.3884367942810059,
          -0.7140008807182312,
          -2.59879207611084,
          -2.4768197536468506,
          -2.79020094871521,
          0.9195737242698669,
          0.4437640607357025,
          -3.0326857566833496,
          -3.032930850982666,
          -0.19953307509422302,
          -2.798530101776123,
          -2.5117087364196777,
          -1.9568476676940918,
          -3.5379533767700195,
          -3.410677671432495,
          -6.556118488311768,
          -4.3121490478515625,
          -4.594820499420166,
          -5.469381332397461,
          -5.308681011199951,
          -5.004605770111084,
          -5.638632774353027,
          -4.781658172607422,
          -11.895265579223633,
          -2.0203006267547607,
          -3.5346240997314453,
          -1.7684130668640137,
          -1.7503432035446167,
          -1.3731616735458374,
          -2.274016857147217,
          -1.7902852296829224,
          -1.7090818881988525,
          1.6718850135803223,
          1.5816941261291504,
          1.4783393144607544,
          0.7382558584213257,
          1.563803791999817,
          -0.10745985805988312,
          0.8126714825630188,
          -3.285022735595703,
          1.8332552909851074,
          -0.6805346012115479,
          -4.917081356048584,
          -2.8348662853240967,
          1.1253012418746948
         ],
         "y": [
          -2.335360527038574,
          -7.7346272468566895,
          -5.5560784339904785,
          -8.926433563232422,
          -6.071552276611328,
          -6.264793395996094,
          -6.575736045837402,
          -8.405547142028809,
          -5.438358783721924,
          -7.370777606964111,
          -4.481733322143555,
          -9.145427703857422,
          -8.392160415649414,
          -4.195847988128662,
          -3.428785800933838,
          -5.9620842933654785,
          -4.357433795928955,
          -5.352654457092285,
          -3.6233720779418945,
          -5.232904434204102,
          -3.2911083698272705,
          -5.318873405456543,
          -4.313727378845215,
          -4.1214189529418945,
          -3.4871084690093994,
          -5.139627456665039,
          0.8883853554725647,
          -5.618924617767334,
          -5.365184307098389,
          -1.3600455522537231,
          -1.2894319295883179,
          1.698355793952942,
          0.21004408597946167,
          -4.10762357711792,
          -1.0820435285568237,
          0.8754655122756958,
          -0.9859659075737,
          -5.506242275238037,
          0.01678399182856083,
          -5.355037689208984,
          1.2326072454452515,
          -0.9040559530258179,
          -0.675254225730896,
          1.7896617650985718,
          -0.9679729342460632,
          0.9865584373474121,
          1.101410150527954,
          -4.5895514488220215,
          -4.6120829582214355,
          -0.6013191342353821,
          -0.5787487030029297,
          -2.4610464572906494,
          -1.6790746450424194,
          -1.281447410583496,
          -1.9935003519058228,
          -1.3365271091461182,
          -0.6925838589668274,
          -1.2000166177749634,
          -1.4735134840011597,
          -1.5731316804885864,
          -2.2235724925994873,
          -1.3561599254608154,
          -1.2928963899612427,
          -1.9041523933410645,
          -0.4287949502468109,
          -2.8260293006896973,
          -0.27590814232826233,
          -2.7205889225006104,
          -2.3933444023132324,
          -3.5023117065429688,
          1.5069018602371216,
          -3.8333802223205566,
          -5.485445022583008,
          0.19973020255565643,
          -6.952685356140137,
          -0.3836662173271179,
          -4.1724395751953125,
          -10.656527519226074,
          -1.6643508672714233,
          -5.138930797576904,
          1.9364230632781982,
          1.8100106716156006,
          1.8045839071273804,
          -2.22615122795105,
          -10.571366310119629,
          0.4892898201942444,
          0.6011685729026794,
          -2.7888548374176025,
          0.4072481095790863,
          -10.731918334960938,
          -1.3263813257217407,
          -0.009670021943747997,
          -0.5210273265838623,
          -0.41837137937545776,
          -0.26936468482017517,
          0.40215325355529785,
          -0.45149487257003784,
          1.8670446872711182,
          -0.1731099933385849,
          1.5758116245269775,
          -0.4192773103713989,
          -4.682238578796387,
          -6.594776630401611,
          -3.52463698387146,
          -2.14652681350708,
          -3.8317480087280273,
          -6.830428123474121,
          -2.8974239826202393,
          -3.047152042388916,
          -5.491374492645264,
          -1.9989722967147827,
          -5.689858913421631,
          -4.524102687835693,
          -3.9101083278656006,
          -0.08478618413209915,
          -7.90638542175293,
          -7.467137336730957,
          -7.2581257820129395,
          -8.763558387756348,
          -6.988485813140869,
          -6.93161678314209,
          -7.1290435791015625,
          -10.015509605407715,
          -8.129985809326172,
          -7.683114051818848,
          -6.928806781768799,
          -6.762292861938477,
          -5.459874153137207,
          -6.626316070556641,
          -6.695282936096191,
          -6.286172866821289,
          -5.5307183265686035,
          -6.176853656768799,
          -3.719045400619507,
          -7.008397579193115,
          -6.341485977172852,
          -6.194670677185059,
          -6.771040439605713,
          -7.142819404602051,
          1.4521442651748657,
          1.7438132762908936,
          1.8831089735031128,
          0.014522464014589787,
          0.3201521635055542,
          2.016523599624634,
          1.587417483329773,
          1.3536475896835327,
          1.2312177419662476,
          0.8828184604644775,
          0.5341009497642517,
          0.8882064819335938,
          0.5590283870697021,
          -5.794144153594971,
          -9.564743041992188,
          -5.151362895965576,
          -3.314129114151001,
          -6.26654052734375,
          -4.31486177444458,
          -3.495913505554199,
          -5.823446750640869,
          -5.485396862030029,
          -5.025003433227539,
          -5.27311372756958,
          -4.260406017303467,
          -1.8946603536605835,
          -5.640187740325928,
          -5.876474857330322,
          -3.865351676940918,
          -4.437758922576904,
          -3.007277727127075,
          -7.57647180557251,
          -5.453993797302246,
          -4.160566329956055,
          -2.1546709537506104
         ],
         "z": [
          6.5244574546813965,
          4.298973083496094,
          6.530811309814453,
          3.3163485527038574,
          6.041913032531738,
          6.870987415313721,
          3.8958427906036377,
          4.294079303741455,
          5.361408233642578,
          5.81116247177124,
          8.007184982299805,
          3.2318949699401855,
          7.105417728424072,
          5.6568708419799805,
          5.703893661499023,
          8.202545166015625,
          5.690670013427734,
          3.961014747619629,
          7.14064359664917,
          3.99360728263855,
          9.02164363861084,
          7.482443809509277,
          7.35653829574585,
          7.792703628540039,
          9.15381145477295,
          5.439960956573486,
          4.633840560913086,
          2.1687119007110596,
          1.950865387916565,
          7.385507583618164,
          6.6939873695373535,
          3.876417875289917,
          5.322096347808838,
          4.325260162353516,
          5.592494010925293,
          3.83769154548645,
          6.63026237487793,
          2.325263738632202,
          2.412457227706909,
          4.479692459106445,
          5.030158519744873,
          4.258852005004883,
          3.3196496963500977,
          2.765387535095215,
          2.5146114826202393,
          6.33440637588501,
          6.011269569396973,
          4.607758045196533,
          4.995482444763184,
          5.025672912597656,
          3.4679181575775146,
          10.293269157409668,
          9.337993621826172,
          9.110560417175293,
          9.781026840209961,
          9.81020736694336,
          10.143835067749023,
          10.382593154907227,
          9.884489059448242,
          9.194732666015625,
          10.411266326904297,
          10.435152053833008,
          10.225500106811523,
          9.914207458496094,
          5.4581217765808105,
          3.2587201595306396,
          5.740013599395752,
          4.1180291175842285,
          4.2219061851501465,
          3.4620730876922607,
          5.1688456535339355,
          4.956800937652588,
          2.797302484512329,
          5.322413444519043,
          3.348438262939453,
          6.027746677398682,
          3.540391445159912,
          10.27232551574707,
          7.233818054199219,
          3.510542869567871,
          3.3284223079681396,
          3.325801134109497,
          3.164818286895752,
          4.656958103179932,
          10.258200645446777,
          4.307090759277344,
          4.165774822235107,
          7.101991653442383,
          4.477790355682373,
          10.267870903015137,
          4.019381999969482,
          3.7904367446899414,
          3.960110902786255,
          4.580117702484131,
          3.2858948707580566,
          3.719355583190918,
          5.1747941970825195,
          3.3009674549102783,
          4.1602606773376465,
          3.8229317665100098,
          5.029813289642334,
          1.2859128713607788,
          4.037378311157227,
          4.3728485107421875,
          3.822932481765747,
          6.6785149574279785,
          4.138460159301758,
          3.9707229137420654,
          3.9524190425872803,
          1.89812171459198,
          3.5136988162994385,
          7.31431245803833,
          4.1313018798828125,
          4.254940986633301,
          2.9861807823181152,
          3.772451877593994,
          4.303273677825928,
          2.297518014907837,
          4.260953903198242,
          0.9171381592750549,
          2.5459978580474854,
          3.8694119453430176,
          10.193195343017578,
          4.6285552978515625,
          5.26862907409668,
          5.842716693878174,
          5.17963981628418,
          4.841660022735596,
          4.0710015296936035,
          4.307178974151611,
          5.923704624176025,
          5.916282653808594,
          4.617840766906738,
          5.508224964141846,
          4.903766632080078,
          6.155306339263916,
          5.595669269561768,
          3.8198888301849365,
          4.192324638366699,
          3.2218222618103027,
          3.6036508083343506,
          3.5155327320098877,
          3.777913808822632,
          2.6710524559020996,
          2.899770736694336,
          2.432058095932007,
          2.617152452468872,
          2.9591779708862305,
          3.8368475437164307,
          4.0997138023376465,
          2.9363114833831787,
          4.271831512451172,
          6.280550956726074,
          3.097072124481201,
          2.086261749267578,
          9.202387809753418,
          4.1802849769592285,
          9.41122817993164,
          9.109088897705078,
          8.897782325744629,
          9.379862785339355,
          6.970796585083008,
          4.537351608276367,
          6.798648357391357,
          6.362218856811523,
          3.073171854019165,
          2.0430853366851807,
          6.674989223480225,
          6.977803707122803,
          6.8921074867248535,
          6.955923557281494,
          8.40312385559082,
          6.863940715789795,
          6.511366367340088
         ]
        },
        {
         "marker": {
          "color": "rgba(128, 177, 211, 1.0)",
          "line": {
           "width": 1.3
          },
          "opacity": 0.8,
          "size": 12,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": 9,
         "textfont": {
          "color": "#4D5663"
         },
         "type": "scatter3d",
         "x": [
          -3.5452239513397217,
          0.8987004160881042,
          0.7113070487976074,
          0.76677405834198,
          1.5517014265060425,
          -5.101104259490967,
          -1.0601961612701416,
          0.17317542433738708,
          -6.136868953704834,
          -0.060231588780879974,
          -0.4307577908039093,
          -2.2882699966430664,
          -6.4795942306518555,
          -1.153012752532959,
          -0.7794856429100037,
          -1.0691170692443848,
          -0.5070387125015259,
          -2.2192330360412598,
          -0.9279105067253113,
          -1.7440407276153564,
          -2.753859519958496,
          -3.42671799659729,
          -0.6218461394309998,
          -4.308475971221924,
          -3.424391746520996,
          -4.5274338722229,
          -3.212934970855713,
          -4.345305919647217,
          -1.6678754091262817,
          -5.112109184265137,
          -2.0134782791137695,
          -4.028072834014893,
          -3.3288891315460205,
          -4.113256454467773,
          -3.605736255645752,
          -8.994102478027344,
          -9.648197174072266,
          -4.259121894836426,
          -6.145261764526367,
          -2.37394118309021,
          -2.418226480484009,
          -4.193965911865234,
          -4.139916896820068,
          -3.912768840789795,
          -4.244919776916504,
          -4.09126091003418,
          -3.608605146408081,
          -4.099870204925537,
          -3.8030147552490234,
          -7.7499589920043945,
          -3.884312629699707,
          -3.5599889755249023,
          -8.021580696105957,
          -2.158449172973633,
          -0.5793607831001282,
          -6.620200157165527,
          -2.9081857204437256,
          -7.6478800773620605,
          -4.666223049163818,
          -2.91481614112854,
          -2.8969552516937256,
          -2.91925311088562,
          -6.921403884887695,
          -3.4657881259918213,
          -9.367088317871094,
          -10.69479751586914,
          -10.022095680236816,
          -10.997507095336914,
          -9.755760192871094,
          -10.471936225891113,
          -10.339160919189453,
          -10.990245819091797,
          -10.650537490844727,
          -10.893157958984375,
          -10.08554744720459,
          -9.597884178161621,
          -9.572175979614258,
          -2.321605920791626,
          -6.032505989074707,
          -3.4721579551696777,
          -6.233365058898926,
          -0.005729478783905506,
          -6.5399651527404785,
          -3.8515615463256836,
          -3.6142213344573975,
          -6.312745094299316,
          -2.408769369125366,
          -7.229518890380859,
          -7.52880334854126,
          -5.223739147186279,
          -1.2023955583572388,
          -2.406672716140747,
          -1.7564573287963867,
          -4.0315093994140625,
          -1.2019113302230835,
          -2.7786712646484375,
          -1.1159764528274536,
          -1.2856892347335815,
          -1.1904006004333496,
          -2.5106115341186523,
          -3.571286916732788,
          0.8822445273399353,
          -2.801027536392212,
          -1.6019443273544312,
          0.5174892544746399,
          -0.035314369946718216,
          -4.705508232116699,
          0.5837446451187134,
          -4.942124366760254,
          0.39733657240867615,
          0.3234463632106781,
          0.7222546339035034,
          -1.1044061183929443,
          -2.551095962524414,
          0.9948933720588684,
          -1.9387518167495728,
          -4.83139181137085,
          -0.3318290114402771,
          -4.603866100311279,
          -5.227324485778809,
          -6.0109944343566895,
          -4.826846122741699,
          -1.29799222946167,
          -4.648032188415527,
          -5.025382041931152,
          -4.509164333343506,
          -4.286328315734863,
          -4.9305620193481445,
          -5.169703483581543,
          -3.0391526222229004,
          -4.735513687133789,
          -5.432796001434326,
          -5.496824741363525,
          -3.0655100345611572,
          -5.150146007537842,
          -1.8831006288528442,
          -4.178787708282471,
          -3.6008310317993164,
          -6.631713390350342,
          -6.568338871002197,
          -7.794665813446045,
          -4.3895158767700195,
          -5.766277313232422,
          -4.2099833488464355,
          -4.317129135131836,
          -5.618536949157715,
          -5.002274990081787,
          -3.2450146675109863,
          -4.601253032684326,
          -5.656275749206543,
          -3.7573347091674805,
          -5.037494659423828,
          -7.0247297286987305,
          -6.677652835845947,
          -10.065397262573242,
          -7.903085231781006,
          -7.904557228088379,
          -8.098923683166504,
          -4.216858863830566,
          -4.201270580291748,
          -8.729108810424805,
          -1.0699952840805054,
          -3.9289650917053223,
          0.19364136457443237,
          5.242171287536621,
          -4.200894832611084,
          -3.973729372024536,
          -2.8062546253204346,
          -4.030859470367432,
          -1.6586061716079712,
          -5.067908763885498,
          -6.371127605438232,
          -5.902195453643799,
          -4.293332099914551,
          -3.0899105072021484,
          -4.727687835693359,
          -5.011448860168457,
          -0.5729548931121826,
          -5.565677642822266,
          -3.591493606567383
         ],
         "y": [
          6.2141900062561035,
          10.732292175292969,
          10.139453887939453,
          11.143545150756836,
          9.170663833618164,
          13.285693168640137,
          -7.940405368804932,
          9.45600414276123,
          13.533422470092773,
          11.444572448730469,
          12.233986854553223,
          6.5655717849731445,
          11.762133598327637,
          10.755566596984863,
          8.768488883972168,
          10.08327579498291,
          10.329419136047363,
          12.423651695251465,
          10.973310470581055,
          8.497230529785156,
          7.053796768188477,
          6.990411281585693,
          9.441194534301758,
          6.640681266784668,
          7.668744087219238,
          -6.756194114685059,
          -6.4502363204956055,
          11.919219017028809,
          12.725125312805176,
          6.724958896636963,
          9.543999671936035,
          -6.064614772796631,
          -6.443902969360352,
          -6.560335636138916,
          -6.215483665466309,
          -1.0925471782684326,
          -0.6780577898025513,
          -6.454477787017822,
          12.80986499786377,
          11.554337501525879,
          11.647439002990723,
          7.576629638671875,
          7.796771049499512,
          9.899489402770996,
          9.531002044677734,
          7.886047840118408,
          9.352054595947266,
          7.881032943725586,
          9.753850936889648,
          11.13195514678955,
          9.546371459960938,
          5.438201904296875,
          9.371904373168945,
          5.654523849487305,
          -4.513395309448242,
          11.219331741333008,
          5.155284881591797,
          9.919486999511719,
          8.52518367767334,
          5.138667583465576,
          5.15177059173584,
          10.542475700378418,
          9.61723804473877,
          11.467488288879395,
          -0.4737580120563507,
          -0.6972350478172302,
          0.029107850044965744,
          -0.7746095061302185,
          -0.7347769141197205,
          -0.5612821578979492,
          -0.17616461217403412,
          -0.3101782202720642,
          0.11739662289619446,
          -0.8892012238502502,
          -0.8781147003173828,
          -0.15736667811870575,
          -1.2064143419265747,
          11.249374389648438,
          10.769349098205566,
          11.899808883666992,
          10.902691841125488,
          8.371675491333008,
          10.291570663452148,
          12.226974487304688,
          8.286294937133789,
          11.275747299194336,
          12.305252075195312,
          11.397576332092285,
          11.231154441833496,
          12.474898338317871,
          12.135167121887207,
          10.737773895263672,
          11.596725463867188,
          12.153912544250488,
          10.207104682922363,
          11.986929893493652,
          12.136144638061523,
          12.043828010559082,
          10.423619270324707,
          11.152774810791016,
          12.549439430236816,
          9.326777458190918,
          10.672612190246582,
          6.179229259490967,
          7.689123153686523,
          7.840329170227051,
          5.644383907318115,
          8.078897476196289,
          5.847241401672363,
          7.602556228637695,
          -5.878284454345703,
          8.373934745788574,
          7.490850925445557,
          8.37104606628418,
          7.335646152496338,
          6.8211212158203125,
          6.394490718841553,
          12.394442558288574,
          6.452043056488037,
          8.629375457763672,
          8.281880378723145,
          8.72381591796875,
          8.670578002929688,
          6.8155927658081055,
          8.394925117492676,
          7.429281711578369,
          7.136112689971924,
          12.032958030700684,
          6.526446342468262,
          10.525069236755371,
          9.986067771911621,
          9.217979431152344,
          9.995776176452637,
          9.345136642456055,
          7.838392734527588,
          12.76759147644043,
          9.332334518432617,
          11.126167297363281,
          9.732451438903809,
          9.275304794311523,
          10.18766975402832,
          11.639954566955566,
          12.666860580444336,
          11.671326637268066,
          10.815666198730469,
          11.9705171585083,
          13.164933204650879,
          12.341290473937988,
          12.745698928833008,
          11.731030464172363,
          12.305394172668457,
          10.297494888305664,
          12.453042984008789,
          12.207681655883789,
          0.33506157994270325,
          0.2921890318393707,
          0.30532148480415344,
          0.19982406497001648,
          -4.658197402954102,
          2.2165589332580566,
          -1.0658572912216187,
          11.975008010864258,
          -5.625916957855225,
          11.545854568481445,
          1.7092149257659912,
          2.062174081802368,
          -5.2132463455200195,
          10.473968505859375,
          8.536468505859375,
          11.328756332397461,
          10.560187339782715,
          12.91752815246582,
          11.640753746032715,
          9.344059944152832,
          9.404285430908203,
          9.262243270874023,
          8.489307403564453,
          8.778897285461426,
          10.058999061584473,
          7.257660388946533
         ],
         "z": [
          4.153817176818848,
          1.8563268184661865,
          2.017605781555176,
          1.8954007625579834,
          0.934510350227356,
          0.8980085849761963,
          -0.4560340642929077,
          2.372796058654785,
          2.220562219619751,
          2.7022452354431152,
          1.8653817176818848,
          0.2510356605052948,
          3.820190668106079,
          2.534221887588501,
          2.9237594604492188,
          2.7204854488372803,
          3.4082529544830322,
          3.3505821228027344,
          2.160252094268799,
          2.770977258682251,
          2.3276846408843994,
          2.283174514770508,
          3.0303211212158203,
          4.477685451507568,
          3.7662129402160645,
          -3.049593687057495,
          -3.03337025642395,
          1.4674897193908691,
          2.566132068634033,
          0.9630584716796875,
          -0.8602898716926575,
          -3.510307788848877,
          -3.076331853866577,
          -3.169595956802368,
          -3.3002071380615234,
          -1.7908830642700195,
          -1.6569396257400513,
          -3.3491718769073486,
          2.7834722995758057,
          4.058655261993408,
          4.057628631591797,
          5.435980796813965,
          5.57108736038208,
          2.5587427616119385,
          2.136270046234131,
          5.563952922821045,
          3.9014759063720703,
          5.690803527832031,
          3.768275499343872,
          3.201664686203003,
          3.5669021606445312,
          6.446746349334717,
          2.6645667552948,
          6.9406561851501465,
          3.1719696521759033,
          4.2951436042785645,
          7.045725345611572,
          2.048830509185791,
          -0.4578186273574829,
          7.070099353790283,
          7.062145233154297,
          0.702146053314209,
          2.076268196105957,
          4.292128562927246,
          -1.1985838413238525,
          -1.3448234796524048,
          -1.5836031436920166,
          -1.2162203788757324,
          0.41804203391075134,
          -1.1987264156341553,
          -1.0067076683044434,
          -0.3263910412788391,
          -0.47420015931129456,
          -1.6638295650482178,
          -1.3522887229919434,
          -0.9434458613395691,
          -0.4273045063018799,
          0.928360641002655,
          5.063099384307861,
          4.424432754516602,
          4.43352746963501,
          9.38079833984375,
          2.9416792392730713,
          4.202037811279297,
          3.2986090183258057,
          4.213424205780029,
          3.3474464416503906,
          3.3314952850341797,
          3.1574625968933105,
          2.939375400543213,
          -0.3032200336456299,
          -0.5966781973838806,
          -0.7059921622276306,
          1.5690134763717651,
          -0.19022706151008606,
          0.1970559060573578,
          0.09765657782554626,
          -0.4213085174560547,
          -0.07448218017816544,
          -1.230575680732727,
          1.6448737382888794,
          -1.2945724725723267,
          -0.7768455147743225,
          2.8872382640838623,
          -0.4859846234321594,
          -1.5127800703048706,
          1.5751370191574097,
          -0.6137477159500122,
          1.3650131225585938,
          -0.4683651924133301,
          1.4285974502563477,
          -0.7761644721031189,
          0.953112006187439,
          1.0660701990127563,
          -0.38243502378463745,
          0.27856534719467163,
          4.551403045654297,
          1.5362794399261475,
          4.469351291656494,
          0.10482241958379745,
          0.5561321973800659,
          -0.3723442852497101,
          2.653322696685791,
          1.9035511016845703,
          -0.4724498391151428,
          1.7553956508636475,
          1.9813388586044312,
          1.8946480751037598,
          0.8943776488304138,
          -1.5813803672790527,
          -0.48941805958747864,
          -0.3396601378917694,
          1.1629506349563599,
          2.347252130508423,
          -0.7453425526618958,
          2.7550461292266846,
          0.5999251008033752,
          3.0156943798065186,
          0.7984657883644104,
          0.49349287152290344,
          1.3036388158798218,
          -0.34458860754966736,
          1.842875361442566,
          -0.28185731172561646,
          1.2231954336166382,
          1.6185272932052612,
          0.7165954113006592,
          -0.134721577167511,
          -0.028158199042081833,
          1.6283528804779053,
          -0.35634300112724304,
          1.2286934852600098,
          1.0623972415924072,
          1.2438963651657104,
          -0.8277313709259033,
          -1.526956558227539,
          -1.5903428792953491,
          -1.4469149112701416,
          -3.51767897605896,
          -14.44665813446045,
          -1.8865114450454712,
          2.0736563205718994,
          -3.5436041355133057,
          3.214747428894043,
          7.116480827331543,
          -14.536808967590332,
          -3.5508482456207275,
          0.24412795901298523,
          1.3624029159545898,
          1.7647836208343506,
          2.7693138122558594,
          2.6243536472320557,
          1.3114138841629028,
          2.71907901763916,
          1.794679045677185,
          3.01986026763916,
          2.7951812744140625,
          3.668999433517456,
          3.1330723762512207,
          4.058205604553223
         ]
        }
       ],
       "layout": {
        "legend": {
         "bgcolor": "#F5F6F9",
         "font": {
          "color": "#4D5663"
         }
        },
        "paper_bgcolor": "#F5F6F9",
        "plot_bgcolor": "#F5F6F9",
        "scene": {
         "xaxis": {
          "gridcolor": "#9499A3",
          "showgrid": true,
          "tickfont": {
           "color": "#4D5663"
          },
          "title": "",
          "titlefont": {
           "color": "#4D5663"
          },
          "zerolinecolor": "#9499A3"
         },
         "yaxis": {
          "gridcolor": "#9499A3",
          "showgrid": true,
          "tickfont": {
           "color": "#4D5663"
          },
          "title": "",
          "titlefont": {
           "color": "#4D5663"
          },
          "zerolinecolor": "#9499A3"
         },
         "zaxis": {
          "gridcolor": "#9499A3",
          "showgrid": true,
          "tickfont": {
           "color": "#4D5663"
          },
          "title": "",
          "titlefont": {
           "color": "#4D5663"
          },
          "zerolinecolor": "#9499A3"
         }
        },
        "title": "T-SNE 3D demo",
        "titlefont": {
         "color": "#4D5663"
        }
       }
      },
      "text/html": [
       "<div id=\"72e7236e-b4b4-43c7-8cdc-eb81d079a029\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"72e7236e-b4b4-43c7-8cdc-eb81d079a029\", [{\"type\": \"scatter3d\", \"x\": [2.644545555114746, 0.03308841213583946, -1.1813353300094604, -1.8606873750686646, -2.511894702911377, 2.9136877059936523, 3.5985608100891113, -1.5059148073196411, -0.37507161498069763, 4.730902194976807, 2.3637795448303223, 1.1334855556488037, -0.42548826336860657, 2.0898375511169434, -1.010321021080017, 1.603029727935791, -2.150287389755249, -0.4557243585586548, 2.032132148742676, -1.231459379196167, -0.49044322967529297, 0.8546522259712219, -2.2519729137420654, 0.7782018780708313, 1.742220163345337, 0.5687474608421326, -0.3724197447299957, 0.08703026920557022, 0.9939014911651611, 0.30537375807762146, 1.386106014251709, 3.045429229736328, 2.337897777557373, 1.720536470413208, 0.9367567300796509, 0.5722203850746155, 0.6567646265029907, 3.533115863800049, 3.506016492843628, 1.8850548267364502, 1.2332979440689087, 0.9685823917388916, -1.5980215072631836, 1.1206222772598267, 2.36203932762146, 1.9457670450210571, 4.745760917663574, -0.991393506526947, 3.673412561416626, 2.623690366744995, 1.0392217636108398, 2.0958778858184814, 4.209120273590088, 3.4068050384521484, 4.317223072052002, 4.270819187164307, 4.827152729034424, 4.510911464691162, 3.6158556938171387, 0.4231966733932495, 1.9309958219528198, 5.516477584838867, 4.472803115844727, 4.32534646987915, 4.280980110168457, -1.4626933336257935, 1.5180964469909668, -1.533578634262085, 0.7174404859542847, 1.2539626359939575, -1.4014054536819458, 1.0087313652038574, -2.67923641204834, -1.7085020542144775, -2.0054633617401123, 0.9860870242118835, 0.4405594766139984, -1.444814920425415, 2.799365997314453, 2.7119829654693604, 0.8627581000328064, 2.139770746231079, 1.5694608688354492, 3.3068041801452637, -0.8770229816436768, -1.9512728452682495, -1.230717658996582, -2.504639148712158, 3.5486538410186768, 2.5957884788513184, 1.6662949323654175, 4.325659275054932, 4.418684959411621, 5.298583984375, 4.668051242828369, 3.9108848571777344, 5.054770469665527, 2.8771181106567383, 5.471211910247803, 4.353833198547363, 5.344956398010254, 2.310926675796509, 2.2371435165405273, 5.686141490936279, 5.650480270385742, 2.6145570278167725, 5.221519947052002, 5.321629524230957, 2.7225825786590576, 5.2155232429504395, 2.6549668312072754, 3.7892539501190186, 2.4910104274749756, 4.22224760055542, 5.366903305053711, 2.1096179485321045, 0.5800105929374695, 2.1149206161499023, -1.733886957168579, -1.939658761024475, -1.7320433855056763, 2.4193434715270996, 1.5785276889801025, 1.7003239393234253, 2.298651695251465, 2.7283501625061035, 1.3125557899475098, 5.803750038146973, 1.635360836982727, 1.9851796627044678, 3.82065486907959, -1.8325811624526978, 0.23366659879684448, 0.051943425089120865, -1.9094544649124146, 0.8382778763771057, 2.592280149459839, 0.8770537376403809, 1.4837019443511963, -1.1695820093154907, 4.65665864944458, 3.6780190467834473, 2.7248988151550293, 4.476814270019531, 4.002392768859863, 3.5420963764190674, 3.755396842956543, 3.8239705562591553, 2.5800724029541016, 3.697172164916992, 3.752075672149658, 4.631152153015137, 3.320222854614258, -0.422157883644104, -0.03288615494966507, -0.646160900592804, -2.345409870147705, 2.0882558822631836, -1.3978296518325806, 1.9143792390823364, 0.4781865179538727, -1.195197582244873, 2.6881978511810303, -1.6869139671325684, 0.7946316599845886, 3.1751246452331543, 2.446516275405884, 0.9900432825088501, 2.168485641479492, -1.6152288913726807, -0.27808400988578796, 2.1292901039123535, -1.9773379564285278, -0.02765979990363121, -0.20242446660995483, 1.0449535846710205, 0.8490106463432312, -2.3051249980926514], \"y\": [22.25951385498047, 24.176992416381836, 21.785917282104492, 21.6221923828125, 22.031354904174805, 20.663576126098633, 22.18168830871582, 21.353479385375977, 21.871112823486328, 24.358537673950195, 23.859846115112305, 20.992475509643555, 21.518888473510742, 21.987396240234375, 23.586763381958008, 21.514801025390625, 22.300647735595703, 22.935653686523438, 24.723316192626953, 20.681760787963867, 21.49909782409668, 22.73981475830078, 21.190357208251953, 21.48859977722168, 24.10454750061035, 21.8496036529541, 23.607816696166992, 25.32268714904785, 23.357746124267578, 24.255584716796875, 24.184267044067383, 20.775020599365234, 24.454856872558594, 24.287187576293945, 21.94518280029297, 24.184837341308594, 22.172443389892578, 20.0750732421875, 21.845598220825195, 24.89164161682129, 23.971771240234375, 22.4375, 23.668365478515625, 25.217287063598633, 23.314563751220703, 22.065385818481445, 22.657054901123047, 23.456146240234375, 22.182384490966797, 23.060401916503906, 23.75383186340332, 23.382192611694336, 20.340822219848633, 25.105375289916992, 20.695077896118164, 20.183908462524414, 24.429460525512695, 19.90261459350586, 25.93440055847168, 22.893051147460938, 18.496692657470703, 21.518667221069336, 19.791566848754883, 20.480581283569336, 20.689334869384766, 22.081148147583008, 21.466463088989258, 21.804676055908203, 21.767803192138672, 23.625791549682617, 20.070341110229492, 20.803449630737305, 20.794973373413086, 20.401165008544922, 23.063987731933594, 21.795438766479492, 20.691116333007812, 19.941112518310547, 24.755348205566406, 25.666807174682617, 24.604598999023438, 24.19566535949707, 23.756603240966797, 19.10026741027832, 23.789737701416016, 21.877145767211914, 21.742843627929688, 21.219993591308594, 22.576732635498047, 22.581567764282227, 19.438962936401367, 24.7239933013916, 24.304594039916992, 21.37442398071289, 23.674558639526367, 22.952415466308594, 24.00343894958496, 24.740615844726562, 23.664749145507812, 22.893613815307617, 24.750272750854492, 21.62708282470703, 22.75641632080078, 21.91501808166504, 22.938018798828125, 21.511615753173828, 21.74382781982422, 21.788978576660156, 25.998085021972656, 22.07013702392578, 26.15476417541504, 25.966556549072266, 20.82691764831543, 24.581233978271484, 21.26730728149414, 21.776660919189453, 21.088899612426758, 21.731582641601562, 21.903663635253906, 21.668790817260742, 21.8953914642334, 21.437814712524414, 22.28543472290039, 21.59790802001953, 21.597572326660156, 18.64767837524414, 21.58429718017578, 21.842910766601562, 19.146902084350586, 20.296953201293945, 25.649499893188477, 19.78982162475586, 20.811487197875977, 20.94723129272461, 21.729326248168945, 22.05788230895996, 22.012544631958008, 19.963525772094727, 19.995195388793945, 19.612173080444336, 23.733240127563477, 23.25984001159668, 25.124048233032227, 22.88530158996582, 22.77019691467285, 22.925060272216797, 22.934106826782227, 25.677261352539062, 25.210227966308594, 25.552379608154297, 22.844675064086914, 22.99800682067871, 22.506160736083984, 21.126319885253906, 20.274538040161133, 22.1842041015625, 19.122529983520508, 20.39008140563965, 19.44737434387207, 19.90376853942871, 19.80162239074707, 19.639263153076172, 25.570632934570312, 20.693735122680664, 22.424694061279297, 23.716524124145508, 22.889015197753906, 24.479137420654297, 22.615829467773438, 21.601348876953125, 25.2949275970459, 23.41631317138672, 24.186105728149414, 25.37824249267578, 25.199295043945312, 24.524431228637695, 19.998912811279297, 22.526391983032227], \"z\": [-1.9292606115341187, -2.5914926528930664, -7.3494720458984375, -1.5264109373092651, -5.996274948120117, -4.520977020263672, -7.276357650756836, -8.084244728088379, -8.63754940032959, -6.866645812988281, -6.43996000289917, -8.826441764831543, -8.426254272460938, -4.787093639373779, -7.119477272033691, -8.215618133544922, -5.33062744140625, -5.462334156036377, -5.656154632568359, -8.300060272216797, -8.51948070526123, -7.140420436859131, -7.507429599761963, -8.88784408569336, -6.395082950592041, -7.314884185791016, -2.2752878665924072, -6.363030433654785, -2.6778037548065186, -1.4142754077911377, -0.07165339589118958, -4.406280517578125, -3.131192445755005, -2.744267702102661, -3.5837018489837646, -2.901963233947754, -2.956057071685791, -6.68018102645874, -5.836273670196533, -7.788674354553223, -6.482784271240234, -7.1286540031433105, -6.458746433258057, -7.5867204666137695, -6.1115593910217285, -6.9685139656066895, -2.978332042694092, -5.420497894287109, -2.485715866088867, -8.05246353149414, -8.481369018554688, -3.8719968795776367, -2.1112051010131836, -2.4325995445251465, -1.1351313591003418, -1.7650721073150635, -3.7392656803131104, -3.830408811569214, -5.5082807540893555, -1.3451792001724243, -6.268732070922852, -2.3536977767944336, -1.544303297996521, -0.5138711333274841, -2.3502237796783447, -3.69229793548584, 0.8639624118804932, -4.143296718597412, -2.817782163619995, -6.441438674926758, -5.060263633728027, -0.7109747529029846, -7.903613567352295, -5.312132358551025, -5.221382141113281, -4.023004531860352, -5.410628318786621, -4.939663410186768, -0.4147368371486664, -3.9236836433410645, -1.0299053192138672, -2.8502607345581055, -2.8419904708862305, -7.221343994140625, -2.8432812690734863, -2.6855814456939697, -6.314162254333496, -6.605260848999023, -3.306826591491699, -2.0118699073791504, -3.3604657649993896, -2.9239821434020996, -3.079122543334961, -3.961977005004883, -2.0969815254211426, -3.240055561065674, -2.3188059329986572, -0.383673757314682, -5.168666839599609, -2.1128933429718018, -2.187486410140991, -1.956154227256775, -5.977368354797363, -6.496505260467529, -3.9816174507141113, -6.943090915679932, -7.944777011871338, -7.9180402755737305, -4.915209770202637, -3.28794264793396, -5.013430118560791, -5.341499328613281, -2.1093246936798096, -4.396109104156494, -3.9975194931030273, -1.1679614782333374, -2.4302878379821777, 0.5975602269172668, 0.36931952834129333, -0.5692277550697327, 0.3466615378856659, 0.3113330006599426, 0.7957611680030823, 0.808590829372406, 0.27480655908584595, -6.838045597076416, 1.193999171257019, -6.516894340515137, -5.765609264373779, -5.828574180603027, -6.548303127288818, -7.029991149902344, -5.196873664855957, -5.553402423858643, -2.086463212966919, -1.6483289003372192, -1.6013069152832031, -4.954973220825195, -5.918783664703369, -6.90612268447876, -2.9889705181121826, -6.657566070556641, -2.3090152740478516, -5.89799165725708, -5.582448482513428, -4.600179195404053, -4.76690673828125, -6.36293363571167, -6.8597259521484375, -6.7194108963012695, -4.220125198364258, -5.670261383056641, -3.0905652046203613, -6.059903144836426, -6.688298225402832, -6.0354156494140625, -7.725232124328613, -5.200483322143555, -8.041502952575684, -2.2775235176086426, -7.597530841827393, -8.215959548950195, -4.137556552886963, -6.633802890777588, -1.6257325410842896, -6.5853776931762695, -6.886780738830566, -8.423072814941406, -2.477160930633545, -4.975984573364258, -6.818063735961914, -1.520279049873352, -6.5103912353515625, -6.389538764953613, -4.749855041503906, -8.234357833862305, -7.900266170501709, -5.110470294952393], \"mode\": \"markers\", \"name\": 0, \"marker\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-10.827566146850586, -11.909122467041016, -11.305717468261719, -12.903533935546875, -12.534194946289062, -12.346872329711914, -12.307214736938477, -11.602080345153809, -12.780597686767578, -12.966633796691895, -10.946525573730469, -9.92597770690918, -12.905599594116211, -12.122573852539062, -12.58407211303711, -12.6441068649292, -11.21564769744873, -12.181347846984863, -11.21117877960205, -13.072080612182617, -11.5850248336792, -13.467394828796387, -12.65672492980957, -10.465242385864258, -11.917826652526855, -10.545066833496094, -8.642694473266602, -8.828369140625, -8.061355590820312, -8.110196113586426, -6.3602752685546875, -13.368795394897461, -9.113539695739746, -8.548568725585938, -8.671355247497559, -8.389947891235352, -9.568779945373535, -9.377766609191895, -8.490273475646973, -11.696104049682617, -10.55137825012207, -10.265970230102539, -11.469453811645508, -10.639190673828125, 13.748291015625, -11.224167823791504, -11.033990859985352, -10.97247314453125, -12.228050231933594, -10.267788887023926, -10.454047203063965, -10.768467903137207, 14.184226036071777, 13.449821472167969, 13.321700096130371, 13.736357688903809, 13.599352836608887, 13.52845573425293, 14.046616554260254, 13.2211332321167, 14.026569366455078, 12.928370475769043, 14.04179573059082, -5.733801364898682, 14.552776336669922, -7.7613043785095215, -7.555898189544678, -7.907632827758789, -6.491315841674805, -6.5335469245910645, -7.583098888397217, -8.04887866973877, -7.495293617248535, -8.429256439208984, -8.08998966217041, -7.456004619598389, -8.086626052856445, -7.810412406921387, -9.89983081817627, -8.758214950561523, -8.125533103942871, -5.3304057121276855, -7.033037185668945, 13.371352195739746, -6.0597100257873535, -8.248050689697266, -8.526755332946777, -9.926668167114258, -9.042177200317383, -8.971946716308594, -6.662446975708008, 13.455527305603027, 13.466410636901855, 13.645353317260742, 14.593564987182617, 14.332561492919922, 14.1117525100708, 14.475223541259766, 14.308937072753906, 13.568138122558594, 14.08556079864502, 14.274847030639648, 14.383922576904297, 14.061666488647461, -5.201333522796631, -6.280808925628662, -9.439273834228516, -6.279049873352051, -9.390647888183594, -8.876214027404785, -9.733814239501953, -9.206414222717285, -9.05965518951416, -6.038912296295166, -8.249279975891113, -10.405864715576172, -9.388751029968262, -12.059313774108887, -12.192066192626953, -12.509997367858887, -7.131499290466309, -12.396586418151855, -11.217509269714355, -9.362257957458496, -9.504068374633789, -12.60523509979248, -9.6105318069458, -9.48205280303955, -10.11495590209961, -12.875414848327637, -11.982316017150879, -12.412790298461914, -12.810571670532227, -11.118916511535645, -10.345826148986816, -12.061213493347168, -9.436575889587402, -12.481501579284668, -9.037550926208496, -10.490727424621582, -9.76076889038086, -10.477005958557129, -11.202588081359863, -11.761089324951172, -12.092497825622559, -11.925593376159668, -12.115891456604004, -12.305166244506836, -12.075262069702148, -12.00821590423584, -12.035648345947266, -11.831503868103027, -11.938721656799316, -12.271206855773926, -12.29833698272705, -11.787409782409668, -11.179159164428711, -10.026984214782715, -9.932075500488281, -10.646199226379395, -11.141708374023438, -10.465107917785645, -10.321433067321777, -11.154510498046875, -11.596464157104492, -10.807507514953613, -10.313669204711914, -10.350810050964355, -10.559351921081543, -6.169316291809082, -6.757174491882324, -7.51202917098999, -5.885586261749268, -7.409930229187012, -7.318585395812988, -6.175550937652588, -5.042765140533447, -6.081454753875732, -6.386892795562744, -7.114294528961182, -5.375392913818359, -5.376293659210205], \"y\": [-4.184731483459473, -2.4871349334716797, -1.2325547933578491, -2.1476402282714844, -1.8157031536102295, -1.4614334106445312, -1.9841479063034058, -2.1650314331054688, -3.050720453262329, -2.2791333198547363, -4.110365867614746, -9.39643383026123, -1.392618179321289, 1.1305358409881592, -0.9726213812828064, -0.17304782569408417, -0.32710108160972595, 0.09231075644493103, -0.4894208312034607, -2.16263747215271, -0.4459267258644104, -2.432382822036743, -0.2299826443195343, -1.6553964614868164, -2.5007309913635254, -1.5809317827224731, -7.073297500610352, -4.885290622711182, -5.839223861694336, -10.00139331817627, -7.683035850524902, -2.3967082500457764, -7.9815826416015625, -5.345093250274658, -5.045544624328613, -6.247196197509766, -8.054810523986816, -5.468915939331055, -10.607678413391113, 1.3126368522644043, -1.141910433769226, -0.9937639832496643, -0.542533814907074, -1.1897557973861694, -7.880704402923584, -0.8732361793518066, -1.9332401752471924, -2.4349889755249023, -1.7345863580703735, -1.0912736654281616, -1.0579053163528442, -0.484576016664505, -6.895153045654297, -8.009840965270996, -8.227214813232422, -8.68260383605957, -8.212570190429688, -8.927892684936523, -8.160848617553711, -8.421318054199219, -7.9686479568481445, -8.638541221618652, -7.059431552886963, -9.756778717041016, -6.010536193847656, -7.676952838897705, -10.099018096923828, -10.199301719665527, -7.34100866317749, -7.444638252258301, -5.362453460693359, -8.926629066467285, -5.168266773223877, -9.932950973510742, -10.37427043914795, -9.049175262451172, -8.81424617767334, -7.797077178955078, -6.1078200340271, -5.4367499351501465, -5.661554336547852, -8.863814353942871, -8.28874683380127, -9.261943817138672, -5.922898769378662, -10.776016235351562, -7.259383201599121, -7.530503273010254, -8.283665657043457, -6.501480579376221, -5.504086494445801, -9.049112319946289, -9.023128509521484, -9.501691818237305, -5.871133804321289, -7.112838268280029, -7.6776957511901855, -6.25387716293335, -7.196028709411621, -9.026862144470215, -7.366619110107422, -6.336265563964844, -6.194252014160156, -8.06201457977295, -7.754131317138672, -7.841803073883057, -7.307444095611572, -7.381941795349121, -8.246374130249023, -9.600674629211426, -7.136697292327881, -9.462654113769531, -6.87540864944458, -6.4388203620910645, -6.538257122039795, -8.626861572265625, -8.777498245239258, -2.6072120666503906, -1.964064598083496, -5.94359016418457, -6.755452632904053, -4.296993255615234, -6.747904300689697, -9.097959518432617, -6.48012113571167, -5.014648914337158, -8.38864803314209, -8.58858871459961, -9.645350456237793, -6.946598052978516, 2.0794358253479004, -4.91234016418457, 0.26123300194740295, -7.2413482666015625, -6.432297706604004, -0.2945283055305481, -6.155461311340332, -1.8480299711227417, -5.860062122344971, -5.664259910583496, -7.528328895568848, -8.121729850769043, -8.029393196105957, 1.6566225290298462, 1.9948441982269287, 0.3173580467700958, 1.4295073747634888, 1.8614689111709595, 2.4313676357269287, 2.4290924072265625, 2.7162318229675293, 1.9640926122665405, 0.3128484785556793, 1.9365031719207764, 2.18473744392395, 2.512389898300171, -6.01318359375, -10.137521743774414, -10.335636138916016, -6.179143905639648, -7.466185092926025, -10.316793441772461, -8.169886589050293, -7.461458206176758, -6.59722375869751, -6.503052234649658, -6.528499603271484, -5.9073686599731445, -5.99923849105835, -10.520843505859375, -8.517810821533203, -10.356085777282715, -10.008685111999512, -7.984958648681641, -9.725578308105469, -7.501064300537109, -8.587014198303223, -5.457345485687256, -6.555988311767578, -9.570831298828125, -8.484935760498047, -8.185859680175781], \"z\": [8.216835975646973, 2.7501862049102783, 4.3673272132873535, 4.214907646179199, 5.6060872077941895, 5.090933799743652, 6.377938270568848, 4.992412090301514, 5.092120170593262, 4.167708873748779, 8.081120491027832, 9.250310897827148, 2.88070011138916, 2.766906976699829, 2.6548357009887695, 2.190154552459717, 3.078521728515625, 2.3211910724639893, 3.8932430744171143, 2.7041075229644775, 3.1095476150512695, 2.0486624240875244, 2.0879619121551514, 3.5159075260162354, 2.7265326976776123, 3.1176061630249023, 7.632228374481201, 5.751526355743408, 6.026551723480225, 8.731374740600586, 9.8975830078125, 2.1702075004577637, 8.458090782165527, 6.318399906158447, 5.926570892333984, 8.228814125061035, 10.680869102478027, 10.50156021118164, 7.218724727630615, 4.657943248748779, 6.664333820343018, 4.459747791290283, 4.735278606414795, 6.613256931304932, 10.158440589904785, 4.646866321563721, 6.646491527557373, 6.835513591766357, 4.510189056396484, 5.362056732177734, 5.9895195960998535, 4.694235324859619, 8.737723350524902, 9.7448148727417, 8.7872314453125, 8.98465347290039, 7.641672134399414, 9.084696769714355, 7.855481147766113, 8.078290939331055, 7.9857025146484375, 7.988214015960693, 8.327959060668945, 8.534163475036621, 8.3378324508667, 6.81044864654541, 8.369301795959473, 8.09942626953125, 5.724946975708008, 5.778990268707275, 9.798503875732422, 6.0823140144348145, 9.703640937805176, 5.890573501586914, 6.461719036102295, 6.5609588623046875, 5.788365840911865, 6.047486305236816, 10.191986083984375, 11.38203239440918, 9.675158500671387, 7.799160480499268, 7.817317008972168, 10.409672737121582, 8.514512062072754, 8.573502540588379, 7.318488597869873, 8.173089027404785, 9.291983604431152, 9.2286376953125, 8.488640785217285, 10.0855131149292, 10.349488258361816, 10.143784523010254, 8.707046508789062, 9.855874061584473, 9.96664810180664, 8.926997184753418, 9.748351097106934, 10.037096977233887, 9.551153182983398, 9.160361289978027, 9.241886138916016, 9.95088005065918, 8.408488273620605, 9.13671588897705, 10.126965522766113, 7.458561420440674, 9.361599922180176, 6.384341239929199, 10.346393585205078, 8.590277671813965, 10.623109817504883, 7.689265251159668, 8.72296142578125, 7.713599681854248, 8.993642807006836, 6.146723747253418, 5.8919997215271, 7.051689147949219, 8.716550827026367, 6.856541156768799, 10.67857837677002, 8.253110885620117, 9.943920135498047, 7.13579797744751, 8.316609382629395, 8.161541938781738, 6.802364349365234, 7.044095516204834, 5.898270606994629, 7.011117935180664, 1.9829432964324951, 10.381963729858398, 10.288970947265625, 5.300385475158691, 9.435563087463379, 6.184915065765381, 11.714577674865723, 10.75485610961914, 11.183302879333496, 9.229645729064941, 9.285008430480957, 5.573055744171143, 4.694080829620361, 4.574207782745361, 3.164231061935425, 3.1227669715881348, 4.423942565917969, 4.364450931549072, 3.8934097290039062, 5.6128363609313965, 4.496248722076416, 3.8342273235321045, 3.269373893737793, 4.78983736038208, 9.356736183166504, 8.247152328491211, 7.652048587799072, 11.502643585205078, 9.32398796081543, 8.241077423095703, 10.171581268310547, 9.918570518493652, 11.125935554504395, 11.590723037719727, 10.259759902954102, 11.29261589050293, 11.539640426635742, 8.344965934753418, 6.524571895599365, 8.9097900390625, 8.444796562194824, 7.5806121826171875, 9.49682331085205, 7.330178260803223, 7.740687370300293, 9.858963966369629, 7.905205249786377, 8.362271308898926, 7.842913627624512, 8.095987319946289], \"mode\": \"markers\", \"name\": 1, \"marker\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.48753610253334045, 9.342896461486816, 5.920720100402832, 0.5340273976325989, -0.5768459439277649, -0.7002596259117126, -0.5440384745597839, -0.9355037212371826, -1.2001891136169434, 6.799711227416992, 3.9255945682525635, 0.16667887568473816, 0.7469857931137085, 5.529292106628418, 3.986828565597534, 4.822013854980469, 5.723148822784424, 4.32041072845459, 7.230229377746582, 7.1137166023254395, 4.877756118774414, 5.217931270599365, 5.3250603675842285, 7.316779613494873, 7.031344890594482, 5.750073432922363, 4.680910110473633, 5.216151714324951, 3.757751226425171, 4.423910140991211, 3.8926637172698975, 4.9139909744262695, 5.351200580596924, 4.839890003204346, 3.708493232727051, 3.5841658115386963, 3.887220621109009, 3.5433969497680664, 5.996980667114258, 8.694512367248535, 9.467896461486816, 9.694934844970703, 9.705801963806152, 8.073246002197266, 8.239194869995117, 9.094963073730469, 9.817119598388672, 8.207430839538574, 9.057477951049805, 8.153432846069336, 9.265279769897461, 0.15686911344528198, 7.65172004699707, 8.604114532470703, 8.567939758300781, 7.435904026031494, 7.733501434326172, 7.031217098236084, 7.736171722412109, 7.789455890655518, 5.0481767654418945, 7.415810585021973, 8.219293594360352, 5.537779331207275, 7.69680118560791, 3.898101329803467, 4.767670154571533, 4.634403705596924, 4.423253536224365, 4.506598472595215, 4.1608381271362305, 4.2346930503845215, 4.432117938995361, 5.3253397941589355, 3.8891544342041016, 3.622177839279175, 3.5049526691436768, 3.617863893508911, 5.152515411376953, 6.2199482917785645, 4.433529376983643, 4.910932540893555, 6.647972106933594, 4.0372209548950195, 8.423776626586914, 4.900318622589111, 6.2963385581970215, 3.87650465965271, 5.444586277008057, 6.146601676940918, 3.5618555545806885, 5.618246078491211, 8.52247428894043, 6.403207302093506, 7.13467264175415, 8.3141508102417, 7.992909908294678, 7.501036167144775, 8.16124439239502, 7.73394250869751, 7.5649919509887695, 8.314526557922363, 8.750493049621582, 6.662895202636719, 4.70881986618042, 7.691251754760742, 6.414530277252197, 7.114837169647217, 9.045122146606445, 6.253516674041748, 7.746669292449951, 8.563700675964355, 4.781879425048828, 7.731500625610352, 5.756507873535156, 5.703646659851074, 4.316622734069824, 5.1402692794799805, 4.35775089263916, 4.095414161682129, 4.84674596786499, 3.6314966678619385, 4.012618541717529, 2.91635799407959, 3.9765655994415283, 3.0923633575439453, 3.3960349559783936, 5.993826866149902, 8.586572647094727, 6.5414557456970215, 6.275485038757324, 6.807520866394043, 8.053889274597168, 6.635629177093506, 7.6771063804626465, 7.806852340698242, 7.460266590118408, 6.594245910644531, 7.470962047576904, 6.935745716094971, 8.406828880310059, 8.82966423034668, 8.207500457763672, 8.038198471069336, 9.145187377929688, 8.740948677062988, 8.919992446899414, 8.561885833740234, 8.675537109375, 7.977952480316162, 7.792421340942383, 5.957779884338379, 8.891460418701172, 5.806069850921631, 8.3233003616333, 9.204745292663574, 7.910576820373535, 6.815467834472656, 8.151593208312988, 3.9385364055633545, 8.311202049255371, 5.760833740234375, 7.505275726318359, 5.864363193511963, 7.884149074554443, 3.3405802249908447, 6.41190242767334, 8.122574806213379, 7.9350104331970215, 7.9210286140441895, 9.411046981811523, 7.395853042602539, 5.109996318817139, 6.391575336456299, 7.969184875488281, 9.345258712768555, 9.788956642150879], \"y\": [-3.0230133533477783, -5.803776741027832, -6.646180152893066, -3.1597909927368164, -2.4828293323516846, -2.3433947563171387, -2.937822103500366, -2.322186231613159, -2.0848731994628906, -10.913689613342285, -5.759332180023193, -2.8852438926696777, -3.2230634689331055, -10.925117492675781, -10.654276847839355, -4.499629974365234, -9.665587425231934, -10.208765983581543, -12.334656715393066, -9.960440635681152, -4.40047550201416, -9.822434425354004, -10.631241798400879, -12.643016815185547, -12.849943161010742, -9.801929473876953, -8.601359367370605, -8.804906845092773, -9.417587280273438, -11.217595100402832, -9.524253845214844, -8.21703815460205, -9.665761947631836, -8.435726165771484, -10.551716804504395, -9.431286811828613, -8.66014289855957, -10.642617225646973, -9.334747314453125, -6.32099723815918, -4.810490608215332, -7.83773946762085, -5.001193046569824, -6.41934061050415, -5.7355427742004395, -4.429324150085449, -6.187462329864502, -8.819232940673828, -9.93310260772705, -9.424782752990723, -8.798408508300781, -3.622349500656128, -2.381507396697998, -4.265542030334473, -4.096609592437744, -5.662094593048096, -5.7116475105285645, -5.160619735717773, -5.732185363769531, -3.613231658935547, -8.773444175720215, -10.995110511779785, -5.2571892738342285, -7.393367767333984, -5.844871997833252, -8.741111755371094, -8.377230644226074, -7.686216831207275, -5.049793720245361, -6.750277042388916, -4.617552280426025, -4.545808792114258, -5.7304534912109375, -8.945582389831543, -12.144099235534668, -7.702841758728027, -7.377834796905518, -8.397455215454102, -10.821002006530762, -9.754030227661133, -11.981307029724121, -9.837611198425293, -12.935803413391113, -11.673752784729004, -9.783019065856934, -12.61043930053711, -12.631281852722168, -4.458306312561035, -12.721665382385254, 0.27218011021614075, -8.374934196472168, -7.964495658874512, -11.519248008728027, -7.309785842895508, -7.067631244659424, -3.929759979248047, -5.6713409423828125, -4.083427906036377, -4.278022289276123, -8.33504581451416, -5.783756256103516, -3.567812204360962, -7.635630130767822, -10.07242202758789, -5.443800449371338, -3.6675033569335938, -3.2658684253692627, -4.048700332641602, -4.525984764099121, -1.7722610235214233, -6.292186737060547, -7.659564971923828, -5.395066738128662, -2.6741631031036377, -10.629714012145996, -7.236163139343262, -7.150862693786621, -5.637694358825684, -7.994674205780029, -10.809659004211426, -7.881167888641357, -7.5290985107421875, -4.649866580963135, -8.49604606628418, -12.201005935668945, -10.050792694091797, -7.584517478942871, -2.929123878479004, -2.2800185680389404, -2.474308729171753, -1.5423648357391357, -1.0183888673782349, -1.2073591947555542, -1.5771859884262085, -5.140833854675293, -0.6957600116729736, -4.486873626708984, -1.7786870002746582, -3.7313809394836426, -2.786655902862549, -9.760163307189941, -10.548978805541992, -9.179364204406738, -7.044344425201416, -8.926294326782227, -8.329384803771973, -8.691298484802246, -8.864411354064941, -8.303722381591797, -12.114180564880371, -7.721554756164551, -4.98110818862915, -8.64352035522461, -6.423591136932373, -1.6374300718307495, -3.9323582649230957, -0.37985745072364807, -7.0665154457092285, -0.7088648676872253, -9.083423614501953, -1.4760186672210693, -11.0220947265625, -10.075287818908691, -2.2343106269836426, -7.846498489379883, -8.48452377319336, -6.319341659545898, -12.068151473999023, -9.43150520324707, -11.897432327270508, -10.565208435058594, -6.623371124267578, -7.179174423217773, -6.3657546043396, -7.063424587249756, -8.10330581665039, -9.568429946899414], \"z\": [13.081997871398926, 17.51533317565918, 18.596454620361328, 13.791665077209473, 13.713499069213867, 13.735552787780762, 13.188928604125977, 13.747230529785156, 13.861645698547363, 16.760478973388672, 18.320281982421875, 13.790016174316406, 13.892999649047852, 15.14416790008545, 14.642023086547852, 14.828497886657715, 13.069965362548828, 14.518391609191895, 15.796555519104004, 13.34091567993164, 14.447178840637207, 13.82674789428711, 14.688305854797363, 15.640652656555176, 15.57707691192627, 12.844115257263184, 17.645322799682617, 17.311370849609375, 17.022335052490234, 16.90280532836914, 15.13888168334961, 16.972387313842773, 17.183530807495117, 16.26658821105957, 16.72413444519043, 15.8154296875, 17.357946395874023, 16.77614974975586, 16.36362648010254, 17.501197814941406, 16.020191192626953, 15.97821044921875, 16.13930320739746, 16.169240951538086, 15.869599342346191, 15.641743659973145, 16.66248893737793, 16.934467315673828, 15.34618091583252, 16.991321563720703, 15.883705139160156, 13.316110610961914, 17.7568416595459, 20.307512283325195, 20.145545959472656, 20.058753967285156, 20.26122283935547, 18.78605079650879, 20.243473052978516, 18.713232040405273, 18.18583869934082, 17.398962020874023, 20.28758430480957, 16.70880126953125, 20.274187088012695, 12.751047134399414, 12.493386268615723, 13.942596435546875, 13.551274299621582, 12.844311714172363, 13.112722396850586, 13.255538940429688, 13.262901306152344, 12.45284366607666, 16.100120544433594, 13.377217292785645, 13.290375709533691, 13.283239364624023, 16.07564926147461, 16.11756706237793, 15.928165435791016, 14.240092277526855, 15.66114330291748, 15.80513858795166, 14.681000709533691, 15.930338859558105, 15.808135986328125, 15.521710395812988, 15.868448257446289, 11.63801383972168, 14.098136901855469, 17.899112701416016, 15.141097068786621, 16.995393753051758, 16.77592658996582, 17.32029914855957, 17.72783660888672, 17.111154556274414, 17.54372787475586, 16.838876724243164, 18.22320556640625, 17.309938430786133, 15.286474227905273, 16.86497688293457, 18.250228881835938, 18.383949279785156, 16.916053771972656, 17.39310073852539, 15.742141723632812, 16.9420108795166, 17.099515914916992, 15.62519645690918, 18.2977237701416, 17.53416633605957, 16.247251510620117, 17.80048370361328, 14.291086196899414, 15.56667423248291, 13.704442977905273, 16.24686622619629, 16.001611709594727, 16.74109649658203, 15.663398742675781, 16.564952850341797, 15.936542510986328, 16.635059356689453, 16.475513458251953, 16.433868408203125, 17.11330795288086, 16.461660385131836, 16.778902053833008, 16.77367401123047, 16.241485595703125, 17.12515640258789, 15.777256965637207, 16.015546798706055, 18.034263610839844, 18.06739616394043, 16.962717056274414, 18.064319610595703, 15.515357971191406, 14.693791389465332, 15.360334396362305, 14.390057563781738, 15.797721862792969, 14.361010551452637, 14.016501426696777, 15.077579498291016, 14.502897262573242, 15.384842872619629, 15.152931213378906, 15.771039009094238, 13.969176292419434, 18.720535278320312, 15.410653114318848, 15.289288520812988, 15.845248222351074, 16.941831588745117, 16.190046310424805, 13.140289306640625, 15.54455852508545, 16.026193618774414, 13.234776496887207, 16.65988540649414, 16.649322509765625, 13.149500846862793, 13.453786849975586, 15.504497528076172, 15.244528770446777, 15.473670959472656, 14.488847732543945, 13.305045127868652, 13.7070951461792, 13.470211029052734, 14.186084747314453, 15.330533981323242, 14.464659690856934], \"mode\": \"markers\", \"name\": 2, \"marker\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [7.3015546798706055, 7.413646697998047, 7.079817771911621, 9.41799545288086, 7.8926496505737305, 9.116058349609375, 8.641244888305664, 8.530816078186035, 8.805084228515625, 8.285299301147461, 8.461874008178711, 8.587034225463867, 7.770370960235596, 9.038240432739258, 8.48620319366455, 8.037731170654297, 8.393963813781738, 8.388808250427246, 9.901891708374023, 7.614129543304443, 9.537302017211914, 8.875494956970215, 9.280976295471191, 9.145796775817871, 8.079692840576172, 6.743386268615723, 6.792569637298584, 4.669057369232178, 8.504585266113281, 4.764706134796143, 6.141941070556641, 5.10050630569458, 5.931851863861084, 5.940941333770752, 4.908916473388672, 6.9559197425842285, 6.850910663604736, 6.987812519073486, 8.250082969665527, 8.474345207214355, 5.894638538360596, 5.125760555267334, 7.765382289886475, 4.940516948699951, 4.465898513793945, 4.691445827484131, 4.6430559158325195, 5.0326762199401855, 5.137178897857666, 5.465907096862793, 6.051137447357178, 6.333110332489014, 4.809304237365723, 0.39993351697921753, 1.2319936752319336, 0.5986347198486328, 1.0111987590789795, 0.36060038208961487, 3.6950836181640625, -0.16849970817565918, 0.6116019487380981, 0.3035270571708679, 0.6335434317588806, 0.5618917942047119, 1.2769150733947754, 1.2266126871109009, 4.06983757019043, 3.6076669692993164, 4.2194671630859375, 4.097118377685547, 4.791540622711182, 4.271080017089844, 4.794374942779541, 5.963459014892578, 4.087339401245117, 4.07149076461792, 6.898747444152832, 6.849942207336426, 4.766132831573486, 6.862674713134766, 7.272140026092529, 8.185503959655762, 9.24951171875, 9.148548126220703, 9.293006896972656, 6.025407791137695, 6.079094409942627, 8.214132308959961, 7.250162601470947, 7.561081886291504, 8.512157440185547, 6.155101299285889, 8.579785346984863, 8.379480361938477, 6.8668694496154785, 7.507997035980225, 8.296615600585938, 8.5652494430542, 8.624847412109375, 7.207060813903809, 8.692774772644043, 8.642618179321289, 7.997570991516113, 9.040600776672363, 7.261545658111572, 8.35949993133545, 8.171317100524902, 7.158025741577148, 6.129117965698242, 6.211386680603027, 6.556643009185791, 5.0654296875, 6.274228572845459, 8.180363655090332, 8.325225830078125, -5.2500319480896, 7.966953277587891, 6.513846397399902, 5.712750434875488, 6.547682285308838, 7.8892011642456055, 8.602629661560059, 7.78570556640625, 8.567706108093262, 6.688238143920898, 7.206857681274414, 7.922371864318848, 7.3681960105896, 6.358635902404785, 8.350835800170898, 7.963878631591797, 7.552842140197754, 6.7603678703308105, 6.8904852867126465, 6.523571491241455, 6.321026802062988, 5.064694881439209, 4.876662731170654, 4.969051361083984, 6.914379596710205, 7.962066173553467, 7.3277587890625, 4.4863080978393555, 6.349786281585693, 6.1473188400268555, 5.964600563049316, 6.856779098510742, 8.907320022583008, 6.164173126220703, 8.19694995880127, 6.458999156951904, 7.515409469604492, 7.7584547996521, 6.4070963859558105, 9.258638381958008, 8.656461715698242, 7.742297172546387, 6.472586631774902, 4.975527286529541, 7.792771339416504, 7.679525375366211, 7.563621997833252, 7.779302597045898, 8.53715705871582, 7.360236644744873, 7.252785682678223, 6.83721923828125, 6.148585796356201, 6.5689167976379395, 7.037393569946289, 6.081777572631836, 8.328965187072754, 6.31028938293457, 8.779223442077637, 8.926855087280273, 9.299132347106934, 5.537827968597412, 8.805577278137207, 8.64305591583252, 8.154556274414062, 5.01324462890625, 6.297050476074219, 7.359136581420898], \"y\": [7.1785359382629395, 3.864008903503418, 1.3133739233016968, 4.630995273590088, 2.2634544372558594, 4.30478572845459, 3.6939890384674072, 2.092458724975586, 2.133413553237915, 3.210071086883545, 1.2485584020614624, 1.7851381301879883, -2.5580968856811523, 0.987450897693634, 3.796293258666992, 1.3320999145507812, 2.302276134490967, 3.970040798187256, 2.8655712604522705, 1.9913325309753418, 3.089046001434326, 2.1676244735717773, 2.236450433731079, 2.5259580612182617, 1.719977855682373, 0.9696843028068542, 7.097827911376953, 5.292856693267822, 7.434632778167725, 5.4091691970825195, 5.008094787597656, 4.865855693817139, 5.672499656677246, 5.553225040435791, 5.394509315490723, 4.7270660400390625, 5.058369159698486, 4.693751811981201, 7.745229244232178, 3.719390630722046, 4.623905181884766, 8.57890510559082, 11.08814525604248, 8.135305404663086, 8.077716827392578, 7.736551284790039, 8.153565406799316, 7.9978485107421875, 7.953851699829102, 7.974357604980469, 7.091980934143066, 7.3569746017456055, 8.862397193908691, 6.97905969619751, 6.540913105010986, 6.278901100158691, 7.19066047668457, 7.802128791809082, 5.940244197845459, 6.156862258911133, 6.98833703994751, 7.825969696044922, 5.931926250457764, 6.341174602508545, 7.101954460144043, 6.909090042114258, 5.358790397644043, 6.213089942932129, 4.626309871673584, 4.298932075500488, 5.955036640167236, 5.340080261230469, 6.414392948150635, 4.984899997711182, 5.527099132537842, 6.250779628753662, 5.1043829917907715, 5.1283159255981445, 4.392301559448242, 4.28283166885376, 5.054572105407715, 6.028068542480469, 5.316318988800049, 4.782440185546875, 4.5940728187561035, 4.127394676208496, 3.689979076385498, 5.063234329223633, 5.7853498458862305, 6.195620059967041, 6.1464104652404785, 2.8238604068756104, 9.368953704833984, 8.292845726013184, 9.069997787475586, 8.60964584350586, 7.55056619644165, 8.318000793457031, 10.269136428833008, 10.397805213928223, 10.769248962402344, 9.16501522064209, 10.920327186584473, 6.821186542510986, 10.32992172241211, 8.066303253173828, 8.522756576538086, 7.173116207122803, 6.140641212463379, 7.6940789222717285, 5.826387405395508, 8.025869369506836, 7.439008712768555, 7.80825662612915, 7.6835856437683105, -12.01269817352295, 7.898909091949463, 8.36392593383789, 8.244439125061035, 5.141961574554443, 7.113368988037109, -2.004786491394043, 6.866845607757568, 3.1962218284606934, 1.4604192972183228, 5.353181838989258, 0.9971900582313538, 2.680790662765503, 8.676675796508789, 5.23794412612915, 0.8092613220214844, 6.060222148895264, 5.710188865661621, 9.262499809265137, 7.39066219329834, 2.7000203132629395, 5.687589168548584, 7.465916156768799, 7.793002605438232, 6.952779293060303, 2.1715011596679688, 7.536888599395752, 6.5605998039245605, 8.180418968200684, 6.949100494384766, 8.3487548828125, 6.215232849121094, 5.947609901428223, 8.137346267700195, 7.896887302398682, 8.606088638305664, 6.926698684692383, 7.155182361602783, 5.245785236358643, 6.18391227722168, 7.633050441741943, 6.422194480895996, 2.4297497272491455, 3.0902750492095947, 2.1590843200683594, -1.7285085916519165, -1.5511311292648315, -2.4158542156219482, -1.6515036821365356, -1.1453649997711182, 1.4924074411392212, 2.643249750137329, 1.111543893814087, 2.510246992111206, 2.9808223247528076, 3.688323736190796, -0.25383463501930237, 1.944154977798462, -1.8047997951507568, -0.0382850207388401, -0.2637055814266205, 3.670882225036621, -0.6044549942016602, 0.41956353187561035, 2.968255043029785, 4.68057918548584, 2.0011773109436035, 3.9870824813842773], \"z\": [3.457082748413086, 7.813357353210449, 10.625985145568848, 8.951018333435059, 7.202033996582031, 9.027458190917969, 9.509380340576172, 8.508039474487305, 10.058058738708496, 9.733043670654297, 8.575311660766602, 9.186284065246582, 5.96522331237793, 10.05478286743164, 9.933396339416504, 10.333454132080078, 7.640806198120117, 10.218793869018555, 9.48549747467041, 11.274240493774414, 8.854496002197266, 9.982268333435059, 10.093697547912598, 8.892887115478516, 10.935257911682129, 10.966038703918457, 3.4117183685302734, 5.760101318359375, 7.823007106781006, 6.461649417877197, 3.705294370651245, 7.5353007316589355, 5.406838417053223, 5.414632797241211, 6.045984745025635, 7.275136470794678, 3.5640647411346436, 3.3654794692993164, 7.498910903930664, 6.760550498962402, 7.769204139709473, 3.118394374847412, 5.502676486968994, 4.221892833709717, 4.631917953491211, 2.954195022583008, 4.27570915222168, 2.5102415084838867, 2.958331346511841, 2.4414215087890625, 1.768036961555481, 2.2810137271881104, 2.3046460151672363, 9.590048789978027, 10.563082695007324, 11.353801727294922, 9.805440902709961, 9.7677583694458, 11.30720329284668, 10.213329315185547, 10.078442573547363, 9.92353630065918, 10.341127395629883, 10.80351448059082, 10.147517204284668, 10.224152565002441, 6.959818363189697, 7.8176655769348145, 5.910393238067627, 9.306009292602539, 8.305523872375488, 7.314127445220947, 8.817092895507812, 6.337478160858154, 7.90092134475708, 8.909493446350098, 1.9332506656646729, 1.992470383644104, 5.418702125549316, 2.4268975257873535, 4.580986976623535, 5.5728230476379395, 5.379965305328369, 4.5948405265808105, 4.61843204498291, 10.531536102294922, 10.39426040649414, 7.162641525268555, 3.6482954025268555, 5.001523971557617, 3.8537964820861816, 7.211933612823486, 6.1578803062438965, 3.6898040771484375, 2.9432592391967773, 2.7600600719451904, 4.8364644050598145, 3.8751556873321533, 6.242915630340576, 4.603460788726807, 6.289338111877441, 6.385032653808594, 5.683082580566406, 4.873601913452148, 4.5842108726501465, 8.143477439880371, 8.291282653808594, 8.694341659545898, 9.463286399841309, 9.10683536529541, 9.577226638793945, 7.882725238800049, 9.07645034790039, 8.713706016540527, 8.847810745239258, -3.343414306640625, 9.151348114013672, 9.504532814025879, 7.359191417694092, 9.048007011413574, 10.318567276000977, 5.229144096374512, 10.506729125976562, 6.85231351852417, 9.883637428283691, 10.106297492980957, 8.24681568145752, 9.000930786132812, 7.063814163208008, 7.200260639190674, 8.348262786865234, 8.129061698913574, 9.944450378417969, 2.889303207397461, 7.299322605133057, 7.5644850730896, 8.23703670501709, 8.841851234436035, 8.103852272033691, 7.125003337860107, 6.456498622894287, 5.822904586791992, 7.900754451751709, 7.253457069396973, 3.282724618911743, 3.8693795204162598, 3.240403175354004, 5.89702844619751, 3.410221815109253, 5.506599426269531, 3.925466537475586, 6.7483601570129395, 4.344146251678467, 5.498439311981201, 5.983231544494629, 6.231650352478027, 4.34853458404541, 8.48622989654541, 9.226417541503906, 6.629359722137451, 6.177629470825195, 5.9769768714904785, 5.998683929443359, 7.252555847167969, 5.992919921875, 7.322041034698486, 8.840625762939453, 6.970469951629639, 7.833456039428711, 8.283370018005371, 2.3362534046173096, 5.39408540725708, 2.3070385456085205, 5.121795177459717, 5.31194543838501, 5.044065475463867, 2.072270631790161, 5.322558403015137, 5.844764232635498, 6.983829498291016, 4.602605819702148, 2.2854599952697754, 5.413284778594971], \"mode\": \"markers\", \"name\": 3, \"marker\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-17.475631713867188, -16.9200439453125, -16.779300689697266, -17.3725643157959, -18.362926483154297, -15.99202823638916, -14.958146095275879, -17.1932430267334, -17.288366317749023, -16.64014434814453, -16.43488121032715, -15.077937126159668, -17.483543395996094, -16.035764694213867, -16.77069854736328, -17.181533813476562, -17.857561111450195, -18.836952209472656, -18.860429763793945, -17.33972930908203, -17.249568939208984, -18.888463973999023, -17.15690803527832, -16.83964729309082, -16.815723419189453, -16.440338134765625, -16.880521774291992, -17.93008804321289, -19.08321189880371, -18.221040725708008, -18.948444366455078, -17.06877326965332, -20.204471588134766, -15.401065826416016, -21.748117446899414, -17.80739402770996, -18.635290145874023, -17.243412017822266, -19.30828857421875, -19.847984313964844, -18.297382354736328, -16.9330997467041, -19.21842384338379, -18.28573226928711, -16.68873405456543, -19.48590850830078, -18.077537536621094, -16.682510375976562, -17.856081008911133, -16.879377365112305, -19.266130447387695, -18.948246002197266, -17.714859008789062, -21.17378807067871, -19.904176712036133, -19.370073318481445, -17.915176391601562, -19.148733139038086, -19.86643409729004, -19.939531326293945, -21.923114776611328, -19.687210083007812, -18.93956184387207, -19.149442672729492, -17.189393997192383, -17.55948829650879, -16.163740158081055, -16.42409324645996, -16.056486129760742, -17.855098724365234, -17.852113723754883, -19.621604919433594, -15.297622680664062, -22.014265060424805, -15.061985969543457, -22.280719757080078, -15.189435005187988, -22.131532669067383, -19.860668182373047, -21.138683319091797, -19.742414474487305, -19.085100173950195, -20.949913024902344, -19.464548110961914, -22.037817001342773, -22.557777404785156, -21.139108657836914, -19.356395721435547, -22.03240966796875, -21.729068756103516, -17.879589080810547, -17.967140197753906, -15.393442153930664, -15.172039985656738, -14.717047691345215, -15.471721649169922, -22.4145450592041, -14.651443481445312, -17.01142120361328, -17.254627227783203, -14.496809005737305, -13.491331100463867, -14.884119033813477, -14.117115020751953, -13.891798973083496, -14.872306823730469, -14.013284683227539, -14.827863693237305, -15.07956600189209, -14.556427001953125, -14.76125431060791, -16.6553897857666, -17.482324600219727, -14.554553031921387, -16.807344436645508, -14.694486618041992, -17.594263076782227, -19.02825927734375, -18.88616180419922, -18.259449005126953, -21.367347717285156, -17.022502899169922, -18.31441307067871, -18.328750610351562, -20.311399459838867, -20.20806312561035, -17.71664810180664, -19.045501708984375, -16.818326950073242, -22.154335021972656, -22.41827964782715, -22.550125122070312, -21.742185592651367, -21.719758987426758, -21.004127502441406, -21.05904197692871, -21.82407569885254, -18.114713668823242, -19.710264205932617, -19.623271942138672, -19.409099578857422, -21.020841598510742, -18.63784408569336, -20.591102600097656, -19.317956924438477, -18.457120895385742, -20.508085250854492, -19.25472640991211, -20.043235778808594, -19.351797103881836, -19.422616958618164, -19.842121124267578, -17.636667251586914, -20.140214920043945, -19.062105178833008, -16.61094093322754, -16.964670181274414, -17.197771072387695, -18.709362030029297, -16.68568229675293, -0.7213875651359558, -0.7671758532524109, -19.368436813354492, -16.925567626953125, -16.805282592773438, -17.164466857910156, -0.6628260016441345, -17.977924346923828, -17.40603256225586, -19.380779266357422, -18.900787353515625, -18.99045753479004, -16.954164505004883, -17.566144943237305, -18.21288299560547, -20.495525360107422, -16.734569549560547, -17.36549186706543, -20.21017074584961, -19.358144760131836, -19.08414649963379], \"y\": [1.3763108253479004, -0.8642842769622803, -0.18564866483211517, -1.3922797441482544, -0.061121173202991486, -1.3161226511001587, -4.597584247589111, -0.25225716829299927, 0.08347262442111969, -2.390944242477417, -1.6633461713790894, -4.516882419586182, -1.405064344406128, -5.284055709838867, -5.272739410400391, -3.8789172172546387, -5.00050163269043, -3.3332018852233887, -4.232583045959473, -4.979456424713135, -4.631378173828125, -4.176174163818359, -3.780022382736206, -3.053952693939209, -5.152273654937744, -2.023808479309082, -2.8237578868865967, -3.266784429550171, -0.5571475028991699, -2.436776638031006, -3.1764023303985596, -2.929800510406494, -0.4154728949069977, -3.640127420425415, 0.3351626694202423, -0.9489519000053406, -2.713541030883789, -1.2696365118026733, -3.5696299076080322, -4.661483287811279, -3.4086177349090576, -3.0434908866882324, -3.891988515853882, -2.95988392829895, -0.7163217067718506, -3.893519401550293, -3.498169422149658, -1.3861767053604126, -2.3192665576934814, -1.1064105033874512, -3.7100021839141846, -6.139007091522217, -6.170920372009277, -4.5376152992248535, -4.786737442016602, -3.8550446033477783, -6.149044036865234, -6.556962490081787, -5.293094158172607, -5.788503170013428, -5.1773762702941895, -3.509835720062256, -6.833011627197266, -6.178643703460693, -4.005849361419678, -4.277078151702881, -1.228192687034607, -3.7157175540924072, -3.68741774559021, -3.721937894821167, -3.985443115234375, -6.111423969268799, -6.7680583000183105, -5.240442752838135, -6.266303539276123, -4.375089168548584, -6.463327884674072, -2.211951494216919, -2.2744150161743164, -3.326772451400757, -0.4755805432796478, -3.2801601886749268, -3.142165422439575, 1.67550528049469, -2.851680278778076, 0.5837539434432983, -3.331151008605957, -1.1768951416015625, -2.1842117309570312, 0.7144724130630493, 1.511224627494812, 1.7724709510803223, 0.913096010684967, -0.22552946209907532, 0.6953033208847046, 0.9465413689613342, 2.477287769317627, 0.674345076084137, 2.2946889400482178, 1.4154152870178223, -0.44934162497520447, -1.311837077140808, -2.3257665634155273, -1.4681835174560547, -1.1016372442245483, -1.063894510269165, -0.4149930477142334, -2.088578224182129, -4.383401393890381, -1.5421336889266968, -3.069019079208374, -1.2860041856765747, 0.46800604462623596, -1.4078000783920288, -0.9221764802932739, -3.3428661823272705, -1.503509759902954, 1.6008810997009277, -4.148882865905762, 1.671847939491272, 0.6119957566261292, -0.26191794872283936, -0.07208486646413803, -0.819257915019989, -0.34821617603302, 0.7809972763061523, 0.06000767648220062, -0.032093919813632965, -2.6986806392669678, 1.7816420793533325, 2.0815818309783936, 2.1119015216827393, 1.6568992137908936, 2.007845878601074, 0.4708136320114136, 0.5808534026145935, 2.180819034576416, -0.9051434993743896, 0.542583167552948, 0.34466391801834106, -0.023428848013281822, 0.5004860162734985, -6.272749900817871, -4.192598819732666, -4.820032596588135, -2.4622771739959717, -4.7379655838012695, -3.8598201274871826, -3.459428310394287, -4.959980487823486, -4.61604118347168, -3.8183987140655518, -5.6627936363220215, -4.345124244689941, -3.1010589599609375, -2.9748620986938477, -2.107071876525879, -4.408398151397705, -2.4858527183532715, -4.562985420227051, -8.163947105407715, -8.138551712036133, -2.2300045490264893, -3.0802409648895264, -2.598252296447754, -5.318418025970459, -8.188207626342773, -2.1514933109283447, 2.5414345264434814, -0.28545865416526794, 0.13193055987358093, 0.48689910769462585, 0.9127366542816162, 2.2642884254455566, 2.2099664211273193, 0.9889585375785828, 0.2855018377304077, 1.410605788230896, 2.0545413494110107, 1.5541902780532837, -0.6704782247543335], \"z\": [-1.8102673292160034, -4.0876336097717285, -1.3409059047698975, -4.68557071685791, -3.080174684524536, -8.197813034057617, -4.852209568023682, -2.0293080806732178, -1.899247646331787, -8.80775260925293, -7.933374404907227, -4.978802680969238, -5.096914768218994, -0.5252307057380676, 0.13911163806915283, -0.32341331243515015, 0.900323212146759, -0.09659407287836075, 1.4098893404006958, 0.44582197070121765, 0.3452126681804657, 1.3113654851913452, 0.486491322517395, 0.6469846963882446, 0.10927528142929077, -7.611862659454346, -5.847756862640381, -7.742164134979248, -5.944921016693115, -6.823691368103027, -7.800638675689697, -5.814254283905029, -5.4871954917907715, -7.030957221984863, -4.3130035400390625, -6.61550235748291, -7.213767051696777, -5.002145767211914, 0.4922327995300293, -2.474665641784668, -0.6438981890678406, -1.7579455375671387, -1.651850700378418, -0.3866024613380432, -0.9151185750961304, -1.5652029514312744, -1.2974838018417358, -0.8628331422805786, -0.5724542140960693, -1.1272536516189575, 0.7152950763702393, -5.777735233306885, -6.694233417510986, -4.148437976837158, -6.0242018699646, -6.131462097167969, -6.282955646514893, -5.798614978790283, -5.705326080322266, -6.124820232391357, -5.060049533843994, -6.394657611846924, -5.849935054779053, -6.386712551116943, -0.8655476570129395, -0.7001035809516907, -0.09618090838193893, -1.8943978548049927, -2.431898593902588, -0.7882996797561646, -1.3157035112380981, -6.279134273529053, -7.231850624084473, -5.001996994018555, -7.323042392730713, -5.2255859375, -7.2808685302734375, -3.8305513858795166, -3.1171488761901855, -4.854804992675781, -4.274731636047363, -3.704712152481079, -3.731288194656372, -3.7263221740722656, -4.083231449127197, -3.630441427230835, -4.156848430633545, -2.977146625518799, -3.881103038787842, -3.64558482170105, -3.8685598373413086, -3.67511248588562, -3.732269048690796, -6.0128068923950195, -4.052994251251221, -3.6880834102630615, -4.438479423522949, -4.072926044464111, -2.6184866428375244, -3.9791319370269775, -5.491838455200195, -5.834179878234863, -6.682351589202881, -6.044618606567383, -5.767200946807861, -6.083579063415527, -5.215037822723389, -6.714287757873535, -7.6231889724731445, -6.415344715118408, -6.73353910446167, -7.049036026000977, -5.738692283630371, -6.613891124725342, -6.410061836242676, -6.63644552230835, -5.925558090209961, -3.3196167945861816, -5.3577117919921875, -3.562839984893799, -3.3846724033355713, -5.829578399658203, -4.088128566741943, -4.345372676849365, -5.336322784423828, -4.69972038269043, -6.254402160644531, -3.001224994659424, -8.8432035446167, -3.8033640384674072, -3.926255464553833, -3.850144386291504, -3.8240065574645996, -3.5494227409362793, -5.191485404968262, -5.452659606933594, -3.6041717529296875, -4.9573187828063965, -2.1149303913116455, -2.2173173427581787, -2.0980987548828125, -5.301987648010254, -5.334067344665527, -4.260056018829346, -4.87274694442749, -3.6605255603790283, -4.2109375, -4.411825180053711, -4.166650295257568, -5.067562580108643, -4.906900882720947, -4.277406215667725, -6.447353839874268, -4.256455898284912, -3.350863456726074, -6.57667875289917, -7.3807692527771, -7.577743053436279, -6.939297676086426, -7.365035057067871, -0.83269864320755, -0.8035109043121338, -6.996661186218262, -6.218621253967285, -6.695049285888672, -7.162291049957275, -0.8496039509773254, -7.211385726928711, -1.465680718421936, -5.984722137451172, -5.309928894042969, -6.797394752502441, -5.157110691070557, -2.2588980197906494, -2.541815996170044, -4.168274879455566, -2.529292583465576, -1.9942600727081299, -3.266576051712036, -3.2910678386688232, -3.7956504821777344], \"mode\": \"markers\", \"name\": 4, \"marker\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.08301404863595963, -2.685412883758545, 0.11812525242567062, -2.065103769302368, -2.0740439891815186, -1.9415643215179443, -1.7632330656051636, -2.3618361949920654, 0.9039490222930908, 0.36622196435928345, -0.5399121642112732, -2.997023105621338, -1.367246389389038, -2.286656618118286, -3.288245677947998, -1.578566312789917, -2.5331385135650635, -1.9881923198699951, -2.510267972946167, -1.7635242938995361, -1.756783366203308, -2.030202865600586, -2.6245710849761963, -1.6635650396347046, -2.3962714672088623, -1.9413384199142456, -2.2913501262664795, -4.229553699493408, -1.02217698097229, -2.1270029544830322, 1.334639549255371, 0.5512004494667053, -2.5109853744506836, -1.5131442546844482, -1.9582120180130005, -1.5567059516906738, -1.0681118965148926, -0.29521244764328003, -3.871781587600708, -3.6050350666046143, -2.638490915298462, -2.685260772705078, -3.923652172088623, -1.8278509378433228, -4.743711948394775, -3.1679635047912598, -1.7970341444015503, -1.7971936464309692, -2.929746389389038, -1.9805090427398682, -1.008275032043457, -2.510981798171997, -0.3979075253009796, 0.7887973785400391, -0.6775175929069519, -2.3585994243621826, -0.12713831663131714, -0.3372274935245514, -0.3158126175403595, -0.7211278080940247, 1.1280663013458252, -0.6121706366539001, -0.2599552869796753, -0.5415381789207458, 0.6752017140388489, 2.9522006511688232, 0.5318238139152527, 0.2765246033668518, 3.6861367225646973, 0.05322457104921341, 0.09648960083723068, -0.7519342303276062, 2.9399023056030273, 3.142392873764038, 2.2810864448547363, -1.1027745008468628, -0.5602957010269165, -1.0312026739120483, -3.9483911991119385, -3.704113006591797, -2.9973814487457275, -4.06766939163208, -1.417641520500183, -4.155812740325928, -2.9504125118255615, -3.7995011806488037, -3.1028635501861572, -3.4725520610809326, -2.1726913452148438, -3.412452220916748, -3.2547852993011475, -0.5532779693603516, -1.3061474561691284, -0.5794751048088074, -0.7364785671234131, -1.3821651935577393, -0.7487194538116455, -1.8653740882873535, -1.616836667060852, -0.9036091566085815, -1.3793689012527466, -1.2662389278411865, -1.0550596714019775, -0.6775572896003723, -1.4608708620071411, -2.8570568561553955, -1.3703632354736328, -0.7197443246841431, -2.171964168548584, -0.6757805347442627, -1.2362651824951172, 0.47996610403060913, 0.05537354201078415, 0.45838475227355957, 1.346112847328186, -1.7535303831100464, 1.422371745109558, 2.032029390335083, 2.3222949504852295, -3.1105005741119385, -0.17827466130256653, -3.3185434341430664, -3.925459146499634, 2.911428451538086, -0.012044054456055164, 1.328801155090332, -4.02610445022583, -2.9068996906280518, -0.7725733518600464, -1.3384082317352295, 0.9745394587516785, -0.08269917964935303, 1.743085503578186, 0.5044799447059631, 1.026587963104248, -2.2987101078033447, 0.5574591755867004, 2.1890807151794434, 8.306465148925781, 1.0656418800354004, -1.6651159524917603, 2.9569315910339355, -2.461531400680542, 0.11348544806241989, 0.35467529296875, 0.553004264831543, 0.34884965419769287, 0.20930007100105286, 0.590826153755188, -1.1918977499008179, 1.01048743724823, 1.170082688331604, -1.244591236114502, -0.33900654315948486, 1.019712209701538, -0.308161199092865, -2.0805859565734863, -1.2604767084121704, -2.040910005569458, -3.9544737339019775, -3.666987180709839, -1.8537839651107788, -2.5605692863464355, -2.5662386417388916, 0.18803484737873077, -2.3622665405273438, -3.9234251976013184, -1.0320810079574585, -2.1728572845458984, 1.5489953756332397, 1.8714027404785156, 1.9678151607513428, 1.3252170085906982, -0.658654510974884, -2.102800130844116, 1.9588251113891602, -0.23541276156902313, 1.9602326154708862, 0.9017851948738098, 2.1247057914733887, 1.7088865041732788, 1.0286864042282104], \"y\": [8.477279663085938, 1.9757733345031738, -0.9237343072891235, 4.598019599914551, 0.1974790394306183, 0.16510653495788574, -0.7547478079795837, 5.143782615661621, 1.5874905586242676, 1.9343715906143188, 0.46202367544174194, -0.19374212622642517, 0.18827319145202637, -1.1067554950714111, 0.8215852379798889, -2.7442564964294434, 0.11364280432462692, -2.2075932025909424, -1.903007984161377, -0.07010767608880997, -0.5873476266860962, -2.7818069458007812, -2.21036434173584, -2.141915798187256, -2.5560083389282227, -1.8075737953186035, 6.366917610168457, 0.09785566478967667, 5.095004558563232, 5.962522983551025, 4.080295085906982, 6.3360595703125, 6.120059967041016, 3.1250154972076416, 6.0772223472595215, 6.991847038269043, 3.875454902648926, 4.789083480834961, -1.0792672634124756, 4.093114852905273, 2.132740020751953, 2.401906967163086, 4.411002159118652, 2.578615188598633, 4.788196086883545, 2.6378300189971924, 7.221619129180908, 2.6228368282318115, 3.9670653343200684, 2.397157907485962, 0.6064704060554504, 2.2971842288970947, 7.920051574707031, 7.848963737487793, 7.786123752593994, 5.586735248565674, 8.111760139465332, 8.250167846679688, 7.505863189697266, 6.7325439453125, 8.281481742858887, 8.198933601379395, 6.3659491539001465, 8.16354751586914, 7.8452935218811035, 5.320967674255371, -0.6293837428092957, -0.7078018188476562, 4.281156539916992, 1.3387490510940552, -1.5030895471572876, 0.14241650700569153, 3.4795479774475098, 3.6074888706207275, 4.452942848205566, 0.010821809060871601, -0.705488383769989, -2.733104944229126, 1.104385495185852, -1.5025237798690796, -1.5033526420593262, -0.08275897800922394, -0.6498454809188843, 0.8573750257492065, 0.4385674297809601, -0.2801494896411896, -0.5776200890541077, 0.8389964699745178, -1.2619118690490723, 1.9412020444869995, -1.172173261642456, 5.9927520751953125, 7.921871662139893, 8.549057006835938, 7.452877521514893, 6.682126522064209, 8.21383285522461, 8.319872856140137, 6.717569828033447, 7.255167484283447, 5.193469524383545, 7.6774115562438965, 7.944188594818115, 5.667378902435303, 2.4072604179382324, 3.5098743438720703, 6.734063148498535, 2.938420295715332, 3.2105960845947266, 2.9071414470672607, 4.206096649169922, 4.674686431884766, 1.350136399269104, 1.9583545923233032, 4.594621181488037, 2.2688398361206055, 3.7108664512634277, 3.4908158779144287, 4.616276741027832, -2.1014010906219482, 4.367406845092773, 2.019371271133423, 1.296053409576416, 3.5073301792144775, -0.8989943265914917, 3.6299328804016113, -1.8225783109664917, -2.251286506652832, -2.73053240776062, -0.6413944363594055, 6.0080671310424805, 4.5148701667785645, 3.2304437160491943, 3.000117540359497, 2.424269676208496, 4.191417694091797, 2.9551639556884766, 3.400696277618408, -0.7207544445991516, 1.1551964282989502, 2.527508020401001, 3.3322196006774902, 5.213438987731934, 6.48717737197876, 5.844298362731934, 6.345604419708252, 5.859102249145508, 5.668928146362305, 5.78239631652832, 7.329810619354248, 5.215967178344727, 3.0007247924804688, 7.426074028015137, 8.430139541625977, 5.300679683685303, 5.094590187072754, -0.7239847779273987, -0.42214474081993103, 2.2745883464813232, 2.1595492362976074, -2.582289457321167, -0.3243989646434784, -2.932546377182007, -0.6358117461204529, 1.6328983306884766, 2.2416396141052246, -0.35265251994132996, -0.02009865641593933, 2.2694971561431885, 6.722196102142334, 5.973117351531982, 6.365815162658691, 5.248581886291504, 6.18495512008667, 5.128190040588379, 6.262630939483643, 7.7462544441223145, 6.577381610870361, 7.149861812591553, 5.6691203117370605, 5.909104347229004, 7.877176761627197], \"z\": [2.638666868209839, -13.1295747756958, -12.570115089416504, -10.626434326171875, -9.244645118713379, -9.242835998535156, -9.738129615783691, -11.605634689331055, -9.39612865447998, -10.615882873535156, -11.8826904296875, -12.515128135681152, -8.947940826416016, -12.8359956741333, -11.593602180480957, -15.225564002990723, -11.983981132507324, -14.585907936096191, -13.575278282165527, -12.028617858886719, -12.530350685119629, -15.132817268371582, -13.017965316772461, -12.995837211608887, -13.431105613708496, -12.157633781433105, -7.474548816680908, -12.04387092590332, -8.788961410522461, -8.634729385375977, -6.761839866638184, -3.823632001876831, -8.919053077697754, -14.348984718322754, -8.940908432006836, -7.786739349365234, -9.961227416992188, -6.4460859298706055, -13.750614166259766, -8.74514102935791, -8.700179100036621, -8.656865119934082, -8.516143798828125, -8.499526023864746, -8.135307312011719, -8.236083030700684, -10.386449813842773, -8.583449363708496, -9.815776824951172, -8.758439064025879, -12.924365997314453, -7.675414562225342, -10.099129676818848, -7.348390579223633, -8.203527450561523, -10.228873252868652, -7.041338920593262, -7.7375688552856445, -8.154033660888672, -8.59896469116211, -7.545482635498047, -6.947836399078369, -8.543924331665039, -10.391666412353516, -7.550856113433838, -10.25745677947998, -12.875212669372559, -13.09660816192627, -10.524514198303223, -14.679059982299805, -12.988259315490723, -13.096343040466309, -9.989843368530273, -10.149417877197266, -8.411529541015625, -13.293327331542969, -14.3537015914917, -15.410759925842285, -12.41807746887207, -14.308440208435059, -14.246042251586914, -10.501265525817871, -14.133788108825684, -12.4866304397583, -12.529155731201172, -10.58408260345459, -11.154260635375977, -10.96519947052002, -13.778495788574219, -10.754508018493652, -13.972305297851562, -8.65164566040039, -5.809396743774414, -4.357920169830322, -4.753599166870117, -7.032557487487793, -4.556517124176025, -4.145081520080566, -6.774106502532959, -5.5294718742370605, -8.792222023010254, -4.748089790344238, -4.635593414306641, -5.983297348022461, -12.815730094909668, -11.731903076171875, -9.822376251220703, -12.408835411071777, -13.669946670532227, -12.578861236572266, -9.976461410522461, -11.246935844421387, -14.677328109741211, -11.072927474975586, -11.021286010742188, -13.020500183105469, -10.963907241821289, -8.032773971557617, -8.331586837768555, -14.234539985656738, -9.872110366821289, -10.570356369018555, -12.579244613647461, -9.716479301452637, -13.637505531311035, -8.9832763671875, -14.118635177612305, -13.159001350402832, -15.466452598571777, -12.254449844360352, -6.669647216796875, -8.043474197387695, -9.680412292480469, -8.796931266784668, -9.435870170593262, -10.50840950012207, -8.609429359436035, -8.586153030395508, -8.386133193969727, -11.143800735473633, -10.953659057617188, -8.3147611618042, -11.712831497192383, -8.092391967773438, -6.319811820983887, -3.8066208362579346, -6.402787685394287, -6.500784873962402, -6.436359882354736, -6.6068115234375, -5.931481838226318, -7.9142842292785645, -6.655228137969971, -4.962485313415527, -7.405322551727295, -8.590423583984375, -14.836255073547363, -15.062471389770508, -13.156697273254395, -14.325615882873535, -14.854331016540527, -15.221579551696777, -15.24837875366211, -14.480378150939941, -10.428231239318848, -14.288919448852539, -12.190363883972168, -15.108146667480469, -14.213895797729492, -9.38515567779541, -9.836130142211914, -10.622176170349121, -9.744072914123535, -10.558465957641602, -11.482954978942871, -9.96630573272705, -10.123441696166992, -10.691003799438477, -8.62801456451416, -8.905112266540527, -10.930227279663086, -9.265571594238281], \"mode\": \"markers\", \"name\": 5, \"marker\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [10.928581237792969, 14.73205852508545, 10.616498947143555, 13.407443046569824, 11.0814208984375, 13.82938003540039, 11.366425514221191, 12.363516807556152, 11.124995231628418, 11.928298950195312, 9.788389205932617, 8.649663925170898, 11.032812118530273, 11.023523330688477, 13.388391494750977, 11.960299491882324, 11.727598190307617, 11.306059837341309, 11.625654220581055, 11.443159103393555, 11.413480758666992, 11.99350643157959, 13.632010459899902, 11.275300979614258, 13.25624942779541, 12.846925735473633, 12.930723190307617, 12.016923904418945, 13.549726486206055, 11.167546272277832, 14.752256393432617, 14.753996849060059, 15.708040237426758, 14.042840003967285, 12.311342239379883, 13.629748344421387, 12.77941608428955, 15.120826721191406, 10.305264472961426, 10.105396270751953, 11.27318286895752, 10.554213523864746, 9.978879928588867, 11.510895729064941, 10.246987342834473, 11.498729705810547, 10.66536808013916, 12.761981964111328, 11.898797035217285, 11.531963348388672, 7.558645725250244, 10.328418731689453, 9.321782112121582, 11.046360969543457, 9.190189361572266, 8.19082260131836, 8.477437019348145, 9.962220191955566, 8.816391944885254, 8.476259231567383, 8.199174880981445, 10.285454750061035, 10.457393646240234, 8.79902458190918, 13.899377822875977, 13.583479881286621, 13.263427734375, 11.342669486999512, 12.855134010314941, 12.753312110900879, 16.083839416503906, 12.011197090148926, 13.465595245361328, 13.701361656188965, 12.27675724029541, 13.576075553894043, 13.753466606140137, 12.750475883483887, 12.742444038391113, 12.128085136413574, 11.979413986206055, 11.513972282409668, 11.111129760742188, 11.949187278747559, 12.798749923706055, 10.598867416381836, 12.781291961669922, 12.619077682495117, 13.103315353393555, 12.35090446472168, 14.191083908081055, 12.369609832763672, 13.025566101074219, 14.017561912536621, 14.194077491760254, 13.557043075561523, 14.285233497619629, 13.930904388427734, 13.72063159942627, 13.962530136108398, 14.88211727142334, 12.573196411132812, 11.849102020263672, 11.79589557647705, 12.37200927734375, 14.710803031921387, 14.069846153259277, 10.476723670959473, 13.968059539794922, 15.398099899291992, 14.74520492553711, 12.849966049194336, 14.159468650817871, 15.65445613861084, 10.003945350646973, 14.512845993041992, 12.80517292022705, 9.836610794067383, 14.677617073059082, 14.65211009979248, 13.189669609069824, 15.36994457244873, 11.938821792602539, 11.923858642578125, 14.713403701782227, 15.213513374328613, 15.351487159729004, 11.40341854095459, 15.173064231872559, 15.10869026184082, 15.194818496704102, 16.104053497314453, 15.653685569763184, 12.52519702911377, 12.47620677947998, 12.982973098754883, 12.562165260314941, 14.245780944824219, 16.049272537231445, 15.201370239257812, 14.66342830657959, 13.674386978149414, 12.16520881652832, 12.283397674560547, 12.43907356262207, 9.851729393005371, 13.277972221374512, 11.935848236083984, 12.333867073059082, 12.325150489807129, 11.757737159729004, 12.646659851074219, 12.599878311157227, 12.547486305236816, 14.046171188354492, 15.239639282226562, 13.059599876403809, 11.551423072814941, 12.687994956970215, 14.219928741455078, 12.489447593688965, 12.334845542907715, 13.9990234375, 14.312472343444824, 12.973272323608398, 15.992984771728516, 12.283699035644531, 10.460855484008789, 10.240951538085938, 10.978190422058105, 10.037720680236816, 10.377548217773438, 10.864388465881348, 9.635683059692383, 10.621908187866211, 11.633678436279297, 10.229207038879395, 12.252172470092773, 11.241827964782715, 11.368793487548828, 11.665700912475586], \"y\": [-4.555772304534912, -3.0798490047454834, -5.07667350769043, -2.9969136714935303, -4.532172679901123, -2.7674264907836914, -4.68100643157959, -5.484598159790039, -4.81699275970459, -3.533393144607544, -5.0779571533203125, -4.171670913696289, -4.8468098640441895, -2.112997055053711, -0.35549023747444153, -3.4447615146636963, -4.371364116668701, -4.5566911697387695, -2.6455800533294678, -4.6928935050964355, -3.6940810680389404, -5.436384201049805, -3.509286403656006, 0.39570024609565735, 0.37298548221588135, -1.2760002613067627, -2.0995240211486816, -4.6942620277404785, -2.2965927124023438, 0.003800175618380308, -3.8448472023010254, -3.6948208808898926, -2.7438266277313232, -3.824270248413086, -1.1980246305465698, -2.001319646835327, -2.5418169498443604, -4.378009796142578, 0.5561990737915039, 1.3399263620376587, 0.7634656429290771, 1.84735906124115, 0.06857366114854813, 0.6119768023490906, 0.9307846426963806, 0.7005715370178223, -2.40329647064209, 0.9796587228775024, 2.0050415992736816, 0.0951060876250267, -3.9778895378112793, -1.75751531124115, -0.7366616129875183, -1.6234617233276367, -2.3193929195404053, -2.8552439212799072, -1.5980942249298096, -1.985949158668518, -0.7955102324485779, -1.5510621070861816, -3.183882474899292, -1.6650846004486084, -2.391695737838745, -2.1215991973876953, -4.466310501098633, -3.9928088188171387, -3.6745173931121826, -3.8205299377441406, -5.278356552124023, -1.979064702987671, -2.540736198425293, -2.8883445262908936, -3.279137134552002, -5.319445610046387, -1.7346775531768799, -4.907657146453857, -4.8811187744140625, 2.855128526687622, 3.288177967071533, 1.2584363222122192, 2.217480182647705, -2.0404036045074463, -0.17817917466163635, 2.324289560317993, 2.946188449859619, -0.006329053547233343, 2.0265846252441406, 0.5780669450759888, -3.0788049697875977, -3.429385185241699, -3.591782331466675, -4.074133396148682, -1.4304571151733398, -1.5784144401550293, -3.603304862976074, -1.474019169807434, -1.1677937507629395, -2.553158760070801, -1.7586190700531006, -2.6869704723358154, -0.508087158203125, -1.431227207183838, -0.2327839881181717, -1.934393286705017, 1.0321983098983765, -1.7993921041488647, -3.1064391136169434, -2.915008783340454, -5.045597076416016, -1.6885952949523926, -3.2376179695129395, -5.170385360717773, -4.887719631195068, -1.284198522567749, -5.195748329162598, -0.4236205518245697, -0.46665069460868835, -3.1534759998321533, -1.9469162225723267, -2.8477530479431152, 0.9030784368515015, -1.433334231376648, -2.060364007949829, -2.4282684326171875, -0.4243639409542084, -0.7112997174263, -0.9167152047157288, -1.3341442346572876, -0.4985508918762207, -1.248765230178833, -1.8688066005706787, 0.13925665616989136, -0.17047187685966492, 0.3678939640522003, 0.9101667404174805, 1.2531967163085938, -0.21617503464221954, -0.8370160460472107, 0.03834408521652222, -1.5415815114974976, 0.7549495697021484, 1.82317054271698, 0.3457164168357849, 0.6869778037071228, -0.3029048442840576, -0.4437790811061859, 0.7849535346031189, -1.3132591247558594, -3.6737706661224365, -1.7717258930206299, 0.5680280327796936, 0.5210446119308472, -0.36929604411125183, -0.24235616624355316, -1.5204514265060425, -1.2865394353866577, -1.102216362953186, -4.3541259765625, -0.7682923078536987, -0.9085873961448669, -2.683286190032959, -3.179900646209717, -1.0231866836547852, -0.8369622826576233, -2.4196906089782715, -2.5896382331848145, -3.533053398132324, -2.428522825241089, -4.743182182312012, 0.41702529788017273, -3.792389392852783, -3.354996919631958, 0.2576545476913452, -5.385371208190918, -3.308063507080078, -5.824520111083984, -4.856675148010254, -4.9417033195495605, -4.661458492279053, -4.486875057220459, -0.7284959554672241], \"z\": [-4.404854774475098, -3.5896875858306885, -4.863114356994629, -2.765070676803589, -5.570187568664551, -5.70928955078125, -5.103144645690918, -9.223640441894531, -4.703556537628174, -3.9581363201141357, -3.5987842082977295, -5.229947566986084, -2.8687074184417725, -9.098127365112305, -4.092918395996094, -4.464502811431885, -9.749593734741211, -8.040881156921387, -4.2998480796813965, -7.942378520965576, -9.159761428833008, -8.972823143005371, -3.6013951301574707, -6.125542163848877, -9.66050910949707, -9.843951225280762, -8.620857238769531, -9.973774909973145, -7.13043212890625, -10.862403869628906, -9.227628707885742, -9.11330509185791, -6.849229335784912, -4.586303234100342, -10.649145126342773, -7.22301721572876, -9.082145690917969, -9.220341682434082, -5.504188060760498, -4.785943984985352, -3.841313123703003, -4.292050361633301, -10.179333686828613, -3.808116912841797, -5.036420822143555, -3.573967218399048, -5.194639682769775, -3.395033597946167, -3.7249066829681396, -4.44541597366333, -5.156561374664307, -5.876122951507568, -8.600176811218262, -7.193210601806641, -6.571809768676758, -5.912238597869873, -7.481404781341553, -5.9842424392700195, -8.453910827636719, -7.486588954925537, -5.741471290588379, -5.828007221221924, -5.973723411560059, -5.978321552276611, -8.782179832458496, -9.023652076721191, -9.191444396972656, -9.584782600402832, -9.382787704467773, -10.608541488647461, -6.650765895843506, -11.281296730041504, -9.181797981262207, -5.7219390869140625, -10.521173477172852, -5.193536281585693, -5.1956048011779785, -5.830892086029053, -6.165279865264893, -4.536134243011475, -8.247842788696289, -3.7369585037231445, -4.732922554016113, -8.246899604797363, -5.758356094360352, -7.711283206939697, -4.78956937789917, -7.3056321144104, -2.4487855434417725, -10.087541580200195, -11.71653938293457, -10.763004302978516, -11.102485656738281, -9.165815353393555, -11.738966941833496, -8.604683876037598, -9.630780220031738, -10.5607328414917, -10.431729316711426, -5.761842727661133, -7.7440266609191895, -10.061111450195312, -9.409128189086914, -10.91940689086914, -9.184904098510742, -8.782798767089844, -3.7414257526397705, -4.729773044586182, -7.964292049407959, -5.624999046325684, -6.950530529022217, -5.185450077056885, -8.016934394836426, -7.070249080657959, -4.793490409851074, -8.50418758392334, -11.061018943786621, -6.466702461242676, -6.249284267425537, -6.9212470054626465, -4.057268142700195, -5.949678421020508, -5.335129737854004, -5.50938081741333, -6.448243618011475, -5.792942523956299, -5.639039516448975, -5.552145004272461, -4.935196876525879, -2.885342836380005, -3.3594512939453125, -4.223737716674805, -4.280749797821045, -4.231257438659668, -4.513515949249268, -4.242830276489258, -4.277962684631348, -3.819173574447632, -4.198322772979736, -3.9346940517425537, -2.9963762760162354, -4.478946208953857, -9.109329223632812, -9.426217079162598, -10.48753833770752, -8.950920104980469, -9.850252151489258, -9.776653289794922, -11.350913047790527, -7.973001956939697, -8.959567070007324, -8.458429336547852, -7.851080417633057, -7.973262786865234, -6.460412502288818, -2.049076795578003, -2.256197690963745, -2.530614137649536, -3.420377254486084, -2.5767807960510254, -3.44714617729187, -2.6247546672821045, -3.200066328048706, -2.6616392135620117, -2.3818743228912354, -5.069831371307373, -2.177774429321289, -3.123662233352661, -6.985002040863037, -7.545629501342773, -7.730307102203369, -8.216920852661133, -6.912175178527832, -5.481332778930664, -8.390491485595703, -9.385677337646484, -5.898719310760498, -4.964108943939209, -6.861639499664307, -3.6063151359558105, -8.211865425109863], \"mode\": \"markers\", \"name\": 6, \"marker\": {\"color\": \"rgba(255, 255, 51, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.0038599050603806973, -2.093423843383789, -5.1614813804626465, -4.203186988830566, 0.5189491510391235, -4.011181354522705, -2.3547468185424805, -1.1007589101791382, -5.268081188201904, -0.2506669759750366, -3.438760995864868, -1.086936593055725, -1.9506109952926636, 0.7475259900093079, 0.9953192472457886, 2.3045053482055664, -4.0541253089904785, -3.053619861602783, 0.618952751159668, 3.862091064453125, 2.117739677429199, 3.4680979251861572, -2.5390865802764893, 1.7184978723526, 3.0357730388641357, -3.6047608852386475, 0.54502272605896, -3.997831106185913, 1.3913378715515137, -3.7210352420806885, -4.55549430847168, -4.833897590637207, -1.3240302801132202, -0.8627880215644836, 2.2001821994781494, 2.2114803791046143, -0.8493049740791321, -3.605269432067871, -4.734476566314697, -5.112005233764648, -5.481454849243164, -6.742030143737793, -3.252392530441284, -4.906854629516602, -6.155129909515381, -6.75238561630249, -3.7238049507141113, -4.932497978210449, -5.789007186889648, -5.3113908767700195, -3.8952431678771973, 2.3484153747558594, -0.35650771856307983, -4.606544494628906, -2.1524064540863037, -1.3399558067321777, 1.7026128768920898, -4.9679365158081055, 0.5880866050720215, -0.981328547000885, 0.6968358159065247, -0.4237845242023468, 3.1439709663391113, -1.0807324647903442, -0.6166160702705383, -5.045203685760498, -7.243677139282227, -6.988693714141846, -6.991338729858398, -4.860947132110596, -5.23690128326416, -5.358004570007324, -7.077900409698486, -5.522628307342529, -5.664846420288086, -5.995028495788574, -0.8718975186347961, -1.3860259056091309, 0.4139682650566101, 1.324256420135498, 3.1274380683898926, -1.681803584098816, 3.717174768447876, 0.40659648180007935, 0.36991068720817566, -3.1269307136535645, 3.085686206817627, 0.3077988028526306, 0.2916403114795685, 1.4478094577789307, -1.9159818887710571, -0.7151064276695251, -2.3267018795013428, -0.40075796842575073, -3.5688891410827637, -0.6974485516548157, -2.102385997772217, -1.3483690023422241, -2.0147459506988525, -2.6771328449249268, -0.31684306263923645, -1.3564693927764893, 0.8902864456176758, -0.3964707553386688, 1.3423476219177246, 1.1320364475250244, 0.4861558675765991, 1.5586110353469849, 2.4936630725860596, 2.5940346717834473, 2.650512456893921, 0.34077081084251404, -0.8815020322799683, 2.4756155014038086, 1.6613287925720215, 1.297466516494751, -2.447171926498413, -5.284573078155518, 2.354548454284668, 0.5602063536643982, 0.07786351442337036, 1.0662771463394165, 2.2315049171447754, 2.9132258892059326, 0.5561085343360901, 2.004347562789917, -4.472914218902588, -3.3832194805145264, 2.900848627090454, -1.5523601770401, 0.07704093307256699, -1.9240409135818481, -0.2420041412115097, 0.18964052200317383, 1.0083918571472168, 0.7061065435409546, 3.251696825027466, -2.7023136615753174, 0.9018368721008301, -3.829488515853882, -0.47646626830101013, -3.3021438121795654, -4.120022773742676, -3.2500455379486084, -1.9897569417953491, -1.758618950843811, -4.926741123199463, -3.3504562377929688, -2.2356157302856445, -1.8327134847640991, -2.197572708129883, -3.002817392349243, -3.951279640197754, -3.2438719272613525, 2.7159767150878906, 2.259892225265503, 1.8031694889068604, 4.01847505569458, 4.63334321975708, 3.934715986251831, 2.3184194564819336, 4.158658504486084, 3.6760003566741943, -1.287140130996704, 1.7941912412643433, 3.973771333694458, -0.8247756958007812, -3.446972131729126, -0.8560844659805298, -2.94399094581604, -4.774163722991943, 0.6542467474937439, -0.1304192692041397, 2.5079872608184814, 1.73712956905365, -1.0284351110458374, 1.472805380821228, -2.6449522972106934, 2.0234792232513428], \"y\": [-14.87378978729248, -14.992799758911133, -16.009164810180664, -16.07781982421875, -15.198847770690918, -15.59908676147461, -15.320404052734375, -16.423019409179688, -15.004079818725586, -13.746530532836914, -15.752281188964844, -15.866131782531738, -14.832110404968262, -15.198366165161133, -15.467913627624512, -17.314830780029297, -14.795953750610352, -12.786778450012207, -15.726134300231934, -17.370845794677734, -18.436859130859375, -16.935091018676758, -14.562360763549805, -17.201059341430664, -16.917736053466797, -14.450419425964355, -15.736624717712402, -12.466906547546387, -15.105735778808594, -12.219593048095703, -13.5986328125, -12.488883018493652, -13.70108699798584, -14.165482521057129, -15.452167510986328, -16.88955307006836, -14.151620864868164, -13.851947784423828, -8.05136775970459, -7.910179138183594, -7.952444553375244, -7.326693058013916, -8.231036186218262, -7.948731899261475, -8.074149131774902, -7.327517986297607, -8.139480590820312, -6.958268165588379, -8.120327949523926, -7.72078800201416, -8.093320846557617, -18.407934188842773, -15.744479179382324, -13.943017959594727, -15.264066696166992, -15.173357009887695, -16.451908111572266, -13.932562828063965, -15.778517723083496, -16.091337203979492, -15.387688636779785, -15.278268814086914, -17.145156860351562, -15.298505783081055, -15.874232292175293, -14.118123054504395, -13.478314399719238, -13.678407669067383, -13.5923433303833, -14.638111114501953, -13.720020294189453, -14.66633129119873, -13.660449981689453, -14.526524543762207, -14.676115989685059, -14.618999481201172, -15.096253395080566, -13.32794189453125, -16.028505325317383, -14.533734321594238, -15.50760555267334, -13.10110092163086, -16.466726303100586, -14.387377738952637, -14.558728218078613, -14.114677429199219, -15.879446029663086, -16.02851676940918, -14.668243408203125, -17.939115524291992, -10.458918571472168, -11.66860294342041, -10.769630432128906, -11.749162673950195, -11.613960266113281, -11.67934513092041, -11.506993293762207, -13.640445709228516, -11.444998741149902, -10.990805625915527, -11.992609024047852, -11.051833152770996, -12.554625511169434, -12.138071060180664, -12.215166091918945, -11.298348426818848, -13.057896614074707, -11.802077293395996, -11.172024726867676, -13.593469619750977, -11.1051664352417, -12.278803825378418, -14.742188453674316, -13.624513626098633, -11.854788780212402, -16.015552520751953, -13.95228385925293, -13.929598808288574, -15.75998306274414, -15.300117492675781, -15.600991249084473, -16.438438415527344, -15.962347030639648, -17.10924530029297, -16.328006744384766, -16.25541877746582, -14.471693992614746, -14.70804500579834, -16.297653198242188, -12.745055198669434, -13.08325481414795, -12.264738082885742, -13.570121765136719, -13.199846267700195, -17.23832893371582, -16.0325927734375, -15.838339805603027, -14.449100494384766, -17.54448890686035, -14.472676277160645, -14.369009971618652, -11.259127616882324, -11.241586685180664, -11.16564655303955, -11.696975708007812, -10.629524230957031, -11.718764305114746, -12.202559471130371, -11.69134521484375, -12.518017768859863, -11.545552253723145, -10.270639419555664, -11.722517013549805, -10.750029563903809, -18.573463439941406, -18.30267333984375, -14.868929862976074, -16.323776245117188, -16.986724853515625, -16.300466537475586, -16.465044021606445, -16.121238708496094, -15.991500854492188, -16.961219787597656, -17.36432456970215, -15.248392105102539, -16.5437068939209, -15.720941543579102, -16.497047424316406, -12.198442459106445, -14.895672798156738, -16.58143424987793, -15.415570259094238, -17.468984603881836, -16.973941802978516, -14.472723960876465, -17.721494674682617, -13.908499717712402, -17.25748062133789], \"z\": [-0.48415493965148926, -6.933775424957275, -5.140028476715088, -5.765667915344238, -1.026469349861145, -4.553251266479492, -6.788053035736084, -3.338512897491455, -6.477664947509766, -6.870485782623291, -6.312717914581299, -4.949681758880615, -4.719244480133057, -6.714395999908447, -6.888797760009766, -5.302797794342041, -3.603364944458008, -5.7620530128479, -5.504180431365967, -5.451229095458984, -1.754773497581482, -5.830965042114258, -3.334838390350342, -4.626461029052734, -6.007786273956299, -2.24214243888855, -3.9203951358795166, -8.368672370910645, -4.088873386383057, -6.252474308013916, -4.523413181304932, -7.58958625793457, -7.32334041595459, -7.263733863830566, -6.017366886138916, -6.602942943572998, -7.130037784576416, -6.451875686645508, -6.263692378997803, -6.340020179748535, -6.463441371917725, -6.330093860626221, -6.587779521942139, -6.285155773162842, -6.604739189147949, -6.335838794708252, -6.499907493591309, -4.253734588623047, -6.574897766113281, -6.247513771057129, -6.461629390716553, -1.360728144645691, -1.8253527879714966, -4.2177414894104, -5.2602152824401855, -2.281973123550415, -1.1998810768127441, -3.437190055847168, -2.5175812244415283, -2.3114118576049805, -4.816307544708252, -3.56778883934021, -3.2365033626556396, -2.046691417694092, -3.4909121990203857, -3.4279778003692627, -5.987387180328369, -6.217676639556885, -6.249998092651367, -4.7053117752075195, -4.527806282043457, -5.136596202850342, -6.010014057159424, -5.239480972290039, -5.20936393737793, -5.912710189819336, -2.982024908065796, -6.1499762535095215, -4.547298431396484, -5.012302875518799, -5.0133957862854, -5.494068622589111, -5.584421157836914, -5.588831901550293, -6.043522357940674, -2.7521116733551025, -5.486516952514648, -6.442264556884766, -5.8251752853393555, -2.0537753105163574, -7.682677745819092, -8.510226249694824, -7.240685939788818, -7.73695182800293, -7.336568832397461, -8.185402870178223, -8.256637573242188, -5.707413196563721, -8.242775917053223, -7.669823169708252, -7.123222351074219, -6.897960662841797, -5.946230888366699, -7.075456619262695, -5.446816444396973, -6.427515029907227, -7.287545204162598, -5.734737873077393, -6.4827423095703125, -3.6448440551757812, -6.5369791984558105, -7.414454936981201, -0.765368640422821, -4.174315929412842, -6.053696632385254, -1.2099077701568604, -3.370213031768799, -3.533334732055664, -1.8485620021820068, -1.1383745670318604, -3.1621792316436768, -0.611502468585968, -1.7197805643081665, -2.8500635623931885, -3.9067611694335938, -0.7987844347953796, -3.326378345489502, -1.4852861166000366, -2.2502706050872803, -4.513653755187988, -3.8356211185455322, -4.882072448730469, -2.9797990322113037, -4.0274128913879395, -1.625738263130188, -1.5417221784591675, -5.125356674194336, -6.103024482727051, -4.903584003448486, -5.528587341308594, -2.6794145107269287, -6.418857097625732, -6.197110176086426, -6.639581680297852, -5.897033214569092, -6.0745930671691895, -6.524253845214844, -6.226407527923584, -4.941376686096191, -6.261125087738037, -5.734434604644775, -6.47698974609375, -6.08341646194458, -6.4106855392456055, -0.9817137122154236, -1.388361930847168, -3.4706428050994873, -2.784533739089966, -2.6779849529266357, -3.13222599029541, -3.165391445159912, -4.640491008758545, -2.198925733566284, -4.499117851257324, -4.591620445251465, -3.157543182373047, -2.414297580718994, -4.912849426269531, -2.3170077800750732, -8.70190143585205, -4.535368919372559, -5.381048202514648, -7.920151710510254, -5.761022090911865, -6.712001800537109, -4.316093921661377, -2.2630138397216797, -2.9137978553771973, -5.0658392906188965], \"mode\": \"markers\", \"name\": 7, \"marker\": {\"color\": \"rgba(128, 128, 0, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.16157656908035278, 0.15423166751861572, -0.17687584459781647, -1.28054940700531, 0.21375955641269684, -2.5616447925567627, -3.0202224254608154, -1.4151943922042847, -2.863831043243408, 1.0990471839904785, -0.4150402247905731, -1.4690122604370117, -11.103476524353027, -0.1691625416278839, -2.4708406925201416, -1.5828388929367065, -0.2516637146472931, 3.543043851852417, -0.3823775053024292, 3.325946092605591, -0.9141373634338379, -1.6292195320129395, -1.35783052444458, -0.5436268448829651, -0.8295237421989441, -2.65995192527771, -1.7683762311935425, -1.23227858543396, -1.6341456174850464, -1.921139121055603, -2.0058372020721436, -3.035966634750366, -1.8596128225326538, -0.7151488065719604, -1.6095281839370728, 0.7338882684707642, -2.402966022491455, -1.5958341360092163, -3.3810296058654785, -0.18362490832805634, -4.9542460441589355, -3.3022751808166504, -2.2300944328308105, -3.9021189212799072, -2.3455810546875, -0.6825240850448608, -2.674910545349121, -0.3550781011581421, -1.382484793663025, -2.906243085861206, -2.6572744846343994, -2.43422794342041, -1.343428134918213, -0.9123102426528931, -2.414853572845459, -0.8972333073616028, -0.3597951829433441, -0.6092586517333984, -1.0098567008972168, -2.835836172103882, -2.2843148708343506, -0.9595056176185608, -0.8233073949813843, -2.292461633682251, -0.687346875667572, -0.9812159538269043, -0.6621478199958801, -1.8495362997055054, -1.7407035827636719, -1.689937710762024, -2.8370585441589355, -2.976701021194458, -2.581181049346924, -2.4992127418518066, -3.714125394821167, -0.5891281366348267, -2.1158859729766846, -0.34822168946266174, -12.302939414978027, -3.239616870880127, -1.8877739906311035, -5.771195411682129, -6.019748687744141, -4.372987270355225, -0.27826908230781555, -6.866299629211426, -6.652362823486328, 2.256918430328369, -6.874943256378174, -0.4910142123699188, -0.5875145792961121, -0.43685799837112427, 0.10284221917390823, -0.6202135682106018, -1.9115371704101562, -0.3927057981491089, -2.514127731323242, -3.3847382068634033, 0.41369277238845825, -2.3249218463897705, -0.8965171575546265, -1.0664514303207397, 1.6470783948898315, 2.6218984127044678, 2.3090240955352783, -0.9953585267066956, 1.65755295753479, 2.489218235015869, 2.4156510829925537, 0.15140517055988312, 2.812136650085449, 1.757753849029541, 2.864362955093384, 2.679401397705078, 0.277237206697464, -2.1607553958892822, -1.496523380279541, 0.39066916704177856, -0.2472631335258484, -1.4818799495697021, 0.3657974600791931, 0.6293726563453674, 0.36914902925491333, -1.4437462091445923, -0.014960494823753834, -0.43568870425224304, 0.29839804768562317, -2.7002975940704346, -3.1363213062286377, -1.3884367942810059, -0.7140008807182312, -2.59879207611084, -2.4768197536468506, -2.79020094871521, 0.9195737242698669, 0.4437640607357025, -3.0326857566833496, -3.032930850982666, -0.19953307509422302, -2.798530101776123, -2.5117087364196777, -1.9568476676940918, -3.5379533767700195, -3.410677671432495, -6.556118488311768, -4.3121490478515625, -4.594820499420166, -5.469381332397461, -5.308681011199951, -5.004605770111084, -5.638632774353027, -4.781658172607422, -11.895265579223633, -2.0203006267547607, -3.5346240997314453, -1.7684130668640137, -1.7503432035446167, -1.3731616735458374, -2.274016857147217, -1.7902852296829224, -1.7090818881988525, 1.6718850135803223, 1.5816941261291504, 1.4783393144607544, 0.7382558584213257, 1.563803791999817, -0.10745985805988312, 0.8126714825630188, -3.285022735595703, 1.8332552909851074, -0.6805346012115479, -4.917081356048584, -2.8348662853240967, 1.1253012418746948], \"y\": [-2.335360527038574, -7.7346272468566895, -5.5560784339904785, -8.926433563232422, -6.071552276611328, -6.264793395996094, -6.575736045837402, -8.405547142028809, -5.438358783721924, -7.370777606964111, -4.481733322143555, -9.145427703857422, -8.392160415649414, -4.195847988128662, -3.428785800933838, -5.9620842933654785, -4.357433795928955, -5.352654457092285, -3.6233720779418945, -5.232904434204102, -3.2911083698272705, -5.318873405456543, -4.313727378845215, -4.1214189529418945, -3.4871084690093994, -5.139627456665039, 0.8883853554725647, -5.618924617767334, -5.365184307098389, -1.3600455522537231, -1.2894319295883179, 1.698355793952942, 0.21004408597946167, -4.10762357711792, -1.0820435285568237, 0.8754655122756958, -0.9859659075737, -5.506242275238037, 0.01678399182856083, -5.355037689208984, 1.2326072454452515, -0.9040559530258179, -0.675254225730896, 1.7896617650985718, -0.9679729342460632, 0.9865584373474121, 1.101410150527954, -4.5895514488220215, -4.6120829582214355, -0.6013191342353821, -0.5787487030029297, -2.4610464572906494, -1.6790746450424194, -1.281447410583496, -1.9935003519058228, -1.3365271091461182, -0.6925838589668274, -1.2000166177749634, -1.4735134840011597, -1.5731316804885864, -2.2235724925994873, -1.3561599254608154, -1.2928963899612427, -1.9041523933410645, -0.4287949502468109, -2.8260293006896973, -0.27590814232826233, -2.7205889225006104, -2.3933444023132324, -3.5023117065429688, 1.5069018602371216, -3.8333802223205566, -5.485445022583008, 0.19973020255565643, -6.952685356140137, -0.3836662173271179, -4.1724395751953125, -10.656527519226074, -1.6643508672714233, -5.138930797576904, 1.9364230632781982, 1.8100106716156006, 1.8045839071273804, -2.22615122795105, -10.571366310119629, 0.4892898201942444, 0.6011685729026794, -2.7888548374176025, 0.4072481095790863, -10.731918334960938, -1.3263813257217407, -0.009670021943747997, -0.5210273265838623, -0.41837137937545776, -0.26936468482017517, 0.40215325355529785, -0.45149487257003784, 1.8670446872711182, -0.1731099933385849, 1.5758116245269775, -0.4192773103713989, -4.682238578796387, -6.594776630401611, -3.52463698387146, -2.14652681350708, -3.8317480087280273, -6.830428123474121, -2.8974239826202393, -3.047152042388916, -5.491374492645264, -1.9989722967147827, -5.689858913421631, -4.524102687835693, -3.9101083278656006, -0.08478618413209915, -7.90638542175293, -7.467137336730957, -7.2581257820129395, -8.763558387756348, -6.988485813140869, -6.93161678314209, -7.1290435791015625, -10.015509605407715, -8.129985809326172, -7.683114051818848, -6.928806781768799, -6.762292861938477, -5.459874153137207, -6.626316070556641, -6.695282936096191, -6.286172866821289, -5.5307183265686035, -6.176853656768799, -3.719045400619507, -7.008397579193115, -6.341485977172852, -6.194670677185059, -6.771040439605713, -7.142819404602051, 1.4521442651748657, 1.7438132762908936, 1.8831089735031128, 0.014522464014589787, 0.3201521635055542, 2.016523599624634, 1.587417483329773, 1.3536475896835327, 1.2312177419662476, 0.8828184604644775, 0.5341009497642517, 0.8882064819335938, 0.5590283870697021, -5.794144153594971, -9.564743041992188, -5.151362895965576, -3.314129114151001, -6.26654052734375, -4.31486177444458, -3.495913505554199, -5.823446750640869, -5.485396862030029, -5.025003433227539, -5.27311372756958, -4.260406017303467, -1.8946603536605835, -5.640187740325928, -5.876474857330322, -3.865351676940918, -4.437758922576904, -3.007277727127075, -7.57647180557251, -5.453993797302246, -4.160566329956055, -2.1546709537506104], \"z\": [6.5244574546813965, 4.298973083496094, 6.530811309814453, 3.3163485527038574, 6.041913032531738, 6.870987415313721, 3.8958427906036377, 4.294079303741455, 5.361408233642578, 5.81116247177124, 8.007184982299805, 3.2318949699401855, 7.105417728424072, 5.6568708419799805, 5.703893661499023, 8.202545166015625, 5.690670013427734, 3.961014747619629, 7.14064359664917, 3.99360728263855, 9.02164363861084, 7.482443809509277, 7.35653829574585, 7.792703628540039, 9.15381145477295, 5.439960956573486, 4.633840560913086, 2.1687119007110596, 1.950865387916565, 7.385507583618164, 6.6939873695373535, 3.876417875289917, 5.322096347808838, 4.325260162353516, 5.592494010925293, 3.83769154548645, 6.63026237487793, 2.325263738632202, 2.412457227706909, 4.479692459106445, 5.030158519744873, 4.258852005004883, 3.3196496963500977, 2.765387535095215, 2.5146114826202393, 6.33440637588501, 6.011269569396973, 4.607758045196533, 4.995482444763184, 5.025672912597656, 3.4679181575775146, 10.293269157409668, 9.337993621826172, 9.110560417175293, 9.781026840209961, 9.81020736694336, 10.143835067749023, 10.382593154907227, 9.884489059448242, 9.194732666015625, 10.411266326904297, 10.435152053833008, 10.225500106811523, 9.914207458496094, 5.4581217765808105, 3.2587201595306396, 5.740013599395752, 4.1180291175842285, 4.2219061851501465, 3.4620730876922607, 5.1688456535339355, 4.956800937652588, 2.797302484512329, 5.322413444519043, 3.348438262939453, 6.027746677398682, 3.540391445159912, 10.27232551574707, 7.233818054199219, 3.510542869567871, 3.3284223079681396, 3.325801134109497, 3.164818286895752, 4.656958103179932, 10.258200645446777, 4.307090759277344, 4.165774822235107, 7.101991653442383, 4.477790355682373, 10.267870903015137, 4.019381999969482, 3.7904367446899414, 3.960110902786255, 4.580117702484131, 3.2858948707580566, 3.719355583190918, 5.1747941970825195, 3.3009674549102783, 4.1602606773376465, 3.8229317665100098, 5.029813289642334, 1.2859128713607788, 4.037378311157227, 4.3728485107421875, 3.822932481765747, 6.6785149574279785, 4.138460159301758, 3.9707229137420654, 3.9524190425872803, 1.89812171459198, 3.5136988162994385, 7.31431245803833, 4.1313018798828125, 4.254940986633301, 2.9861807823181152, 3.772451877593994, 4.303273677825928, 2.297518014907837, 4.260953903198242, 0.9171381592750549, 2.5459978580474854, 3.8694119453430176, 10.193195343017578, 4.6285552978515625, 5.26862907409668, 5.842716693878174, 5.17963981628418, 4.841660022735596, 4.0710015296936035, 4.307178974151611, 5.923704624176025, 5.916282653808594, 4.617840766906738, 5.508224964141846, 4.903766632080078, 6.155306339263916, 5.595669269561768, 3.8198888301849365, 4.192324638366699, 3.2218222618103027, 3.6036508083343506, 3.5155327320098877, 3.777913808822632, 2.6710524559020996, 2.899770736694336, 2.432058095932007, 2.617152452468872, 2.9591779708862305, 3.8368475437164307, 4.0997138023376465, 2.9363114833831787, 4.271831512451172, 6.280550956726074, 3.097072124481201, 2.086261749267578, 9.202387809753418, 4.1802849769592285, 9.41122817993164, 9.109088897705078, 8.897782325744629, 9.379862785339355, 6.970796585083008, 4.537351608276367, 6.798648357391357, 6.362218856811523, 3.073171854019165, 2.0430853366851807, 6.674989223480225, 6.977803707122803, 6.8921074867248535, 6.955923557281494, 8.40312385559082, 6.863940715789795, 6.511366367340088], \"mode\": \"markers\", \"name\": 8, \"marker\": {\"color\": \"rgba(251, 128, 114, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-3.5452239513397217, 0.8987004160881042, 0.7113070487976074, 0.76677405834198, 1.5517014265060425, -5.101104259490967, -1.0601961612701416, 0.17317542433738708, -6.136868953704834, -0.060231588780879974, -0.4307577908039093, -2.2882699966430664, -6.4795942306518555, -1.153012752532959, -0.7794856429100037, -1.0691170692443848, -0.5070387125015259, -2.2192330360412598, -0.9279105067253113, -1.7440407276153564, -2.753859519958496, -3.42671799659729, -0.6218461394309998, -4.308475971221924, -3.424391746520996, -4.5274338722229, -3.212934970855713, -4.345305919647217, -1.6678754091262817, -5.112109184265137, -2.0134782791137695, -4.028072834014893, -3.3288891315460205, -4.113256454467773, -3.605736255645752, -8.994102478027344, -9.648197174072266, -4.259121894836426, -6.145261764526367, -2.37394118309021, -2.418226480484009, -4.193965911865234, -4.139916896820068, -3.912768840789795, -4.244919776916504, -4.09126091003418, -3.608605146408081, -4.099870204925537, -3.8030147552490234, -7.7499589920043945, -3.884312629699707, -3.5599889755249023, -8.021580696105957, -2.158449172973633, -0.5793607831001282, -6.620200157165527, -2.9081857204437256, -7.6478800773620605, -4.666223049163818, -2.91481614112854, -2.8969552516937256, -2.91925311088562, -6.921403884887695, -3.4657881259918213, -9.367088317871094, -10.69479751586914, -10.022095680236816, -10.997507095336914, -9.755760192871094, -10.471936225891113, -10.339160919189453, -10.990245819091797, -10.650537490844727, -10.893157958984375, -10.08554744720459, -9.597884178161621, -9.572175979614258, -2.321605920791626, -6.032505989074707, -3.4721579551696777, -6.233365058898926, -0.005729478783905506, -6.5399651527404785, -3.8515615463256836, -3.6142213344573975, -6.312745094299316, -2.408769369125366, -7.229518890380859, -7.52880334854126, -5.223739147186279, -1.2023955583572388, -2.406672716140747, -1.7564573287963867, -4.0315093994140625, -1.2019113302230835, -2.7786712646484375, -1.1159764528274536, -1.2856892347335815, -1.1904006004333496, -2.5106115341186523, -3.571286916732788, 0.8822445273399353, -2.801027536392212, -1.6019443273544312, 0.5174892544746399, -0.035314369946718216, -4.705508232116699, 0.5837446451187134, -4.942124366760254, 0.39733657240867615, 0.3234463632106781, 0.7222546339035034, -1.1044061183929443, -2.551095962524414, 0.9948933720588684, -1.9387518167495728, -4.83139181137085, -0.3318290114402771, -4.603866100311279, -5.227324485778809, -6.0109944343566895, -4.826846122741699, -1.29799222946167, -4.648032188415527, -5.025382041931152, -4.509164333343506, -4.286328315734863, -4.9305620193481445, -5.169703483581543, -3.0391526222229004, -4.735513687133789, -5.432796001434326, -5.496824741363525, -3.0655100345611572, -5.150146007537842, -1.8831006288528442, -4.178787708282471, -3.6008310317993164, -6.631713390350342, -6.568338871002197, -7.794665813446045, -4.3895158767700195, -5.766277313232422, -4.2099833488464355, -4.317129135131836, -5.618536949157715, -5.002274990081787, -3.2450146675109863, -4.601253032684326, -5.656275749206543, -3.7573347091674805, -5.037494659423828, -7.0247297286987305, -6.677652835845947, -10.065397262573242, -7.903085231781006, -7.904557228088379, -8.098923683166504, -4.216858863830566, -4.201270580291748, -8.729108810424805, -1.0699952840805054, -3.9289650917053223, 0.19364136457443237, 5.242171287536621, -4.200894832611084, -3.973729372024536, -2.8062546253204346, -4.030859470367432, -1.6586061716079712, -5.067908763885498, -6.371127605438232, -5.902195453643799, -4.293332099914551, -3.0899105072021484, -4.727687835693359, -5.011448860168457, -0.5729548931121826, -5.565677642822266, -3.591493606567383], \"y\": [6.2141900062561035, 10.732292175292969, 10.139453887939453, 11.143545150756836, 9.170663833618164, 13.285693168640137, -7.940405368804932, 9.45600414276123, 13.533422470092773, 11.444572448730469, 12.233986854553223, 6.5655717849731445, 11.762133598327637, 10.755566596984863, 8.768488883972168, 10.08327579498291, 10.329419136047363, 12.423651695251465, 10.973310470581055, 8.497230529785156, 7.053796768188477, 6.990411281585693, 9.441194534301758, 6.640681266784668, 7.668744087219238, -6.756194114685059, -6.4502363204956055, 11.919219017028809, 12.725125312805176, 6.724958896636963, 9.543999671936035, -6.064614772796631, -6.443902969360352, -6.560335636138916, -6.215483665466309, -1.0925471782684326, -0.6780577898025513, -6.454477787017822, 12.80986499786377, 11.554337501525879, 11.647439002990723, 7.576629638671875, 7.796771049499512, 9.899489402770996, 9.531002044677734, 7.886047840118408, 9.352054595947266, 7.881032943725586, 9.753850936889648, 11.13195514678955, 9.546371459960938, 5.438201904296875, 9.371904373168945, 5.654523849487305, -4.513395309448242, 11.219331741333008, 5.155284881591797, 9.919486999511719, 8.52518367767334, 5.138667583465576, 5.15177059173584, 10.542475700378418, 9.61723804473877, 11.467488288879395, -0.4737580120563507, -0.6972350478172302, 0.029107850044965744, -0.7746095061302185, -0.7347769141197205, -0.5612821578979492, -0.17616461217403412, -0.3101782202720642, 0.11739662289619446, -0.8892012238502502, -0.8781147003173828, -0.15736667811870575, -1.2064143419265747, 11.249374389648438, 10.769349098205566, 11.899808883666992, 10.902691841125488, 8.371675491333008, 10.291570663452148, 12.226974487304688, 8.286294937133789, 11.275747299194336, 12.305252075195312, 11.397576332092285, 11.231154441833496, 12.474898338317871, 12.135167121887207, 10.737773895263672, 11.596725463867188, 12.153912544250488, 10.207104682922363, 11.986929893493652, 12.136144638061523, 12.043828010559082, 10.423619270324707, 11.152774810791016, 12.549439430236816, 9.326777458190918, 10.672612190246582, 6.179229259490967, 7.689123153686523, 7.840329170227051, 5.644383907318115, 8.078897476196289, 5.847241401672363, 7.602556228637695, -5.878284454345703, 8.373934745788574, 7.490850925445557, 8.37104606628418, 7.335646152496338, 6.8211212158203125, 6.394490718841553, 12.394442558288574, 6.452043056488037, 8.629375457763672, 8.281880378723145, 8.72381591796875, 8.670578002929688, 6.8155927658081055, 8.394925117492676, 7.429281711578369, 7.136112689971924, 12.032958030700684, 6.526446342468262, 10.525069236755371, 9.986067771911621, 9.217979431152344, 9.995776176452637, 9.345136642456055, 7.838392734527588, 12.76759147644043, 9.332334518432617, 11.126167297363281, 9.732451438903809, 9.275304794311523, 10.18766975402832, 11.639954566955566, 12.666860580444336, 11.671326637268066, 10.815666198730469, 11.9705171585083, 13.164933204650879, 12.341290473937988, 12.745698928833008, 11.731030464172363, 12.305394172668457, 10.297494888305664, 12.453042984008789, 12.207681655883789, 0.33506157994270325, 0.2921890318393707, 0.30532148480415344, 0.19982406497001648, -4.658197402954102, 2.2165589332580566, -1.0658572912216187, 11.975008010864258, -5.625916957855225, 11.545854568481445, 1.7092149257659912, 2.062174081802368, -5.2132463455200195, 10.473968505859375, 8.536468505859375, 11.328756332397461, 10.560187339782715, 12.91752815246582, 11.640753746032715, 9.344059944152832, 9.404285430908203, 9.262243270874023, 8.489307403564453, 8.778897285461426, 10.058999061584473, 7.257660388946533], \"z\": [4.153817176818848, 1.8563268184661865, 2.017605781555176, 1.8954007625579834, 0.934510350227356, 0.8980085849761963, -0.4560340642929077, 2.372796058654785, 2.220562219619751, 2.7022452354431152, 1.8653817176818848, 0.2510356605052948, 3.820190668106079, 2.534221887588501, 2.9237594604492188, 2.7204854488372803, 3.4082529544830322, 3.3505821228027344, 2.160252094268799, 2.770977258682251, 2.3276846408843994, 2.283174514770508, 3.0303211212158203, 4.477685451507568, 3.7662129402160645, -3.049593687057495, -3.03337025642395, 1.4674897193908691, 2.566132068634033, 0.9630584716796875, -0.8602898716926575, -3.510307788848877, -3.076331853866577, -3.169595956802368, -3.3002071380615234, -1.7908830642700195, -1.6569396257400513, -3.3491718769073486, 2.7834722995758057, 4.058655261993408, 4.057628631591797, 5.435980796813965, 5.57108736038208, 2.5587427616119385, 2.136270046234131, 5.563952922821045, 3.9014759063720703, 5.690803527832031, 3.768275499343872, 3.201664686203003, 3.5669021606445312, 6.446746349334717, 2.6645667552948, 6.9406561851501465, 3.1719696521759033, 4.2951436042785645, 7.045725345611572, 2.048830509185791, -0.4578186273574829, 7.070099353790283, 7.062145233154297, 0.702146053314209, 2.076268196105957, 4.292128562927246, -1.1985838413238525, -1.3448234796524048, -1.5836031436920166, -1.2162203788757324, 0.41804203391075134, -1.1987264156341553, -1.0067076683044434, -0.3263910412788391, -0.47420015931129456, -1.6638295650482178, -1.3522887229919434, -0.9434458613395691, -0.4273045063018799, 0.928360641002655, 5.063099384307861, 4.424432754516602, 4.43352746963501, 9.38079833984375, 2.9416792392730713, 4.202037811279297, 3.2986090183258057, 4.213424205780029, 3.3474464416503906, 3.3314952850341797, 3.1574625968933105, 2.939375400543213, -0.3032200336456299, -0.5966781973838806, -0.7059921622276306, 1.5690134763717651, -0.19022706151008606, 0.1970559060573578, 0.09765657782554626, -0.4213085174560547, -0.07448218017816544, -1.230575680732727, 1.6448737382888794, -1.2945724725723267, -0.7768455147743225, 2.8872382640838623, -0.4859846234321594, -1.5127800703048706, 1.5751370191574097, -0.6137477159500122, 1.3650131225585938, -0.4683651924133301, 1.4285974502563477, -0.7761644721031189, 0.953112006187439, 1.0660701990127563, -0.38243502378463745, 0.27856534719467163, 4.551403045654297, 1.5362794399261475, 4.469351291656494, 0.10482241958379745, 0.5561321973800659, -0.3723442852497101, 2.653322696685791, 1.9035511016845703, -0.4724498391151428, 1.7553956508636475, 1.9813388586044312, 1.8946480751037598, 0.8943776488304138, -1.5813803672790527, -0.48941805958747864, -0.3396601378917694, 1.1629506349563599, 2.347252130508423, -0.7453425526618958, 2.7550461292266846, 0.5999251008033752, 3.0156943798065186, 0.7984657883644104, 0.49349287152290344, 1.3036388158798218, -0.34458860754966736, 1.842875361442566, -0.28185731172561646, 1.2231954336166382, 1.6185272932052612, 0.7165954113006592, -0.134721577167511, -0.028158199042081833, 1.6283528804779053, -0.35634300112724304, 1.2286934852600098, 1.0623972415924072, 1.2438963651657104, -0.8277313709259033, -1.526956558227539, -1.5903428792953491, -1.4469149112701416, -3.51767897605896, -14.44665813446045, -1.8865114450454712, 2.0736563205718994, -3.5436041355133057, 3.214747428894043, 7.116480827331543, -14.536808967590332, -3.5508482456207275, 0.24412795901298523, 1.3624029159545898, 1.7647836208343506, 2.7693138122558594, 2.6243536472320557, 1.3114138841629028, 2.71907901763916, 1.794679045677185, 3.01986026763916, 2.7951812744140625, 3.668999433517456, 3.1330723762512207, 4.058205604553223], \"mode\": \"markers\", \"name\": 9, \"marker\": {\"color\": \"rgba(128, 177, 211, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}], {\"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"titlefont\": {\"color\": \"#4D5663\"}, \"title\": \"T-SNE 3D demo\", \"scene\": {\"xaxis\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#9499A3\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#9499A3\", \"showgrid\": true, \"title\": \"\"}, \"yaxis\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#9499A3\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#9499A3\", \"showgrid\": true, \"title\": \"\"}, \"zaxis\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#9499A3\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#9499A3\", \"showgrid\": true, \"title\": \"\"}}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ],
      "text/vnd.plotly.v1+html": [
       "<div id=\"72e7236e-b4b4-43c7-8cdc-eb81d079a029\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"72e7236e-b4b4-43c7-8cdc-eb81d079a029\", [{\"type\": \"scatter3d\", \"x\": [2.644545555114746, 0.03308841213583946, -1.1813353300094604, -1.8606873750686646, -2.511894702911377, 2.9136877059936523, 3.5985608100891113, -1.5059148073196411, -0.37507161498069763, 4.730902194976807, 2.3637795448303223, 1.1334855556488037, -0.42548826336860657, 2.0898375511169434, -1.010321021080017, 1.603029727935791, -2.150287389755249, -0.4557243585586548, 2.032132148742676, -1.231459379196167, -0.49044322967529297, 0.8546522259712219, -2.2519729137420654, 0.7782018780708313, 1.742220163345337, 0.5687474608421326, -0.3724197447299957, 0.08703026920557022, 0.9939014911651611, 0.30537375807762146, 1.386106014251709, 3.045429229736328, 2.337897777557373, 1.720536470413208, 0.9367567300796509, 0.5722203850746155, 0.6567646265029907, 3.533115863800049, 3.506016492843628, 1.8850548267364502, 1.2332979440689087, 0.9685823917388916, -1.5980215072631836, 1.1206222772598267, 2.36203932762146, 1.9457670450210571, 4.745760917663574, -0.991393506526947, 3.673412561416626, 2.623690366744995, 1.0392217636108398, 2.0958778858184814, 4.209120273590088, 3.4068050384521484, 4.317223072052002, 4.270819187164307, 4.827152729034424, 4.510911464691162, 3.6158556938171387, 0.4231966733932495, 1.9309958219528198, 5.516477584838867, 4.472803115844727, 4.32534646987915, 4.280980110168457, -1.4626933336257935, 1.5180964469909668, -1.533578634262085, 0.7174404859542847, 1.2539626359939575, -1.4014054536819458, 1.0087313652038574, -2.67923641204834, -1.7085020542144775, -2.0054633617401123, 0.9860870242118835, 0.4405594766139984, -1.444814920425415, 2.799365997314453, 2.7119829654693604, 0.8627581000328064, 2.139770746231079, 1.5694608688354492, 3.3068041801452637, -0.8770229816436768, -1.9512728452682495, -1.230717658996582, -2.504639148712158, 3.5486538410186768, 2.5957884788513184, 1.6662949323654175, 4.325659275054932, 4.418684959411621, 5.298583984375, 4.668051242828369, 3.9108848571777344, 5.054770469665527, 2.8771181106567383, 5.471211910247803, 4.353833198547363, 5.344956398010254, 2.310926675796509, 2.2371435165405273, 5.686141490936279, 5.650480270385742, 2.6145570278167725, 5.221519947052002, 5.321629524230957, 2.7225825786590576, 5.2155232429504395, 2.6549668312072754, 3.7892539501190186, 2.4910104274749756, 4.22224760055542, 5.366903305053711, 2.1096179485321045, 0.5800105929374695, 2.1149206161499023, -1.733886957168579, -1.939658761024475, -1.7320433855056763, 2.4193434715270996, 1.5785276889801025, 1.7003239393234253, 2.298651695251465, 2.7283501625061035, 1.3125557899475098, 5.803750038146973, 1.635360836982727, 1.9851796627044678, 3.82065486907959, -1.8325811624526978, 0.23366659879684448, 0.051943425089120865, -1.9094544649124146, 0.8382778763771057, 2.592280149459839, 0.8770537376403809, 1.4837019443511963, -1.1695820093154907, 4.65665864944458, 3.6780190467834473, 2.7248988151550293, 4.476814270019531, 4.002392768859863, 3.5420963764190674, 3.755396842956543, 3.8239705562591553, 2.5800724029541016, 3.697172164916992, 3.752075672149658, 4.631152153015137, 3.320222854614258, -0.422157883644104, -0.03288615494966507, -0.646160900592804, -2.345409870147705, 2.0882558822631836, -1.3978296518325806, 1.9143792390823364, 0.4781865179538727, -1.195197582244873, 2.6881978511810303, -1.6869139671325684, 0.7946316599845886, 3.1751246452331543, 2.446516275405884, 0.9900432825088501, 2.168485641479492, -1.6152288913726807, -0.27808400988578796, 2.1292901039123535, -1.9773379564285278, -0.02765979990363121, -0.20242446660995483, 1.0449535846710205, 0.8490106463432312, -2.3051249980926514], \"y\": [22.25951385498047, 24.176992416381836, 21.785917282104492, 21.6221923828125, 22.031354904174805, 20.663576126098633, 22.18168830871582, 21.353479385375977, 21.871112823486328, 24.358537673950195, 23.859846115112305, 20.992475509643555, 21.518888473510742, 21.987396240234375, 23.586763381958008, 21.514801025390625, 22.300647735595703, 22.935653686523438, 24.723316192626953, 20.681760787963867, 21.49909782409668, 22.73981475830078, 21.190357208251953, 21.48859977722168, 24.10454750061035, 21.8496036529541, 23.607816696166992, 25.32268714904785, 23.357746124267578, 24.255584716796875, 24.184267044067383, 20.775020599365234, 24.454856872558594, 24.287187576293945, 21.94518280029297, 24.184837341308594, 22.172443389892578, 20.0750732421875, 21.845598220825195, 24.89164161682129, 23.971771240234375, 22.4375, 23.668365478515625, 25.217287063598633, 23.314563751220703, 22.065385818481445, 22.657054901123047, 23.456146240234375, 22.182384490966797, 23.060401916503906, 23.75383186340332, 23.382192611694336, 20.340822219848633, 25.105375289916992, 20.695077896118164, 20.183908462524414, 24.429460525512695, 19.90261459350586, 25.93440055847168, 22.893051147460938, 18.496692657470703, 21.518667221069336, 19.791566848754883, 20.480581283569336, 20.689334869384766, 22.081148147583008, 21.466463088989258, 21.804676055908203, 21.767803192138672, 23.625791549682617, 20.070341110229492, 20.803449630737305, 20.794973373413086, 20.401165008544922, 23.063987731933594, 21.795438766479492, 20.691116333007812, 19.941112518310547, 24.755348205566406, 25.666807174682617, 24.604598999023438, 24.19566535949707, 23.756603240966797, 19.10026741027832, 23.789737701416016, 21.877145767211914, 21.742843627929688, 21.219993591308594, 22.576732635498047, 22.581567764282227, 19.438962936401367, 24.7239933013916, 24.304594039916992, 21.37442398071289, 23.674558639526367, 22.952415466308594, 24.00343894958496, 24.740615844726562, 23.664749145507812, 22.893613815307617, 24.750272750854492, 21.62708282470703, 22.75641632080078, 21.91501808166504, 22.938018798828125, 21.511615753173828, 21.74382781982422, 21.788978576660156, 25.998085021972656, 22.07013702392578, 26.15476417541504, 25.966556549072266, 20.82691764831543, 24.581233978271484, 21.26730728149414, 21.776660919189453, 21.088899612426758, 21.731582641601562, 21.903663635253906, 21.668790817260742, 21.8953914642334, 21.437814712524414, 22.28543472290039, 21.59790802001953, 21.597572326660156, 18.64767837524414, 21.58429718017578, 21.842910766601562, 19.146902084350586, 20.296953201293945, 25.649499893188477, 19.78982162475586, 20.811487197875977, 20.94723129272461, 21.729326248168945, 22.05788230895996, 22.012544631958008, 19.963525772094727, 19.995195388793945, 19.612173080444336, 23.733240127563477, 23.25984001159668, 25.124048233032227, 22.88530158996582, 22.77019691467285, 22.925060272216797, 22.934106826782227, 25.677261352539062, 25.210227966308594, 25.552379608154297, 22.844675064086914, 22.99800682067871, 22.506160736083984, 21.126319885253906, 20.274538040161133, 22.1842041015625, 19.122529983520508, 20.39008140563965, 19.44737434387207, 19.90376853942871, 19.80162239074707, 19.639263153076172, 25.570632934570312, 20.693735122680664, 22.424694061279297, 23.716524124145508, 22.889015197753906, 24.479137420654297, 22.615829467773438, 21.601348876953125, 25.2949275970459, 23.41631317138672, 24.186105728149414, 25.37824249267578, 25.199295043945312, 24.524431228637695, 19.998912811279297, 22.526391983032227], \"z\": [-1.9292606115341187, -2.5914926528930664, -7.3494720458984375, -1.5264109373092651, -5.996274948120117, -4.520977020263672, -7.276357650756836, -8.084244728088379, -8.63754940032959, -6.866645812988281, -6.43996000289917, -8.826441764831543, -8.426254272460938, -4.787093639373779, -7.119477272033691, -8.215618133544922, -5.33062744140625, -5.462334156036377, -5.656154632568359, -8.300060272216797, -8.51948070526123, -7.140420436859131, -7.507429599761963, -8.88784408569336, -6.395082950592041, -7.314884185791016, -2.2752878665924072, -6.363030433654785, -2.6778037548065186, -1.4142754077911377, -0.07165339589118958, -4.406280517578125, -3.131192445755005, -2.744267702102661, -3.5837018489837646, -2.901963233947754, -2.956057071685791, -6.68018102645874, -5.836273670196533, -7.788674354553223, -6.482784271240234, -7.1286540031433105, -6.458746433258057, -7.5867204666137695, -6.1115593910217285, -6.9685139656066895, -2.978332042694092, -5.420497894287109, -2.485715866088867, -8.05246353149414, -8.481369018554688, -3.8719968795776367, -2.1112051010131836, -2.4325995445251465, -1.1351313591003418, -1.7650721073150635, -3.7392656803131104, -3.830408811569214, -5.5082807540893555, -1.3451792001724243, -6.268732070922852, -2.3536977767944336, -1.544303297996521, -0.5138711333274841, -2.3502237796783447, -3.69229793548584, 0.8639624118804932, -4.143296718597412, -2.817782163619995, -6.441438674926758, -5.060263633728027, -0.7109747529029846, -7.903613567352295, -5.312132358551025, -5.221382141113281, -4.023004531860352, -5.410628318786621, -4.939663410186768, -0.4147368371486664, -3.9236836433410645, -1.0299053192138672, -2.8502607345581055, -2.8419904708862305, -7.221343994140625, -2.8432812690734863, -2.6855814456939697, -6.314162254333496, -6.605260848999023, -3.306826591491699, -2.0118699073791504, -3.3604657649993896, -2.9239821434020996, -3.079122543334961, -3.961977005004883, -2.0969815254211426, -3.240055561065674, -2.3188059329986572, -0.383673757314682, -5.168666839599609, -2.1128933429718018, -2.187486410140991, -1.956154227256775, -5.977368354797363, -6.496505260467529, -3.9816174507141113, -6.943090915679932, -7.944777011871338, -7.9180402755737305, -4.915209770202637, -3.28794264793396, -5.013430118560791, -5.341499328613281, -2.1093246936798096, -4.396109104156494, -3.9975194931030273, -1.1679614782333374, -2.4302878379821777, 0.5975602269172668, 0.36931952834129333, -0.5692277550697327, 0.3466615378856659, 0.3113330006599426, 0.7957611680030823, 0.808590829372406, 0.27480655908584595, -6.838045597076416, 1.193999171257019, -6.516894340515137, -5.765609264373779, -5.828574180603027, -6.548303127288818, -7.029991149902344, -5.196873664855957, -5.553402423858643, -2.086463212966919, -1.6483289003372192, -1.6013069152832031, -4.954973220825195, -5.918783664703369, -6.90612268447876, -2.9889705181121826, -6.657566070556641, -2.3090152740478516, -5.89799165725708, -5.582448482513428, -4.600179195404053, -4.76690673828125, -6.36293363571167, -6.8597259521484375, -6.7194108963012695, -4.220125198364258, -5.670261383056641, -3.0905652046203613, -6.059903144836426, -6.688298225402832, -6.0354156494140625, -7.725232124328613, -5.200483322143555, -8.041502952575684, -2.2775235176086426, -7.597530841827393, -8.215959548950195, -4.137556552886963, -6.633802890777588, -1.6257325410842896, -6.5853776931762695, -6.886780738830566, -8.423072814941406, -2.477160930633545, -4.975984573364258, -6.818063735961914, -1.520279049873352, -6.5103912353515625, -6.389538764953613, -4.749855041503906, -8.234357833862305, -7.900266170501709, -5.110470294952393], \"mode\": \"markers\", \"name\": 0, \"marker\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-10.827566146850586, -11.909122467041016, -11.305717468261719, -12.903533935546875, -12.534194946289062, -12.346872329711914, -12.307214736938477, -11.602080345153809, -12.780597686767578, -12.966633796691895, -10.946525573730469, -9.92597770690918, -12.905599594116211, -12.122573852539062, -12.58407211303711, -12.6441068649292, -11.21564769744873, -12.181347846984863, -11.21117877960205, -13.072080612182617, -11.5850248336792, -13.467394828796387, -12.65672492980957, -10.465242385864258, -11.917826652526855, -10.545066833496094, -8.642694473266602, -8.828369140625, -8.061355590820312, -8.110196113586426, -6.3602752685546875, -13.368795394897461, -9.113539695739746, -8.548568725585938, -8.671355247497559, -8.389947891235352, -9.568779945373535, -9.377766609191895, -8.490273475646973, -11.696104049682617, -10.55137825012207, -10.265970230102539, -11.469453811645508, -10.639190673828125, 13.748291015625, -11.224167823791504, -11.033990859985352, -10.97247314453125, -12.228050231933594, -10.267788887023926, -10.454047203063965, -10.768467903137207, 14.184226036071777, 13.449821472167969, 13.321700096130371, 13.736357688903809, 13.599352836608887, 13.52845573425293, 14.046616554260254, 13.2211332321167, 14.026569366455078, 12.928370475769043, 14.04179573059082, -5.733801364898682, 14.552776336669922, -7.7613043785095215, -7.555898189544678, -7.907632827758789, -6.491315841674805, -6.5335469245910645, -7.583098888397217, -8.04887866973877, -7.495293617248535, -8.429256439208984, -8.08998966217041, -7.456004619598389, -8.086626052856445, -7.810412406921387, -9.89983081817627, -8.758214950561523, -8.125533103942871, -5.3304057121276855, -7.033037185668945, 13.371352195739746, -6.0597100257873535, -8.248050689697266, -8.526755332946777, -9.926668167114258, -9.042177200317383, -8.971946716308594, -6.662446975708008, 13.455527305603027, 13.466410636901855, 13.645353317260742, 14.593564987182617, 14.332561492919922, 14.1117525100708, 14.475223541259766, 14.308937072753906, 13.568138122558594, 14.08556079864502, 14.274847030639648, 14.383922576904297, 14.061666488647461, -5.201333522796631, -6.280808925628662, -9.439273834228516, -6.279049873352051, -9.390647888183594, -8.876214027404785, -9.733814239501953, -9.206414222717285, -9.05965518951416, -6.038912296295166, -8.249279975891113, -10.405864715576172, -9.388751029968262, -12.059313774108887, -12.192066192626953, -12.509997367858887, -7.131499290466309, -12.396586418151855, -11.217509269714355, -9.362257957458496, -9.504068374633789, -12.60523509979248, -9.6105318069458, -9.48205280303955, -10.11495590209961, -12.875414848327637, -11.982316017150879, -12.412790298461914, -12.810571670532227, -11.118916511535645, -10.345826148986816, -12.061213493347168, -9.436575889587402, -12.481501579284668, -9.037550926208496, -10.490727424621582, -9.76076889038086, -10.477005958557129, -11.202588081359863, -11.761089324951172, -12.092497825622559, -11.925593376159668, -12.115891456604004, -12.305166244506836, -12.075262069702148, -12.00821590423584, -12.035648345947266, -11.831503868103027, -11.938721656799316, -12.271206855773926, -12.29833698272705, -11.787409782409668, -11.179159164428711, -10.026984214782715, -9.932075500488281, -10.646199226379395, -11.141708374023438, -10.465107917785645, -10.321433067321777, -11.154510498046875, -11.596464157104492, -10.807507514953613, -10.313669204711914, -10.350810050964355, -10.559351921081543, -6.169316291809082, -6.757174491882324, -7.51202917098999, -5.885586261749268, -7.409930229187012, -7.318585395812988, -6.175550937652588, -5.042765140533447, -6.081454753875732, -6.386892795562744, -7.114294528961182, -5.375392913818359, -5.376293659210205], \"y\": [-4.184731483459473, -2.4871349334716797, -1.2325547933578491, -2.1476402282714844, -1.8157031536102295, -1.4614334106445312, -1.9841479063034058, -2.1650314331054688, -3.050720453262329, -2.2791333198547363, -4.110365867614746, -9.39643383026123, -1.392618179321289, 1.1305358409881592, -0.9726213812828064, -0.17304782569408417, -0.32710108160972595, 0.09231075644493103, -0.4894208312034607, -2.16263747215271, -0.4459267258644104, -2.432382822036743, -0.2299826443195343, -1.6553964614868164, -2.5007309913635254, -1.5809317827224731, -7.073297500610352, -4.885290622711182, -5.839223861694336, -10.00139331817627, -7.683035850524902, -2.3967082500457764, -7.9815826416015625, -5.345093250274658, -5.045544624328613, -6.247196197509766, -8.054810523986816, -5.468915939331055, -10.607678413391113, 1.3126368522644043, -1.141910433769226, -0.9937639832496643, -0.542533814907074, -1.1897557973861694, -7.880704402923584, -0.8732361793518066, -1.9332401752471924, -2.4349889755249023, -1.7345863580703735, -1.0912736654281616, -1.0579053163528442, -0.484576016664505, -6.895153045654297, -8.009840965270996, -8.227214813232422, -8.68260383605957, -8.212570190429688, -8.927892684936523, -8.160848617553711, -8.421318054199219, -7.9686479568481445, -8.638541221618652, -7.059431552886963, -9.756778717041016, -6.010536193847656, -7.676952838897705, -10.099018096923828, -10.199301719665527, -7.34100866317749, -7.444638252258301, -5.362453460693359, -8.926629066467285, -5.168266773223877, -9.932950973510742, -10.37427043914795, -9.049175262451172, -8.81424617767334, -7.797077178955078, -6.1078200340271, -5.4367499351501465, -5.661554336547852, -8.863814353942871, -8.28874683380127, -9.261943817138672, -5.922898769378662, -10.776016235351562, -7.259383201599121, -7.530503273010254, -8.283665657043457, -6.501480579376221, -5.504086494445801, -9.049112319946289, -9.023128509521484, -9.501691818237305, -5.871133804321289, -7.112838268280029, -7.6776957511901855, -6.25387716293335, -7.196028709411621, -9.026862144470215, -7.366619110107422, -6.336265563964844, -6.194252014160156, -8.06201457977295, -7.754131317138672, -7.841803073883057, -7.307444095611572, -7.381941795349121, -8.246374130249023, -9.600674629211426, -7.136697292327881, -9.462654113769531, -6.87540864944458, -6.4388203620910645, -6.538257122039795, -8.626861572265625, -8.777498245239258, -2.6072120666503906, -1.964064598083496, -5.94359016418457, -6.755452632904053, -4.296993255615234, -6.747904300689697, -9.097959518432617, -6.48012113571167, -5.014648914337158, -8.38864803314209, -8.58858871459961, -9.645350456237793, -6.946598052978516, 2.0794358253479004, -4.91234016418457, 0.26123300194740295, -7.2413482666015625, -6.432297706604004, -0.2945283055305481, -6.155461311340332, -1.8480299711227417, -5.860062122344971, -5.664259910583496, -7.528328895568848, -8.121729850769043, -8.029393196105957, 1.6566225290298462, 1.9948441982269287, 0.3173580467700958, 1.4295073747634888, 1.8614689111709595, 2.4313676357269287, 2.4290924072265625, 2.7162318229675293, 1.9640926122665405, 0.3128484785556793, 1.9365031719207764, 2.18473744392395, 2.512389898300171, -6.01318359375, -10.137521743774414, -10.335636138916016, -6.179143905639648, -7.466185092926025, -10.316793441772461, -8.169886589050293, -7.461458206176758, -6.59722375869751, -6.503052234649658, -6.528499603271484, -5.9073686599731445, -5.99923849105835, -10.520843505859375, -8.517810821533203, -10.356085777282715, -10.008685111999512, -7.984958648681641, -9.725578308105469, -7.501064300537109, -8.587014198303223, -5.457345485687256, -6.555988311767578, -9.570831298828125, -8.484935760498047, -8.185859680175781], \"z\": [8.216835975646973, 2.7501862049102783, 4.3673272132873535, 4.214907646179199, 5.6060872077941895, 5.090933799743652, 6.377938270568848, 4.992412090301514, 5.092120170593262, 4.167708873748779, 8.081120491027832, 9.250310897827148, 2.88070011138916, 2.766906976699829, 2.6548357009887695, 2.190154552459717, 3.078521728515625, 2.3211910724639893, 3.8932430744171143, 2.7041075229644775, 3.1095476150512695, 2.0486624240875244, 2.0879619121551514, 3.5159075260162354, 2.7265326976776123, 3.1176061630249023, 7.632228374481201, 5.751526355743408, 6.026551723480225, 8.731374740600586, 9.8975830078125, 2.1702075004577637, 8.458090782165527, 6.318399906158447, 5.926570892333984, 8.228814125061035, 10.680869102478027, 10.50156021118164, 7.218724727630615, 4.657943248748779, 6.664333820343018, 4.459747791290283, 4.735278606414795, 6.613256931304932, 10.158440589904785, 4.646866321563721, 6.646491527557373, 6.835513591766357, 4.510189056396484, 5.362056732177734, 5.9895195960998535, 4.694235324859619, 8.737723350524902, 9.7448148727417, 8.7872314453125, 8.98465347290039, 7.641672134399414, 9.084696769714355, 7.855481147766113, 8.078290939331055, 7.9857025146484375, 7.988214015960693, 8.327959060668945, 8.534163475036621, 8.3378324508667, 6.81044864654541, 8.369301795959473, 8.09942626953125, 5.724946975708008, 5.778990268707275, 9.798503875732422, 6.0823140144348145, 9.703640937805176, 5.890573501586914, 6.461719036102295, 6.5609588623046875, 5.788365840911865, 6.047486305236816, 10.191986083984375, 11.38203239440918, 9.675158500671387, 7.799160480499268, 7.817317008972168, 10.409672737121582, 8.514512062072754, 8.573502540588379, 7.318488597869873, 8.173089027404785, 9.291983604431152, 9.2286376953125, 8.488640785217285, 10.0855131149292, 10.349488258361816, 10.143784523010254, 8.707046508789062, 9.855874061584473, 9.96664810180664, 8.926997184753418, 9.748351097106934, 10.037096977233887, 9.551153182983398, 9.160361289978027, 9.241886138916016, 9.95088005065918, 8.408488273620605, 9.13671588897705, 10.126965522766113, 7.458561420440674, 9.361599922180176, 6.384341239929199, 10.346393585205078, 8.590277671813965, 10.623109817504883, 7.689265251159668, 8.72296142578125, 7.713599681854248, 8.993642807006836, 6.146723747253418, 5.8919997215271, 7.051689147949219, 8.716550827026367, 6.856541156768799, 10.67857837677002, 8.253110885620117, 9.943920135498047, 7.13579797744751, 8.316609382629395, 8.161541938781738, 6.802364349365234, 7.044095516204834, 5.898270606994629, 7.011117935180664, 1.9829432964324951, 10.381963729858398, 10.288970947265625, 5.300385475158691, 9.435563087463379, 6.184915065765381, 11.714577674865723, 10.75485610961914, 11.183302879333496, 9.229645729064941, 9.285008430480957, 5.573055744171143, 4.694080829620361, 4.574207782745361, 3.164231061935425, 3.1227669715881348, 4.423942565917969, 4.364450931549072, 3.8934097290039062, 5.6128363609313965, 4.496248722076416, 3.8342273235321045, 3.269373893737793, 4.78983736038208, 9.356736183166504, 8.247152328491211, 7.652048587799072, 11.502643585205078, 9.32398796081543, 8.241077423095703, 10.171581268310547, 9.918570518493652, 11.125935554504395, 11.590723037719727, 10.259759902954102, 11.29261589050293, 11.539640426635742, 8.344965934753418, 6.524571895599365, 8.9097900390625, 8.444796562194824, 7.5806121826171875, 9.49682331085205, 7.330178260803223, 7.740687370300293, 9.858963966369629, 7.905205249786377, 8.362271308898926, 7.842913627624512, 8.095987319946289], \"mode\": \"markers\", \"name\": 1, \"marker\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.48753610253334045, 9.342896461486816, 5.920720100402832, 0.5340273976325989, -0.5768459439277649, -0.7002596259117126, -0.5440384745597839, -0.9355037212371826, -1.2001891136169434, 6.799711227416992, 3.9255945682525635, 0.16667887568473816, 0.7469857931137085, 5.529292106628418, 3.986828565597534, 4.822013854980469, 5.723148822784424, 4.32041072845459, 7.230229377746582, 7.1137166023254395, 4.877756118774414, 5.217931270599365, 5.3250603675842285, 7.316779613494873, 7.031344890594482, 5.750073432922363, 4.680910110473633, 5.216151714324951, 3.757751226425171, 4.423910140991211, 3.8926637172698975, 4.9139909744262695, 5.351200580596924, 4.839890003204346, 3.708493232727051, 3.5841658115386963, 3.887220621109009, 3.5433969497680664, 5.996980667114258, 8.694512367248535, 9.467896461486816, 9.694934844970703, 9.705801963806152, 8.073246002197266, 8.239194869995117, 9.094963073730469, 9.817119598388672, 8.207430839538574, 9.057477951049805, 8.153432846069336, 9.265279769897461, 0.15686911344528198, 7.65172004699707, 8.604114532470703, 8.567939758300781, 7.435904026031494, 7.733501434326172, 7.031217098236084, 7.736171722412109, 7.789455890655518, 5.0481767654418945, 7.415810585021973, 8.219293594360352, 5.537779331207275, 7.69680118560791, 3.898101329803467, 4.767670154571533, 4.634403705596924, 4.423253536224365, 4.506598472595215, 4.1608381271362305, 4.2346930503845215, 4.432117938995361, 5.3253397941589355, 3.8891544342041016, 3.622177839279175, 3.5049526691436768, 3.617863893508911, 5.152515411376953, 6.2199482917785645, 4.433529376983643, 4.910932540893555, 6.647972106933594, 4.0372209548950195, 8.423776626586914, 4.900318622589111, 6.2963385581970215, 3.87650465965271, 5.444586277008057, 6.146601676940918, 3.5618555545806885, 5.618246078491211, 8.52247428894043, 6.403207302093506, 7.13467264175415, 8.3141508102417, 7.992909908294678, 7.501036167144775, 8.16124439239502, 7.73394250869751, 7.5649919509887695, 8.314526557922363, 8.750493049621582, 6.662895202636719, 4.70881986618042, 7.691251754760742, 6.414530277252197, 7.114837169647217, 9.045122146606445, 6.253516674041748, 7.746669292449951, 8.563700675964355, 4.781879425048828, 7.731500625610352, 5.756507873535156, 5.703646659851074, 4.316622734069824, 5.1402692794799805, 4.35775089263916, 4.095414161682129, 4.84674596786499, 3.6314966678619385, 4.012618541717529, 2.91635799407959, 3.9765655994415283, 3.0923633575439453, 3.3960349559783936, 5.993826866149902, 8.586572647094727, 6.5414557456970215, 6.275485038757324, 6.807520866394043, 8.053889274597168, 6.635629177093506, 7.6771063804626465, 7.806852340698242, 7.460266590118408, 6.594245910644531, 7.470962047576904, 6.935745716094971, 8.406828880310059, 8.82966423034668, 8.207500457763672, 8.038198471069336, 9.145187377929688, 8.740948677062988, 8.919992446899414, 8.561885833740234, 8.675537109375, 7.977952480316162, 7.792421340942383, 5.957779884338379, 8.891460418701172, 5.806069850921631, 8.3233003616333, 9.204745292663574, 7.910576820373535, 6.815467834472656, 8.151593208312988, 3.9385364055633545, 8.311202049255371, 5.760833740234375, 7.505275726318359, 5.864363193511963, 7.884149074554443, 3.3405802249908447, 6.41190242767334, 8.122574806213379, 7.9350104331970215, 7.9210286140441895, 9.411046981811523, 7.395853042602539, 5.109996318817139, 6.391575336456299, 7.969184875488281, 9.345258712768555, 9.788956642150879], \"y\": [-3.0230133533477783, -5.803776741027832, -6.646180152893066, -3.1597909927368164, -2.4828293323516846, -2.3433947563171387, -2.937822103500366, -2.322186231613159, -2.0848731994628906, -10.913689613342285, -5.759332180023193, -2.8852438926696777, -3.2230634689331055, -10.925117492675781, -10.654276847839355, -4.499629974365234, -9.665587425231934, -10.208765983581543, -12.334656715393066, -9.960440635681152, -4.40047550201416, -9.822434425354004, -10.631241798400879, -12.643016815185547, -12.849943161010742, -9.801929473876953, -8.601359367370605, -8.804906845092773, -9.417587280273438, -11.217595100402832, -9.524253845214844, -8.21703815460205, -9.665761947631836, -8.435726165771484, -10.551716804504395, -9.431286811828613, -8.66014289855957, -10.642617225646973, -9.334747314453125, -6.32099723815918, -4.810490608215332, -7.83773946762085, -5.001193046569824, -6.41934061050415, -5.7355427742004395, -4.429324150085449, -6.187462329864502, -8.819232940673828, -9.93310260772705, -9.424782752990723, -8.798408508300781, -3.622349500656128, -2.381507396697998, -4.265542030334473, -4.096609592437744, -5.662094593048096, -5.7116475105285645, -5.160619735717773, -5.732185363769531, -3.613231658935547, -8.773444175720215, -10.995110511779785, -5.2571892738342285, -7.393367767333984, -5.844871997833252, -8.741111755371094, -8.377230644226074, -7.686216831207275, -5.049793720245361, -6.750277042388916, -4.617552280426025, -4.545808792114258, -5.7304534912109375, -8.945582389831543, -12.144099235534668, -7.702841758728027, -7.377834796905518, -8.397455215454102, -10.821002006530762, -9.754030227661133, -11.981307029724121, -9.837611198425293, -12.935803413391113, -11.673752784729004, -9.783019065856934, -12.61043930053711, -12.631281852722168, -4.458306312561035, -12.721665382385254, 0.27218011021614075, -8.374934196472168, -7.964495658874512, -11.519248008728027, -7.309785842895508, -7.067631244659424, -3.929759979248047, -5.6713409423828125, -4.083427906036377, -4.278022289276123, -8.33504581451416, -5.783756256103516, -3.567812204360962, -7.635630130767822, -10.07242202758789, -5.443800449371338, -3.6675033569335938, -3.2658684253692627, -4.048700332641602, -4.525984764099121, -1.7722610235214233, -6.292186737060547, -7.659564971923828, -5.395066738128662, -2.6741631031036377, -10.629714012145996, -7.236163139343262, -7.150862693786621, -5.637694358825684, -7.994674205780029, -10.809659004211426, -7.881167888641357, -7.5290985107421875, -4.649866580963135, -8.49604606628418, -12.201005935668945, -10.050792694091797, -7.584517478942871, -2.929123878479004, -2.2800185680389404, -2.474308729171753, -1.5423648357391357, -1.0183888673782349, -1.2073591947555542, -1.5771859884262085, -5.140833854675293, -0.6957600116729736, -4.486873626708984, -1.7786870002746582, -3.7313809394836426, -2.786655902862549, -9.760163307189941, -10.548978805541992, -9.179364204406738, -7.044344425201416, -8.926294326782227, -8.329384803771973, -8.691298484802246, -8.864411354064941, -8.303722381591797, -12.114180564880371, -7.721554756164551, -4.98110818862915, -8.64352035522461, -6.423591136932373, -1.6374300718307495, -3.9323582649230957, -0.37985745072364807, -7.0665154457092285, -0.7088648676872253, -9.083423614501953, -1.4760186672210693, -11.0220947265625, -10.075287818908691, -2.2343106269836426, -7.846498489379883, -8.48452377319336, -6.319341659545898, -12.068151473999023, -9.43150520324707, -11.897432327270508, -10.565208435058594, -6.623371124267578, -7.179174423217773, -6.3657546043396, -7.063424587249756, -8.10330581665039, -9.568429946899414], \"z\": [13.081997871398926, 17.51533317565918, 18.596454620361328, 13.791665077209473, 13.713499069213867, 13.735552787780762, 13.188928604125977, 13.747230529785156, 13.861645698547363, 16.760478973388672, 18.320281982421875, 13.790016174316406, 13.892999649047852, 15.14416790008545, 14.642023086547852, 14.828497886657715, 13.069965362548828, 14.518391609191895, 15.796555519104004, 13.34091567993164, 14.447178840637207, 13.82674789428711, 14.688305854797363, 15.640652656555176, 15.57707691192627, 12.844115257263184, 17.645322799682617, 17.311370849609375, 17.022335052490234, 16.90280532836914, 15.13888168334961, 16.972387313842773, 17.183530807495117, 16.26658821105957, 16.72413444519043, 15.8154296875, 17.357946395874023, 16.77614974975586, 16.36362648010254, 17.501197814941406, 16.020191192626953, 15.97821044921875, 16.13930320739746, 16.169240951538086, 15.869599342346191, 15.641743659973145, 16.66248893737793, 16.934467315673828, 15.34618091583252, 16.991321563720703, 15.883705139160156, 13.316110610961914, 17.7568416595459, 20.307512283325195, 20.145545959472656, 20.058753967285156, 20.26122283935547, 18.78605079650879, 20.243473052978516, 18.713232040405273, 18.18583869934082, 17.398962020874023, 20.28758430480957, 16.70880126953125, 20.274187088012695, 12.751047134399414, 12.493386268615723, 13.942596435546875, 13.551274299621582, 12.844311714172363, 13.112722396850586, 13.255538940429688, 13.262901306152344, 12.45284366607666, 16.100120544433594, 13.377217292785645, 13.290375709533691, 13.283239364624023, 16.07564926147461, 16.11756706237793, 15.928165435791016, 14.240092277526855, 15.66114330291748, 15.80513858795166, 14.681000709533691, 15.930338859558105, 15.808135986328125, 15.521710395812988, 15.868448257446289, 11.63801383972168, 14.098136901855469, 17.899112701416016, 15.141097068786621, 16.995393753051758, 16.77592658996582, 17.32029914855957, 17.72783660888672, 17.111154556274414, 17.54372787475586, 16.838876724243164, 18.22320556640625, 17.309938430786133, 15.286474227905273, 16.86497688293457, 18.250228881835938, 18.383949279785156, 16.916053771972656, 17.39310073852539, 15.742141723632812, 16.9420108795166, 17.099515914916992, 15.62519645690918, 18.2977237701416, 17.53416633605957, 16.247251510620117, 17.80048370361328, 14.291086196899414, 15.56667423248291, 13.704442977905273, 16.24686622619629, 16.001611709594727, 16.74109649658203, 15.663398742675781, 16.564952850341797, 15.936542510986328, 16.635059356689453, 16.475513458251953, 16.433868408203125, 17.11330795288086, 16.461660385131836, 16.778902053833008, 16.77367401123047, 16.241485595703125, 17.12515640258789, 15.777256965637207, 16.015546798706055, 18.034263610839844, 18.06739616394043, 16.962717056274414, 18.064319610595703, 15.515357971191406, 14.693791389465332, 15.360334396362305, 14.390057563781738, 15.797721862792969, 14.361010551452637, 14.016501426696777, 15.077579498291016, 14.502897262573242, 15.384842872619629, 15.152931213378906, 15.771039009094238, 13.969176292419434, 18.720535278320312, 15.410653114318848, 15.289288520812988, 15.845248222351074, 16.941831588745117, 16.190046310424805, 13.140289306640625, 15.54455852508545, 16.026193618774414, 13.234776496887207, 16.65988540649414, 16.649322509765625, 13.149500846862793, 13.453786849975586, 15.504497528076172, 15.244528770446777, 15.473670959472656, 14.488847732543945, 13.305045127868652, 13.7070951461792, 13.470211029052734, 14.186084747314453, 15.330533981323242, 14.464659690856934], \"mode\": \"markers\", \"name\": 2, \"marker\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [7.3015546798706055, 7.413646697998047, 7.079817771911621, 9.41799545288086, 7.8926496505737305, 9.116058349609375, 8.641244888305664, 8.530816078186035, 8.805084228515625, 8.285299301147461, 8.461874008178711, 8.587034225463867, 7.770370960235596, 9.038240432739258, 8.48620319366455, 8.037731170654297, 8.393963813781738, 8.388808250427246, 9.901891708374023, 7.614129543304443, 9.537302017211914, 8.875494956970215, 9.280976295471191, 9.145796775817871, 8.079692840576172, 6.743386268615723, 6.792569637298584, 4.669057369232178, 8.504585266113281, 4.764706134796143, 6.141941070556641, 5.10050630569458, 5.931851863861084, 5.940941333770752, 4.908916473388672, 6.9559197425842285, 6.850910663604736, 6.987812519073486, 8.250082969665527, 8.474345207214355, 5.894638538360596, 5.125760555267334, 7.765382289886475, 4.940516948699951, 4.465898513793945, 4.691445827484131, 4.6430559158325195, 5.0326762199401855, 5.137178897857666, 5.465907096862793, 6.051137447357178, 6.333110332489014, 4.809304237365723, 0.39993351697921753, 1.2319936752319336, 0.5986347198486328, 1.0111987590789795, 0.36060038208961487, 3.6950836181640625, -0.16849970817565918, 0.6116019487380981, 0.3035270571708679, 0.6335434317588806, 0.5618917942047119, 1.2769150733947754, 1.2266126871109009, 4.06983757019043, 3.6076669692993164, 4.2194671630859375, 4.097118377685547, 4.791540622711182, 4.271080017089844, 4.794374942779541, 5.963459014892578, 4.087339401245117, 4.07149076461792, 6.898747444152832, 6.849942207336426, 4.766132831573486, 6.862674713134766, 7.272140026092529, 8.185503959655762, 9.24951171875, 9.148548126220703, 9.293006896972656, 6.025407791137695, 6.079094409942627, 8.214132308959961, 7.250162601470947, 7.561081886291504, 8.512157440185547, 6.155101299285889, 8.579785346984863, 8.379480361938477, 6.8668694496154785, 7.507997035980225, 8.296615600585938, 8.5652494430542, 8.624847412109375, 7.207060813903809, 8.692774772644043, 8.642618179321289, 7.997570991516113, 9.040600776672363, 7.261545658111572, 8.35949993133545, 8.171317100524902, 7.158025741577148, 6.129117965698242, 6.211386680603027, 6.556643009185791, 5.0654296875, 6.274228572845459, 8.180363655090332, 8.325225830078125, -5.2500319480896, 7.966953277587891, 6.513846397399902, 5.712750434875488, 6.547682285308838, 7.8892011642456055, 8.602629661560059, 7.78570556640625, 8.567706108093262, 6.688238143920898, 7.206857681274414, 7.922371864318848, 7.3681960105896, 6.358635902404785, 8.350835800170898, 7.963878631591797, 7.552842140197754, 6.7603678703308105, 6.8904852867126465, 6.523571491241455, 6.321026802062988, 5.064694881439209, 4.876662731170654, 4.969051361083984, 6.914379596710205, 7.962066173553467, 7.3277587890625, 4.4863080978393555, 6.349786281585693, 6.1473188400268555, 5.964600563049316, 6.856779098510742, 8.907320022583008, 6.164173126220703, 8.19694995880127, 6.458999156951904, 7.515409469604492, 7.7584547996521, 6.4070963859558105, 9.258638381958008, 8.656461715698242, 7.742297172546387, 6.472586631774902, 4.975527286529541, 7.792771339416504, 7.679525375366211, 7.563621997833252, 7.779302597045898, 8.53715705871582, 7.360236644744873, 7.252785682678223, 6.83721923828125, 6.148585796356201, 6.5689167976379395, 7.037393569946289, 6.081777572631836, 8.328965187072754, 6.31028938293457, 8.779223442077637, 8.926855087280273, 9.299132347106934, 5.537827968597412, 8.805577278137207, 8.64305591583252, 8.154556274414062, 5.01324462890625, 6.297050476074219, 7.359136581420898], \"y\": [7.1785359382629395, 3.864008903503418, 1.3133739233016968, 4.630995273590088, 2.2634544372558594, 4.30478572845459, 3.6939890384674072, 2.092458724975586, 2.133413553237915, 3.210071086883545, 1.2485584020614624, 1.7851381301879883, -2.5580968856811523, 0.987450897693634, 3.796293258666992, 1.3320999145507812, 2.302276134490967, 3.970040798187256, 2.8655712604522705, 1.9913325309753418, 3.089046001434326, 2.1676244735717773, 2.236450433731079, 2.5259580612182617, 1.719977855682373, 0.9696843028068542, 7.097827911376953, 5.292856693267822, 7.434632778167725, 5.4091691970825195, 5.008094787597656, 4.865855693817139, 5.672499656677246, 5.553225040435791, 5.394509315490723, 4.7270660400390625, 5.058369159698486, 4.693751811981201, 7.745229244232178, 3.719390630722046, 4.623905181884766, 8.57890510559082, 11.08814525604248, 8.135305404663086, 8.077716827392578, 7.736551284790039, 8.153565406799316, 7.9978485107421875, 7.953851699829102, 7.974357604980469, 7.091980934143066, 7.3569746017456055, 8.862397193908691, 6.97905969619751, 6.540913105010986, 6.278901100158691, 7.19066047668457, 7.802128791809082, 5.940244197845459, 6.156862258911133, 6.98833703994751, 7.825969696044922, 5.931926250457764, 6.341174602508545, 7.101954460144043, 6.909090042114258, 5.358790397644043, 6.213089942932129, 4.626309871673584, 4.298932075500488, 5.955036640167236, 5.340080261230469, 6.414392948150635, 4.984899997711182, 5.527099132537842, 6.250779628753662, 5.1043829917907715, 5.1283159255981445, 4.392301559448242, 4.28283166885376, 5.054572105407715, 6.028068542480469, 5.316318988800049, 4.782440185546875, 4.5940728187561035, 4.127394676208496, 3.689979076385498, 5.063234329223633, 5.7853498458862305, 6.195620059967041, 6.1464104652404785, 2.8238604068756104, 9.368953704833984, 8.292845726013184, 9.069997787475586, 8.60964584350586, 7.55056619644165, 8.318000793457031, 10.269136428833008, 10.397805213928223, 10.769248962402344, 9.16501522064209, 10.920327186584473, 6.821186542510986, 10.32992172241211, 8.066303253173828, 8.522756576538086, 7.173116207122803, 6.140641212463379, 7.6940789222717285, 5.826387405395508, 8.025869369506836, 7.439008712768555, 7.80825662612915, 7.6835856437683105, -12.01269817352295, 7.898909091949463, 8.36392593383789, 8.244439125061035, 5.141961574554443, 7.113368988037109, -2.004786491394043, 6.866845607757568, 3.1962218284606934, 1.4604192972183228, 5.353181838989258, 0.9971900582313538, 2.680790662765503, 8.676675796508789, 5.23794412612915, 0.8092613220214844, 6.060222148895264, 5.710188865661621, 9.262499809265137, 7.39066219329834, 2.7000203132629395, 5.687589168548584, 7.465916156768799, 7.793002605438232, 6.952779293060303, 2.1715011596679688, 7.536888599395752, 6.5605998039245605, 8.180418968200684, 6.949100494384766, 8.3487548828125, 6.215232849121094, 5.947609901428223, 8.137346267700195, 7.896887302398682, 8.606088638305664, 6.926698684692383, 7.155182361602783, 5.245785236358643, 6.18391227722168, 7.633050441741943, 6.422194480895996, 2.4297497272491455, 3.0902750492095947, 2.1590843200683594, -1.7285085916519165, -1.5511311292648315, -2.4158542156219482, -1.6515036821365356, -1.1453649997711182, 1.4924074411392212, 2.643249750137329, 1.111543893814087, 2.510246992111206, 2.9808223247528076, 3.688323736190796, -0.25383463501930237, 1.944154977798462, -1.8047997951507568, -0.0382850207388401, -0.2637055814266205, 3.670882225036621, -0.6044549942016602, 0.41956353187561035, 2.968255043029785, 4.68057918548584, 2.0011773109436035, 3.9870824813842773], \"z\": [3.457082748413086, 7.813357353210449, 10.625985145568848, 8.951018333435059, 7.202033996582031, 9.027458190917969, 9.509380340576172, 8.508039474487305, 10.058058738708496, 9.733043670654297, 8.575311660766602, 9.186284065246582, 5.96522331237793, 10.05478286743164, 9.933396339416504, 10.333454132080078, 7.640806198120117, 10.218793869018555, 9.48549747467041, 11.274240493774414, 8.854496002197266, 9.982268333435059, 10.093697547912598, 8.892887115478516, 10.935257911682129, 10.966038703918457, 3.4117183685302734, 5.760101318359375, 7.823007106781006, 6.461649417877197, 3.705294370651245, 7.5353007316589355, 5.406838417053223, 5.414632797241211, 6.045984745025635, 7.275136470794678, 3.5640647411346436, 3.3654794692993164, 7.498910903930664, 6.760550498962402, 7.769204139709473, 3.118394374847412, 5.502676486968994, 4.221892833709717, 4.631917953491211, 2.954195022583008, 4.27570915222168, 2.5102415084838867, 2.958331346511841, 2.4414215087890625, 1.768036961555481, 2.2810137271881104, 2.3046460151672363, 9.590048789978027, 10.563082695007324, 11.353801727294922, 9.805440902709961, 9.7677583694458, 11.30720329284668, 10.213329315185547, 10.078442573547363, 9.92353630065918, 10.341127395629883, 10.80351448059082, 10.147517204284668, 10.224152565002441, 6.959818363189697, 7.8176655769348145, 5.910393238067627, 9.306009292602539, 8.305523872375488, 7.314127445220947, 8.817092895507812, 6.337478160858154, 7.90092134475708, 8.909493446350098, 1.9332506656646729, 1.992470383644104, 5.418702125549316, 2.4268975257873535, 4.580986976623535, 5.5728230476379395, 5.379965305328369, 4.5948405265808105, 4.61843204498291, 10.531536102294922, 10.39426040649414, 7.162641525268555, 3.6482954025268555, 5.001523971557617, 3.8537964820861816, 7.211933612823486, 6.1578803062438965, 3.6898040771484375, 2.9432592391967773, 2.7600600719451904, 4.8364644050598145, 3.8751556873321533, 6.242915630340576, 4.603460788726807, 6.289338111877441, 6.385032653808594, 5.683082580566406, 4.873601913452148, 4.5842108726501465, 8.143477439880371, 8.291282653808594, 8.694341659545898, 9.463286399841309, 9.10683536529541, 9.577226638793945, 7.882725238800049, 9.07645034790039, 8.713706016540527, 8.847810745239258, -3.343414306640625, 9.151348114013672, 9.504532814025879, 7.359191417694092, 9.048007011413574, 10.318567276000977, 5.229144096374512, 10.506729125976562, 6.85231351852417, 9.883637428283691, 10.106297492980957, 8.24681568145752, 9.000930786132812, 7.063814163208008, 7.200260639190674, 8.348262786865234, 8.129061698913574, 9.944450378417969, 2.889303207397461, 7.299322605133057, 7.5644850730896, 8.23703670501709, 8.841851234436035, 8.103852272033691, 7.125003337860107, 6.456498622894287, 5.822904586791992, 7.900754451751709, 7.253457069396973, 3.282724618911743, 3.8693795204162598, 3.240403175354004, 5.89702844619751, 3.410221815109253, 5.506599426269531, 3.925466537475586, 6.7483601570129395, 4.344146251678467, 5.498439311981201, 5.983231544494629, 6.231650352478027, 4.34853458404541, 8.48622989654541, 9.226417541503906, 6.629359722137451, 6.177629470825195, 5.9769768714904785, 5.998683929443359, 7.252555847167969, 5.992919921875, 7.322041034698486, 8.840625762939453, 6.970469951629639, 7.833456039428711, 8.283370018005371, 2.3362534046173096, 5.39408540725708, 2.3070385456085205, 5.121795177459717, 5.31194543838501, 5.044065475463867, 2.072270631790161, 5.322558403015137, 5.844764232635498, 6.983829498291016, 4.602605819702148, 2.2854599952697754, 5.413284778594971], \"mode\": \"markers\", \"name\": 3, \"marker\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-17.475631713867188, -16.9200439453125, -16.779300689697266, -17.3725643157959, -18.362926483154297, -15.99202823638916, -14.958146095275879, -17.1932430267334, -17.288366317749023, -16.64014434814453, -16.43488121032715, -15.077937126159668, -17.483543395996094, -16.035764694213867, -16.77069854736328, -17.181533813476562, -17.857561111450195, -18.836952209472656, -18.860429763793945, -17.33972930908203, -17.249568939208984, -18.888463973999023, -17.15690803527832, -16.83964729309082, -16.815723419189453, -16.440338134765625, -16.880521774291992, -17.93008804321289, -19.08321189880371, -18.221040725708008, -18.948444366455078, -17.06877326965332, -20.204471588134766, -15.401065826416016, -21.748117446899414, -17.80739402770996, -18.635290145874023, -17.243412017822266, -19.30828857421875, -19.847984313964844, -18.297382354736328, -16.9330997467041, -19.21842384338379, -18.28573226928711, -16.68873405456543, -19.48590850830078, -18.077537536621094, -16.682510375976562, -17.856081008911133, -16.879377365112305, -19.266130447387695, -18.948246002197266, -17.714859008789062, -21.17378807067871, -19.904176712036133, -19.370073318481445, -17.915176391601562, -19.148733139038086, -19.86643409729004, -19.939531326293945, -21.923114776611328, -19.687210083007812, -18.93956184387207, -19.149442672729492, -17.189393997192383, -17.55948829650879, -16.163740158081055, -16.42409324645996, -16.056486129760742, -17.855098724365234, -17.852113723754883, -19.621604919433594, -15.297622680664062, -22.014265060424805, -15.061985969543457, -22.280719757080078, -15.189435005187988, -22.131532669067383, -19.860668182373047, -21.138683319091797, -19.742414474487305, -19.085100173950195, -20.949913024902344, -19.464548110961914, -22.037817001342773, -22.557777404785156, -21.139108657836914, -19.356395721435547, -22.03240966796875, -21.729068756103516, -17.879589080810547, -17.967140197753906, -15.393442153930664, -15.172039985656738, -14.717047691345215, -15.471721649169922, -22.4145450592041, -14.651443481445312, -17.01142120361328, -17.254627227783203, -14.496809005737305, -13.491331100463867, -14.884119033813477, -14.117115020751953, -13.891798973083496, -14.872306823730469, -14.013284683227539, -14.827863693237305, -15.07956600189209, -14.556427001953125, -14.76125431060791, -16.6553897857666, -17.482324600219727, -14.554553031921387, -16.807344436645508, -14.694486618041992, -17.594263076782227, -19.02825927734375, -18.88616180419922, -18.259449005126953, -21.367347717285156, -17.022502899169922, -18.31441307067871, -18.328750610351562, -20.311399459838867, -20.20806312561035, -17.71664810180664, -19.045501708984375, -16.818326950073242, -22.154335021972656, -22.41827964782715, -22.550125122070312, -21.742185592651367, -21.719758987426758, -21.004127502441406, -21.05904197692871, -21.82407569885254, -18.114713668823242, -19.710264205932617, -19.623271942138672, -19.409099578857422, -21.020841598510742, -18.63784408569336, -20.591102600097656, -19.317956924438477, -18.457120895385742, -20.508085250854492, -19.25472640991211, -20.043235778808594, -19.351797103881836, -19.422616958618164, -19.842121124267578, -17.636667251586914, -20.140214920043945, -19.062105178833008, -16.61094093322754, -16.964670181274414, -17.197771072387695, -18.709362030029297, -16.68568229675293, -0.7213875651359558, -0.7671758532524109, -19.368436813354492, -16.925567626953125, -16.805282592773438, -17.164466857910156, -0.6628260016441345, -17.977924346923828, -17.40603256225586, -19.380779266357422, -18.900787353515625, -18.99045753479004, -16.954164505004883, -17.566144943237305, -18.21288299560547, -20.495525360107422, -16.734569549560547, -17.36549186706543, -20.21017074584961, -19.358144760131836, -19.08414649963379], \"y\": [1.3763108253479004, -0.8642842769622803, -0.18564866483211517, -1.3922797441482544, -0.061121173202991486, -1.3161226511001587, -4.597584247589111, -0.25225716829299927, 0.08347262442111969, -2.390944242477417, -1.6633461713790894, -4.516882419586182, -1.405064344406128, -5.284055709838867, -5.272739410400391, -3.8789172172546387, -5.00050163269043, -3.3332018852233887, -4.232583045959473, -4.979456424713135, -4.631378173828125, -4.176174163818359, -3.780022382736206, -3.053952693939209, -5.152273654937744, -2.023808479309082, -2.8237578868865967, -3.266784429550171, -0.5571475028991699, -2.436776638031006, -3.1764023303985596, -2.929800510406494, -0.4154728949069977, -3.640127420425415, 0.3351626694202423, -0.9489519000053406, -2.713541030883789, -1.2696365118026733, -3.5696299076080322, -4.661483287811279, -3.4086177349090576, -3.0434908866882324, -3.891988515853882, -2.95988392829895, -0.7163217067718506, -3.893519401550293, -3.498169422149658, -1.3861767053604126, -2.3192665576934814, -1.1064105033874512, -3.7100021839141846, -6.139007091522217, -6.170920372009277, -4.5376152992248535, -4.786737442016602, -3.8550446033477783, -6.149044036865234, -6.556962490081787, -5.293094158172607, -5.788503170013428, -5.1773762702941895, -3.509835720062256, -6.833011627197266, -6.178643703460693, -4.005849361419678, -4.277078151702881, -1.228192687034607, -3.7157175540924072, -3.68741774559021, -3.721937894821167, -3.985443115234375, -6.111423969268799, -6.7680583000183105, -5.240442752838135, -6.266303539276123, -4.375089168548584, -6.463327884674072, -2.211951494216919, -2.2744150161743164, -3.326772451400757, -0.4755805432796478, -3.2801601886749268, -3.142165422439575, 1.67550528049469, -2.851680278778076, 0.5837539434432983, -3.331151008605957, -1.1768951416015625, -2.1842117309570312, 0.7144724130630493, 1.511224627494812, 1.7724709510803223, 0.913096010684967, -0.22552946209907532, 0.6953033208847046, 0.9465413689613342, 2.477287769317627, 0.674345076084137, 2.2946889400482178, 1.4154152870178223, -0.44934162497520447, -1.311837077140808, -2.3257665634155273, -1.4681835174560547, -1.1016372442245483, -1.063894510269165, -0.4149930477142334, -2.088578224182129, -4.383401393890381, -1.5421336889266968, -3.069019079208374, -1.2860041856765747, 0.46800604462623596, -1.4078000783920288, -0.9221764802932739, -3.3428661823272705, -1.503509759902954, 1.6008810997009277, -4.148882865905762, 1.671847939491272, 0.6119957566261292, -0.26191794872283936, -0.07208486646413803, -0.819257915019989, -0.34821617603302, 0.7809972763061523, 0.06000767648220062, -0.032093919813632965, -2.6986806392669678, 1.7816420793533325, 2.0815818309783936, 2.1119015216827393, 1.6568992137908936, 2.007845878601074, 0.4708136320114136, 0.5808534026145935, 2.180819034576416, -0.9051434993743896, 0.542583167552948, 0.34466391801834106, -0.023428848013281822, 0.5004860162734985, -6.272749900817871, -4.192598819732666, -4.820032596588135, -2.4622771739959717, -4.7379655838012695, -3.8598201274871826, -3.459428310394287, -4.959980487823486, -4.61604118347168, -3.8183987140655518, -5.6627936363220215, -4.345124244689941, -3.1010589599609375, -2.9748620986938477, -2.107071876525879, -4.408398151397705, -2.4858527183532715, -4.562985420227051, -8.163947105407715, -8.138551712036133, -2.2300045490264893, -3.0802409648895264, -2.598252296447754, -5.318418025970459, -8.188207626342773, -2.1514933109283447, 2.5414345264434814, -0.28545865416526794, 0.13193055987358093, 0.48689910769462585, 0.9127366542816162, 2.2642884254455566, 2.2099664211273193, 0.9889585375785828, 0.2855018377304077, 1.410605788230896, 2.0545413494110107, 1.5541902780532837, -0.6704782247543335], \"z\": [-1.8102673292160034, -4.0876336097717285, -1.3409059047698975, -4.68557071685791, -3.080174684524536, -8.197813034057617, -4.852209568023682, -2.0293080806732178, -1.899247646331787, -8.80775260925293, -7.933374404907227, -4.978802680969238, -5.096914768218994, -0.5252307057380676, 0.13911163806915283, -0.32341331243515015, 0.900323212146759, -0.09659407287836075, 1.4098893404006958, 0.44582197070121765, 0.3452126681804657, 1.3113654851913452, 0.486491322517395, 0.6469846963882446, 0.10927528142929077, -7.611862659454346, -5.847756862640381, -7.742164134979248, -5.944921016693115, -6.823691368103027, -7.800638675689697, -5.814254283905029, -5.4871954917907715, -7.030957221984863, -4.3130035400390625, -6.61550235748291, -7.213767051696777, -5.002145767211914, 0.4922327995300293, -2.474665641784668, -0.6438981890678406, -1.7579455375671387, -1.651850700378418, -0.3866024613380432, -0.9151185750961304, -1.5652029514312744, -1.2974838018417358, -0.8628331422805786, -0.5724542140960693, -1.1272536516189575, 0.7152950763702393, -5.777735233306885, -6.694233417510986, -4.148437976837158, -6.0242018699646, -6.131462097167969, -6.282955646514893, -5.798614978790283, -5.705326080322266, -6.124820232391357, -5.060049533843994, -6.394657611846924, -5.849935054779053, -6.386712551116943, -0.8655476570129395, -0.7001035809516907, -0.09618090838193893, -1.8943978548049927, -2.431898593902588, -0.7882996797561646, -1.3157035112380981, -6.279134273529053, -7.231850624084473, -5.001996994018555, -7.323042392730713, -5.2255859375, -7.2808685302734375, -3.8305513858795166, -3.1171488761901855, -4.854804992675781, -4.274731636047363, -3.704712152481079, -3.731288194656372, -3.7263221740722656, -4.083231449127197, -3.630441427230835, -4.156848430633545, -2.977146625518799, -3.881103038787842, -3.64558482170105, -3.8685598373413086, -3.67511248588562, -3.732269048690796, -6.0128068923950195, -4.052994251251221, -3.6880834102630615, -4.438479423522949, -4.072926044464111, -2.6184866428375244, -3.9791319370269775, -5.491838455200195, -5.834179878234863, -6.682351589202881, -6.044618606567383, -5.767200946807861, -6.083579063415527, -5.215037822723389, -6.714287757873535, -7.6231889724731445, -6.415344715118408, -6.73353910446167, -7.049036026000977, -5.738692283630371, -6.613891124725342, -6.410061836242676, -6.63644552230835, -5.925558090209961, -3.3196167945861816, -5.3577117919921875, -3.562839984893799, -3.3846724033355713, -5.829578399658203, -4.088128566741943, -4.345372676849365, -5.336322784423828, -4.69972038269043, -6.254402160644531, -3.001224994659424, -8.8432035446167, -3.8033640384674072, -3.926255464553833, -3.850144386291504, -3.8240065574645996, -3.5494227409362793, -5.191485404968262, -5.452659606933594, -3.6041717529296875, -4.9573187828063965, -2.1149303913116455, -2.2173173427581787, -2.0980987548828125, -5.301987648010254, -5.334067344665527, -4.260056018829346, -4.87274694442749, -3.6605255603790283, -4.2109375, -4.411825180053711, -4.166650295257568, -5.067562580108643, -4.906900882720947, -4.277406215667725, -6.447353839874268, -4.256455898284912, -3.350863456726074, -6.57667875289917, -7.3807692527771, -7.577743053436279, -6.939297676086426, -7.365035057067871, -0.83269864320755, -0.8035109043121338, -6.996661186218262, -6.218621253967285, -6.695049285888672, -7.162291049957275, -0.8496039509773254, -7.211385726928711, -1.465680718421936, -5.984722137451172, -5.309928894042969, -6.797394752502441, -5.157110691070557, -2.2588980197906494, -2.541815996170044, -4.168274879455566, -2.529292583465576, -1.9942600727081299, -3.266576051712036, -3.2910678386688232, -3.7956504821777344], \"mode\": \"markers\", \"name\": 4, \"marker\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.08301404863595963, -2.685412883758545, 0.11812525242567062, -2.065103769302368, -2.0740439891815186, -1.9415643215179443, -1.7632330656051636, -2.3618361949920654, 0.9039490222930908, 0.36622196435928345, -0.5399121642112732, -2.997023105621338, -1.367246389389038, -2.286656618118286, -3.288245677947998, -1.578566312789917, -2.5331385135650635, -1.9881923198699951, -2.510267972946167, -1.7635242938995361, -1.756783366203308, -2.030202865600586, -2.6245710849761963, -1.6635650396347046, -2.3962714672088623, -1.9413384199142456, -2.2913501262664795, -4.229553699493408, -1.02217698097229, -2.1270029544830322, 1.334639549255371, 0.5512004494667053, -2.5109853744506836, -1.5131442546844482, -1.9582120180130005, -1.5567059516906738, -1.0681118965148926, -0.29521244764328003, -3.871781587600708, -3.6050350666046143, -2.638490915298462, -2.685260772705078, -3.923652172088623, -1.8278509378433228, -4.743711948394775, -3.1679635047912598, -1.7970341444015503, -1.7971936464309692, -2.929746389389038, -1.9805090427398682, -1.008275032043457, -2.510981798171997, -0.3979075253009796, 0.7887973785400391, -0.6775175929069519, -2.3585994243621826, -0.12713831663131714, -0.3372274935245514, -0.3158126175403595, -0.7211278080940247, 1.1280663013458252, -0.6121706366539001, -0.2599552869796753, -0.5415381789207458, 0.6752017140388489, 2.9522006511688232, 0.5318238139152527, 0.2765246033668518, 3.6861367225646973, 0.05322457104921341, 0.09648960083723068, -0.7519342303276062, 2.9399023056030273, 3.142392873764038, 2.2810864448547363, -1.1027745008468628, -0.5602957010269165, -1.0312026739120483, -3.9483911991119385, -3.704113006591797, -2.9973814487457275, -4.06766939163208, -1.417641520500183, -4.155812740325928, -2.9504125118255615, -3.7995011806488037, -3.1028635501861572, -3.4725520610809326, -2.1726913452148438, -3.412452220916748, -3.2547852993011475, -0.5532779693603516, -1.3061474561691284, -0.5794751048088074, -0.7364785671234131, -1.3821651935577393, -0.7487194538116455, -1.8653740882873535, -1.616836667060852, -0.9036091566085815, -1.3793689012527466, -1.2662389278411865, -1.0550596714019775, -0.6775572896003723, -1.4608708620071411, -2.8570568561553955, -1.3703632354736328, -0.7197443246841431, -2.171964168548584, -0.6757805347442627, -1.2362651824951172, 0.47996610403060913, 0.05537354201078415, 0.45838475227355957, 1.346112847328186, -1.7535303831100464, 1.422371745109558, 2.032029390335083, 2.3222949504852295, -3.1105005741119385, -0.17827466130256653, -3.3185434341430664, -3.925459146499634, 2.911428451538086, -0.012044054456055164, 1.328801155090332, -4.02610445022583, -2.9068996906280518, -0.7725733518600464, -1.3384082317352295, 0.9745394587516785, -0.08269917964935303, 1.743085503578186, 0.5044799447059631, 1.026587963104248, -2.2987101078033447, 0.5574591755867004, 2.1890807151794434, 8.306465148925781, 1.0656418800354004, -1.6651159524917603, 2.9569315910339355, -2.461531400680542, 0.11348544806241989, 0.35467529296875, 0.553004264831543, 0.34884965419769287, 0.20930007100105286, 0.590826153755188, -1.1918977499008179, 1.01048743724823, 1.170082688331604, -1.244591236114502, -0.33900654315948486, 1.019712209701538, -0.308161199092865, -2.0805859565734863, -1.2604767084121704, -2.040910005569458, -3.9544737339019775, -3.666987180709839, -1.8537839651107788, -2.5605692863464355, -2.5662386417388916, 0.18803484737873077, -2.3622665405273438, -3.9234251976013184, -1.0320810079574585, -2.1728572845458984, 1.5489953756332397, 1.8714027404785156, 1.9678151607513428, 1.3252170085906982, -0.658654510974884, -2.102800130844116, 1.9588251113891602, -0.23541276156902313, 1.9602326154708862, 0.9017851948738098, 2.1247057914733887, 1.7088865041732788, 1.0286864042282104], \"y\": [8.477279663085938, 1.9757733345031738, -0.9237343072891235, 4.598019599914551, 0.1974790394306183, 0.16510653495788574, -0.7547478079795837, 5.143782615661621, 1.5874905586242676, 1.9343715906143188, 0.46202367544174194, -0.19374212622642517, 0.18827319145202637, -1.1067554950714111, 0.8215852379798889, -2.7442564964294434, 0.11364280432462692, -2.2075932025909424, -1.903007984161377, -0.07010767608880997, -0.5873476266860962, -2.7818069458007812, -2.21036434173584, -2.141915798187256, -2.5560083389282227, -1.8075737953186035, 6.366917610168457, 0.09785566478967667, 5.095004558563232, 5.962522983551025, 4.080295085906982, 6.3360595703125, 6.120059967041016, 3.1250154972076416, 6.0772223472595215, 6.991847038269043, 3.875454902648926, 4.789083480834961, -1.0792672634124756, 4.093114852905273, 2.132740020751953, 2.401906967163086, 4.411002159118652, 2.578615188598633, 4.788196086883545, 2.6378300189971924, 7.221619129180908, 2.6228368282318115, 3.9670653343200684, 2.397157907485962, 0.6064704060554504, 2.2971842288970947, 7.920051574707031, 7.848963737487793, 7.786123752593994, 5.586735248565674, 8.111760139465332, 8.250167846679688, 7.505863189697266, 6.7325439453125, 8.281481742858887, 8.198933601379395, 6.3659491539001465, 8.16354751586914, 7.8452935218811035, 5.320967674255371, -0.6293837428092957, -0.7078018188476562, 4.281156539916992, 1.3387490510940552, -1.5030895471572876, 0.14241650700569153, 3.4795479774475098, 3.6074888706207275, 4.452942848205566, 0.010821809060871601, -0.705488383769989, -2.733104944229126, 1.104385495185852, -1.5025237798690796, -1.5033526420593262, -0.08275897800922394, -0.6498454809188843, 0.8573750257492065, 0.4385674297809601, -0.2801494896411896, -0.5776200890541077, 0.8389964699745178, -1.2619118690490723, 1.9412020444869995, -1.172173261642456, 5.9927520751953125, 7.921871662139893, 8.549057006835938, 7.452877521514893, 6.682126522064209, 8.21383285522461, 8.319872856140137, 6.717569828033447, 7.255167484283447, 5.193469524383545, 7.6774115562438965, 7.944188594818115, 5.667378902435303, 2.4072604179382324, 3.5098743438720703, 6.734063148498535, 2.938420295715332, 3.2105960845947266, 2.9071414470672607, 4.206096649169922, 4.674686431884766, 1.350136399269104, 1.9583545923233032, 4.594621181488037, 2.2688398361206055, 3.7108664512634277, 3.4908158779144287, 4.616276741027832, -2.1014010906219482, 4.367406845092773, 2.019371271133423, 1.296053409576416, 3.5073301792144775, -0.8989943265914917, 3.6299328804016113, -1.8225783109664917, -2.251286506652832, -2.73053240776062, -0.6413944363594055, 6.0080671310424805, 4.5148701667785645, 3.2304437160491943, 3.000117540359497, 2.424269676208496, 4.191417694091797, 2.9551639556884766, 3.400696277618408, -0.7207544445991516, 1.1551964282989502, 2.527508020401001, 3.3322196006774902, 5.213438987731934, 6.48717737197876, 5.844298362731934, 6.345604419708252, 5.859102249145508, 5.668928146362305, 5.78239631652832, 7.329810619354248, 5.215967178344727, 3.0007247924804688, 7.426074028015137, 8.430139541625977, 5.300679683685303, 5.094590187072754, -0.7239847779273987, -0.42214474081993103, 2.2745883464813232, 2.1595492362976074, -2.582289457321167, -0.3243989646434784, -2.932546377182007, -0.6358117461204529, 1.6328983306884766, 2.2416396141052246, -0.35265251994132996, -0.02009865641593933, 2.2694971561431885, 6.722196102142334, 5.973117351531982, 6.365815162658691, 5.248581886291504, 6.18495512008667, 5.128190040588379, 6.262630939483643, 7.7462544441223145, 6.577381610870361, 7.149861812591553, 5.6691203117370605, 5.909104347229004, 7.877176761627197], \"z\": [2.638666868209839, -13.1295747756958, -12.570115089416504, -10.626434326171875, -9.244645118713379, -9.242835998535156, -9.738129615783691, -11.605634689331055, -9.39612865447998, -10.615882873535156, -11.8826904296875, -12.515128135681152, -8.947940826416016, -12.8359956741333, -11.593602180480957, -15.225564002990723, -11.983981132507324, -14.585907936096191, -13.575278282165527, -12.028617858886719, -12.530350685119629, -15.132817268371582, -13.017965316772461, -12.995837211608887, -13.431105613708496, -12.157633781433105, -7.474548816680908, -12.04387092590332, -8.788961410522461, -8.634729385375977, -6.761839866638184, -3.823632001876831, -8.919053077697754, -14.348984718322754, -8.940908432006836, -7.786739349365234, -9.961227416992188, -6.4460859298706055, -13.750614166259766, -8.74514102935791, -8.700179100036621, -8.656865119934082, -8.516143798828125, -8.499526023864746, -8.135307312011719, -8.236083030700684, -10.386449813842773, -8.583449363708496, -9.815776824951172, -8.758439064025879, -12.924365997314453, -7.675414562225342, -10.099129676818848, -7.348390579223633, -8.203527450561523, -10.228873252868652, -7.041338920593262, -7.7375688552856445, -8.154033660888672, -8.59896469116211, -7.545482635498047, -6.947836399078369, -8.543924331665039, -10.391666412353516, -7.550856113433838, -10.25745677947998, -12.875212669372559, -13.09660816192627, -10.524514198303223, -14.679059982299805, -12.988259315490723, -13.096343040466309, -9.989843368530273, -10.149417877197266, -8.411529541015625, -13.293327331542969, -14.3537015914917, -15.410759925842285, -12.41807746887207, -14.308440208435059, -14.246042251586914, -10.501265525817871, -14.133788108825684, -12.4866304397583, -12.529155731201172, -10.58408260345459, -11.154260635375977, -10.96519947052002, -13.778495788574219, -10.754508018493652, -13.972305297851562, -8.65164566040039, -5.809396743774414, -4.357920169830322, -4.753599166870117, -7.032557487487793, -4.556517124176025, -4.145081520080566, -6.774106502532959, -5.5294718742370605, -8.792222023010254, -4.748089790344238, -4.635593414306641, -5.983297348022461, -12.815730094909668, -11.731903076171875, -9.822376251220703, -12.408835411071777, -13.669946670532227, -12.578861236572266, -9.976461410522461, -11.246935844421387, -14.677328109741211, -11.072927474975586, -11.021286010742188, -13.020500183105469, -10.963907241821289, -8.032773971557617, -8.331586837768555, -14.234539985656738, -9.872110366821289, -10.570356369018555, -12.579244613647461, -9.716479301452637, -13.637505531311035, -8.9832763671875, -14.118635177612305, -13.159001350402832, -15.466452598571777, -12.254449844360352, -6.669647216796875, -8.043474197387695, -9.680412292480469, -8.796931266784668, -9.435870170593262, -10.50840950012207, -8.609429359436035, -8.586153030395508, -8.386133193969727, -11.143800735473633, -10.953659057617188, -8.3147611618042, -11.712831497192383, -8.092391967773438, -6.319811820983887, -3.8066208362579346, -6.402787685394287, -6.500784873962402, -6.436359882354736, -6.6068115234375, -5.931481838226318, -7.9142842292785645, -6.655228137969971, -4.962485313415527, -7.405322551727295, -8.590423583984375, -14.836255073547363, -15.062471389770508, -13.156697273254395, -14.325615882873535, -14.854331016540527, -15.221579551696777, -15.24837875366211, -14.480378150939941, -10.428231239318848, -14.288919448852539, -12.190363883972168, -15.108146667480469, -14.213895797729492, -9.38515567779541, -9.836130142211914, -10.622176170349121, -9.744072914123535, -10.558465957641602, -11.482954978942871, -9.96630573272705, -10.123441696166992, -10.691003799438477, -8.62801456451416, -8.905112266540527, -10.930227279663086, -9.265571594238281], \"mode\": \"markers\", \"name\": 5, \"marker\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [10.928581237792969, 14.73205852508545, 10.616498947143555, 13.407443046569824, 11.0814208984375, 13.82938003540039, 11.366425514221191, 12.363516807556152, 11.124995231628418, 11.928298950195312, 9.788389205932617, 8.649663925170898, 11.032812118530273, 11.023523330688477, 13.388391494750977, 11.960299491882324, 11.727598190307617, 11.306059837341309, 11.625654220581055, 11.443159103393555, 11.413480758666992, 11.99350643157959, 13.632010459899902, 11.275300979614258, 13.25624942779541, 12.846925735473633, 12.930723190307617, 12.016923904418945, 13.549726486206055, 11.167546272277832, 14.752256393432617, 14.753996849060059, 15.708040237426758, 14.042840003967285, 12.311342239379883, 13.629748344421387, 12.77941608428955, 15.120826721191406, 10.305264472961426, 10.105396270751953, 11.27318286895752, 10.554213523864746, 9.978879928588867, 11.510895729064941, 10.246987342834473, 11.498729705810547, 10.66536808013916, 12.761981964111328, 11.898797035217285, 11.531963348388672, 7.558645725250244, 10.328418731689453, 9.321782112121582, 11.046360969543457, 9.190189361572266, 8.19082260131836, 8.477437019348145, 9.962220191955566, 8.816391944885254, 8.476259231567383, 8.199174880981445, 10.285454750061035, 10.457393646240234, 8.79902458190918, 13.899377822875977, 13.583479881286621, 13.263427734375, 11.342669486999512, 12.855134010314941, 12.753312110900879, 16.083839416503906, 12.011197090148926, 13.465595245361328, 13.701361656188965, 12.27675724029541, 13.576075553894043, 13.753466606140137, 12.750475883483887, 12.742444038391113, 12.128085136413574, 11.979413986206055, 11.513972282409668, 11.111129760742188, 11.949187278747559, 12.798749923706055, 10.598867416381836, 12.781291961669922, 12.619077682495117, 13.103315353393555, 12.35090446472168, 14.191083908081055, 12.369609832763672, 13.025566101074219, 14.017561912536621, 14.194077491760254, 13.557043075561523, 14.285233497619629, 13.930904388427734, 13.72063159942627, 13.962530136108398, 14.88211727142334, 12.573196411132812, 11.849102020263672, 11.79589557647705, 12.37200927734375, 14.710803031921387, 14.069846153259277, 10.476723670959473, 13.968059539794922, 15.398099899291992, 14.74520492553711, 12.849966049194336, 14.159468650817871, 15.65445613861084, 10.003945350646973, 14.512845993041992, 12.80517292022705, 9.836610794067383, 14.677617073059082, 14.65211009979248, 13.189669609069824, 15.36994457244873, 11.938821792602539, 11.923858642578125, 14.713403701782227, 15.213513374328613, 15.351487159729004, 11.40341854095459, 15.173064231872559, 15.10869026184082, 15.194818496704102, 16.104053497314453, 15.653685569763184, 12.52519702911377, 12.47620677947998, 12.982973098754883, 12.562165260314941, 14.245780944824219, 16.049272537231445, 15.201370239257812, 14.66342830657959, 13.674386978149414, 12.16520881652832, 12.283397674560547, 12.43907356262207, 9.851729393005371, 13.277972221374512, 11.935848236083984, 12.333867073059082, 12.325150489807129, 11.757737159729004, 12.646659851074219, 12.599878311157227, 12.547486305236816, 14.046171188354492, 15.239639282226562, 13.059599876403809, 11.551423072814941, 12.687994956970215, 14.219928741455078, 12.489447593688965, 12.334845542907715, 13.9990234375, 14.312472343444824, 12.973272323608398, 15.992984771728516, 12.283699035644531, 10.460855484008789, 10.240951538085938, 10.978190422058105, 10.037720680236816, 10.377548217773438, 10.864388465881348, 9.635683059692383, 10.621908187866211, 11.633678436279297, 10.229207038879395, 12.252172470092773, 11.241827964782715, 11.368793487548828, 11.665700912475586], \"y\": [-4.555772304534912, -3.0798490047454834, -5.07667350769043, -2.9969136714935303, -4.532172679901123, -2.7674264907836914, -4.68100643157959, -5.484598159790039, -4.81699275970459, -3.533393144607544, -5.0779571533203125, -4.171670913696289, -4.8468098640441895, -2.112997055053711, -0.35549023747444153, -3.4447615146636963, -4.371364116668701, -4.5566911697387695, -2.6455800533294678, -4.6928935050964355, -3.6940810680389404, -5.436384201049805, -3.509286403656006, 0.39570024609565735, 0.37298548221588135, -1.2760002613067627, -2.0995240211486816, -4.6942620277404785, -2.2965927124023438, 0.003800175618380308, -3.8448472023010254, -3.6948208808898926, -2.7438266277313232, -3.824270248413086, -1.1980246305465698, -2.001319646835327, -2.5418169498443604, -4.378009796142578, 0.5561990737915039, 1.3399263620376587, 0.7634656429290771, 1.84735906124115, 0.06857366114854813, 0.6119768023490906, 0.9307846426963806, 0.7005715370178223, -2.40329647064209, 0.9796587228775024, 2.0050415992736816, 0.0951060876250267, -3.9778895378112793, -1.75751531124115, -0.7366616129875183, -1.6234617233276367, -2.3193929195404053, -2.8552439212799072, -1.5980942249298096, -1.985949158668518, -0.7955102324485779, -1.5510621070861816, -3.183882474899292, -1.6650846004486084, -2.391695737838745, -2.1215991973876953, -4.466310501098633, -3.9928088188171387, -3.6745173931121826, -3.8205299377441406, -5.278356552124023, -1.979064702987671, -2.540736198425293, -2.8883445262908936, -3.279137134552002, -5.319445610046387, -1.7346775531768799, -4.907657146453857, -4.8811187744140625, 2.855128526687622, 3.288177967071533, 1.2584363222122192, 2.217480182647705, -2.0404036045074463, -0.17817917466163635, 2.324289560317993, 2.946188449859619, -0.006329053547233343, 2.0265846252441406, 0.5780669450759888, -3.0788049697875977, -3.429385185241699, -3.591782331466675, -4.074133396148682, -1.4304571151733398, -1.5784144401550293, -3.603304862976074, -1.474019169807434, -1.1677937507629395, -2.553158760070801, -1.7586190700531006, -2.6869704723358154, -0.508087158203125, -1.431227207183838, -0.2327839881181717, -1.934393286705017, 1.0321983098983765, -1.7993921041488647, -3.1064391136169434, -2.915008783340454, -5.045597076416016, -1.6885952949523926, -3.2376179695129395, -5.170385360717773, -4.887719631195068, -1.284198522567749, -5.195748329162598, -0.4236205518245697, -0.46665069460868835, -3.1534759998321533, -1.9469162225723267, -2.8477530479431152, 0.9030784368515015, -1.433334231376648, -2.060364007949829, -2.4282684326171875, -0.4243639409542084, -0.7112997174263, -0.9167152047157288, -1.3341442346572876, -0.4985508918762207, -1.248765230178833, -1.8688066005706787, 0.13925665616989136, -0.17047187685966492, 0.3678939640522003, 0.9101667404174805, 1.2531967163085938, -0.21617503464221954, -0.8370160460472107, 0.03834408521652222, -1.5415815114974976, 0.7549495697021484, 1.82317054271698, 0.3457164168357849, 0.6869778037071228, -0.3029048442840576, -0.4437790811061859, 0.7849535346031189, -1.3132591247558594, -3.6737706661224365, -1.7717258930206299, 0.5680280327796936, 0.5210446119308472, -0.36929604411125183, -0.24235616624355316, -1.5204514265060425, -1.2865394353866577, -1.102216362953186, -4.3541259765625, -0.7682923078536987, -0.9085873961448669, -2.683286190032959, -3.179900646209717, -1.0231866836547852, -0.8369622826576233, -2.4196906089782715, -2.5896382331848145, -3.533053398132324, -2.428522825241089, -4.743182182312012, 0.41702529788017273, -3.792389392852783, -3.354996919631958, 0.2576545476913452, -5.385371208190918, -3.308063507080078, -5.824520111083984, -4.856675148010254, -4.9417033195495605, -4.661458492279053, -4.486875057220459, -0.7284959554672241], \"z\": [-4.404854774475098, -3.5896875858306885, -4.863114356994629, -2.765070676803589, -5.570187568664551, -5.70928955078125, -5.103144645690918, -9.223640441894531, -4.703556537628174, -3.9581363201141357, -3.5987842082977295, -5.229947566986084, -2.8687074184417725, -9.098127365112305, -4.092918395996094, -4.464502811431885, -9.749593734741211, -8.040881156921387, -4.2998480796813965, -7.942378520965576, -9.159761428833008, -8.972823143005371, -3.6013951301574707, -6.125542163848877, -9.66050910949707, -9.843951225280762, -8.620857238769531, -9.973774909973145, -7.13043212890625, -10.862403869628906, -9.227628707885742, -9.11330509185791, -6.849229335784912, -4.586303234100342, -10.649145126342773, -7.22301721572876, -9.082145690917969, -9.220341682434082, -5.504188060760498, -4.785943984985352, -3.841313123703003, -4.292050361633301, -10.179333686828613, -3.808116912841797, -5.036420822143555, -3.573967218399048, -5.194639682769775, -3.395033597946167, -3.7249066829681396, -4.44541597366333, -5.156561374664307, -5.876122951507568, -8.600176811218262, -7.193210601806641, -6.571809768676758, -5.912238597869873, -7.481404781341553, -5.9842424392700195, -8.453910827636719, -7.486588954925537, -5.741471290588379, -5.828007221221924, -5.973723411560059, -5.978321552276611, -8.782179832458496, -9.023652076721191, -9.191444396972656, -9.584782600402832, -9.382787704467773, -10.608541488647461, -6.650765895843506, -11.281296730041504, -9.181797981262207, -5.7219390869140625, -10.521173477172852, -5.193536281585693, -5.1956048011779785, -5.830892086029053, -6.165279865264893, -4.536134243011475, -8.247842788696289, -3.7369585037231445, -4.732922554016113, -8.246899604797363, -5.758356094360352, -7.711283206939697, -4.78956937789917, -7.3056321144104, -2.4487855434417725, -10.087541580200195, -11.71653938293457, -10.763004302978516, -11.102485656738281, -9.165815353393555, -11.738966941833496, -8.604683876037598, -9.630780220031738, -10.5607328414917, -10.431729316711426, -5.761842727661133, -7.7440266609191895, -10.061111450195312, -9.409128189086914, -10.91940689086914, -9.184904098510742, -8.782798767089844, -3.7414257526397705, -4.729773044586182, -7.964292049407959, -5.624999046325684, -6.950530529022217, -5.185450077056885, -8.016934394836426, -7.070249080657959, -4.793490409851074, -8.50418758392334, -11.061018943786621, -6.466702461242676, -6.249284267425537, -6.9212470054626465, -4.057268142700195, -5.949678421020508, -5.335129737854004, -5.50938081741333, -6.448243618011475, -5.792942523956299, -5.639039516448975, -5.552145004272461, -4.935196876525879, -2.885342836380005, -3.3594512939453125, -4.223737716674805, -4.280749797821045, -4.231257438659668, -4.513515949249268, -4.242830276489258, -4.277962684631348, -3.819173574447632, -4.198322772979736, -3.9346940517425537, -2.9963762760162354, -4.478946208953857, -9.109329223632812, -9.426217079162598, -10.48753833770752, -8.950920104980469, -9.850252151489258, -9.776653289794922, -11.350913047790527, -7.973001956939697, -8.959567070007324, -8.458429336547852, -7.851080417633057, -7.973262786865234, -6.460412502288818, -2.049076795578003, -2.256197690963745, -2.530614137649536, -3.420377254486084, -2.5767807960510254, -3.44714617729187, -2.6247546672821045, -3.200066328048706, -2.6616392135620117, -2.3818743228912354, -5.069831371307373, -2.177774429321289, -3.123662233352661, -6.985002040863037, -7.545629501342773, -7.730307102203369, -8.216920852661133, -6.912175178527832, -5.481332778930664, -8.390491485595703, -9.385677337646484, -5.898719310760498, -4.964108943939209, -6.861639499664307, -3.6063151359558105, -8.211865425109863], \"mode\": \"markers\", \"name\": 6, \"marker\": {\"color\": \"rgba(255, 255, 51, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.0038599050603806973, -2.093423843383789, -5.1614813804626465, -4.203186988830566, 0.5189491510391235, -4.011181354522705, -2.3547468185424805, -1.1007589101791382, -5.268081188201904, -0.2506669759750366, -3.438760995864868, -1.086936593055725, -1.9506109952926636, 0.7475259900093079, 0.9953192472457886, 2.3045053482055664, -4.0541253089904785, -3.053619861602783, 0.618952751159668, 3.862091064453125, 2.117739677429199, 3.4680979251861572, -2.5390865802764893, 1.7184978723526, 3.0357730388641357, -3.6047608852386475, 0.54502272605896, -3.997831106185913, 1.3913378715515137, -3.7210352420806885, -4.55549430847168, -4.833897590637207, -1.3240302801132202, -0.8627880215644836, 2.2001821994781494, 2.2114803791046143, -0.8493049740791321, -3.605269432067871, -4.734476566314697, -5.112005233764648, -5.481454849243164, -6.742030143737793, -3.252392530441284, -4.906854629516602, -6.155129909515381, -6.75238561630249, -3.7238049507141113, -4.932497978210449, -5.789007186889648, -5.3113908767700195, -3.8952431678771973, 2.3484153747558594, -0.35650771856307983, -4.606544494628906, -2.1524064540863037, -1.3399558067321777, 1.7026128768920898, -4.9679365158081055, 0.5880866050720215, -0.981328547000885, 0.6968358159065247, -0.4237845242023468, 3.1439709663391113, -1.0807324647903442, -0.6166160702705383, -5.045203685760498, -7.243677139282227, -6.988693714141846, -6.991338729858398, -4.860947132110596, -5.23690128326416, -5.358004570007324, -7.077900409698486, -5.522628307342529, -5.664846420288086, -5.995028495788574, -0.8718975186347961, -1.3860259056091309, 0.4139682650566101, 1.324256420135498, 3.1274380683898926, -1.681803584098816, 3.717174768447876, 0.40659648180007935, 0.36991068720817566, -3.1269307136535645, 3.085686206817627, 0.3077988028526306, 0.2916403114795685, 1.4478094577789307, -1.9159818887710571, -0.7151064276695251, -2.3267018795013428, -0.40075796842575073, -3.5688891410827637, -0.6974485516548157, -2.102385997772217, -1.3483690023422241, -2.0147459506988525, -2.6771328449249268, -0.31684306263923645, -1.3564693927764893, 0.8902864456176758, -0.3964707553386688, 1.3423476219177246, 1.1320364475250244, 0.4861558675765991, 1.5586110353469849, 2.4936630725860596, 2.5940346717834473, 2.650512456893921, 0.34077081084251404, -0.8815020322799683, 2.4756155014038086, 1.6613287925720215, 1.297466516494751, -2.447171926498413, -5.284573078155518, 2.354548454284668, 0.5602063536643982, 0.07786351442337036, 1.0662771463394165, 2.2315049171447754, 2.9132258892059326, 0.5561085343360901, 2.004347562789917, -4.472914218902588, -3.3832194805145264, 2.900848627090454, -1.5523601770401, 0.07704093307256699, -1.9240409135818481, -0.2420041412115097, 0.18964052200317383, 1.0083918571472168, 0.7061065435409546, 3.251696825027466, -2.7023136615753174, 0.9018368721008301, -3.829488515853882, -0.47646626830101013, -3.3021438121795654, -4.120022773742676, -3.2500455379486084, -1.9897569417953491, -1.758618950843811, -4.926741123199463, -3.3504562377929688, -2.2356157302856445, -1.8327134847640991, -2.197572708129883, -3.002817392349243, -3.951279640197754, -3.2438719272613525, 2.7159767150878906, 2.259892225265503, 1.8031694889068604, 4.01847505569458, 4.63334321975708, 3.934715986251831, 2.3184194564819336, 4.158658504486084, 3.6760003566741943, -1.287140130996704, 1.7941912412643433, 3.973771333694458, -0.8247756958007812, -3.446972131729126, -0.8560844659805298, -2.94399094581604, -4.774163722991943, 0.6542467474937439, -0.1304192692041397, 2.5079872608184814, 1.73712956905365, -1.0284351110458374, 1.472805380821228, -2.6449522972106934, 2.0234792232513428], \"y\": [-14.87378978729248, -14.992799758911133, -16.009164810180664, -16.07781982421875, -15.198847770690918, -15.59908676147461, -15.320404052734375, -16.423019409179688, -15.004079818725586, -13.746530532836914, -15.752281188964844, -15.866131782531738, -14.832110404968262, -15.198366165161133, -15.467913627624512, -17.314830780029297, -14.795953750610352, -12.786778450012207, -15.726134300231934, -17.370845794677734, -18.436859130859375, -16.935091018676758, -14.562360763549805, -17.201059341430664, -16.917736053466797, -14.450419425964355, -15.736624717712402, -12.466906547546387, -15.105735778808594, -12.219593048095703, -13.5986328125, -12.488883018493652, -13.70108699798584, -14.165482521057129, -15.452167510986328, -16.88955307006836, -14.151620864868164, -13.851947784423828, -8.05136775970459, -7.910179138183594, -7.952444553375244, -7.326693058013916, -8.231036186218262, -7.948731899261475, -8.074149131774902, -7.327517986297607, -8.139480590820312, -6.958268165588379, -8.120327949523926, -7.72078800201416, -8.093320846557617, -18.407934188842773, -15.744479179382324, -13.943017959594727, -15.264066696166992, -15.173357009887695, -16.451908111572266, -13.932562828063965, -15.778517723083496, -16.091337203979492, -15.387688636779785, -15.278268814086914, -17.145156860351562, -15.298505783081055, -15.874232292175293, -14.118123054504395, -13.478314399719238, -13.678407669067383, -13.5923433303833, -14.638111114501953, -13.720020294189453, -14.66633129119873, -13.660449981689453, -14.526524543762207, -14.676115989685059, -14.618999481201172, -15.096253395080566, -13.32794189453125, -16.028505325317383, -14.533734321594238, -15.50760555267334, -13.10110092163086, -16.466726303100586, -14.387377738952637, -14.558728218078613, -14.114677429199219, -15.879446029663086, -16.02851676940918, -14.668243408203125, -17.939115524291992, -10.458918571472168, -11.66860294342041, -10.769630432128906, -11.749162673950195, -11.613960266113281, -11.67934513092041, -11.506993293762207, -13.640445709228516, -11.444998741149902, -10.990805625915527, -11.992609024047852, -11.051833152770996, -12.554625511169434, -12.138071060180664, -12.215166091918945, -11.298348426818848, -13.057896614074707, -11.802077293395996, -11.172024726867676, -13.593469619750977, -11.1051664352417, -12.278803825378418, -14.742188453674316, -13.624513626098633, -11.854788780212402, -16.015552520751953, -13.95228385925293, -13.929598808288574, -15.75998306274414, -15.300117492675781, -15.600991249084473, -16.438438415527344, -15.962347030639648, -17.10924530029297, -16.328006744384766, -16.25541877746582, -14.471693992614746, -14.70804500579834, -16.297653198242188, -12.745055198669434, -13.08325481414795, -12.264738082885742, -13.570121765136719, -13.199846267700195, -17.23832893371582, -16.0325927734375, -15.838339805603027, -14.449100494384766, -17.54448890686035, -14.472676277160645, -14.369009971618652, -11.259127616882324, -11.241586685180664, -11.16564655303955, -11.696975708007812, -10.629524230957031, -11.718764305114746, -12.202559471130371, -11.69134521484375, -12.518017768859863, -11.545552253723145, -10.270639419555664, -11.722517013549805, -10.750029563903809, -18.573463439941406, -18.30267333984375, -14.868929862976074, -16.323776245117188, -16.986724853515625, -16.300466537475586, -16.465044021606445, -16.121238708496094, -15.991500854492188, -16.961219787597656, -17.36432456970215, -15.248392105102539, -16.5437068939209, -15.720941543579102, -16.497047424316406, -12.198442459106445, -14.895672798156738, -16.58143424987793, -15.415570259094238, -17.468984603881836, -16.973941802978516, -14.472723960876465, -17.721494674682617, -13.908499717712402, -17.25748062133789], \"z\": [-0.48415493965148926, -6.933775424957275, -5.140028476715088, -5.765667915344238, -1.026469349861145, -4.553251266479492, -6.788053035736084, -3.338512897491455, -6.477664947509766, -6.870485782623291, -6.312717914581299, -4.949681758880615, -4.719244480133057, -6.714395999908447, -6.888797760009766, -5.302797794342041, -3.603364944458008, -5.7620530128479, -5.504180431365967, -5.451229095458984, -1.754773497581482, -5.830965042114258, -3.334838390350342, -4.626461029052734, -6.007786273956299, -2.24214243888855, -3.9203951358795166, -8.368672370910645, -4.088873386383057, -6.252474308013916, -4.523413181304932, -7.58958625793457, -7.32334041595459, -7.263733863830566, -6.017366886138916, -6.602942943572998, -7.130037784576416, -6.451875686645508, -6.263692378997803, -6.340020179748535, -6.463441371917725, -6.330093860626221, -6.587779521942139, -6.285155773162842, -6.604739189147949, -6.335838794708252, -6.499907493591309, -4.253734588623047, -6.574897766113281, -6.247513771057129, -6.461629390716553, -1.360728144645691, -1.8253527879714966, -4.2177414894104, -5.2602152824401855, -2.281973123550415, -1.1998810768127441, -3.437190055847168, -2.5175812244415283, -2.3114118576049805, -4.816307544708252, -3.56778883934021, -3.2365033626556396, -2.046691417694092, -3.4909121990203857, -3.4279778003692627, -5.987387180328369, -6.217676639556885, -6.249998092651367, -4.7053117752075195, -4.527806282043457, -5.136596202850342, -6.010014057159424, -5.239480972290039, -5.20936393737793, -5.912710189819336, -2.982024908065796, -6.1499762535095215, -4.547298431396484, -5.012302875518799, -5.0133957862854, -5.494068622589111, -5.584421157836914, -5.588831901550293, -6.043522357940674, -2.7521116733551025, -5.486516952514648, -6.442264556884766, -5.8251752853393555, -2.0537753105163574, -7.682677745819092, -8.510226249694824, -7.240685939788818, -7.73695182800293, -7.336568832397461, -8.185402870178223, -8.256637573242188, -5.707413196563721, -8.242775917053223, -7.669823169708252, -7.123222351074219, -6.897960662841797, -5.946230888366699, -7.075456619262695, -5.446816444396973, -6.427515029907227, -7.287545204162598, -5.734737873077393, -6.4827423095703125, -3.6448440551757812, -6.5369791984558105, -7.414454936981201, -0.765368640422821, -4.174315929412842, -6.053696632385254, -1.2099077701568604, -3.370213031768799, -3.533334732055664, -1.8485620021820068, -1.1383745670318604, -3.1621792316436768, -0.611502468585968, -1.7197805643081665, -2.8500635623931885, -3.9067611694335938, -0.7987844347953796, -3.326378345489502, -1.4852861166000366, -2.2502706050872803, -4.513653755187988, -3.8356211185455322, -4.882072448730469, -2.9797990322113037, -4.0274128913879395, -1.625738263130188, -1.5417221784591675, -5.125356674194336, -6.103024482727051, -4.903584003448486, -5.528587341308594, -2.6794145107269287, -6.418857097625732, -6.197110176086426, -6.639581680297852, -5.897033214569092, -6.0745930671691895, -6.524253845214844, -6.226407527923584, -4.941376686096191, -6.261125087738037, -5.734434604644775, -6.47698974609375, -6.08341646194458, -6.4106855392456055, -0.9817137122154236, -1.388361930847168, -3.4706428050994873, -2.784533739089966, -2.6779849529266357, -3.13222599029541, -3.165391445159912, -4.640491008758545, -2.198925733566284, -4.499117851257324, -4.591620445251465, -3.157543182373047, -2.414297580718994, -4.912849426269531, -2.3170077800750732, -8.70190143585205, -4.535368919372559, -5.381048202514648, -7.920151710510254, -5.761022090911865, -6.712001800537109, -4.316093921661377, -2.2630138397216797, -2.9137978553771973, -5.0658392906188965], \"mode\": \"markers\", \"name\": 7, \"marker\": {\"color\": \"rgba(128, 128, 0, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-0.16157656908035278, 0.15423166751861572, -0.17687584459781647, -1.28054940700531, 0.21375955641269684, -2.5616447925567627, -3.0202224254608154, -1.4151943922042847, -2.863831043243408, 1.0990471839904785, -0.4150402247905731, -1.4690122604370117, -11.103476524353027, -0.1691625416278839, -2.4708406925201416, -1.5828388929367065, -0.2516637146472931, 3.543043851852417, -0.3823775053024292, 3.325946092605591, -0.9141373634338379, -1.6292195320129395, -1.35783052444458, -0.5436268448829651, -0.8295237421989441, -2.65995192527771, -1.7683762311935425, -1.23227858543396, -1.6341456174850464, -1.921139121055603, -2.0058372020721436, -3.035966634750366, -1.8596128225326538, -0.7151488065719604, -1.6095281839370728, 0.7338882684707642, -2.402966022491455, -1.5958341360092163, -3.3810296058654785, -0.18362490832805634, -4.9542460441589355, -3.3022751808166504, -2.2300944328308105, -3.9021189212799072, -2.3455810546875, -0.6825240850448608, -2.674910545349121, -0.3550781011581421, -1.382484793663025, -2.906243085861206, -2.6572744846343994, -2.43422794342041, -1.343428134918213, -0.9123102426528931, -2.414853572845459, -0.8972333073616028, -0.3597951829433441, -0.6092586517333984, -1.0098567008972168, -2.835836172103882, -2.2843148708343506, -0.9595056176185608, -0.8233073949813843, -2.292461633682251, -0.687346875667572, -0.9812159538269043, -0.6621478199958801, -1.8495362997055054, -1.7407035827636719, -1.689937710762024, -2.8370585441589355, -2.976701021194458, -2.581181049346924, -2.4992127418518066, -3.714125394821167, -0.5891281366348267, -2.1158859729766846, -0.34822168946266174, -12.302939414978027, -3.239616870880127, -1.8877739906311035, -5.771195411682129, -6.019748687744141, -4.372987270355225, -0.27826908230781555, -6.866299629211426, -6.652362823486328, 2.256918430328369, -6.874943256378174, -0.4910142123699188, -0.5875145792961121, -0.43685799837112427, 0.10284221917390823, -0.6202135682106018, -1.9115371704101562, -0.3927057981491089, -2.514127731323242, -3.3847382068634033, 0.41369277238845825, -2.3249218463897705, -0.8965171575546265, -1.0664514303207397, 1.6470783948898315, 2.6218984127044678, 2.3090240955352783, -0.9953585267066956, 1.65755295753479, 2.489218235015869, 2.4156510829925537, 0.15140517055988312, 2.812136650085449, 1.757753849029541, 2.864362955093384, 2.679401397705078, 0.277237206697464, -2.1607553958892822, -1.496523380279541, 0.39066916704177856, -0.2472631335258484, -1.4818799495697021, 0.3657974600791931, 0.6293726563453674, 0.36914902925491333, -1.4437462091445923, -0.014960494823753834, -0.43568870425224304, 0.29839804768562317, -2.7002975940704346, -3.1363213062286377, -1.3884367942810059, -0.7140008807182312, -2.59879207611084, -2.4768197536468506, -2.79020094871521, 0.9195737242698669, 0.4437640607357025, -3.0326857566833496, -3.032930850982666, -0.19953307509422302, -2.798530101776123, -2.5117087364196777, -1.9568476676940918, -3.5379533767700195, -3.410677671432495, -6.556118488311768, -4.3121490478515625, -4.594820499420166, -5.469381332397461, -5.308681011199951, -5.004605770111084, -5.638632774353027, -4.781658172607422, -11.895265579223633, -2.0203006267547607, -3.5346240997314453, -1.7684130668640137, -1.7503432035446167, -1.3731616735458374, -2.274016857147217, -1.7902852296829224, -1.7090818881988525, 1.6718850135803223, 1.5816941261291504, 1.4783393144607544, 0.7382558584213257, 1.563803791999817, -0.10745985805988312, 0.8126714825630188, -3.285022735595703, 1.8332552909851074, -0.6805346012115479, -4.917081356048584, -2.8348662853240967, 1.1253012418746948], \"y\": [-2.335360527038574, -7.7346272468566895, -5.5560784339904785, -8.926433563232422, -6.071552276611328, -6.264793395996094, -6.575736045837402, -8.405547142028809, -5.438358783721924, -7.370777606964111, -4.481733322143555, -9.145427703857422, -8.392160415649414, -4.195847988128662, -3.428785800933838, -5.9620842933654785, -4.357433795928955, -5.352654457092285, -3.6233720779418945, -5.232904434204102, -3.2911083698272705, -5.318873405456543, -4.313727378845215, -4.1214189529418945, -3.4871084690093994, -5.139627456665039, 0.8883853554725647, -5.618924617767334, -5.365184307098389, -1.3600455522537231, -1.2894319295883179, 1.698355793952942, 0.21004408597946167, -4.10762357711792, -1.0820435285568237, 0.8754655122756958, -0.9859659075737, -5.506242275238037, 0.01678399182856083, -5.355037689208984, 1.2326072454452515, -0.9040559530258179, -0.675254225730896, 1.7896617650985718, -0.9679729342460632, 0.9865584373474121, 1.101410150527954, -4.5895514488220215, -4.6120829582214355, -0.6013191342353821, -0.5787487030029297, -2.4610464572906494, -1.6790746450424194, -1.281447410583496, -1.9935003519058228, -1.3365271091461182, -0.6925838589668274, -1.2000166177749634, -1.4735134840011597, -1.5731316804885864, -2.2235724925994873, -1.3561599254608154, -1.2928963899612427, -1.9041523933410645, -0.4287949502468109, -2.8260293006896973, -0.27590814232826233, -2.7205889225006104, -2.3933444023132324, -3.5023117065429688, 1.5069018602371216, -3.8333802223205566, -5.485445022583008, 0.19973020255565643, -6.952685356140137, -0.3836662173271179, -4.1724395751953125, -10.656527519226074, -1.6643508672714233, -5.138930797576904, 1.9364230632781982, 1.8100106716156006, 1.8045839071273804, -2.22615122795105, -10.571366310119629, 0.4892898201942444, 0.6011685729026794, -2.7888548374176025, 0.4072481095790863, -10.731918334960938, -1.3263813257217407, -0.009670021943747997, -0.5210273265838623, -0.41837137937545776, -0.26936468482017517, 0.40215325355529785, -0.45149487257003784, 1.8670446872711182, -0.1731099933385849, 1.5758116245269775, -0.4192773103713989, -4.682238578796387, -6.594776630401611, -3.52463698387146, -2.14652681350708, -3.8317480087280273, -6.830428123474121, -2.8974239826202393, -3.047152042388916, -5.491374492645264, -1.9989722967147827, -5.689858913421631, -4.524102687835693, -3.9101083278656006, -0.08478618413209915, -7.90638542175293, -7.467137336730957, -7.2581257820129395, -8.763558387756348, -6.988485813140869, -6.93161678314209, -7.1290435791015625, -10.015509605407715, -8.129985809326172, -7.683114051818848, -6.928806781768799, -6.762292861938477, -5.459874153137207, -6.626316070556641, -6.695282936096191, -6.286172866821289, -5.5307183265686035, -6.176853656768799, -3.719045400619507, -7.008397579193115, -6.341485977172852, -6.194670677185059, -6.771040439605713, -7.142819404602051, 1.4521442651748657, 1.7438132762908936, 1.8831089735031128, 0.014522464014589787, 0.3201521635055542, 2.016523599624634, 1.587417483329773, 1.3536475896835327, 1.2312177419662476, 0.8828184604644775, 0.5341009497642517, 0.8882064819335938, 0.5590283870697021, -5.794144153594971, -9.564743041992188, -5.151362895965576, -3.314129114151001, -6.26654052734375, -4.31486177444458, -3.495913505554199, -5.823446750640869, -5.485396862030029, -5.025003433227539, -5.27311372756958, -4.260406017303467, -1.8946603536605835, -5.640187740325928, -5.876474857330322, -3.865351676940918, -4.437758922576904, -3.007277727127075, -7.57647180557251, -5.453993797302246, -4.160566329956055, -2.1546709537506104], \"z\": [6.5244574546813965, 4.298973083496094, 6.530811309814453, 3.3163485527038574, 6.041913032531738, 6.870987415313721, 3.8958427906036377, 4.294079303741455, 5.361408233642578, 5.81116247177124, 8.007184982299805, 3.2318949699401855, 7.105417728424072, 5.6568708419799805, 5.703893661499023, 8.202545166015625, 5.690670013427734, 3.961014747619629, 7.14064359664917, 3.99360728263855, 9.02164363861084, 7.482443809509277, 7.35653829574585, 7.792703628540039, 9.15381145477295, 5.439960956573486, 4.633840560913086, 2.1687119007110596, 1.950865387916565, 7.385507583618164, 6.6939873695373535, 3.876417875289917, 5.322096347808838, 4.325260162353516, 5.592494010925293, 3.83769154548645, 6.63026237487793, 2.325263738632202, 2.412457227706909, 4.479692459106445, 5.030158519744873, 4.258852005004883, 3.3196496963500977, 2.765387535095215, 2.5146114826202393, 6.33440637588501, 6.011269569396973, 4.607758045196533, 4.995482444763184, 5.025672912597656, 3.4679181575775146, 10.293269157409668, 9.337993621826172, 9.110560417175293, 9.781026840209961, 9.81020736694336, 10.143835067749023, 10.382593154907227, 9.884489059448242, 9.194732666015625, 10.411266326904297, 10.435152053833008, 10.225500106811523, 9.914207458496094, 5.4581217765808105, 3.2587201595306396, 5.740013599395752, 4.1180291175842285, 4.2219061851501465, 3.4620730876922607, 5.1688456535339355, 4.956800937652588, 2.797302484512329, 5.322413444519043, 3.348438262939453, 6.027746677398682, 3.540391445159912, 10.27232551574707, 7.233818054199219, 3.510542869567871, 3.3284223079681396, 3.325801134109497, 3.164818286895752, 4.656958103179932, 10.258200645446777, 4.307090759277344, 4.165774822235107, 7.101991653442383, 4.477790355682373, 10.267870903015137, 4.019381999969482, 3.7904367446899414, 3.960110902786255, 4.580117702484131, 3.2858948707580566, 3.719355583190918, 5.1747941970825195, 3.3009674549102783, 4.1602606773376465, 3.8229317665100098, 5.029813289642334, 1.2859128713607788, 4.037378311157227, 4.3728485107421875, 3.822932481765747, 6.6785149574279785, 4.138460159301758, 3.9707229137420654, 3.9524190425872803, 1.89812171459198, 3.5136988162994385, 7.31431245803833, 4.1313018798828125, 4.254940986633301, 2.9861807823181152, 3.772451877593994, 4.303273677825928, 2.297518014907837, 4.260953903198242, 0.9171381592750549, 2.5459978580474854, 3.8694119453430176, 10.193195343017578, 4.6285552978515625, 5.26862907409668, 5.842716693878174, 5.17963981628418, 4.841660022735596, 4.0710015296936035, 4.307178974151611, 5.923704624176025, 5.916282653808594, 4.617840766906738, 5.508224964141846, 4.903766632080078, 6.155306339263916, 5.595669269561768, 3.8198888301849365, 4.192324638366699, 3.2218222618103027, 3.6036508083343506, 3.5155327320098877, 3.777913808822632, 2.6710524559020996, 2.899770736694336, 2.432058095932007, 2.617152452468872, 2.9591779708862305, 3.8368475437164307, 4.0997138023376465, 2.9363114833831787, 4.271831512451172, 6.280550956726074, 3.097072124481201, 2.086261749267578, 9.202387809753418, 4.1802849769592285, 9.41122817993164, 9.109088897705078, 8.897782325744629, 9.379862785339355, 6.970796585083008, 4.537351608276367, 6.798648357391357, 6.362218856811523, 3.073171854019165, 2.0430853366851807, 6.674989223480225, 6.977803707122803, 6.8921074867248535, 6.955923557281494, 8.40312385559082, 6.863940715789795, 6.511366367340088], \"mode\": \"markers\", \"name\": 8, \"marker\": {\"color\": \"rgba(251, 128, 114, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}, {\"type\": \"scatter3d\", \"x\": [-3.5452239513397217, 0.8987004160881042, 0.7113070487976074, 0.76677405834198, 1.5517014265060425, -5.101104259490967, -1.0601961612701416, 0.17317542433738708, -6.136868953704834, -0.060231588780879974, -0.4307577908039093, -2.2882699966430664, -6.4795942306518555, -1.153012752532959, -0.7794856429100037, -1.0691170692443848, -0.5070387125015259, -2.2192330360412598, -0.9279105067253113, -1.7440407276153564, -2.753859519958496, -3.42671799659729, -0.6218461394309998, -4.308475971221924, -3.424391746520996, -4.5274338722229, -3.212934970855713, -4.345305919647217, -1.6678754091262817, -5.112109184265137, -2.0134782791137695, -4.028072834014893, -3.3288891315460205, -4.113256454467773, -3.605736255645752, -8.994102478027344, -9.648197174072266, -4.259121894836426, -6.145261764526367, -2.37394118309021, -2.418226480484009, -4.193965911865234, -4.139916896820068, -3.912768840789795, -4.244919776916504, -4.09126091003418, -3.608605146408081, -4.099870204925537, -3.8030147552490234, -7.7499589920043945, -3.884312629699707, -3.5599889755249023, -8.021580696105957, -2.158449172973633, -0.5793607831001282, -6.620200157165527, -2.9081857204437256, -7.6478800773620605, -4.666223049163818, -2.91481614112854, -2.8969552516937256, -2.91925311088562, -6.921403884887695, -3.4657881259918213, -9.367088317871094, -10.69479751586914, -10.022095680236816, -10.997507095336914, -9.755760192871094, -10.471936225891113, -10.339160919189453, -10.990245819091797, -10.650537490844727, -10.893157958984375, -10.08554744720459, -9.597884178161621, -9.572175979614258, -2.321605920791626, -6.032505989074707, -3.4721579551696777, -6.233365058898926, -0.005729478783905506, -6.5399651527404785, -3.8515615463256836, -3.6142213344573975, -6.312745094299316, -2.408769369125366, -7.229518890380859, -7.52880334854126, -5.223739147186279, -1.2023955583572388, -2.406672716140747, -1.7564573287963867, -4.0315093994140625, -1.2019113302230835, -2.7786712646484375, -1.1159764528274536, -1.2856892347335815, -1.1904006004333496, -2.5106115341186523, -3.571286916732788, 0.8822445273399353, -2.801027536392212, -1.6019443273544312, 0.5174892544746399, -0.035314369946718216, -4.705508232116699, 0.5837446451187134, -4.942124366760254, 0.39733657240867615, 0.3234463632106781, 0.7222546339035034, -1.1044061183929443, -2.551095962524414, 0.9948933720588684, -1.9387518167495728, -4.83139181137085, -0.3318290114402771, -4.603866100311279, -5.227324485778809, -6.0109944343566895, -4.826846122741699, -1.29799222946167, -4.648032188415527, -5.025382041931152, -4.509164333343506, -4.286328315734863, -4.9305620193481445, -5.169703483581543, -3.0391526222229004, -4.735513687133789, -5.432796001434326, -5.496824741363525, -3.0655100345611572, -5.150146007537842, -1.8831006288528442, -4.178787708282471, -3.6008310317993164, -6.631713390350342, -6.568338871002197, -7.794665813446045, -4.3895158767700195, -5.766277313232422, -4.2099833488464355, -4.317129135131836, -5.618536949157715, -5.002274990081787, -3.2450146675109863, -4.601253032684326, -5.656275749206543, -3.7573347091674805, -5.037494659423828, -7.0247297286987305, -6.677652835845947, -10.065397262573242, -7.903085231781006, -7.904557228088379, -8.098923683166504, -4.216858863830566, -4.201270580291748, -8.729108810424805, -1.0699952840805054, -3.9289650917053223, 0.19364136457443237, 5.242171287536621, -4.200894832611084, -3.973729372024536, -2.8062546253204346, -4.030859470367432, -1.6586061716079712, -5.067908763885498, -6.371127605438232, -5.902195453643799, -4.293332099914551, -3.0899105072021484, -4.727687835693359, -5.011448860168457, -0.5729548931121826, -5.565677642822266, -3.591493606567383], \"y\": [6.2141900062561035, 10.732292175292969, 10.139453887939453, 11.143545150756836, 9.170663833618164, 13.285693168640137, -7.940405368804932, 9.45600414276123, 13.533422470092773, 11.444572448730469, 12.233986854553223, 6.5655717849731445, 11.762133598327637, 10.755566596984863, 8.768488883972168, 10.08327579498291, 10.329419136047363, 12.423651695251465, 10.973310470581055, 8.497230529785156, 7.053796768188477, 6.990411281585693, 9.441194534301758, 6.640681266784668, 7.668744087219238, -6.756194114685059, -6.4502363204956055, 11.919219017028809, 12.725125312805176, 6.724958896636963, 9.543999671936035, -6.064614772796631, -6.443902969360352, -6.560335636138916, -6.215483665466309, -1.0925471782684326, -0.6780577898025513, -6.454477787017822, 12.80986499786377, 11.554337501525879, 11.647439002990723, 7.576629638671875, 7.796771049499512, 9.899489402770996, 9.531002044677734, 7.886047840118408, 9.352054595947266, 7.881032943725586, 9.753850936889648, 11.13195514678955, 9.546371459960938, 5.438201904296875, 9.371904373168945, 5.654523849487305, -4.513395309448242, 11.219331741333008, 5.155284881591797, 9.919486999511719, 8.52518367767334, 5.138667583465576, 5.15177059173584, 10.542475700378418, 9.61723804473877, 11.467488288879395, -0.4737580120563507, -0.6972350478172302, 0.029107850044965744, -0.7746095061302185, -0.7347769141197205, -0.5612821578979492, -0.17616461217403412, -0.3101782202720642, 0.11739662289619446, -0.8892012238502502, -0.8781147003173828, -0.15736667811870575, -1.2064143419265747, 11.249374389648438, 10.769349098205566, 11.899808883666992, 10.902691841125488, 8.371675491333008, 10.291570663452148, 12.226974487304688, 8.286294937133789, 11.275747299194336, 12.305252075195312, 11.397576332092285, 11.231154441833496, 12.474898338317871, 12.135167121887207, 10.737773895263672, 11.596725463867188, 12.153912544250488, 10.207104682922363, 11.986929893493652, 12.136144638061523, 12.043828010559082, 10.423619270324707, 11.152774810791016, 12.549439430236816, 9.326777458190918, 10.672612190246582, 6.179229259490967, 7.689123153686523, 7.840329170227051, 5.644383907318115, 8.078897476196289, 5.847241401672363, 7.602556228637695, -5.878284454345703, 8.373934745788574, 7.490850925445557, 8.37104606628418, 7.335646152496338, 6.8211212158203125, 6.394490718841553, 12.394442558288574, 6.452043056488037, 8.629375457763672, 8.281880378723145, 8.72381591796875, 8.670578002929688, 6.8155927658081055, 8.394925117492676, 7.429281711578369, 7.136112689971924, 12.032958030700684, 6.526446342468262, 10.525069236755371, 9.986067771911621, 9.217979431152344, 9.995776176452637, 9.345136642456055, 7.838392734527588, 12.76759147644043, 9.332334518432617, 11.126167297363281, 9.732451438903809, 9.275304794311523, 10.18766975402832, 11.639954566955566, 12.666860580444336, 11.671326637268066, 10.815666198730469, 11.9705171585083, 13.164933204650879, 12.341290473937988, 12.745698928833008, 11.731030464172363, 12.305394172668457, 10.297494888305664, 12.453042984008789, 12.207681655883789, 0.33506157994270325, 0.2921890318393707, 0.30532148480415344, 0.19982406497001648, -4.658197402954102, 2.2165589332580566, -1.0658572912216187, 11.975008010864258, -5.625916957855225, 11.545854568481445, 1.7092149257659912, 2.062174081802368, -5.2132463455200195, 10.473968505859375, 8.536468505859375, 11.328756332397461, 10.560187339782715, 12.91752815246582, 11.640753746032715, 9.344059944152832, 9.404285430908203, 9.262243270874023, 8.489307403564453, 8.778897285461426, 10.058999061584473, 7.257660388946533], \"z\": [4.153817176818848, 1.8563268184661865, 2.017605781555176, 1.8954007625579834, 0.934510350227356, 0.8980085849761963, -0.4560340642929077, 2.372796058654785, 2.220562219619751, 2.7022452354431152, 1.8653817176818848, 0.2510356605052948, 3.820190668106079, 2.534221887588501, 2.9237594604492188, 2.7204854488372803, 3.4082529544830322, 3.3505821228027344, 2.160252094268799, 2.770977258682251, 2.3276846408843994, 2.283174514770508, 3.0303211212158203, 4.477685451507568, 3.7662129402160645, -3.049593687057495, -3.03337025642395, 1.4674897193908691, 2.566132068634033, 0.9630584716796875, -0.8602898716926575, -3.510307788848877, -3.076331853866577, -3.169595956802368, -3.3002071380615234, -1.7908830642700195, -1.6569396257400513, -3.3491718769073486, 2.7834722995758057, 4.058655261993408, 4.057628631591797, 5.435980796813965, 5.57108736038208, 2.5587427616119385, 2.136270046234131, 5.563952922821045, 3.9014759063720703, 5.690803527832031, 3.768275499343872, 3.201664686203003, 3.5669021606445312, 6.446746349334717, 2.6645667552948, 6.9406561851501465, 3.1719696521759033, 4.2951436042785645, 7.045725345611572, 2.048830509185791, -0.4578186273574829, 7.070099353790283, 7.062145233154297, 0.702146053314209, 2.076268196105957, 4.292128562927246, -1.1985838413238525, -1.3448234796524048, -1.5836031436920166, -1.2162203788757324, 0.41804203391075134, -1.1987264156341553, -1.0067076683044434, -0.3263910412788391, -0.47420015931129456, -1.6638295650482178, -1.3522887229919434, -0.9434458613395691, -0.4273045063018799, 0.928360641002655, 5.063099384307861, 4.424432754516602, 4.43352746963501, 9.38079833984375, 2.9416792392730713, 4.202037811279297, 3.2986090183258057, 4.213424205780029, 3.3474464416503906, 3.3314952850341797, 3.1574625968933105, 2.939375400543213, -0.3032200336456299, -0.5966781973838806, -0.7059921622276306, 1.5690134763717651, -0.19022706151008606, 0.1970559060573578, 0.09765657782554626, -0.4213085174560547, -0.07448218017816544, -1.230575680732727, 1.6448737382888794, -1.2945724725723267, -0.7768455147743225, 2.8872382640838623, -0.4859846234321594, -1.5127800703048706, 1.5751370191574097, -0.6137477159500122, 1.3650131225585938, -0.4683651924133301, 1.4285974502563477, -0.7761644721031189, 0.953112006187439, 1.0660701990127563, -0.38243502378463745, 0.27856534719467163, 4.551403045654297, 1.5362794399261475, 4.469351291656494, 0.10482241958379745, 0.5561321973800659, -0.3723442852497101, 2.653322696685791, 1.9035511016845703, -0.4724498391151428, 1.7553956508636475, 1.9813388586044312, 1.8946480751037598, 0.8943776488304138, -1.5813803672790527, -0.48941805958747864, -0.3396601378917694, 1.1629506349563599, 2.347252130508423, -0.7453425526618958, 2.7550461292266846, 0.5999251008033752, 3.0156943798065186, 0.7984657883644104, 0.49349287152290344, 1.3036388158798218, -0.34458860754966736, 1.842875361442566, -0.28185731172561646, 1.2231954336166382, 1.6185272932052612, 0.7165954113006592, -0.134721577167511, -0.028158199042081833, 1.6283528804779053, -0.35634300112724304, 1.2286934852600098, 1.0623972415924072, 1.2438963651657104, -0.8277313709259033, -1.526956558227539, -1.5903428792953491, -1.4469149112701416, -3.51767897605896, -14.44665813446045, -1.8865114450454712, 2.0736563205718994, -3.5436041355133057, 3.214747428894043, 7.116480827331543, -14.536808967590332, -3.5508482456207275, 0.24412795901298523, 1.3624029159545898, 1.7647836208343506, 2.7693138122558594, 2.6243536472320557, 1.3114138841629028, 2.71907901763916, 1.794679045677185, 3.01986026763916, 2.7951812744140625, 3.668999433517456, 3.1330723762512207, 4.058205604553223], \"mode\": \"markers\", \"name\": 9, \"marker\": {\"color\": \"rgba(128, 177, 211, 1.0)\", \"symbol\": \"dot\", \"size\": 12, \"opacity\": 0.8, \"line\": {\"width\": 1.3}}, \"textfont\": {\"color\": \"#4D5663\"}}], {\"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"titlefont\": {\"color\": \"#4D5663\"}, \"title\": \"T-SNE 3D demo\", \"scene\": {\"xaxis\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#9499A3\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#9499A3\", \"showgrid\": true, \"title\": \"\"}, \"yaxis\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#9499A3\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#9499A3\", \"showgrid\": true, \"title\": \"\"}, \"zaxis\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#9499A3\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#9499A3\", \"showgrid\": true, \"title\": \"\"}}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "embed3d.iplot(kind=\"scatter3d\", x=\"X\", y=\"Y\", z=\"Z\", mode=\"markers\", categories=\"label\", title=\"T-SNE 3D demo\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## その他、よく使うグラフの作り方"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "toy1 = pd.DataFrame(np.random.random((100,6)), \n",
    "                    columns=(\"特徴1\",\"特徴2\",\"特徴3\",\"特徴4\",\"特徴5\",\"特徴6\"))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "data": [
        {
         "line": {
          "color": "rgba(255, 153, 51, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴1",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "y": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ]
        },
        {
         "line": {
          "color": "rgba(55, 128, 191, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴2",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "y": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ]
        },
        {
         "line": {
          "color": "rgba(50, 171, 96, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴3",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "y": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ]
        },
        {
         "line": {
          "color": "rgba(128, 0, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴4",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "y": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ]
        },
        {
         "line": {
          "color": "rgba(219, 64, 82, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴5",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "y": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ]
        },
        {
         "line": {
          "color": "rgba(0, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴6",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "y": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ]
        }
       ],
       "layout": {
        "legend": {
         "bgcolor": "#F5F6F9",
         "font": {
          "color": "#4D5663"
         }
        },
        "paper_bgcolor": "#F5F6F9",
        "plot_bgcolor": "#F5F6F9",
        "titlefont": {
         "color": "#4D5663"
        },
        "xaxis1": {
         "gridcolor": "#E1E5ED",
         "showgrid": true,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        },
        "yaxis1": {
         "gridcolor": "#E1E5ED",
         "showgrid": true,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        }
       }
      },
      "text/html": [
       "<div id=\"38bce555-7943-4e7c-9730-aa79dfd4f145\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"38bce555-7943-4e7c-9730-aa79dfd4f145\", [{\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}], {\"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"yaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"xaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"titlefont\": {\"color\": \"#4D5663\"}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ],
      "text/vnd.plotly.v1+html": [
       "<div id=\"38bce555-7943-4e7c-9730-aa79dfd4f145\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"38bce555-7943-4e7c-9730-aa79dfd4f145\", [{\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\"}], {\"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"yaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"xaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"titlefont\": {\"color\": \"#4D5663\"}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "toy1.iplot()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "data": [
        {
         "line": {
          "color": "rgba(255, 153, 51, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴1",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "xaxis": "x1",
         "y": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "yaxis": "y1"
        },
        {
         "line": {
          "color": "rgba(55, 128, 191, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴2",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "xaxis": "x2",
         "y": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "yaxis": "y2"
        },
        {
         "line": {
          "color": "rgba(50, 171, 96, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴3",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "xaxis": "x3",
         "y": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "yaxis": "y3"
        },
        {
         "line": {
          "color": "rgba(128, 0, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴4",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "xaxis": "x4",
         "y": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "yaxis": "y4"
        },
        {
         "line": {
          "color": "rgba(219, 64, 82, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴5",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "xaxis": "x5",
         "y": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "yaxis": "y5"
        },
        {
         "line": {
          "color": "rgba(0, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "mode": "lines",
         "name": "特徴6",
         "text": "",
         "type": "scatter",
         "x": [
          0,
          1,
          2,
          3,
          4,
          5,
          6,
          7,
          8,
          9,
          10,
          11,
          12,
          13,
          14,
          15,
          16,
          17,
          18,
          19,
          20,
          21,
          22,
          23,
          24,
          25,
          26,
          27,
          28,
          29,
          30,
          31,
          32,
          33,
          34,
          35,
          36,
          37,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          46,
          47,
          48,
          49,
          50,
          51,
          52,
          53,
          54,
          55,
          56,
          57,
          58,
          59,
          60,
          61,
          62,
          63,
          64,
          65,
          66,
          67,
          68,
          69,
          70,
          71,
          72,
          73,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          82,
          83,
          84,
          85,
          86,
          87,
          88,
          89,
          90,
          91,
          92,
          93,
          94,
          95,
          96,
          97,
          98,
          99
         ],
         "xaxis": "x6",
         "y": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "yaxis": "y6"
        }
       ],
       "layout": {
        "annotations": [
         {
          "font": {
           "size": 16
          },
          "showarrow": false,
          "text": "特徴1",
          "x": 0.225,
          "xanchor": "center",
          "xref": "paper",
          "y": 1,
          "yanchor": "bottom",
          "yref": "paper"
         },
         {
          "font": {
           "size": 16
          },
          "showarrow": false,
          "text": "特徴2",
          "x": 0.775,
          "xanchor": "center",
          "xref": "paper",
          "y": 1,
          "yanchor": "bottom",
          "yref": "paper"
         },
         {
          "font": {
           "size": 16
          },
          "showarrow": false,
          "text": "特徴3",
          "x": 0.225,
          "xanchor": "center",
          "xref": "paper",
          "y": 0.6111111111111112,
          "yanchor": "bottom",
          "yref": "paper"
         },
         {
          "font": {
           "size": 16
          },
          "showarrow": false,
          "text": "特徴4",
          "x": 0.775,
          "xanchor": "center",
          "xref": "paper",
          "y": 0.6111111111111112,
          "yanchor": "bottom",
          "yref": "paper"
         },
         {
          "font": {
           "size": 16
          },
          "showarrow": false,
          "text": "特徴5",
          "x": 0.225,
          "xanchor": "center",
          "xref": "paper",
          "y": 0.22222222222222224,
          "yanchor": "bottom",
          "yref": "paper"
         },
         {
          "font": {
           "size": 16
          },
          "showarrow": false,
          "text": "特徴6",
          "x": 0.775,
          "xanchor": "center",
          "xref": "paper",
          "y": 0.22222222222222224,
          "yanchor": "bottom",
          "yref": "paper"
         }
        ],
        "legend": {
         "bgcolor": "#F5F6F9",
         "font": {
          "color": "#4D5663"
         }
        },
        "paper_bgcolor": "#F5F6F9",
        "plot_bgcolor": "#F5F6F9",
        "titlefont": {
         "color": "#4D5663"
        },
        "xaxis1": {
         "anchor": "y1",
         "domain": [
          0,
          0.45
         ],
         "gridcolor": "#E1E5ED",
         "showgrid": true,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        },
        "xaxis2": {
         "anchor": "y2",
         "domain": [
          0.55,
          1
         ]
        },
        "xaxis3": {
         "anchor": "y3",
         "domain": [
          0,
          0.45
         ]
        },
        "xaxis4": {
         "anchor": "y4",
         "domain": [
          0.55,
          1
         ]
        },
        "xaxis5": {
         "anchor": "y5",
         "domain": [
          0,
          0.45
         ]
        },
        "xaxis6": {
         "anchor": "y6",
         "domain": [
          0.55,
          1
         ]
        },
        "yaxis1": {
         "anchor": "x1",
         "domain": [
          0.7777777777777778,
          1
         ],
         "gridcolor": "#E1E5ED",
         "showgrid": true,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        },
        "yaxis2": {
         "anchor": "x2",
         "domain": [
          0.7777777777777778,
          1
         ]
        },
        "yaxis3": {
         "anchor": "x3",
         "domain": [
          0.3888888888888889,
          0.6111111111111112
         ]
        },
        "yaxis4": {
         "anchor": "x4",
         "domain": [
          0.3888888888888889,
          0.6111111111111112
         ]
        },
        "yaxis5": {
         "anchor": "x5",
         "domain": [
          0,
          0.22222222222222224
         ]
        },
        "yaxis6": {
         "anchor": "x6",
         "domain": [
          0,
          0.22222222222222224
         ]
        }
       }
      },
      "text/html": [
       "<div id=\"e4738e68-d16f-4119-a893-d64ba6f76af0\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"e4738e68-d16f-4119-a893-d64ba6f76af0\", [{\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x1\", \"yaxis\": \"y1\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x2\", \"yaxis\": \"y2\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x3\", \"yaxis\": \"y3\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x4\", \"yaxis\": \"y4\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x5\", \"yaxis\": \"y5\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x6\", \"yaxis\": \"y6\"}], {\"xaxis1\": {\"domain\": [0.0, 0.45], \"anchor\": \"y1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"yaxis1\": {\"domain\": [0.7777777777777778, 1.0], \"anchor\": \"x1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"xaxis2\": {\"domain\": [0.55, 1.0], \"anchor\": \"y2\"}, \"yaxis2\": {\"domain\": [0.7777777777777778, 1.0], \"anchor\": \"x2\"}, \"xaxis3\": {\"domain\": [0.0, 0.45], \"anchor\": \"y3\"}, \"yaxis3\": {\"domain\": [0.3888888888888889, 0.6111111111111112], \"anchor\": \"x3\"}, \"xaxis4\": {\"domain\": [0.55, 1.0], \"anchor\": \"y4\"}, \"yaxis4\": {\"domain\": [0.3888888888888889, 0.6111111111111112], \"anchor\": \"x4\"}, \"xaxis5\": {\"domain\": [0.0, 0.45], \"anchor\": \"y5\"}, \"yaxis5\": {\"domain\": [0.0, 0.22222222222222224], \"anchor\": \"x5\"}, \"xaxis6\": {\"domain\": [0.55, 1.0], \"anchor\": \"y6\"}, \"yaxis6\": {\"domain\": [0.0, 0.22222222222222224], \"anchor\": \"x6\"}, \"annotations\": [{\"y\": 1.0, \"xref\": \"paper\", \"x\": 0.225, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb41\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 1.0, \"xref\": \"paper\", \"x\": 0.775, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb42\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.6111111111111112, \"xref\": \"paper\", \"x\": 0.225, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb43\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.6111111111111112, \"xref\": \"paper\", \"x\": 0.775, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb44\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.22222222222222224, \"xref\": \"paper\", \"x\": 0.225, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb45\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.22222222222222224, \"xref\": \"paper\", \"x\": 0.775, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb46\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}], \"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"titlefont\": {\"color\": \"#4D5663\"}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ],
      "text/vnd.plotly.v1+html": [
       "<div id=\"e4738e68-d16f-4119-a893-d64ba6f76af0\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"e4738e68-d16f-4119-a893-d64ba6f76af0\", [{\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x1\", \"yaxis\": \"y1\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x2\", \"yaxis\": \"y2\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x3\", \"yaxis\": \"y3\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x4\", \"yaxis\": \"y4\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x5\", \"yaxis\": \"y5\"}, {\"type\": \"scatter\", \"x\": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"lines\", \"xaxis\": \"x6\", \"yaxis\": \"y6\"}], {\"xaxis1\": {\"domain\": [0.0, 0.45], \"anchor\": \"y1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"yaxis1\": {\"domain\": [0.7777777777777778, 1.0], \"anchor\": \"x1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"xaxis2\": {\"domain\": [0.55, 1.0], \"anchor\": \"y2\"}, \"yaxis2\": {\"domain\": [0.7777777777777778, 1.0], \"anchor\": \"x2\"}, \"xaxis3\": {\"domain\": [0.0, 0.45], \"anchor\": \"y3\"}, \"yaxis3\": {\"domain\": [0.3888888888888889, 0.6111111111111112], \"anchor\": \"x3\"}, \"xaxis4\": {\"domain\": [0.55, 1.0], \"anchor\": \"y4\"}, \"yaxis4\": {\"domain\": [0.3888888888888889, 0.6111111111111112], \"anchor\": \"x4\"}, \"xaxis5\": {\"domain\": [0.0, 0.45], \"anchor\": \"y5\"}, \"yaxis5\": {\"domain\": [0.0, 0.22222222222222224], \"anchor\": \"x5\"}, \"xaxis6\": {\"domain\": [0.55, 1.0], \"anchor\": \"y6\"}, \"yaxis6\": {\"domain\": [0.0, 0.22222222222222224], \"anchor\": \"x6\"}, \"annotations\": [{\"y\": 1.0, \"xref\": \"paper\", \"x\": 0.225, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb41\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 1.0, \"xref\": \"paper\", \"x\": 0.775, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb42\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.6111111111111112, \"xref\": \"paper\", \"x\": 0.225, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb43\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.6111111111111112, \"xref\": \"paper\", \"x\": 0.775, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb44\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.22222222222222224, \"xref\": \"paper\", \"x\": 0.225, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb45\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}, {\"y\": 0.22222222222222224, \"xref\": \"paper\", \"x\": 0.775, \"yref\": \"paper\", \"text\": \"\\u7279\\u5fb46\", \"showarrow\": false, \"font\": {\"size\": 16}, \"xanchor\": \"center\", \"yanchor\": \"bottom\"}], \"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"titlefont\": {\"color\": \"#4D5663\"}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "toy1.iplot(subplots=True, subplot_titles=True)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "data": [
        {
         "histfunc": "count",
         "histnorm": "",
         "marker": {
          "color": "rgba(255, 153, 51, 1.0)",
          "line": {
           "color": "#4D5663",
           "width": 1.3
          }
         },
         "name": "特徴1",
         "nbinsx": 10,
         "opacity": 0.8,
         "orientation": "v",
         "type": "histogram",
         "x": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "xaxis": "x1",
         "yaxis": "y1"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴1",
         "text": "",
         "type": "scatter",
         "x": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "xaxis": "x2",
         "y": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "yaxis": "y2"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴1",
         "text": "",
         "type": "scatter",
         "x": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "xaxis": "x3",
         "y": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "yaxis": "y3"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴1",
         "text": "",
         "type": "scatter",
         "x": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "xaxis": "x4",
         "y": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "yaxis": "y4"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴1",
         "text": "",
         "type": "scatter",
         "x": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "xaxis": "x5",
         "y": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "yaxis": "y5"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴1",
         "text": "",
         "type": "scatter",
         "x": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "xaxis": "x6",
         "y": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "yaxis": "y6"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴2",
         "text": "",
         "type": "scatter",
         "x": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "xaxis": "x7",
         "y": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "yaxis": "y7"
        },
        {
         "histfunc": "count",
         "histnorm": "",
         "marker": {
          "color": "rgba(55, 128, 191, 1.0)",
          "line": {
           "color": "#4D5663",
           "width": 1.3
          }
         },
         "name": "特徴2",
         "nbinsx": 10,
         "opacity": 0.8,
         "orientation": "v",
         "type": "histogram",
         "x": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "xaxis": "x8",
         "yaxis": "y8"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴2",
         "text": "",
         "type": "scatter",
         "x": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "xaxis": "x9",
         "y": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "yaxis": "y9"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴2",
         "text": "",
         "type": "scatter",
         "x": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "xaxis": "x10",
         "y": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "yaxis": "y10"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴2",
         "text": "",
         "type": "scatter",
         "x": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "xaxis": "x11",
         "y": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "yaxis": "y11"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴2",
         "text": "",
         "type": "scatter",
         "x": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "xaxis": "x12",
         "y": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "yaxis": "y12"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴3",
         "text": "",
         "type": "scatter",
         "x": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "xaxis": "x13",
         "y": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "yaxis": "y13"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴3",
         "text": "",
         "type": "scatter",
         "x": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "xaxis": "x14",
         "y": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "yaxis": "y14"
        },
        {
         "histfunc": "count",
         "histnorm": "",
         "marker": {
          "color": "rgba(50, 171, 96, 1.0)",
          "line": {
           "color": "#4D5663",
           "width": 1.3
          }
         },
         "name": "特徴3",
         "nbinsx": 10,
         "opacity": 0.8,
         "orientation": "v",
         "type": "histogram",
         "x": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "xaxis": "x15",
         "yaxis": "y15"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴3",
         "text": "",
         "type": "scatter",
         "x": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "xaxis": "x16",
         "y": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "yaxis": "y16"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴3",
         "text": "",
         "type": "scatter",
         "x": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "xaxis": "x17",
         "y": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "yaxis": "y17"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴3",
         "text": "",
         "type": "scatter",
         "x": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "xaxis": "x18",
         "y": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "yaxis": "y18"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴4",
         "text": "",
         "type": "scatter",
         "x": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "xaxis": "x19",
         "y": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "yaxis": "y19"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴4",
         "text": "",
         "type": "scatter",
         "x": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "xaxis": "x20",
         "y": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "yaxis": "y20"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴4",
         "text": "",
         "type": "scatter",
         "x": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "xaxis": "x21",
         "y": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "yaxis": "y21"
        },
        {
         "histfunc": "count",
         "histnorm": "",
         "marker": {
          "color": "rgba(128, 0, 128, 1.0)",
          "line": {
           "color": "#4D5663",
           "width": 1.3
          }
         },
         "name": "特徴4",
         "nbinsx": 10,
         "opacity": 0.8,
         "orientation": "v",
         "type": "histogram",
         "x": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "xaxis": "x22",
         "yaxis": "y22"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴4",
         "text": "",
         "type": "scatter",
         "x": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "xaxis": "x23",
         "y": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "yaxis": "y23"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴4",
         "text": "",
         "type": "scatter",
         "x": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "xaxis": "x24",
         "y": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "yaxis": "y24"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴5",
         "text": "",
         "type": "scatter",
         "x": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "xaxis": "x25",
         "y": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "yaxis": "y25"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴5",
         "text": "",
         "type": "scatter",
         "x": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "xaxis": "x26",
         "y": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "yaxis": "y26"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴5",
         "text": "",
         "type": "scatter",
         "x": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "xaxis": "x27",
         "y": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "yaxis": "y27"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴5",
         "text": "",
         "type": "scatter",
         "x": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "xaxis": "x28",
         "y": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "yaxis": "y28"
        },
        {
         "histfunc": "count",
         "histnorm": "",
         "marker": {
          "color": "rgba(219, 64, 82, 1.0)",
          "line": {
           "color": "#4D5663",
           "width": 1.3
          }
         },
         "name": "特徴5",
         "nbinsx": 10,
         "opacity": 0.8,
         "orientation": "v",
         "type": "histogram",
         "x": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "xaxis": "x29",
         "yaxis": "y29"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴5",
         "text": "",
         "type": "scatter",
         "x": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "xaxis": "x30",
         "y": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "yaxis": "y30"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴6",
         "text": "",
         "type": "scatter",
         "x": [
          0.8796881503869705,
          0.31101194605582017,
          0.9159912657434846,
          0.5962382075302861,
          0.24639090773181926,
          0.03391567926515471,
          0.36790444481430096,
          0.4828410023849167,
          0.38912269351161954,
          0.5501012802148034,
          0.9736925380365794,
          0.37701251831385363,
          0.8863313027574682,
          0.5149630377052871,
          0.10738166328987864,
          0.5206062791546459,
          0.5912976462037841,
          0.22973299120583657,
          0.4573628274274526,
          0.7272460481960237,
          0.0403491239156365,
          0.7400048698698451,
          0.21460229110694662,
          0.6888683423595151,
          0.11026316328199359,
          0.09059796364225081,
          0.31990959673090946,
          0.8627072172686058,
          0.6018547964906656,
          0.49492194329708983,
          0.3583417879028372,
          0.5703514175569341,
          0.45590002092623527,
          0.8839693028406439,
          0.5611560712807068,
          0.36728095548929474,
          0.6900164865327159,
          0.21642508774221147,
          0.5614944557999637,
          0.0007644574101798307,
          0.23356938336763866,
          0.3609438513455314,
          0.020392929126960335,
          0.18426427839279247,
          0.9796635806677112,
          0.1990862498931545,
          0.46598782043636355,
          0.16254753729010485,
          0.7596470441105088,
          0.6164082190742632,
          0.2981712080491462,
          0.6514444728929639,
          0.360105323484061,
          0.8473387048023598,
          0.8839518665745426,
          0.6102143073703439,
          0.23954170358153837,
          0.05005420123063686,
          0.3657487815333472,
          0.5479735759078938,
          0.7172572732387065,
          0.02021170633012459,
          0.04523303279226332,
          0.9662352729518541,
          0.38286948722337977,
          0.9672389194042832,
          0.4541443968799791,
          0.6447927017856289,
          0.22349233515369515,
          0.3617948136856617,
          0.26858729239495194,
          0.44857814163430665,
          0.6473920701763463,
          0.2620727175288248,
          0.8908230549531753,
          0.15299855335144685,
          0.9286344490671495,
          0.9416449260020638,
          0.013463402412540515,
          0.4559160308698226,
          0.3912440296579408,
          0.4678527645019539,
          0.7535684457709868,
          0.8648150799451025,
          0.9864845285823228,
          0.47693261586561864,
          0.6432149993415861,
          0.7429430142885227,
          0.3183788213631874,
          0.018647747477644194,
          0.37876456853410345,
          0.6933980898553099,
          0.20128592462431427,
          0.12918919369086612,
          0.19951647569815845,
          0.44165439537938345,
          0.25754686404521343,
          0.8422161201797586,
          0.8029466771323559,
          0.4695864252847147
         ],
         "xaxis": "x31",
         "y": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "yaxis": "y31"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴6",
         "text": "",
         "type": "scatter",
         "x": [
          0.2850541037826074,
          0.25155025876579384,
          0.698545278731228,
          0.14967504203986615,
          0.7259787598063822,
          0.056998169975048585,
          0.6664930346677312,
          0.14908377716580334,
          0.5663644800384876,
          0.28811598164859864,
          0.6140211440872054,
          0.2793373070797651,
          0.7480847004733047,
          0.296266238519848,
          0.5368969874920491,
          0.33640672743695155,
          0.09008302978501981,
          0.29235828513218576,
          0.3976407883086216,
          0.5628614280774802,
          0.9332815221222929,
          0.3735910959565084,
          0.7618500211034487,
          0.9308902924325888,
          0.6467129868990306,
          0.8100737602562768,
          0.023331981827311554,
          0.04193974596313521,
          0.21458858711334505,
          0.931189885037942,
          0.5271100462888462,
          0.9044301464738321,
          0.21722407831228285,
          0.19918367234035506,
          0.11431078510149895,
          0.16527467841396482,
          0.2835544171872829,
          0.22194744057236615,
          0.33608629335464146,
          0.932474414298411,
          0.23450776539169405,
          0.7391543158300712,
          0.31697544777205877,
          0.7549687285282886,
          0.6612666348127837,
          0.6865757670942859,
          0.5457493825054603,
          0.884136840673705,
          0.9429348452119289,
          0.7714682818456293,
          0.13696677613330566,
          0.8237463832334782,
          0.2029448774306245,
          0.5968920278888731,
          0.5245703351216106,
          0.7227642043938939,
          0.6934235480621307,
          0.1124900361446306,
          0.10576417393335458,
          0.031090286969449932,
          0.7712035809862177,
          0.7123031687382922,
          0.17160616748947533,
          0.3395356222888408,
          0.8485894067573986,
          0.45793140770046803,
          0.355416342505564,
          0.6665030669055917,
          0.27524059247615984,
          0.13523481331868825,
          0.5212069951374524,
          0.6737691987282483,
          0.18311369845258607,
          0.11610552698915222,
          0.5569381059434042,
          0.15781001102161774,
          0.6572919476396999,
          0.7647784851610151,
          0.19373719732792605,
          0.029621718329189584,
          0.6462405448533647,
          0.5254476397141129,
          0.6747330388047486,
          0.788167075041062,
          0.8376172719024221,
          0.4460342161316301,
          0.5084279237677516,
          0.8410887872065183,
          0.3240885862317632,
          0.7310399960542304,
          0.569709084451349,
          0.8371239802708226,
          0.008244820777970285,
          0.9235691921961882,
          0.36607142369776746,
          0.32486258420088754,
          0.10557318582019204,
          0.35016220644308305,
          0.4419985281747887,
          0.48006226870678625
         ],
         "xaxis": "x32",
         "y": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "yaxis": "y32"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴6",
         "text": "",
         "type": "scatter",
         "x": [
          0.7460600272391255,
          0.9989153690269862,
          0.02036684974023928,
          0.795850247518187,
          0.19334362798474647,
          0.9880110776211922,
          0.49641988944419846,
          0.31886963871479945,
          0.47526016143235905,
          0.7423976322035429,
          0.5154797549660395,
          0.40841726235245157,
          0.13791941387886542,
          0.4355833697410939,
          0.5810613907574794,
          0.5271512978662364,
          0.9265307328597139,
          0.7048307014235259,
          0.5349480091599211,
          0.4572226900729871,
          0.9666816495640831,
          0.278071788557525,
          0.2757398583047965,
          0.025686271056969967,
          0.036858617800828886,
          0.4427882051793308,
          0.5297861469630643,
          0.48466114234490465,
          0.21245723441761732,
          0.06236194583164756,
          0.7458585483405434,
          0.5579519968413817,
          0.6073271349807343,
          0.5209512558755753,
          0.3264455515995571,
          0.9355486773947842,
          0.7123072136628135,
          0.2990131634634968,
          0.5775664883794402,
          0.9886279751032792,
          0.5347880641668014,
          0.48245620415707535,
          0.832164432616035,
          0.932823465929367,
          0.6585081600076058,
          0.7708344969752476,
          0.5007406391118306,
          0.3480769610469614,
          0.5606720629588454,
          0.5807010431645636,
          0.555094343472377,
          0.21816320616414342,
          0.13365899365129918,
          0.30295061099316034,
          0.31340958131272834,
          0.6015140845055321,
          0.9637440304839351,
          0.6402452378794882,
          0.005360105161705375,
          0.17300303274131767,
          0.6290008942328794,
          0.6980411326873354,
          0.3368731145263837,
          0.5558950168176884,
          0.5576199708795464,
          0.10287219816276738,
          0.39254898948883765,
          0.6514332323964686,
          0.8291294302072703,
          0.8130866147565137,
          0.6492016034671377,
          0.9549581421074428,
          0.1339672999825814,
          0.19423535800275193,
          0.5324783925360591,
          0.6961732601234787,
          0.9687102471701311,
          0.6696051750681296,
          0.5680241755756421,
          0.2867171742264183,
          0.33877927930565355,
          0.008340074278601173,
          0.8308305081611412,
          0.04841054133519451,
          0.37798089409270574,
          0.3085160714063411,
          0.728131439442904,
          0.41044448655053667,
          0.7079177554715657,
          0.06992012832964634,
          0.7457950683919919,
          0.6763711616939186,
          0.4878721145946815,
          0.20549128029932462,
          0.9332131497458775,
          0.9531579376971704,
          0.48626747969697015,
          0.9994953702605477,
          0.6983143726737339,
          0.26708955990309136
         ],
         "xaxis": "x33",
         "y": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "yaxis": "y33"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴6",
         "text": "",
         "type": "scatter",
         "x": [
          0.6177973072645351,
          0.3784764121932017,
          0.5245436936504758,
          0.9616683417466887,
          0.5625988047464932,
          0.4960467054753289,
          0.5765096275600574,
          0.5923745661829463,
          0.6824814478903274,
          0.08269498299042122,
          0.2725623954615256,
          0.17399520767319554,
          0.361955191772919,
          0.48065766496210793,
          0.7174589056582705,
          0.3376329160495888,
          0.6954473903085711,
          0.36961562976902573,
          0.3767090162249682,
          0.9733089768109245,
          0.4034513458175021,
          0.8638559516166862,
          0.2730609598126167,
          0.054438299381962096,
          0.228737808478511,
          0.05904808183306276,
          0.41136681055098856,
          0.03507402795594039,
          0.8297171969466143,
          0.5208603670569473,
          0.014248167026738923,
          0.005558575927227416,
          0.24462692745500192,
          0.7354118088875922,
          0.06836440489243745,
          0.2600910809402166,
          0.27088880395652837,
          0.9541754803724765,
          0.152156186596901,
          0.8895875786336861,
          0.31347758565566564,
          0.18463836903129027,
          0.91802522556144,
          0.8965437503124648,
          0.14166439639170114,
          0.8407370197049922,
          0.8890219459785312,
          0.4348001397432564,
          0.6318377445759965,
          0.6118419280110552,
          0.6295444437910109,
          0.5600689486796782,
          0.3609270061061667,
          0.04072648055075456,
          0.9394552172905118,
          0.9216906322204067,
          0.9188991989377034,
          0.05385600851286909,
          0.6479598394948738,
          0.8092437208690338,
          0.9403593069271908,
          0.24313971947776103,
          0.22325682897818988,
          0.538888610614994,
          0.7203312283614856,
          0.05591923039786029,
          0.7212559763022688,
          0.890883792979236,
          0.5822363216280402,
          0.7704349521417256,
          0.8177998223874463,
          0.9918401681653326,
          0.36792593343052205,
          0.6453800683931861,
          0.12796834980162752,
          0.9255343670235531,
          0.8828333502125524,
          0.053599675900733446,
          0.20814591431890606,
          0.4030171339653472,
          0.5007096931649728,
          0.25367500790736375,
          0.07478603549436358,
          0.23055834084398263,
          0.5221354913478576,
          0.6475260357837425,
          0.07570744168731436,
          0.7651294584181274,
          0.8055963538786817,
          0.18881670492413505,
          0.49660484641451086,
          0.026084762193804956,
          0.09368873485814533,
          0.8125206057404227,
          0.5856188011846184,
          0.13480011117383583,
          0.748043841841606,
          0.038678282424561616,
          0.8086175554566394,
          0.2097749279304275
         ],
         "xaxis": "x34",
         "y": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "yaxis": "y34"
        },
        {
         "line": {
          "color": "rgba(128, 128, 128, 1.0)",
          "dash": "solid",
          "shape": "linear",
          "width": 1.3
         },
         "marker": {
          "size": 2,
          "symbol": "dot"
         },
         "mode": "markers",
         "name": "特徴6",
         "text": "",
         "type": "scatter",
         "x": [
          0.4538965064661792,
          0.779964539432002,
          0.702969166085686,
          0.781566521455753,
          0.1703570572537696,
          0.4894615642885374,
          0.5352648136384826,
          0.5782873141422693,
          0.17661994336555753,
          0.5378082039351939,
          0.23021134079653782,
          0.7450724181611172,
          0.5232314485025407,
          0.0992576707300914,
          0.2938703696122986,
          0.44568462277180476,
          0.09375237000980785,
          0.8251556722753918,
          0.8004085109250393,
          0.8179205611253678,
          0.7303184118852276,
          0.3597254837580617,
          0.21897022838252733,
          0.4065303439358807,
          0.5981507928905542,
          0.8836176018174101,
          0.5623292868379415,
          0.3708842672784104,
          0.008715677398920652,
          0.18358924335649707,
          0.6397899583992791,
          0.542645879050756,
          0.35094099550687363,
          0.8412589824605696,
          0.7673707365185616,
          0.07654905110990717,
          0.25260641266397865,
          0.15636584452228786,
          0.23891018952005794,
          0.32956086872850954,
          0.3316919544654737,
          0.3427536824485037,
          0.39018353426140984,
          0.3744106436146375,
          0.03992060583741053,
          0.6598488451917066,
          0.9372245252862386,
          0.3819637277440324,
          0.7183601011563909,
          0.47996263742215484,
          0.3686912467279405,
          0.8022878483261148,
          0.8577957300638178,
          0.04808147951687447,
          0.06546930745818869,
          0.9548114907702178,
          0.35789805205320546,
          0.5051161462669821,
          0.8373552870646613,
          0.5277583698038274,
          0.36543474982570057,
          0.8443909811581273,
          0.9699369384786177,
          0.2956702396358887,
          0.1633050060283977,
          0.124395649791737,
          0.14639485151011233,
          0.9722227397321922,
          0.15724629356351283,
          0.035444422818634025,
          0.2505921134758732,
          0.7098811911480573,
          0.87233131473316,
          0.8747826873014111,
          0.8247135462511112,
          0.31954633427656076,
          0.4743189542588465,
          0.9070232623008833,
          0.764018146943609,
          0.850274136846549,
          0.18783986963356203,
          0.4234691338921699,
          0.00858594298787363,
          0.808479944846606,
          0.42072044746954373,
          0.7767065358826053,
          0.8385698863005149,
          0.08475823144105621,
          0.022635846714748387,
          0.9057545578400847,
          0.9281017431502535,
          0.5182158638499622,
          0.3303905340751774,
          0.5141715058724675,
          0.7496389687726507,
          0.7578599427361695,
          0.3531559066867431,
          0.36787328252986606,
          0.5485623549654006,
          0.5313090984826163
         ],
         "xaxis": "x35",
         "y": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "yaxis": "y35"
        },
        {
         "histfunc": "count",
         "histnorm": "",
         "marker": {
          "color": "rgba(0, 128, 128, 1.0)",
          "line": {
           "color": "#4D5663",
           "width": 1.3
          }
         },
         "name": "特徴6",
         "nbinsx": 10,
         "opacity": 0.8,
         "orientation": "v",
         "type": "histogram",
         "x": [
          0.1512416205442355,
          0.6153551787748954,
          0.4764189425684032,
          0.3947012733484949,
          0.0375873206552666,
          0.6074042358718497,
          0.6879069197010782,
          0.5432630356168869,
          0.03244767196403642,
          0.7861623786469597,
          0.32596062200296205,
          0.3530476376049738,
          0.011248316097846267,
          0.8155055905667299,
          0.3304954006932912,
          0.7553840122501562,
          0.5912652119462452,
          0.3932779843719274,
          0.5396718741908046,
          0.9019648724100523,
          0.17583589153872126,
          0.8006212807260493,
          0.30082074270958403,
          0.0016504829558823264,
          0.19339767196744895,
          0.7172460183079075,
          0.46098645531800664,
          0.8370704672770218,
          0.31077230770406694,
          0.40418847986662787,
          0.5300074512772918,
          0.2667471459976988,
          0.6032348072921845,
          0.09547762354773226,
          0.6525382249030831,
          0.11666894824793217,
          0.2143736990649997,
          0.8215084573270449,
          0.14667006866644394,
          0.16447724638754313,
          0.9749399535932992,
          0.6260880437906322,
          0.399910941482564,
          0.7704961934745408,
          0.7529393078443101,
          0.24533084393614735,
          0.7711911529710075,
          0.8315680022850523,
          0.6992183903929018,
          0.8894027348280082,
          0.6578088951422109,
          0.8159905381352706,
          0.3798576527023557,
          0.4566149587488326,
          0.179751925795257,
          0.9559308056142148,
          0.3005062663329964,
          0.38693660712750166,
          0.8541656120013534,
          0.9797568851696837,
          0.776848209035442,
          0.6920925855421031,
          0.9252648532241368,
          0.35911257915636996,
          0.7928448149145366,
          0.2734826908512935,
          0.43042050440885227,
          0.5867270859559015,
          0.06020797057705818,
          0.14698664012469242,
          0.7721606062225732,
          0.8057282637969855,
          0.8581031662000709,
          0.8973069968664468,
          0.24669777854894026,
          0.1484888572789409,
          0.4756908973491599,
          0.9591650158284976,
          0.7204310385260341,
          0.12229562095823754,
          0.20335984053130307,
          0.015576059872810633,
          0.8780061447457647,
          0.37817151201873533,
          0.1387347308351209,
          0.6407236819251958,
          0.7356300438237903,
          0.15052293912874704,
          0.30734211624047447,
          0.6527827828210877,
          0.9438133335848098,
          0.4826294120136867,
          0.5224273246186681,
          0.10073297112439239,
          0.21289702066861593,
          0.7214889154184343,
          0.6633621235519349,
          0.8324412514224355,
          0.6047927730640392,
          0.4862974192130832
         ],
         "xaxis": "x36",
         "yaxis": "y36"
        }
       ],
       "layout": {
        "bargap": 0.02,
        "legend": {
         "bgcolor": "#F5F6F9",
         "font": {
          "color": "#4D5663"
         }
        },
        "paper_bgcolor": "#F5F6F9",
        "plot_bgcolor": "#F5F6F9",
        "showlegend": false,
        "titlefont": {
         "color": "#4D5663"
        },
        "xaxis1": {
         "anchor": "y1",
         "domain": [
          0,
          0.125
         ],
         "gridcolor": "#E1E5ED",
         "showgrid": false,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        },
        "xaxis10": {
         "anchor": "y10",
         "domain": [
          0.525,
          0.65
         ]
        },
        "xaxis11": {
         "anchor": "y11",
         "domain": [
          0.7,
          0.825
         ]
        },
        "xaxis12": {
         "anchor": "y12",
         "domain": [
          0.875,
          1
         ]
        },
        "xaxis13": {
         "anchor": "y13",
         "domain": [
          0,
          0.125
         ]
        },
        "xaxis14": {
         "anchor": "y14",
         "domain": [
          0.175,
          0.3
         ]
        },
        "xaxis15": {
         "anchor": "y15",
         "domain": [
          0.35,
          0.475
         ]
        },
        "xaxis16": {
         "anchor": "y16",
         "domain": [
          0.525,
          0.65
         ]
        },
        "xaxis17": {
         "anchor": "y17",
         "domain": [
          0.7,
          0.825
         ]
        },
        "xaxis18": {
         "anchor": "y18",
         "domain": [
          0.875,
          1
         ]
        },
        "xaxis19": {
         "anchor": "y19",
         "domain": [
          0,
          0.125
         ]
        },
        "xaxis2": {
         "anchor": "y2",
         "domain": [
          0.175,
          0.3
         ]
        },
        "xaxis20": {
         "anchor": "y20",
         "domain": [
          0.175,
          0.3
         ]
        },
        "xaxis21": {
         "anchor": "y21",
         "domain": [
          0.35,
          0.475
         ]
        },
        "xaxis22": {
         "anchor": "y22",
         "domain": [
          0.525,
          0.65
         ]
        },
        "xaxis23": {
         "anchor": "y23",
         "domain": [
          0.7,
          0.825
         ]
        },
        "xaxis24": {
         "anchor": "y24",
         "domain": [
          0.875,
          1
         ]
        },
        "xaxis25": {
         "anchor": "y25",
         "domain": [
          0,
          0.125
         ]
        },
        "xaxis26": {
         "anchor": "y26",
         "domain": [
          0.175,
          0.3
         ]
        },
        "xaxis27": {
         "anchor": "y27",
         "domain": [
          0.35,
          0.475
         ]
        },
        "xaxis28": {
         "anchor": "y28",
         "domain": [
          0.525,
          0.65
         ]
        },
        "xaxis29": {
         "anchor": "y29",
         "domain": [
          0.7,
          0.825
         ]
        },
        "xaxis3": {
         "anchor": "y3",
         "domain": [
          0.35,
          0.475
         ]
        },
        "xaxis30": {
         "anchor": "y30",
         "domain": [
          0.875,
          1
         ]
        },
        "xaxis31": {
         "anchor": "y31",
         "domain": [
          0,
          0.125
         ]
        },
        "xaxis32": {
         "anchor": "y32",
         "domain": [
          0.175,
          0.3
         ]
        },
        "xaxis33": {
         "anchor": "y33",
         "domain": [
          0.35,
          0.475
         ]
        },
        "xaxis34": {
         "anchor": "y34",
         "domain": [
          0.525,
          0.65
         ]
        },
        "xaxis35": {
         "anchor": "y35",
         "domain": [
          0.7,
          0.825
         ]
        },
        "xaxis36": {
         "anchor": "y36",
         "domain": [
          0.875,
          1
         ]
        },
        "xaxis4": {
         "anchor": "y4",
         "domain": [
          0.525,
          0.65
         ]
        },
        "xaxis5": {
         "anchor": "y5",
         "domain": [
          0.7,
          0.825
         ]
        },
        "xaxis6": {
         "anchor": "y6",
         "domain": [
          0.875,
          1
         ]
        },
        "xaxis7": {
         "anchor": "y7",
         "domain": [
          0,
          0.125
         ]
        },
        "xaxis8": {
         "anchor": "y8",
         "domain": [
          0.175,
          0.3
         ]
        },
        "xaxis9": {
         "anchor": "y9",
         "domain": [
          0.35,
          0.475
         ]
        },
        "yaxis1": {
         "anchor": "x1",
         "domain": [
          0.8916666666666666,
          0.9999999999999999
         ],
         "gridcolor": "#E1E5ED",
         "showgrid": false,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        },
        "yaxis10": {
         "anchor": "x10",
         "domain": [
          0.7133333333333334,
          0.8216666666666667
         ]
        },
        "yaxis11": {
         "anchor": "x11",
         "domain": [
          0.7133333333333334,
          0.8216666666666667
         ]
        },
        "yaxis12": {
         "anchor": "x12",
         "domain": [
          0.7133333333333334,
          0.8216666666666667
         ]
        },
        "yaxis13": {
         "anchor": "x13",
         "domain": [
          0.5349999999999999,
          0.6433333333333332
         ]
        },
        "yaxis14": {
         "anchor": "x14",
         "domain": [
          0.5349999999999999,
          0.6433333333333332
         ]
        },
        "yaxis15": {
         "anchor": "x15",
         "domain": [
          0.5349999999999999,
          0.6433333333333332
         ]
        },
        "yaxis16": {
         "anchor": "x16",
         "domain": [
          0.5349999999999999,
          0.6433333333333332
         ]
        },
        "yaxis17": {
         "anchor": "x17",
         "domain": [
          0.5349999999999999,
          0.6433333333333332
         ]
        },
        "yaxis18": {
         "anchor": "x18",
         "domain": [
          0.5349999999999999,
          0.6433333333333332
         ]
        },
        "yaxis19": {
         "anchor": "x19",
         "domain": [
          0.3566666666666667,
          0.465
         ]
        },
        "yaxis2": {
         "anchor": "x2",
         "domain": [
          0.8916666666666666,
          0.9999999999999999
         ]
        },
        "yaxis20": {
         "anchor": "x20",
         "domain": [
          0.3566666666666667,
          0.465
         ]
        },
        "yaxis21": {
         "anchor": "x21",
         "domain": [
          0.3566666666666667,
          0.465
         ]
        },
        "yaxis22": {
         "anchor": "x22",
         "domain": [
          0.3566666666666667,
          0.465
         ]
        },
        "yaxis23": {
         "anchor": "x23",
         "domain": [
          0.3566666666666667,
          0.465
         ]
        },
        "yaxis24": {
         "anchor": "x24",
         "domain": [
          0.3566666666666667,
          0.465
         ]
        },
        "yaxis25": {
         "anchor": "x25",
         "domain": [
          0.17833333333333334,
          0.2866666666666667
         ]
        },
        "yaxis26": {
         "anchor": "x26",
         "domain": [
          0.17833333333333334,
          0.2866666666666667
         ]
        },
        "yaxis27": {
         "anchor": "x27",
         "domain": [
          0.17833333333333334,
          0.2866666666666667
         ]
        },
        "yaxis28": {
         "anchor": "x28",
         "domain": [
          0.17833333333333334,
          0.2866666666666667
         ]
        },
        "yaxis29": {
         "anchor": "x29",
         "domain": [
          0.17833333333333334,
          0.2866666666666667
         ]
        },
        "yaxis3": {
         "anchor": "x3",
         "domain": [
          0.8916666666666666,
          0.9999999999999999
         ]
        },
        "yaxis30": {
         "anchor": "x30",
         "domain": [
          0.17833333333333334,
          0.2866666666666667
         ]
        },
        "yaxis31": {
         "anchor": "x31",
         "domain": [
          0,
          0.10833333333333332
         ]
        },
        "yaxis32": {
         "anchor": "x32",
         "domain": [
          0,
          0.10833333333333332
         ]
        },
        "yaxis33": {
         "anchor": "x33",
         "domain": [
          0,
          0.10833333333333332
         ]
        },
        "yaxis34": {
         "anchor": "x34",
         "domain": [
          0,
          0.10833333333333332
         ]
        },
        "yaxis35": {
         "anchor": "x35",
         "domain": [
          0,
          0.10833333333333332
         ]
        },
        "yaxis36": {
         "anchor": "x36",
         "domain": [
          0,
          0.10833333333333332
         ]
        },
        "yaxis4": {
         "anchor": "x4",
         "domain": [
          0.8916666666666666,
          0.9999999999999999
         ]
        },
        "yaxis5": {
         "anchor": "x5",
         "domain": [
          0.8916666666666666,
          0.9999999999999999
         ]
        },
        "yaxis6": {
         "anchor": "x6",
         "domain": [
          0.8916666666666666,
          0.9999999999999999
         ]
        },
        "yaxis7": {
         "anchor": "x7",
         "domain": [
          0.7133333333333334,
          0.8216666666666667
         ]
        },
        "yaxis8": {
         "anchor": "x8",
         "domain": [
          0.7133333333333334,
          0.8216666666666667
         ]
        },
        "yaxis9": {
         "anchor": "x9",
         "domain": [
          0.7133333333333334,
          0.8216666666666667
         ]
        }
       }
      },
      "text/html": [
       "<div id=\"8c74443b-72fe-4c9f-bd36-bbbf63d4f08c\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"8c74443b-72fe-4c9f-bd36-bbbf63d4f08c\", [{\"type\": \"histogram\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"marker\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x1\", \"yaxis\": \"y1\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x2\", \"yaxis\": \"y2\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x3\", \"yaxis\": \"y3\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x4\", \"yaxis\": \"y4\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x5\", \"yaxis\": \"y5\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x6\", \"yaxis\": \"y6\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x7\", \"yaxis\": \"y7\"}, {\"type\": \"histogram\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"marker\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x8\", \"yaxis\": \"y8\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x9\", \"yaxis\": \"y9\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x10\", \"yaxis\": \"y10\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x11\", \"yaxis\": \"y11\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x12\", \"yaxis\": \"y12\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x13\", \"yaxis\": \"y13\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x14\", \"yaxis\": \"y14\"}, {\"type\": \"histogram\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"marker\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x15\", \"yaxis\": \"y15\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x16\", \"yaxis\": \"y16\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x17\", \"yaxis\": \"y17\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x18\", \"yaxis\": \"y18\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x19\", \"yaxis\": \"y19\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x20\", \"yaxis\": \"y20\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x21\", \"yaxis\": \"y21\"}, {\"type\": \"histogram\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"marker\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x22\", \"yaxis\": \"y22\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x23\", \"yaxis\": \"y23\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x24\", \"yaxis\": \"y24\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x25\", \"yaxis\": \"y25\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x26\", \"yaxis\": \"y26\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x27\", \"yaxis\": \"y27\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x28\", \"yaxis\": \"y28\"}, {\"type\": \"histogram\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"marker\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x29\", \"yaxis\": \"y29\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x30\", \"yaxis\": \"y30\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x31\", \"yaxis\": \"y31\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x32\", \"yaxis\": \"y32\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x33\", \"yaxis\": \"y33\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x34\", \"yaxis\": \"y34\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x35\", \"yaxis\": \"y35\"}, {\"type\": \"histogram\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"marker\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x36\", \"yaxis\": \"y36\"}], {\"xaxis1\": {\"domain\": [0.0, 0.125], \"anchor\": \"y1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": false, \"title\": \"\"}, \"yaxis1\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": false, \"title\": \"\"}, \"xaxis2\": {\"domain\": [0.175, 0.3], \"anchor\": \"y2\"}, \"yaxis2\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x2\"}, \"xaxis3\": {\"domain\": [0.35, 0.475], \"anchor\": \"y3\"}, \"yaxis3\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x3\"}, \"xaxis4\": {\"domain\": [0.525, 0.65], \"anchor\": \"y4\"}, \"yaxis4\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x4\"}, \"xaxis5\": {\"domain\": [0.7, 0.825], \"anchor\": \"y5\"}, \"yaxis5\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x5\"}, \"xaxis6\": {\"domain\": [0.875, 1.0], \"anchor\": \"y6\"}, \"yaxis6\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x6\"}, \"xaxis7\": {\"domain\": [0.0, 0.125], \"anchor\": \"y7\"}, \"yaxis7\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x7\"}, \"xaxis8\": {\"domain\": [0.175, 0.3], \"anchor\": \"y8\"}, \"yaxis8\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x8\"}, \"xaxis9\": {\"domain\": [0.35, 0.475], \"anchor\": \"y9\"}, \"yaxis9\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x9\"}, \"xaxis10\": {\"domain\": [0.525, 0.65], \"anchor\": \"y10\"}, \"yaxis10\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x10\"}, \"xaxis11\": {\"domain\": [0.7, 0.825], \"anchor\": \"y11\"}, \"yaxis11\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x11\"}, \"xaxis12\": {\"domain\": [0.875, 1.0], \"anchor\": \"y12\"}, \"yaxis12\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x12\"}, \"xaxis13\": {\"domain\": [0.0, 0.125], \"anchor\": \"y13\"}, \"yaxis13\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x13\"}, \"xaxis14\": {\"domain\": [0.175, 0.3], \"anchor\": \"y14\"}, \"yaxis14\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x14\"}, \"xaxis15\": {\"domain\": [0.35, 0.475], \"anchor\": \"y15\"}, \"yaxis15\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x15\"}, \"xaxis16\": {\"domain\": [0.525, 0.65], \"anchor\": \"y16\"}, \"yaxis16\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x16\"}, \"xaxis17\": {\"domain\": [0.7, 0.825], \"anchor\": \"y17\"}, \"yaxis17\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x17\"}, \"xaxis18\": {\"domain\": [0.875, 1.0], \"anchor\": \"y18\"}, \"yaxis18\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x18\"}, \"xaxis19\": {\"domain\": [0.0, 0.125], \"anchor\": \"y19\"}, \"yaxis19\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x19\"}, \"xaxis20\": {\"domain\": [0.175, 0.3], \"anchor\": \"y20\"}, \"yaxis20\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x20\"}, \"xaxis21\": {\"domain\": [0.35, 0.475], \"anchor\": \"y21\"}, \"yaxis21\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x21\"}, \"xaxis22\": {\"domain\": [0.525, 0.65], \"anchor\": \"y22\"}, \"yaxis22\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x22\"}, \"xaxis23\": {\"domain\": [0.7, 0.825], \"anchor\": \"y23\"}, \"yaxis23\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x23\"}, \"xaxis24\": {\"domain\": [0.875, 1.0], \"anchor\": \"y24\"}, \"yaxis24\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x24\"}, \"xaxis25\": {\"domain\": [0.0, 0.125], \"anchor\": \"y25\"}, \"yaxis25\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x25\"}, \"xaxis26\": {\"domain\": [0.175, 0.3], \"anchor\": \"y26\"}, \"yaxis26\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x26\"}, \"xaxis27\": {\"domain\": [0.35, 0.475], \"anchor\": \"y27\"}, \"yaxis27\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x27\"}, \"xaxis28\": {\"domain\": [0.525, 0.65], \"anchor\": \"y28\"}, \"yaxis28\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x28\"}, \"xaxis29\": {\"domain\": [0.7, 0.825], \"anchor\": \"y29\"}, \"yaxis29\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x29\"}, \"xaxis30\": {\"domain\": [0.875, 1.0], \"anchor\": \"y30\"}, \"yaxis30\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x30\"}, \"xaxis31\": {\"domain\": [0.0, 0.125], \"anchor\": \"y31\"}, \"yaxis31\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x31\"}, \"xaxis32\": {\"domain\": [0.175, 0.3], \"anchor\": \"y32\"}, \"yaxis32\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x32\"}, \"xaxis33\": {\"domain\": [0.35, 0.475], \"anchor\": \"y33\"}, \"yaxis33\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x33\"}, \"xaxis34\": {\"domain\": [0.525, 0.65], \"anchor\": \"y34\"}, \"yaxis34\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x34\"}, \"xaxis35\": {\"domain\": [0.7, 0.825], \"anchor\": \"y35\"}, \"yaxis35\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x35\"}, \"xaxis36\": {\"domain\": [0.875, 1.0], \"anchor\": \"y36\"}, \"yaxis36\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x36\"}, \"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"titlefont\": {\"color\": \"#4D5663\"}, \"bargap\": 0.02, \"showlegend\": false}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ],
      "text/vnd.plotly.v1+html": [
       "<div id=\"8c74443b-72fe-4c9f-bd36-bbbf63d4f08c\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"8c74443b-72fe-4c9f-bd36-bbbf63d4f08c\", [{\"type\": \"histogram\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"marker\": {\"color\": \"rgba(255, 153, 51, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x1\", \"yaxis\": \"y1\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x2\", \"yaxis\": \"y2\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x3\", \"yaxis\": \"y3\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x4\", \"yaxis\": \"y4\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x5\", \"yaxis\": \"y5\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"name\": \"\\u7279\\u5fb41\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x6\", \"yaxis\": \"y6\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x7\", \"yaxis\": \"y7\"}, {\"type\": \"histogram\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"marker\": {\"color\": \"rgba(55, 128, 191, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x8\", \"yaxis\": \"y8\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x9\", \"yaxis\": \"y9\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x10\", \"yaxis\": \"y10\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x11\", \"yaxis\": \"y11\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"name\": \"\\u7279\\u5fb42\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x12\", \"yaxis\": \"y12\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x13\", \"yaxis\": \"y13\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x14\", \"yaxis\": \"y14\"}, {\"type\": \"histogram\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"marker\": {\"color\": \"rgba(50, 171, 96, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x15\", \"yaxis\": \"y15\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x16\", \"yaxis\": \"y16\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x17\", \"yaxis\": \"y17\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"name\": \"\\u7279\\u5fb43\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x18\", \"yaxis\": \"y18\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x19\", \"yaxis\": \"y19\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x20\", \"yaxis\": \"y20\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x21\", \"yaxis\": \"y21\"}, {\"type\": \"histogram\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"marker\": {\"color\": \"rgba(128, 0, 128, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x22\", \"yaxis\": \"y22\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x23\", \"yaxis\": \"y23\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"name\": \"\\u7279\\u5fb44\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x24\", \"yaxis\": \"y24\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x25\", \"yaxis\": \"y25\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x26\", \"yaxis\": \"y26\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x27\", \"yaxis\": \"y27\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x28\", \"yaxis\": \"y28\"}, {\"type\": \"histogram\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"marker\": {\"color\": \"rgba(219, 64, 82, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x29\", \"yaxis\": \"y29\"}, {\"type\": \"scatter\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"y\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"name\": \"\\u7279\\u5fb45\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x30\", \"yaxis\": \"y30\"}, {\"type\": \"scatter\", \"x\": [0.8796881503869705, 0.31101194605582017, 0.9159912657434846, 0.5962382075302861, 0.24639090773181926, 0.03391567926515471, 0.36790444481430096, 0.4828410023849167, 0.38912269351161954, 0.5501012802148034, 0.9736925380365794, 0.37701251831385363, 0.8863313027574682, 0.5149630377052871, 0.10738166328987864, 0.5206062791546459, 0.5912976462037841, 0.22973299120583657, 0.4573628274274526, 0.7272460481960237, 0.0403491239156365, 0.7400048698698451, 0.21460229110694662, 0.6888683423595151, 0.11026316328199359, 0.09059796364225081, 0.31990959673090946, 0.8627072172686058, 0.6018547964906656, 0.49492194329708983, 0.3583417879028372, 0.5703514175569341, 0.45590002092623527, 0.8839693028406439, 0.5611560712807068, 0.36728095548929474, 0.6900164865327159, 0.21642508774221147, 0.5614944557999637, 0.0007644574101798307, 0.23356938336763866, 0.3609438513455314, 0.020392929126960335, 0.18426427839279247, 0.9796635806677112, 0.1990862498931545, 0.46598782043636355, 0.16254753729010485, 0.7596470441105088, 0.6164082190742632, 0.2981712080491462, 0.6514444728929639, 0.360105323484061, 0.8473387048023598, 0.8839518665745426, 0.6102143073703439, 0.23954170358153837, 0.05005420123063686, 0.3657487815333472, 0.5479735759078938, 0.7172572732387065, 0.02021170633012459, 0.04523303279226332, 0.9662352729518541, 0.38286948722337977, 0.9672389194042832, 0.4541443968799791, 0.6447927017856289, 0.22349233515369515, 0.3617948136856617, 0.26858729239495194, 0.44857814163430665, 0.6473920701763463, 0.2620727175288248, 0.8908230549531753, 0.15299855335144685, 0.9286344490671495, 0.9416449260020638, 0.013463402412540515, 0.4559160308698226, 0.3912440296579408, 0.4678527645019539, 0.7535684457709868, 0.8648150799451025, 0.9864845285823228, 0.47693261586561864, 0.6432149993415861, 0.7429430142885227, 0.3183788213631874, 0.018647747477644194, 0.37876456853410345, 0.6933980898553099, 0.20128592462431427, 0.12918919369086612, 0.19951647569815845, 0.44165439537938345, 0.25754686404521343, 0.8422161201797586, 0.8029466771323559, 0.4695864252847147], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x31\", \"yaxis\": \"y31\"}, {\"type\": \"scatter\", \"x\": [0.2850541037826074, 0.25155025876579384, 0.698545278731228, 0.14967504203986615, 0.7259787598063822, 0.056998169975048585, 0.6664930346677312, 0.14908377716580334, 0.5663644800384876, 0.28811598164859864, 0.6140211440872054, 0.2793373070797651, 0.7480847004733047, 0.296266238519848, 0.5368969874920491, 0.33640672743695155, 0.09008302978501981, 0.29235828513218576, 0.3976407883086216, 0.5628614280774802, 0.9332815221222929, 0.3735910959565084, 0.7618500211034487, 0.9308902924325888, 0.6467129868990306, 0.8100737602562768, 0.023331981827311554, 0.04193974596313521, 0.21458858711334505, 0.931189885037942, 0.5271100462888462, 0.9044301464738321, 0.21722407831228285, 0.19918367234035506, 0.11431078510149895, 0.16527467841396482, 0.2835544171872829, 0.22194744057236615, 0.33608629335464146, 0.932474414298411, 0.23450776539169405, 0.7391543158300712, 0.31697544777205877, 0.7549687285282886, 0.6612666348127837, 0.6865757670942859, 0.5457493825054603, 0.884136840673705, 0.9429348452119289, 0.7714682818456293, 0.13696677613330566, 0.8237463832334782, 0.2029448774306245, 0.5968920278888731, 0.5245703351216106, 0.7227642043938939, 0.6934235480621307, 0.1124900361446306, 0.10576417393335458, 0.031090286969449932, 0.7712035809862177, 0.7123031687382922, 0.17160616748947533, 0.3395356222888408, 0.8485894067573986, 0.45793140770046803, 0.355416342505564, 0.6665030669055917, 0.27524059247615984, 0.13523481331868825, 0.5212069951374524, 0.6737691987282483, 0.18311369845258607, 0.11610552698915222, 0.5569381059434042, 0.15781001102161774, 0.6572919476396999, 0.7647784851610151, 0.19373719732792605, 0.029621718329189584, 0.6462405448533647, 0.5254476397141129, 0.6747330388047486, 0.788167075041062, 0.8376172719024221, 0.4460342161316301, 0.5084279237677516, 0.8410887872065183, 0.3240885862317632, 0.7310399960542304, 0.569709084451349, 0.8371239802708226, 0.008244820777970285, 0.9235691921961882, 0.36607142369776746, 0.32486258420088754, 0.10557318582019204, 0.35016220644308305, 0.4419985281747887, 0.48006226870678625], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x32\", \"yaxis\": \"y32\"}, {\"type\": \"scatter\", \"x\": [0.7460600272391255, 0.9989153690269862, 0.02036684974023928, 0.795850247518187, 0.19334362798474647, 0.9880110776211922, 0.49641988944419846, 0.31886963871479945, 0.47526016143235905, 0.7423976322035429, 0.5154797549660395, 0.40841726235245157, 0.13791941387886542, 0.4355833697410939, 0.5810613907574794, 0.5271512978662364, 0.9265307328597139, 0.7048307014235259, 0.5349480091599211, 0.4572226900729871, 0.9666816495640831, 0.278071788557525, 0.2757398583047965, 0.025686271056969967, 0.036858617800828886, 0.4427882051793308, 0.5297861469630643, 0.48466114234490465, 0.21245723441761732, 0.06236194583164756, 0.7458585483405434, 0.5579519968413817, 0.6073271349807343, 0.5209512558755753, 0.3264455515995571, 0.9355486773947842, 0.7123072136628135, 0.2990131634634968, 0.5775664883794402, 0.9886279751032792, 0.5347880641668014, 0.48245620415707535, 0.832164432616035, 0.932823465929367, 0.6585081600076058, 0.7708344969752476, 0.5007406391118306, 0.3480769610469614, 0.5606720629588454, 0.5807010431645636, 0.555094343472377, 0.21816320616414342, 0.13365899365129918, 0.30295061099316034, 0.31340958131272834, 0.6015140845055321, 0.9637440304839351, 0.6402452378794882, 0.005360105161705375, 0.17300303274131767, 0.6290008942328794, 0.6980411326873354, 0.3368731145263837, 0.5558950168176884, 0.5576199708795464, 0.10287219816276738, 0.39254898948883765, 0.6514332323964686, 0.8291294302072703, 0.8130866147565137, 0.6492016034671377, 0.9549581421074428, 0.1339672999825814, 0.19423535800275193, 0.5324783925360591, 0.6961732601234787, 0.9687102471701311, 0.6696051750681296, 0.5680241755756421, 0.2867171742264183, 0.33877927930565355, 0.008340074278601173, 0.8308305081611412, 0.04841054133519451, 0.37798089409270574, 0.3085160714063411, 0.728131439442904, 0.41044448655053667, 0.7079177554715657, 0.06992012832964634, 0.7457950683919919, 0.6763711616939186, 0.4878721145946815, 0.20549128029932462, 0.9332131497458775, 0.9531579376971704, 0.48626747969697015, 0.9994953702605477, 0.6983143726737339, 0.26708955990309136], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x33\", \"yaxis\": \"y33\"}, {\"type\": \"scatter\", \"x\": [0.6177973072645351, 0.3784764121932017, 0.5245436936504758, 0.9616683417466887, 0.5625988047464932, 0.4960467054753289, 0.5765096275600574, 0.5923745661829463, 0.6824814478903274, 0.08269498299042122, 0.2725623954615256, 0.17399520767319554, 0.361955191772919, 0.48065766496210793, 0.7174589056582705, 0.3376329160495888, 0.6954473903085711, 0.36961562976902573, 0.3767090162249682, 0.9733089768109245, 0.4034513458175021, 0.8638559516166862, 0.2730609598126167, 0.054438299381962096, 0.228737808478511, 0.05904808183306276, 0.41136681055098856, 0.03507402795594039, 0.8297171969466143, 0.5208603670569473, 0.014248167026738923, 0.005558575927227416, 0.24462692745500192, 0.7354118088875922, 0.06836440489243745, 0.2600910809402166, 0.27088880395652837, 0.9541754803724765, 0.152156186596901, 0.8895875786336861, 0.31347758565566564, 0.18463836903129027, 0.91802522556144, 0.8965437503124648, 0.14166439639170114, 0.8407370197049922, 0.8890219459785312, 0.4348001397432564, 0.6318377445759965, 0.6118419280110552, 0.6295444437910109, 0.5600689486796782, 0.3609270061061667, 0.04072648055075456, 0.9394552172905118, 0.9216906322204067, 0.9188991989377034, 0.05385600851286909, 0.6479598394948738, 0.8092437208690338, 0.9403593069271908, 0.24313971947776103, 0.22325682897818988, 0.538888610614994, 0.7203312283614856, 0.05591923039786029, 0.7212559763022688, 0.890883792979236, 0.5822363216280402, 0.7704349521417256, 0.8177998223874463, 0.9918401681653326, 0.36792593343052205, 0.6453800683931861, 0.12796834980162752, 0.9255343670235531, 0.8828333502125524, 0.053599675900733446, 0.20814591431890606, 0.4030171339653472, 0.5007096931649728, 0.25367500790736375, 0.07478603549436358, 0.23055834084398263, 0.5221354913478576, 0.6475260357837425, 0.07570744168731436, 0.7651294584181274, 0.8055963538786817, 0.18881670492413505, 0.49660484641451086, 0.026084762193804956, 0.09368873485814533, 0.8125206057404227, 0.5856188011846184, 0.13480011117383583, 0.748043841841606, 0.038678282424561616, 0.8086175554566394, 0.2097749279304275], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x34\", \"yaxis\": \"y34\"}, {\"type\": \"scatter\", \"x\": [0.4538965064661792, 0.779964539432002, 0.702969166085686, 0.781566521455753, 0.1703570572537696, 0.4894615642885374, 0.5352648136384826, 0.5782873141422693, 0.17661994336555753, 0.5378082039351939, 0.23021134079653782, 0.7450724181611172, 0.5232314485025407, 0.0992576707300914, 0.2938703696122986, 0.44568462277180476, 0.09375237000980785, 0.8251556722753918, 0.8004085109250393, 0.8179205611253678, 0.7303184118852276, 0.3597254837580617, 0.21897022838252733, 0.4065303439358807, 0.5981507928905542, 0.8836176018174101, 0.5623292868379415, 0.3708842672784104, 0.008715677398920652, 0.18358924335649707, 0.6397899583992791, 0.542645879050756, 0.35094099550687363, 0.8412589824605696, 0.7673707365185616, 0.07654905110990717, 0.25260641266397865, 0.15636584452228786, 0.23891018952005794, 0.32956086872850954, 0.3316919544654737, 0.3427536824485037, 0.39018353426140984, 0.3744106436146375, 0.03992060583741053, 0.6598488451917066, 0.9372245252862386, 0.3819637277440324, 0.7183601011563909, 0.47996263742215484, 0.3686912467279405, 0.8022878483261148, 0.8577957300638178, 0.04808147951687447, 0.06546930745818869, 0.9548114907702178, 0.35789805205320546, 0.5051161462669821, 0.8373552870646613, 0.5277583698038274, 0.36543474982570057, 0.8443909811581273, 0.9699369384786177, 0.2956702396358887, 0.1633050060283977, 0.124395649791737, 0.14639485151011233, 0.9722227397321922, 0.15724629356351283, 0.035444422818634025, 0.2505921134758732, 0.7098811911480573, 0.87233131473316, 0.8747826873014111, 0.8247135462511112, 0.31954633427656076, 0.4743189542588465, 0.9070232623008833, 0.764018146943609, 0.850274136846549, 0.18783986963356203, 0.4234691338921699, 0.00858594298787363, 0.808479944846606, 0.42072044746954373, 0.7767065358826053, 0.8385698863005149, 0.08475823144105621, 0.022635846714748387, 0.9057545578400847, 0.9281017431502535, 0.5182158638499622, 0.3303905340751774, 0.5141715058724675, 0.7496389687726507, 0.7578599427361695, 0.3531559066867431, 0.36787328252986606, 0.5485623549654006, 0.5313090984826163], \"y\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"text\": \"\", \"line\": {\"color\": \"rgba(128, 128, 128, 1.0)\", \"width\": 1.3, \"dash\": \"solid\", \"shape\": \"linear\"}, \"mode\": \"markers\", \"marker\": {\"symbol\": \"dot\", \"size\": 2}, \"xaxis\": \"x35\", \"yaxis\": \"y35\"}, {\"type\": \"histogram\", \"x\": [0.1512416205442355, 0.6153551787748954, 0.4764189425684032, 0.3947012733484949, 0.0375873206552666, 0.6074042358718497, 0.6879069197010782, 0.5432630356168869, 0.03244767196403642, 0.7861623786469597, 0.32596062200296205, 0.3530476376049738, 0.011248316097846267, 0.8155055905667299, 0.3304954006932912, 0.7553840122501562, 0.5912652119462452, 0.3932779843719274, 0.5396718741908046, 0.9019648724100523, 0.17583589153872126, 0.8006212807260493, 0.30082074270958403, 0.0016504829558823264, 0.19339767196744895, 0.7172460183079075, 0.46098645531800664, 0.8370704672770218, 0.31077230770406694, 0.40418847986662787, 0.5300074512772918, 0.2667471459976988, 0.6032348072921845, 0.09547762354773226, 0.6525382249030831, 0.11666894824793217, 0.2143736990649997, 0.8215084573270449, 0.14667006866644394, 0.16447724638754313, 0.9749399535932992, 0.6260880437906322, 0.399910941482564, 0.7704961934745408, 0.7529393078443101, 0.24533084393614735, 0.7711911529710075, 0.8315680022850523, 0.6992183903929018, 0.8894027348280082, 0.6578088951422109, 0.8159905381352706, 0.3798576527023557, 0.4566149587488326, 0.179751925795257, 0.9559308056142148, 0.3005062663329964, 0.38693660712750166, 0.8541656120013534, 0.9797568851696837, 0.776848209035442, 0.6920925855421031, 0.9252648532241368, 0.35911257915636996, 0.7928448149145366, 0.2734826908512935, 0.43042050440885227, 0.5867270859559015, 0.06020797057705818, 0.14698664012469242, 0.7721606062225732, 0.8057282637969855, 0.8581031662000709, 0.8973069968664468, 0.24669777854894026, 0.1484888572789409, 0.4756908973491599, 0.9591650158284976, 0.7204310385260341, 0.12229562095823754, 0.20335984053130307, 0.015576059872810633, 0.8780061447457647, 0.37817151201873533, 0.1387347308351209, 0.6407236819251958, 0.7356300438237903, 0.15052293912874704, 0.30734211624047447, 0.6527827828210877, 0.9438133335848098, 0.4826294120136867, 0.5224273246186681, 0.10073297112439239, 0.21289702066861593, 0.7214889154184343, 0.6633621235519349, 0.8324412514224355, 0.6047927730640392, 0.4862974192130832], \"name\": \"\\u7279\\u5fb46\", \"marker\": {\"color\": \"rgba(0, 128, 128, 1.0)\", \"line\": {\"width\": 1.3, \"color\": \"#4D5663\"}}, \"orientation\": \"v\", \"opacity\": 0.8, \"histfunc\": \"count\", \"histnorm\": \"\", \"nbinsx\": 10, \"xaxis\": \"x36\", \"yaxis\": \"y36\"}], {\"xaxis1\": {\"domain\": [0.0, 0.125], \"anchor\": \"y1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": false, \"title\": \"\"}, \"yaxis1\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x1\", \"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": false, \"title\": \"\"}, \"xaxis2\": {\"domain\": [0.175, 0.3], \"anchor\": \"y2\"}, \"yaxis2\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x2\"}, \"xaxis3\": {\"domain\": [0.35, 0.475], \"anchor\": \"y3\"}, \"yaxis3\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x3\"}, \"xaxis4\": {\"domain\": [0.525, 0.65], \"anchor\": \"y4\"}, \"yaxis4\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x4\"}, \"xaxis5\": {\"domain\": [0.7, 0.825], \"anchor\": \"y5\"}, \"yaxis5\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x5\"}, \"xaxis6\": {\"domain\": [0.875, 1.0], \"anchor\": \"y6\"}, \"yaxis6\": {\"domain\": [0.8916666666666666, 0.9999999999999999], \"anchor\": \"x6\"}, \"xaxis7\": {\"domain\": [0.0, 0.125], \"anchor\": \"y7\"}, \"yaxis7\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x7\"}, \"xaxis8\": {\"domain\": [0.175, 0.3], \"anchor\": \"y8\"}, \"yaxis8\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x8\"}, \"xaxis9\": {\"domain\": [0.35, 0.475], \"anchor\": \"y9\"}, \"yaxis9\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x9\"}, \"xaxis10\": {\"domain\": [0.525, 0.65], \"anchor\": \"y10\"}, \"yaxis10\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x10\"}, \"xaxis11\": {\"domain\": [0.7, 0.825], \"anchor\": \"y11\"}, \"yaxis11\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x11\"}, \"xaxis12\": {\"domain\": [0.875, 1.0], \"anchor\": \"y12\"}, \"yaxis12\": {\"domain\": [0.7133333333333334, 0.8216666666666667], \"anchor\": \"x12\"}, \"xaxis13\": {\"domain\": [0.0, 0.125], \"anchor\": \"y13\"}, \"yaxis13\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x13\"}, \"xaxis14\": {\"domain\": [0.175, 0.3], \"anchor\": \"y14\"}, \"yaxis14\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x14\"}, \"xaxis15\": {\"domain\": [0.35, 0.475], \"anchor\": \"y15\"}, \"yaxis15\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x15\"}, \"xaxis16\": {\"domain\": [0.525, 0.65], \"anchor\": \"y16\"}, \"yaxis16\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x16\"}, \"xaxis17\": {\"domain\": [0.7, 0.825], \"anchor\": \"y17\"}, \"yaxis17\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x17\"}, \"xaxis18\": {\"domain\": [0.875, 1.0], \"anchor\": \"y18\"}, \"yaxis18\": {\"domain\": [0.5349999999999999, 0.6433333333333332], \"anchor\": \"x18\"}, \"xaxis19\": {\"domain\": [0.0, 0.125], \"anchor\": \"y19\"}, \"yaxis19\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x19\"}, \"xaxis20\": {\"domain\": [0.175, 0.3], \"anchor\": \"y20\"}, \"yaxis20\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x20\"}, \"xaxis21\": {\"domain\": [0.35, 0.475], \"anchor\": \"y21\"}, \"yaxis21\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x21\"}, \"xaxis22\": {\"domain\": [0.525, 0.65], \"anchor\": \"y22\"}, \"yaxis22\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x22\"}, \"xaxis23\": {\"domain\": [0.7, 0.825], \"anchor\": \"y23\"}, \"yaxis23\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x23\"}, \"xaxis24\": {\"domain\": [0.875, 1.0], \"anchor\": \"y24\"}, \"yaxis24\": {\"domain\": [0.3566666666666667, 0.465], \"anchor\": \"x24\"}, \"xaxis25\": {\"domain\": [0.0, 0.125], \"anchor\": \"y25\"}, \"yaxis25\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x25\"}, \"xaxis26\": {\"domain\": [0.175, 0.3], \"anchor\": \"y26\"}, \"yaxis26\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x26\"}, \"xaxis27\": {\"domain\": [0.35, 0.475], \"anchor\": \"y27\"}, \"yaxis27\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x27\"}, \"xaxis28\": {\"domain\": [0.525, 0.65], \"anchor\": \"y28\"}, \"yaxis28\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x28\"}, \"xaxis29\": {\"domain\": [0.7, 0.825], \"anchor\": \"y29\"}, \"yaxis29\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x29\"}, \"xaxis30\": {\"domain\": [0.875, 1.0], \"anchor\": \"y30\"}, \"yaxis30\": {\"domain\": [0.17833333333333334, 0.2866666666666667], \"anchor\": \"x30\"}, \"xaxis31\": {\"domain\": [0.0, 0.125], \"anchor\": \"y31\"}, \"yaxis31\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x31\"}, \"xaxis32\": {\"domain\": [0.175, 0.3], \"anchor\": \"y32\"}, \"yaxis32\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x32\"}, \"xaxis33\": {\"domain\": [0.35, 0.475], \"anchor\": \"y33\"}, \"yaxis33\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x33\"}, \"xaxis34\": {\"domain\": [0.525, 0.65], \"anchor\": \"y34\"}, \"yaxis34\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x34\"}, \"xaxis35\": {\"domain\": [0.7, 0.825], \"anchor\": \"y35\"}, \"yaxis35\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x35\"}, \"xaxis36\": {\"domain\": [0.875, 1.0], \"anchor\": \"y36\"}, \"yaxis36\": {\"domain\": [0.0, 0.10833333333333332], \"anchor\": \"x36\"}, \"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"titlefont\": {\"color\": \"#4D5663\"}, \"bargap\": 0.02, \"showlegend\": false}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "toy1.scatter_matrix()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "data": [
        {
         "colorscale": [
          [
           0,
           "rgb(255, 153, 51)"
          ],
          [
           0.1111111111111111,
           "rgb(55, 128, 191)"
          ],
          [
           0.2222222222222222,
           "rgb(50, 171, 96)"
          ],
          [
           0.3333333333333333,
           "rgb(128, 0, 128)"
          ],
          [
           0.4444444444444444,
           "rgb(219, 64, 82)"
          ],
          [
           0.5555555555555556,
           "rgb(0, 128, 128)"
          ],
          [
           0.6666666666666666,
           "rgb(255, 255, 51)"
          ],
          [
           0.7777777777777778,
           "rgb(128, 128, 0)"
          ],
          [
           0.8888888888888888,
           "rgb(251, 128, 114)"
          ],
          [
           1,
           "rgb(128, 177, 211)"
          ]
         ],
         "type": "surface",
         "x": [
          -10,
          -9.75,
          -9.5,
          -9.25,
          -9,
          -8.75,
          -8.5,
          -8.25,
          -8,
          -7.75,
          -7.5,
          -7.25,
          -7,
          -6.75,
          -6.5,
          -6.25,
          -6,
          -5.75,
          -5.5,
          -5.25,
          -5,
          -4.75,
          -4.5,
          -4.25,
          -4,
          -3.75,
          -3.5,
          -3.25,
          -3,
          -2.75,
          -2.5,
          -2.25,
          -2,
          -1.75,
          -1.5,
          -1.25,
          -1,
          -0.75,
          -0.5,
          -0.25,
          0,
          0.25,
          0.5,
          0.75,
          1,
          1.25,
          1.5,
          1.75,
          2,
          2.25,
          2.5,
          2.75,
          3,
          3.25,
          3.5,
          3.75,
          4,
          4.25,
          4.5,
          4.75,
          5,
          5.25,
          5.5,
          5.75,
          6,
          6.25,
          6.5,
          6.75,
          7,
          7.25,
          7.5,
          7.75,
          8,
          8.25,
          8.5,
          8.75,
          9,
          9.25,
          9.5,
          9.75
         ],
         "y": [
          -10,
          -9.75,
          -9.5,
          -9.25,
          -9,
          -8.75,
          -8.5,
          -8.25,
          -8,
          -7.75,
          -7.5,
          -7.25,
          -7,
          -6.75,
          -6.5,
          -6.25,
          -6,
          -5.75,
          -5.5,
          -5.25,
          -5,
          -4.75,
          -4.5,
          -4.25,
          -4,
          -3.75,
          -3.5,
          -3.25,
          -3,
          -2.75,
          -2.5,
          -2.25,
          -2,
          -1.75,
          -1.5,
          -1.25,
          -1,
          -0.75,
          -0.5,
          -0.25,
          0,
          0.25,
          0.5,
          0.75,
          1,
          1.25,
          1.5,
          1.75,
          2,
          2.25,
          2.5,
          2.75,
          3,
          3.25,
          3.5,
          3.75,
          4,
          4.25,
          4.5,
          4.75,
          5,
          5.25,
          5.5,
          5.75,
          6,
          6.25,
          6.5,
          6.75,
          7,
          7.25,
          7.5,
          7.75,
          8,
          8.25,
          8.5,
          8.75,
          9,
          9.25,
          9.5,
          9.75
         ],
         "z": [
          [
           0.14141961054935853,
           0.14111903500315878,
           0.13650222610828716,
           0.12777380562398274,
           0.11526115097856117,
           0.0993958462307399,
           0.08069235790121831,
           0.059725017515438364,
           0.037104384846577534,
           0.013454008098850966,
           -0.01061150357619211,
           -0.0345063152690242,
           -0.05769048962428924,
           -0.07968395387291566,
           -0.10007704610444179,
           -0.11853755153953284,
           -0.13481430178982187,
           -0.1487375524385824,
           -0.16021647158282734,
           -0.16923416092386775,
           -0.17584069010379264,
           -0.1801446545297837,
           -0.18230376872794093,
           -0.18251498442862385,
           -0.18100457917857166,
           -0.17801860199902664,
           -0.1738139924448547,
           -0.16865061331126227,
           -0.16278435980926842,
           -0.15646143337355978,
           -0.1499137997580331,
           -0.14335579129849668,
           -0.13698176393514344,
           -0.13096468174943518,
           -0.1254554756233313,
           -0.12058300781296416,
           -0.1164544699167505,
           -0.1131560467581887,
           -0.1107536917561867,
           -0.10929387900894774,
           -0.10880422217787396,
           -0.10929387900894774,
           -0.1107536917561867,
           -0.1131560467581887,
           -0.1164544699167505,
           -0.12058300781296416,
           -0.1254554756233313,
           -0.13096468174943518,
           -0.13698176393514344,
           -0.14335579129849668,
           -0.1499137997580331,
           -0.15646143337355978,
           -0.16278435980926842,
           -0.16865061331126227,
           -0.1738139924448547,
           -0.17801860199902664,
           -0.18100457917857166,
           -0.18251498442862385,
           -0.18230376872794093,
           -0.1801446545297837,
           -0.17584069010379264,
           -0.16923416092386775,
           -0.16021647158282734,
           -0.1487375524385824,
           -0.13481430178982187,
           -0.11853755153953284,
           -0.10007704610444179,
           -0.07968395387291566,
           -0.05769048962428924,
           -0.0345063152690242,
           -0.01061150357619211,
           0.013454008098850966,
           0.037104384846577534,
           0.059725017515438364,
           0.08069235790121831,
           0.0993958462307399,
           0.11526115097856117,
           0.12777380562398274,
           0.13650222610828716,
           0.14111903500315878
          ],
          [
           0.14111903500315878,
           0.13632396086944565,
           0.12719030582037316,
           0.11405907878471819,
           0.09738828403656238,
           0.07773008237271903,
           0.05570574218106777,
           0.03197958453286062,
           0.007233082355737275,
           -0.017859822184363938,
           -0.042655257000177006,
           -0.06655906279410359,
           -0.08904297911487404,
           -0.10965701691843574,
           -0.12803786284735597,
           -0.14391335124448024,
           -0.15710321083861073,
           -0.16751643729146143,
           -0.1751457556394694,
           -0.1800597155006458,
           -0.18239300622958532,
           -0.18233559039097344,
           -0.18012123502583363,
           -0.1760159755489718,
           -0.17030698199702413,
           -0.16329221750830802,
           -0.15527119023634722,
           -0.14653700801271363,
           -0.13736985507049018,
           -0.12803192632998142,
           -0.11876378051842666,
           -0.10978201113265723,
           -0.10127808535368477,
           -0.09341816596346665,
           -0.08634370978474622,
           -0.08017262722723162,
           -0.0750007897964791,
           -0.07090368426500879,
           -0.06793803188546253,
           -0.06614321685638791,
           -0.06554239869174844,
           -0.06614321685638791,
           -0.06793803188546253,
           -0.07090368426500879,
           -0.0750007897964791,
           -0.08017262722723162,
           -0.08634370978474622,
           -0.09341816596346665,
           -0.10127808535368477,
           -0.10978201113265723,
           -0.11876378051842666,
           -0.12803192632998142,
           -0.13736985507049018,
           -0.14653700801271363,
           -0.15527119023634722,
           -0.16329221750830802,
           -0.17030698199702413,
           -0.1760159755489718,
           -0.18012123502583363,
           -0.18233559039097344,
           -0.18239300622958532,
           -0.1800597155006458,
           -0.1751457556394694,
           -0.16751643729146143,
           -0.15710321083861073,
           -0.14391335124448024,
           -0.12803786284735597,
           -0.10965701691843574,
           -0.08904297911487404,
           -0.06655906279410359,
           -0.042655257000177006,
           -0.017859822184363938,
           0.007233082355737275,
           0.03197958453286062,
           0.05570574218106777,
           0.07773008237271903,
           0.09738828403656238,
           0.11405907878471819,
           0.12719030582037316,
           0.13632396086944565
          ],
          [
           0.13650222610828716,
           0.12719030582037316,
           0.1136526088802527,
           0.09636827159298987,
           0.0759235678781371,
           0.05298490441364873,
           0.028270310898122826,
           0.0025207381574719806,
           -0.023527608249201665,
           -0.04916880920228074,
           -0.07374973820785838,
           -0.09668883252747353,
           -0.11749065565570795,
           -0.13575600794040762,
           -0.1511875643863488,
           -0.163591222139663,
           -0.17287351607260817,
           -0.17903560277058095,
           -0.1821644169794075,
           -0.18242166855756492,
           -0.1800313728705813,
           -0.1752665961050691,
           -0.16843605361995675,
           -0.15987112992755653,
           -0.1499137997580331,
           -0.13890582780165694,
           -0.1271795169340972,
           -0.11505016730310495,
           -0.10281030706494565,
           -0.0907256642328181,
           -0.07903277128303789,
           -0.06793803188546253,
           -0.05761803324395176,
           -0.04822085787410071,
           -0.039868134180728126,
           -0.032657564269347995,
           -0.026665677985416577,
           -0.021950582012676394,
           -0.01855449981019833,
           -0.016505930263581485,
           -0.015821288518275644,
           -0.016505930263581485,
           -0.01855449981019833,
           -0.021950582012676394,
           -0.026665677985416577,
           -0.032657564269347995,
           -0.039868134180728126,
           -0.04822085787410071,
           -0.05761803324395176,
           -0.06793803188546253,
           -0.07903277128303789,
           -0.0907256642328181,
           -0.10281030706494565,
           -0.11505016730310495,
           -0.1271795169340972,
           -0.13890582780165694,
           -0.1499137997580331,
           -0.15987112992755653,
           -0.16843605361995675,
           -0.1752665961050691,
           -0.1800313728705813,
           -0.18242166855756492,
           -0.1821644169794075,
           -0.17903560277058095,
           -0.17287351607260817,
           -0.163591222139663,
           -0.1511875643863488,
           -0.13575600794040762,
           -0.11749065565570795,
           -0.09668883252747353,
           -0.07374973820785838,
           -0.04916880920228074,
           -0.023527608249201665,
           0.0025207381574719806,
           0.028270310898122826,
           0.05298490441364873,
           0.0759235678781371,
           0.09636827159298987,
           0.1136526088802527,
           0.12719030582037316
          ],
          [
           0.12777380562398274,
           0.11405907878471819,
           0.09636827159298987,
           0.07531659368730659,
           0.05161237775613617,
           0.026026147564044762,
           -0.0006409754282528475,
           -0.027588123185645037,
           -0.054043516875550875,
           -0.07929019757294747,
           -0.10268778525178764,
           -0.12368964794720452,
           -0.14185512230149663,
           -0.15685668268767797,
           -0.16848219583369567,
           -0.17663261032673944,
           -0.18131560690315682,
           -0.1826358700412797,
           -0.18078273088932142,
           -0.1760159755489718,
           -0.16865061331126227,
           -0.15904136091487175,
           -0.14756752732225356,
           -0.13461888616197776,
           -0.12058300781296416,
           -0.10583439818051152,
           -0.0907256642328181,
           -0.07558080422426758,
           -0.060690608986011814,
           -0.046310064114579955,
           -0.032657564269347995,
           -0.019915691575644292,
           -0.00823327044894154,
           0.0022716100207446164,
           0.011507919583092052,
           0.019407660252202565,
           0.025921773001301992,
           0.031016232090896562,
           0.03466854669458865,
           0.03686485131708162,
           0.03759772656874239,
           0.03686485131708162,
           0.03466854669458865,
           0.031016232090896562,
           0.025921773001301992,
           0.019407660252202565,
           0.011507919583092052,
           0.0022716100207446164,
           -0.00823327044894154,
           -0.019915691575644292,
           -0.032657564269347995,
           -0.046310064114579955,
           -0.060690608986011814,
           -0.07558080422426758,
           -0.0907256642328181,
           -0.10583439818051152,
           -0.12058300781296416,
           -0.13461888616197776,
           -0.14756752732225356,
           -0.15904136091487175,
           -0.16865061331126227,
           -0.1760159755489718,
           -0.18078273088932142,
           -0.1826358700412797,
           -0.18131560690315682,
           -0.17663261032673944,
           -0.16848219583369567,
           -0.15685668268767797,
           -0.14185512230149663,
           -0.12368964794720452,
           -0.10268778525178764,
           -0.07929019757294747,
           -0.054043516875550875,
           -0.027588123185645037,
           -0.0006409754282528475,
           0.026026147564044762,
           0.05161237775613617,
           0.07531659368730659,
           0.09636827159298987,
           0.11405907878471819
          ],
          [
           0.11526115097856117,
           0.09738828403656238,
           0.0759235678781371,
           0.05161237775613617,
           0.025275083284098894,
           -0.0022274559793407315,
           -0.03002807965783915,
           -0.0572857273340844,
           -0.08321475815193494,
           -0.10711012813756442,
           -0.1283676319466868,
           -0.1464987033293174,
           -0.16113955966514656,
           -0.17205475511311313,
           -0.17913546063850083,
           -0.18239300622958532,
           -0.18194839266053625,
           -0.17801860199902664,
           -0.17090060569317098,
           -0.1609539875623888,
           -0.14858307017251748,
           -0.13421936300715656,
           -0.11830504740258321,
           -0.10127808535368477,
           -0.08355939645450051,
           -0.06554239869174844,
           -0.04758506314163741,
           -0.030004497243790427,
           -0.013073952151520388,
           0.0029779491154211806,
           0.017966041941118966,
           0.031745840459068614,
           0.044209509361482956,
           0.05528095770522729,
           0.0649104168254659,
           0.07306884206017318,
           0.07974244535617742,
           0.08492762656935865,
           0.08862652853638416,
           0.09084339726921295,
           0.09158188560927924,
           0.09084339726921295,
           0.08862652853638416,
           0.08492762656935865,
           0.07974244535617742,
           0.07306884206017318,
           0.0649104168254659,
           0.05528095770522729,
           0.044209509361482956,
           0.031745840459068614,
           0.017966041941118966,
           0.0029779491154211806,
           -0.013073952151520388,
           -0.030004497243790427,
           -0.04758506314163741,
           -0.06554239869174844,
           -0.08355939645450051,
           -0.10127808535368477,
           -0.11830504740258321,
           -0.13421936300715656,
           -0.14858307017251748,
           -0.1609539875623888,
           -0.17090060569317098,
           -0.17801860199902664,
           -0.18194839266053625,
           -0.18239300622958532,
           -0.17913546063850083,
           -0.17205475511311313,
           -0.16113955966514656,
           -0.1464987033293174,
           -0.1283676319466868,
           -0.10711012813756442,
           -0.08321475815193494,
           -0.0572857273340844,
           -0.03002807965783915,
           -0.0022274559793407315,
           0.025275083284098894,
           0.05161237775613617,
           0.0759235678781371,
           0.09738828403656238
          ],
          [
           0.0993958462307399,
           0.07773008237271903,
           0.05298490441364873,
           0.026026147564044762,
           -0.0022274559793407315,
           -0.030841885736018544,
           -0.05890402451081101,
           -0.08555491563889543,
           -0.11001880232017779,
           -0.1316269478872783,
           -0.14983554931501694,
           -0.1642373823959323,
           -0.17456713788189782,
           -0.1807007071005138,
           -0.18264893898060253,
           -0.18054660691367944,
           -0.17463748569481502,
           -0.16525654180237792,
           -0.1528102839666787,
           -0.1377563081818195,
           -0.12058300781296416,
           -0.10179031338845618,
           -0.08187218787401292,
           -0.061301442485772274,
           -0.040517266401149735,
           -0.019915691575644292,
           0.0001569493213448689,
           0.019407660252202565,
           0.03759772656874239,
           0.054541276561040686,
           0.07010183827093616,
           0.08418731130237875,
           0.09674378883254962,
           0.10774865812501504,
           0.11720338291232232,
           0.12512633286074154,
           0.13154597877649798,
           0.13649472168344115,
           0.14000357308347133,
           0.14209785531573388,
           0.14279404657238684,
           0.14209785531573388,
           0.14000357308347133,
           0.13649472168344115,
           0.13154597877649798,
           0.12512633286074154,
           0.11720338291232232,
           0.10774865812501504,
           0.09674378883254962,
           0.08418731130237875,
           0.07010183827093616,
           0.054541276561040686,
           0.03759772656874239,
           0.019407660252202565,
           0.0001569493213448689,
           -0.019915691575644292,
           -0.040517266401149735,
           -0.061301442485772274,
           -0.08187218787401292,
           -0.10179031338845618,
           -0.12058300781296416,
           -0.1377563081818195,
           -0.1528102839666787,
           -0.16525654180237792,
           -0.17463748569481502,
           -0.18054660691367944,
           -0.18264893898060253,
           -0.1807007071005138,
           -0.17456713788189782,
           -0.1642373823959323,
           -0.14983554931501694,
           -0.1316269478872783,
           -0.11001880232017779,
           -0.08555491563889543,
           -0.05890402451081101,
           -0.030841885736018544,
           -0.0022274559793407315,
           0.026026147564044762,
           0.05298490441364873,
           0.07773008237271903
          ],
          [
           0.08069235790121831,
           0.05570574218106777,
           0.028270310898122826,
           -0.0006409754282528475,
           -0.03002807965783915,
           -0.05890402451081101,
           -0.08633239590937543,
           -0.1114606806231028,
           -0.13354819579908725,
           -0.15198770280837584,
           -0.16632015713858264,
           -0.17624240938958516,
           -0.18160802037610754,
           -0.18242166855756492,
           -0.1788278960809016,
           -0.17109514979541934,
           -0.15959621882048483,
           -0.14478624788034108,
           -0.1271795169340972,
           -0.10732612754693129,
           -0.0857896329957062,
           -0.0631265026963309,
           -0.039868134180728126,
           -0.016505930263581485,
           0.0065202421682302655,
           0.02883009042098063,
           0.05010748884225075,
           0.07010183827093616,
           0.08862652853638416,
           0.10555493165712146,
           0.12081441070397907,
           0.13437885433763305,
           0.14626024334832619,
           0.15649972810645998,
           0.16515865057394133,
           0.17230988766358785,
           0.17802983029511174,
           0.18239124981424537,
           0.18545724476618586,
           0.18727640924644018,
           0.18787932061729182,
           0.18727640924644018,
           0.18545724476618586,
           0.18239124981424537,
           0.17802983029511174,
           0.17230988766358785,
           0.16515865057394133,
           0.15649972810645998,
           0.14626024334832619,
           0.13437885433763305,
           0.12081441070397907,
           0.10555493165712146,
           0.08862652853638416,
           0.07010183827093616,
           0.05010748884225075,
           0.02883009042098063,
           0.0065202421682302655,
           -0.016505930263581485,
           -0.039868134180728126,
           -0.0631265026963309,
           -0.0857896329957062,
           -0.10732612754693129,
           -0.1271795169340972,
           -0.14478624788034108,
           -0.15959621882048483,
           -0.17109514979541934,
           -0.1788278960809016,
           -0.18242166855756492,
           -0.18160802037610754,
           -0.17624240938958516,
           -0.16632015713858264,
           -0.15198770280837584,
           -0.13354819579908725,
           -0.1114606806231028,
           -0.08633239590937543,
           -0.05890402451081101,
           -0.03002807965783915,
           -0.0006409754282528475,
           0.028270310898122826,
           0.05570574218106777
          ],
          [
           0.059725017515438364,
           0.03197958453286062,
           0.0025207381574719806,
           -0.027588123185645037,
           -0.0572857273340844,
           -0.08555491563889543,
           -0.1114606806231028,
           -0.13418273806183595,
           -0.15304146672549196,
           -0.16751643729146143,
           -0.17725715646546372,
           -0.18208605074549258,
           -0.18199408570471504,
           -0.17712974307464055,
           -0.16778234479339135,
           -0.1543609103022869,
           -0.13736985507049018,
           -0.11738288358628372,
           -0.0950164022704569,
           -0.07090368426500879,
           -0.045670869380806056,
           -0.019915691575644292,
           0.0058103924762656495,
           0.031016232090896562,
           0.05528095770522729,
           0.07825990831739421,
           0.09968670899986165,
           0.11937185506223688,
           0.13719827990417027,
           0.15311446345017118,
           0.16712567793535366,
           0.1792839709402817,
           0.18967745729212915,
           0.19841943861188654,
           0.20563779959612533,
           0.21146505144444128,
           0.21602931256266372,
           0.21944644111666822,
           0.22181346801290225,
           0.2232034254780841,
           0.22366162672468853,
           0.2232034254780841,
           0.22181346801290225,
           0.21944644111666822,
           0.21602931256266372,
           0.21146505144444128,
           0.20563779959612533,
           0.19841943861188654,
           0.18967745729212915,
           0.1792839709402817,
           0.16712567793535366,
           0.15311446345017118,
           0.13719827990417027,
           0.11937185506223688,
           0.09968670899986165,
           0.07825990831739421,
           0.05528095770522729,
           0.031016232090896562,
           0.0058103924762656495,
           -0.019915691575644292,
           -0.045670869380806056,
           -0.07090368426500879,
           -0.0950164022704569,
           -0.11738288358628372,
           -0.13736985507049018,
           -0.1543609103022869,
           -0.16778234479339135,
           -0.17712974307464055,
           -0.18199408570471504,
           -0.18208605074549258,
           -0.17725715646546372,
           -0.16751643729146143,
           -0.15304146672549196,
           -0.13418273806183595,
           -0.1114606806231028,
           -0.08555491563889543,
           -0.0572857273340844,
           -0.027588123185645037,
           0.0025207381574719806,
           0.03197958453286062
          ],
          [
           0.037104384846577534,
           0.007233082355737275,
           -0.023527608249201665,
           -0.054043516875550875,
           -0.08321475815193494,
           -0.11001880232017779,
           -0.13354819579908725,
           -0.15304146672549196,
           -0.167906160972842,
           -0.17773339606034183,
           -0.18230376872794093,
           -0.18158488243001691,
           -0.17572115154133375,
           -0.16501687105976595,
           -0.1499137997580331,
           -0.13096468174943518,
           -0.10880422217787396,
           -0.08411903827788304,
           -0.05761803324395176,
           -0.030004497243790427,
           -0.001951040868825416,
           0.025921773001301992,
           0.05306249567952219,
           0.07900122348247962,
           0.10335731863015635,
           0.1258425822940911,
           0.14626024334832619,
           0.16450028494360933,
           0.18053174205108255,
           0.1943926655354523,
           0.2061784643801796,
           0.21602931256266372,
           0.22411724822563847,
           0.23063350923189954,
           0.23577655069724138,
           0.23974108638511749,
           0.242708395806646,
           0.24483804991090946,
           0.24626113579560338,
           0.24707500803079696,
           0.24733956165584545,
           0.24707500803079696,
           0.24626113579560338,
           0.24483804991090946,
           0.242708395806646,
           0.23974108638511749,
           0.23577655069724138,
           0.23063350923189954,
           0.22411724822563847,
           0.21602931256266372,
           0.2061784643801796,
           0.1943926655354523,
           0.18053174205108255,
           0.16450028494360933,
           0.14626024334832619,
           0.1258425822940911,
           0.10335731863015635,
           0.07900122348247962,
           0.05306249567952219,
           0.025921773001301992,
           -0.001951040868825416,
           -0.030004497243790427,
           -0.05761803324395176,
           -0.08411903827788304,
           -0.10880422217787396,
           -0.13096468174943518,
           -0.1499137997580331,
           -0.16501687105976595,
           -0.17572115154133375,
           -0.18158488243001691,
           -0.18230376872794093,
           -0.17773339606034183,
           -0.167906160972842,
           -0.15304146672549196,
           -0.13354819579908725,
           -0.11001880232017779,
           -0.08321475815193494,
           -0.054043516875550875,
           -0.023527608249201665,
           0.007233082355737275
          ],
          [
           0.013454008098850966,
           -0.017859822184363938,
           -0.04916880920228074,
           -0.07929019757294747,
           -0.10711012813756442,
           -0.1316269478872783,
           -0.15198770280837584,
           -0.16751643729146143,
           -0.17773339606034183,
           -0.18236471957976835,
           -0.18134271385500067,
           -0.1747972342928682,
           -0.16303912773542587,
           -0.14653700801271363,
           -0.1258888846262905,
           -0.10179031338845618,
           -0.0750007897964791,
           -0.046310064114579955,
           -0.016505930263581485,
           0.013655158230898757,
           0.043473546354522816,
           0.07232710218505171,
           0.09968670899986165,
           0.12512633286074154,
           0.14832776112580212,
           0.16908036038891633,
           0.18727640924644018,
           0.20290271423033404,
           0.21602931256266372,
           0.22679610352037188,
           0.23539823538075702,
           0.2420710146043941,
           0.24707500803079696,
           0.2506818889186662,
           0.2531614457800734,
           0.25477004091850136,
           0.2557406839380664,
           0.2562747828163765,
           0.25653555744366946,
           0.2566430509401283,
           0.2566706526738519,
           0.2566430509401283,
           0.25653555744366946,
           0.2562747828163765,
           0.2557406839380664,
           0.25477004091850136,
           0.2531614457800734,
           0.2506818889186662,
           0.24707500803079696,
           0.2420710146043941,
           0.23539823538075702,
           0.22679610352037188,
           0.21602931256266372,
           0.20290271423033404,
           0.18727640924644018,
           0.16908036038891633,
           0.14832776112580212,
           0.12512633286074154,
           0.09968670899986165,
           0.07232710218505171,
           0.043473546354522816,
           0.013655158230898757,
           -0.016505930263581485,
           -0.046310064114579955,
           -0.0750007897964791,
           -0.10179031338845618,
           -0.1258888846262905,
           -0.14653700801271363,
           -0.16303912773542587,
           -0.1747972342928682,
           -0.18134271385500067,
           -0.18236471957976835,
           -0.17773339606034183,
           -0.16751643729146143,
           -0.15198770280837584,
           -0.1316269478872783,
           -0.10711012813756442,
           -0.07929019757294747,
           -0.04916880920228074,
           -0.017859822184363938
          ],
          [
           -0.01061150357619211,
           -0.042655257000177006,
           -0.07374973820785838,
           -0.10268778525178764,
           -0.1283676319466868,
           -0.14983554931501694,
           -0.16632015713858264,
           -0.17725715646546372,
           -0.18230376872794093,
           -0.18134271385500067,
           -0.17447608825271163,
           -0.16200998595397612,
           -0.14443111863131364,
           -0.12237701362727325,
           -0.09660159075517502,
           -0.06793803188546253,
           -0.03726086233570953,
           -0.005449066140771361,
           0.026648129724923395,
           0.058241427706856384,
           0.08862652853638416,
           0.11720338291232232,
           0.14348926836260514,
           0.16712567793535366,
           0.18787932061729182,
           0.20563779959612533,
           0.22040074178662336,
           0.23226729318028777,
           0.24142096714711753,
           0.24811283911536614,
           0.25264402764959015,
           0.255348298963932,
           0.256575492104657,
           0.2566762997375786,
           0.2559887694405144,
           0.2548267267047997,
           0.25347017586536014,
           0.252157618714697,
           0.25108014921898075,
           0.25037713957121355,
           0.25013332713993036,
           0.25037713957121355,
           0.25108014921898075,
           0.252157618714697,
           0.25347017586536014,
           0.2548267267047997,
           0.2559887694405144,
           0.2566762997375786,
           0.256575492104657,
           0.255348298963932,
           0.25264402764959015,
           0.24811283911536614,
           0.24142096714711753,
           0.23226729318028777,
           0.22040074178662336,
           0.20563779959612533,
           0.18787932061729182,
           0.16712567793535366,
           0.14348926836260514,
           0.11720338291232232,
           0.08862652853638416,
           0.058241427706856384,
           0.026648129724923395,
           -0.005449066140771361,
           -0.03726086233570953,
           -0.06793803188546253,
           -0.09660159075517502,
           -0.12237701362727325,
           -0.14443111863131364,
           -0.16200998595397612,
           -0.17447608825271163,
           -0.18134271385500067,
           -0.18230376872794093,
           -0.17725715646546372,
           -0.16632015713858264,
           -0.14983554931501694,
           -0.1283676319466868,
           -0.10268778525178764,
           -0.07374973820785838,
           -0.042655257000177006
          ],
          [
           -0.0345063152690242,
           -0.06655906279410359,
           -0.09668883252747353,
           -0.12368964794720452,
           -0.1464987033293174,
           -0.1642373823959323,
           -0.17624240938958516,
           -0.18208605074549258,
           -0.18158488243001691,
           -0.1747972342928682,
           -0.16200998595397612,
           -0.1437158894806465,
           -0.12058300781296416,
           -0.09341816596346665,
           -0.0631265026963309,
           -0.03066927919323432,
           0.0029779491154211806,
           0.03686485131708162,
           0.07010183827093616,
           0.1018902143955224,
           0.13154597877649798,
           0.15851669454452746,
           0.18239124981424537,
           0.20290271423033404,
           0.21992483146863692,
           0.23346296309158113,
           0.24364050109720906,
           0.2506818889186662,
           0.254893432701845,
           0.2566430509401283,
           0.2563400102730029,
           0.25441554164532254,
           0.25130504004127213,
           0.24743234013685533,
           0.2431963471432226,
           0.23896010343988033,
           0.23504220166614895,
           0.2317103248693539,
           0.22917661128094333,
           0.22759450814784551,
           0.2270567942100705,
           0.22759450814784551,
           0.22917661128094333,
           0.2317103248693539,
           0.23504220166614895,
           0.23896010343988033,
           0.2431963471432226,
           0.24743234013685533,
           0.25130504004127213,
           0.25441554164532254,
           0.2563400102730029,
           0.2566430509401283,
           0.254893432701845,
           0.2506818889186662,
           0.24364050109720906,
           0.23346296309158113,
           0.21992483146863692,
           0.20290271423033404,
           0.18239124981424537,
           0.15851669454452746,
           0.13154597877649798,
           0.1018902143955224,
           0.07010183827093616,
           0.03686485131708162,
           0.0029779491154211806,
           -0.03066927919323432,
           -0.0631265026963309,
           -0.09341816596346665,
           -0.12058300781296416,
           -0.1437158894806465,
           -0.16200998595397612,
           -0.1747972342928682,
           -0.18158488243001691,
           -0.18208605074549258,
           -0.17624240938958516,
           -0.1642373823959323,
           -0.1464987033293174,
           -0.12368964794720452,
           -0.09668883252747353,
           -0.06655906279410359
          ],
          [
           -0.05769048962428924,
           -0.08904297911487404,
           -0.11749065565570795,
           -0.14185512230149663,
           -0.16113955966514656,
           -0.17456713788189782,
           -0.18160802037610754,
           -0.18199408570471504,
           -0.17572115154133375,
           -0.16303912773542587,
           -0.14443111863131364,
           -0.12058300781296416,
           -0.09234546620178369,
           -0.060690608986011814,
           -0.026665677985416577,
           0.008653858363151095,
           0.044209509361482956,
           0.07900122348247962,
           0.11212338767979044,
           0.14279404657238684,
           0.17037647050011584,
           0.1943926655354523,
           0.2145288714461612,
           0.23063350923189954,
           0.242708395806646,
           0.2508943222213973,
           0.2554522819126627,
           0.2567417315441088,
           0.25519727019112654,
           0.25130504004127213,
           0.2455799958764798,
           0.23854497801642713,
           0.23071227369415245,
           0.2225680860000738,
           0.21456006847846779,
           0.2070878465419809,
           0.20049625055173417,
           0.19507084218595108,
           0.19103523332295086,
           0.18854967763954522,
           0.18771045677679687,
           0.18854967763954522,
           0.19103523332295086,
           0.19507084218595108,
           0.20049625055173417,
           0.2070878465419809,
           0.21456006847846779,
           0.2225680860000738,
           0.23071227369415245,
           0.23854497801642713,
           0.2455799958764798,
           0.25130504004127213,
           0.25519727019112654,
           0.2567417315441088,
           0.2554522819126627,
           0.2508943222213973,
           0.242708395806646,
           0.23063350923189954,
           0.2145288714461612,
           0.1943926655354523,
           0.17037647050011584,
           0.14279404657238684,
           0.11212338767979044,
           0.07900122348247962,
           0.044209509361482956,
           0.008653858363151095,
           -0.026665677985416577,
           -0.060690608986011814,
           -0.09234546620178369,
           -0.12058300781296416,
           -0.14443111863131364,
           -0.16303912773542587,
           -0.17572115154133375,
           -0.18199408570471504,
           -0.18160802037610754,
           -0.17456713788189782,
           -0.16113955966514656,
           -0.14185512230149663,
           -0.11749065565570795,
           -0.08904297911487404
          ],
          [
           -0.07968395387291566,
           -0.10965701691843574,
           -0.13575600794040762,
           -0.15685668268767797,
           -0.17205475511311313,
           -0.1807007071005138,
           -0.18242166855756492,
           -0.17712974307464055,
           -0.16501687105976595,
           -0.14653700801271363,
           -0.12237701362727325,
           -0.09341816596346665,
           -0.060690608986011814,
           -0.02532329427921568,
           0.011507919583092052,
           0.04863139306208121,
           0.08492762656935865,
           0.11937185506223688,
           0.15106960365711752,
           0.1792839709402817,
           0.20345392533496165,
           0.2232034254780841,
           0.2383416766936446,
           0.24885528388828942,
           0.254893432701845,
           0.25674750760048576,
           0.2548267267047997,
           0.24963143467045815,
           0.24172565029557566,
           0.2317103248693539,
           0.22019854657881394,
           0.20779364608280457,
           0.19507084218595108,
           0.18256273925541686,
           0.17074867404778504,
           0.16004763127913005,
           0.15081422331281308,
           0.1433370736825879,
           0.13783886506830845,
           0.134477311926808,
           0.1333463922312941,
           0.134477311926808,
           0.13783886506830845,
           0.1433370736825879,
           0.15081422331281308,
           0.16004763127913005,
           0.17074867404778504,
           0.18256273925541686,
           0.19507084218595108,
           0.20779364608280457,
           0.22019854657881394,
           0.2317103248693539,
           0.24172565029557566,
           0.24963143467045815,
           0.2548267267047997,
           0.25674750760048576,
           0.254893432701845,
           0.24885528388828942,
           0.2383416766936446,
           0.2232034254780841,
           0.20345392533496165,
           0.1792839709402817,
           0.15106960365711752,
           0.11937185506223688,
           0.08492762656935865,
           0.04863139306208121,
           0.011507919583092052,
           -0.02532329427921568,
           -0.060690608986011814,
           -0.09341816596346665,
           -0.12237701362727325,
           -0.14653700801271363,
           -0.16501687105976595,
           -0.17712974307464055,
           -0.18242166855756492,
           -0.1807007071005138,
           -0.17205475511311313,
           -0.15685668268767797,
           -0.13575600794040762,
           -0.10965701691843574
          ],
          [
           -0.10007704610444179,
           -0.12803786284735597,
           -0.1511875643863488,
           -0.16848219583369567,
           -0.17913546063850083,
           -0.18264893898060253,
           -0.1788278960809016,
           -0.16778234479339135,
           -0.1499137997580331,
           -0.1258888846262905,
           -0.09660159075517502,
           -0.0631265026963309,
           -0.026665677985416577,
           0.011507919583092052,
           0.05010748884225075,
           0.0878871354792479,
           0.12369173187889267,
           0.15649972810645998,
           0.18545724476618586,
           0.20990234059772522,
           0.22937894091767205,
           0.24364050109720906,
           0.25264402764959015,
           0.25653555744366946,
           0.25562857790064414,
           0.25037713957121355,
           0.2413455569066888,
           0.22917661128094333,
           0.21456006847846779,
           0.1982031145119569,
           0.18080401871815463,
           0.1630299764243758,
           0.14549969299473817,
           0.12877087581897034,
           0.11333242903336226,
           0.09960082298540655,
           0.08791985781076668,
           0.07856287339249271,
           0.07173638515428266,
           0.06758414818694233,
           0.0661907655654817,
           0.06758414818694233,
           0.07173638515428266,
           0.07856287339249271,
           0.08791985781076668,
           0.09960082298540655,
           0.11333242903336226,
           0.12877087581897034,
           0.14549969299473817,
           0.1630299764243758,
           0.18080401871815463,
           0.1982031145119569,
           0.21456006847846779,
           0.22917661128094333,
           0.2413455569066888,
           0.25037713957121355,
           0.25562857790064414,
           0.25653555744366946,
           0.25264402764959015,
           0.24364050109720906,
           0.22937894091767205,
           0.20990234059772522,
           0.18545724476618586,
           0.15649972810645998,
           0.12369173187889267,
           0.0878871354792479,
           0.05010748884225075,
           0.011507919583092052,
           -0.026665677985416577,
           -0.0631265026963309,
           -0.09660159075517502,
           -0.1258888846262905,
           -0.1499137997580331,
           -0.16778234479339135,
           -0.1788278960809016,
           -0.18264893898060253,
           -0.17913546063850083,
           -0.16848219583369567,
           -0.1511875643863488,
           -0.12803786284735597
          ],
          [
           -0.11853755153953284,
           -0.14391335124448024,
           -0.163591222139663,
           -0.17663261032673944,
           -0.18239300622958532,
           -0.18054660691367944,
           -0.17109514979541934,
           -0.1543609103022869,
           -0.13096468174943518,
           -0.10179031338845618,
           -0.06793803188546253,
           -0.03066927919323432,
           0.008653858363151095,
           0.04863139306208121,
           0.0878871354792479,
           0.12512633286074154,
           0.15918658398472915,
           0.1890798565922851,
           0.21402402107025095,
           0.23346296309158113,
           0.24707500803079696,
           0.25477004091850136,
           0.2566762997375786,
           0.25311832399967577,
           0.24458792842044305,
           0.2317103248693539,
           0.2152076253393881,
           0.19586192453391038,
           0.17447999195279823,
           0.15186131748507978,
           0.12877087581897034,
           0.10591753298818528,
           0.08393854575868848,
           0.06339013493636744,
           0.044743679368913644,
           0.02838670735216783,
           0.014627580006334946,
           0.0037025838949493145,
           -0.004215913110515241,
           -0.009011537058698997,
           -0.010617349295218181,
           -0.009011537058698997,
           -0.004215913110515241,
           0.0037025838949493145,
           0.014627580006334946,
           0.02838670735216783,
           0.044743679368913644,
           0.06339013493636744,
           0.08393854575868848,
           0.10591753298818528,
           0.12877087581897034,
           0.15186131748507978,
           0.17447999195279823,
           0.19586192453391038,
           0.2152076253393881,
           0.2317103248693539,
           0.24458792842044305,
           0.25311832399967577,
           0.2566762997375786,
           0.25477004091850136,
           0.24707500803079696,
           0.23346296309158113,
           0.21402402107025095,
           0.1890798565922851,
           0.15918658398472915,
           0.12512633286074154,
           0.0878871354792479,
           0.04863139306208121,
           0.008653858363151095,
           -0.03066927919323432,
           -0.06793803188546253,
           -0.10179031338845618,
           -0.13096468174943518,
           -0.1543609103022869,
           -0.17109514979541934,
           -0.18054660691367944,
           -0.18239300622958532,
           -0.17663261032673944,
           -0.163591222139663,
           -0.14391335124448024
          ],
          [
           -0.13481430178982187,
           -0.15710321083861073,
           -0.17287351607260817,
           -0.18131560690315682,
           -0.18194839266053625,
           -0.17463748569481502,
           -0.15959621882048483,
           -0.13736985507049018,
           -0.10880422217787396,
           -0.0750007897964791,
           -0.03726086233570953,
           0.0029779491154211806,
           0.044209509361482956,
           0.08492762656935865,
           0.12369173187889267,
           0.15918658398472915,
           0.1902732638436695,
           0.21602931256266372,
           0.23577655069724138,
           0.24909585663212155,
           0.25582893038458626,
           0.2560677827399544,
           0.25013332713993036,
           0.23854497801642713,
           0.22198354690007724,
           0.20124995852555586,
           0.17722237538812438,
           0.15081422331281308,
           0.12293536517635703,
           0.09445829662141196,
           0.0661907655654817,
           0.03885568116655977,
           0.013078615468659323,
           -0.010617349295218181,
           -0.03181017613329085,
           -0.050171999808914604,
           -0.06545830501430487,
           -0.07749482277960204,
           -0.08616386191642225,
           -0.09139170665445415,
           -0.09313849939964196,
           -0.09139170665445415,
           -0.08616386191642225,
           -0.07749482277960204,
           -0.06545830501430487,
           -0.050171999808914604,
           -0.03181017613329085,
           -0.010617349295218181,
           0.013078615468659323,
           0.03885568116655977,
           0.0661907655654817,
           0.09445829662141196,
           0.12293536517635703,
           0.15081422331281308,
           0.17722237538812438,
           0.20124995852555586,
           0.22198354690007724,
           0.23854497801642713,
           0.25013332713993036,
           0.2560677827399544,
           0.25582893038458626,
           0.24909585663212155,
           0.23577655069724138,
           0.21602931256266372,
           0.1902732638436695,
           0.15918658398472915,
           0.12369173187889267,
           0.08492762656935865,
           0.044209509361482956,
           0.0029779491154211806,
           -0.03726086233570953,
           -0.0750007897964791,
           -0.10880422217787396,
           -0.13736985507049018,
           -0.15959621882048483,
           -0.17463748569481502,
           -0.18194839266053625,
           -0.18131560690315682,
           -0.17287351607260817,
           -0.15710321083861073
          ],
          [
           -0.1487375524385824,
           -0.16751643729146143,
           -0.17903560277058095,
           -0.1826358700412797,
           -0.17801860199902664,
           -0.16525654180237792,
           -0.14478624788034108,
           -0.11738288358628372,
           -0.08411903827788304,
           -0.046310064114579955,
           -0.005449066140771361,
           0.03686485131708162,
           0.07900122348247962,
           0.11937185506223688,
           0.15649972810645998,
           0.1890798565922851,
           0.21602931256266372,
           0.2365243422174828,
           0.25002327766855664,
           0.2562747828163765,
           0.2553118000893658,
           0.24743234013685533,
           0.23316893482082693,
           0.21324911772700825,
           0.18854967763954522,
           0.16004763127913005,
           0.12877087581897034,
           0.0957513146109,
           0.06198291759831892,
           0.02838670735216783,
           -0.004215913110515241,
           -0.03512071345143313,
           -0.06374895250625122,
           -0.08964697741323371,
           -0.11247819731414006,
           -0.132008995765264,
           -0.14809048863531396,
           -0.16063822727306362,
           -0.1696119802323752,
           -0.17499760171649797,
           -0.17679272260843765,
           -0.17499760171649797,
           -0.1696119802323752,
           -0.16063822727306362,
           -0.14809048863531396,
           -0.132008995765264,
           -0.11247819731414006,
           -0.08964697741323371,
           -0.06374895250625122,
           -0.03512071345143313,
           -0.004215913110515241,
           0.02838670735216783,
           0.06198291759831892,
           0.0957513146109,
           0.12877087581897034,
           0.16004763127913005,
           0.18854967763954522,
           0.21324911772700825,
           0.23316893482082693,
           0.24743234013685533,
           0.2553118000893658,
           0.2562747828163765,
           0.25002327766855664,
           0.2365243422174828,
           0.21602931256266372,
           0.1890798565922851,
           0.15649972810645998,
           0.11937185506223688,
           0.07900122348247962,
           0.03686485131708162,
           -0.005449066140771361,
           -0.046310064114579955,
           -0.08411903827788304,
           -0.11738288358628372,
           -0.14478624788034108,
           -0.16525654180237792,
           -0.17801860199902664,
           -0.1826358700412797,
           -0.17903560277058095,
           -0.16751643729146143
          ],
          [
           -0.16021647158282734,
           -0.1751457556394694,
           -0.1821644169794075,
           -0.18078273088932142,
           -0.17090060569317098,
           -0.1528102839666787,
           -0.1271795169340972,
           -0.0950164022704569,
           -0.05761803324395176,
           -0.016505930263581485,
           0.026648129724923395,
           0.07010183827093616,
           0.11212338767979044,
           0.15106960365711752,
           0.18545724476618586,
           0.21402402107025095,
           0.23577655069724138,
           0.25002327766855664,
           0.25639126767027576,
           0.2548267267047997,
           0.2455799958764798,
           0.22917661128094333,
           0.2063767337439853,
           0.17812580971586786,
           0.14549969299473817,
           0.1096476200446325,
           0.07173638515428266,
           0.032898814044057145,
           -0.005810793613848673,
           -0.043452159632214875,
           -0.0792240541655952,
           -0.11247819731414006,
           -0.1427221428215067,
           -0.1696119802323752,
           -0.1929363397545002,
           -0.2125937105436689,
           -0.22856545626592412,
           -0.24088710992360066,
           -0.24962054293732017,
           -0.254829433326894,
           -0.2565601183892334,
           -0.254829433326894,
           -0.24962054293732017,
           -0.24088710992360066,
           -0.22856545626592412,
           -0.2125937105436689,
           -0.1929363397545002,
           -0.1696119802323752,
           -0.1427221428215067,
           -0.11247819731414006,
           -0.0792240541655952,
           -0.043452159632214875,
           -0.005810793613848673,
           0.032898814044057145,
           0.07173638515428266,
           0.1096476200446325,
           0.14549969299473817,
           0.17812580971586786,
           0.2063767337439853,
           0.22917661128094333,
           0.2455799958764798,
           0.2548267267047997,
           0.25639126767027576,
           0.25002327766855664,
           0.23577655069724138,
           0.21402402107025095,
           0.18545724476618586,
           0.15106960365711752,
           0.11212338767979044,
           0.07010183827093616,
           0.026648129724923395,
           -0.016505930263581485,
           -0.05761803324395176,
           -0.0950164022704569,
           -0.1271795169340972,
           -0.1528102839666787,
           -0.17090060569317098,
           -0.18078273088932142,
           -0.1821644169794075,
           -0.1751457556394694
          ],
          [
           -0.16923416092386775,
           -0.1800597155006458,
           -0.18242166855756492,
           -0.1760159755489718,
           -0.1609539875623888,
           -0.1377563081818195,
           -0.10732612754693129,
           -0.07090368426500879,
           -0.030004497243790427,
           0.013655158230898757,
           0.058241427706856384,
           0.1018902143955224,
           0.14279404657238684,
           0.1792839709402817,
           0.20990234059772522,
           0.23346296309158113,
           0.24909585663212155,
           0.2562747828163765,
           0.2548267267047997,
           0.24492352037505036,
           0.2270567942100705,
           0.20199833430642128,
           0.17074867404778504,
           0.134477311926808,
           0.09445829662141196,
           0.05200503792795912,
           0.00840808631479302,
           -0.03512071345143313,
           -0.07749482277960204,
           -0.1177881852505473,
           -0.15525760655490364,
           -0.18935183535374994,
           -0.21970771693043264,
           -0.24613461781837798,
           -0.268589046149572,
           -0.28714197491104243,
           -0.30194177876754097,
           -0.31317589634427284,
           -0.3210343185560354,
           -0.32567778292945404,
           -0.32721314035298743,
           -0.32567778292945404,
           -0.3210343185560354,
           -0.31317589634427284,
           -0.30194177876754097,
           -0.28714197491104243,
           -0.268589046149572,
           -0.24613461781837798,
           -0.21970771693043264,
           -0.18935183535374994,
           -0.15525760655490364,
           -0.1177881852505473,
           -0.07749482277960204,
           -0.03512071345143313,
           0.00840808631479302,
           0.05200503792795912,
           0.09445829662141196,
           0.134477311926808,
           0.17074867404778504,
           0.20199833430642128,
           0.2270567942100705,
           0.24492352037505036,
           0.2548267267047997,
           0.2562747828163765,
           0.24909585663212155,
           0.23346296309158113,
           0.20990234059772522,
           0.1792839709402817,
           0.14279404657238684,
           0.1018902143955224,
           0.058241427706856384,
           0.013655158230898757,
           -0.030004497243790427,
           -0.07090368426500879,
           -0.10732612754693129,
           -0.1377563081818195,
           -0.1609539875623888,
           -0.1760159755489718,
           -0.18242166855756492,
           -0.1800597155006458
          ],
          [
           -0.17584069010379264,
           -0.18239300622958532,
           -0.1800313728705813,
           -0.16865061331126227,
           -0.14858307017251748,
           -0.12058300781296416,
           -0.0857896329957062,
           -0.045670869380806056,
           -0.001951040868825416,
           0.043473546354522816,
           0.08862652853638416,
           0.13154597877649798,
           0.17037647050011584,
           0.20345392533496165,
           0.22937894091767205,
           0.24707500803079696,
           0.25582893038458626,
           0.2553118000893658,
           0.2455799958764798,
           0.2270567942100705,
           0.20049625055173417,
           0.16693195814109418,
           0.12761407121954643,
           0.08393854575868848,
           0.037372873633869375,
           -0.010617349295218181,
           -0.05863687417657578,
           -0.10542055787501849,
           -0.14988136590815446,
           -0.19114437378651342,
           -0.22856545626592412,
           -0.2617343483375656,
           -0.29046275344788247,
           -0.31475910259630246,
           -0.33479237619194996,
           -0.35084804028714445,
           -0.3632795822101567,
           -0.37245933283868765,
           -0.3787322233669178,
           -0.382375848005458,
           -0.3835697098652554,
           -0.382375848005458,
           -0.3787322233669178,
           -0.37245933283868765,
           -0.3632795822101567,
           -0.35084804028714445,
           -0.33479237619194996,
           -0.31475910259630246,
           -0.29046275344788247,
           -0.2617343483375656,
           -0.22856545626592412,
           -0.19114437378651342,
           -0.14988136590815446,
           -0.10542055787501849,
           -0.05863687417657578,
           -0.010617349295218181,
           0.037372873633869375,
           0.08393854575868848,
           0.12761407121954643,
           0.16693195814109418,
           0.20049625055173417,
           0.2270567942100705,
           0.2455799958764798,
           0.2553118000893658,
           0.25582893038458626,
           0.24707500803079696,
           0.22937894091767205,
           0.20345392533496165,
           0.17037647050011584,
           0.13154597877649798,
           0.08862652853638416,
           0.043473546354522816,
           -0.001951040868825416,
           -0.045670869380806056,
           -0.0857896329957062,
           -0.12058300781296416,
           -0.14858307017251748,
           -0.16865061331126227,
           -0.1800313728705813,
           -0.18239300622958532
          ],
          [
           -0.1801446545297837,
           -0.18233559039097344,
           -0.1752665961050691,
           -0.15904136091487175,
           -0.13421936300715656,
           -0.10179031338845618,
           -0.0631265026963309,
           -0.019915691575644292,
           0.025921773001301992,
           0.07232710218505171,
           0.11720338291232232,
           0.15851669454452746,
           0.1943926655354523,
           0.2232034254780841,
           0.24364050109720906,
           0.25477004091850136,
           0.2560677827399544,
           0.24743234013685533,
           0.22917661128094333,
           0.20199833430642128,
           0.16693195814109418,
           0.12528500092613942,
           0.07856287339249271,
           0.02838670735216783,
           -0.02359098016854476,
           -0.0757679524450742,
           -0.12666669235949252,
           -0.17499760171649797,
           -0.21970771693043264,
           -0.26001264723920775,
           -0.29541051237375787,
           -0.32567778292945404,
           -0.35084804028714445,
           -0.37117570680030565,
           -0.38708768931988075,
           -0.3991265770886398,
           -0.407889497747319,
           -0.41396693622794944,
           -0.417885750201407,
           -0.4200602785751461,
           -0.4207548585159486,
           -0.4200602785751461,
           -0.417885750201407,
           -0.41396693622794944,
           -0.407889497747319,
           -0.3991265770886398,
           -0.38708768931988075,
           -0.37117570680030565,
           -0.35084804028714445,
           -0.32567778292945404,
           -0.29541051237375787,
           -0.26001264723920775,
           -0.21970771693043264,
           -0.17499760171649797,
           -0.12666669235949252,
           -0.0757679524450742,
           -0.02359098016854476,
           0.02838670735216783,
           0.07856287339249271,
           0.12528500092613942,
           0.16693195814109418,
           0.20199833430642128,
           0.22917661128094333,
           0.24743234013685533,
           0.2560677827399544,
           0.25477004091850136,
           0.24364050109720906,
           0.2232034254780841,
           0.1943926655354523,
           0.15851669454452746,
           0.11720338291232232,
           0.07232710218505171,
           0.025921773001301992,
           -0.019915691575644292,
           -0.0631265026963309,
           -0.10179031338845618,
           -0.13421936300715656,
           -0.15904136091487175,
           -0.1752665961050691,
           -0.18233559039097344
          ],
          [
           -0.18230376872794093,
           -0.18012123502583363,
           -0.16843605361995675,
           -0.14756752732225356,
           -0.11830504740258321,
           -0.08187218787401292,
           -0.039868134180728126,
           0.0058103924762656495,
           0.05306249567952219,
           0.09968670899986165,
           0.14348926836260514,
           0.18239124981424537,
           0.2145288714461612,
           0.2383416766936446,
           0.25264402764959015,
           0.2566762997375786,
           0.25013332713993036,
           0.23316893482082693,
           0.2063767337439853,
           0.17074867404778504,
           0.12761407121954643,
           0.07856287339249271,
           0.02535776443828009,
           -0.030159748399708135,
           -0.08616386191642225,
           -0.1409342819269669,
           -0.1929363397545002,
           -0.24088710992360066,
           -0.2838041182964338,
           -0.3210343185560354,
           -0.35226222727992795,
           -0.37749737145928347,
           -0.3970424421347404,
           -0.41144469052055266,
           -0.42143408131469146,
           -0.42785247459104203,
           -0.43157859884674826,
           -0.4334537754581445,
           -0.434213248547002,
           -0.43442757176285574,
           -0.43445783007337646,
           -0.43442757176285574,
           -0.434213248547002,
           -0.4334537754581445,
           -0.43157859884674826,
           -0.42785247459104203,
           -0.42143408131469146,
           -0.41144469052055266,
           -0.3970424421347404,
           -0.37749737145928347,
           -0.35226222727992795,
           -0.3210343185560354,
           -0.2838041182964338,
           -0.24088710992360066,
           -0.1929363397545002,
           -0.1409342819269669,
           -0.08616386191642225,
           -0.030159748399708135,
           0.02535776443828009,
           0.07856287339249271,
           0.12761407121954643,
           0.17074867404778504,
           0.2063767337439853,
           0.23316893482082693,
           0.25013332713993036,
           0.2566762997375786,
           0.25264402764959015,
           0.2383416766936446,
           0.2145288714461612,
           0.18239124981424537,
           0.14348926836260514,
           0.09968670899986165,
           0.05306249567952219,
           0.0058103924762656495,
           -0.039868134180728126,
           -0.08187218787401292,
           -0.11830504740258321,
           -0.14756752732225356,
           -0.16843605361995675,
           -0.18012123502583363
          ],
          [
           -0.18251498442862385,
           -0.1760159755489718,
           -0.15987112992755653,
           -0.13461888616197776,
           -0.10127808535368477,
           -0.061301442485772274,
           -0.016505930263581485,
           0.031016232090896562,
           0.07900122348247962,
           0.12512633286074154,
           0.16712567793535366,
           0.20290271423033404,
           0.23063350923189954,
           0.24885528388828942,
           0.25653555744366946,
           0.25311832399967577,
           0.23854497801642713,
           0.21324911772700825,
           0.17812580971586786,
           0.134477311926808,
           0.08393854575868848,
           0.02838670735216783,
           -0.030159748399708135,
           -0.08964697741323371,
           -0.14809048863531396,
           -0.2036729142303004,
           -0.254829433326894,
           -0.3003162506586467,
           -0.3392585664190622,
           -0.37117570680030565,
           -0.39598244357893553,
           -0.41396693622794944,
           -0.42574709936268906,
           -0.43220845214435083,
           -0.43442757176285574,
           -0.4335860886421158,
           -0.4308806796227811,
           -0.4274347075936389,
           -0.42421701152445723,
           -0.42197287899622543,
           -0.421171462695804,
           -0.42197287899622543,
           -0.42421701152445723,
           -0.4274347075936389,
           -0.4308806796227811,
           -0.4335860886421158,
           -0.43442757176285574,
           -0.43220845214435083,
           -0.42574709936268906,
           -0.41396693622794944,
           -0.39598244357893553,
           -0.37117570680030565,
           -0.3392585664190622,
           -0.3003162506586467,
           -0.254829433326894,
           -0.2036729142303004,
           -0.14809048863531396,
           -0.08964697741323371,
           -0.030159748399708135,
           0.02838670735216783,
           0.08393854575868848,
           0.134477311926808,
           0.17812580971586786,
           0.21324911772700825,
           0.23854497801642713,
           0.25311832399967577,
           0.25653555744366946,
           0.24885528388828942,
           0.23063350923189954,
           0.20290271423033404,
           0.16712567793535366,
           0.12512633286074154,
           0.07900122348247962,
           0.031016232090896562,
           -0.016505930263581485,
           -0.061301442485772274,
           -0.10127808535368477,
           -0.13461888616197776,
           -0.15987112992755653,
           -0.1760159755489718
          ],
          [
           -0.18100457917857166,
           -0.17030698199702413,
           -0.1499137997580331,
           -0.12058300781296416,
           -0.08355939645450051,
           -0.040517266401149735,
           0.0065202421682302655,
           0.05528095770522729,
           0.10335731863015635,
           0.14832776112580212,
           0.18787932061729182,
           0.21992483146863692,
           0.242708395806646,
           0.254893432701845,
           0.25562857790064414,
           0.24458792842044305,
           0.22198354690007724,
           0.18854967763954522,
           0.14549969299473817,
           0.09445829662141196,
           0.037372873633869375,
           -0.02359098016854476,
           -0.08616386191642225,
           -0.14809048863531396,
           -0.20724458052139974,
           -0.2617343483375656,
           -0.309992807249447,
           -0.35084804028714445,
           -0.3835697098652554,
           -0.407889497747319,
           -0.42399466300627076,
           -0.43249545715781157,
           -0.43436863670247905,
           -0.4308806796227811,
           -0.42349546556438716,
           -0.4137720534188708,
           -0.40325873487122593,
           -0.39338972722403176,
           -0.3853906832849483,
           -0.3801986514917913,
           -0.3784012476539641,
           -0.3801986514917913,
           -0.3853906832849483,
           -0.39338972722403176,
           -0.40325873487122593,
           -0.4137720534188708,
           -0.42349546556438716,
           -0.4308806796227811,
           -0.43436863670247905,
           -0.43249545715781157,
           -0.42399466300627076,
           -0.407889497747319,
           -0.3835697098652554,
           -0.35084804028714445,
           -0.309992807249447,
           -0.2617343483375656,
           -0.20724458052139974,
           -0.14809048863531396,
           -0.08616386191642225,
           -0.02359098016854476,
           0.037372873633869375,
           0.09445829662141196,
           0.14549969299473817,
           0.18854967763954522,
           0.22198354690007724,
           0.24458792842044305,
           0.25562857790064414,
           0.254893432701845,
           0.242708395806646,
           0.21992483146863692,
           0.18787932061729182,
           0.14832776112580212,
           0.10335731863015635,
           0.05528095770522729,
           0.0065202421682302655,
           -0.040517266401149735,
           -0.08355939645450051,
           -0.12058300781296416,
           -0.1499137997580331,
           -0.17030698199702413
          ],
          [
           -0.17801860199902664,
           -0.16329221750830802,
           -0.13890582780165694,
           -0.10583439818051152,
           -0.06554239869174844,
           -0.019915691575644292,
           0.02883009042098063,
           0.07825990831739421,
           0.1258425822940911,
           0.16908036038891633,
           0.20563779959612533,
           0.23346296309158113,
           0.2508943222213973,
           0.25674750760048576,
           0.25037713957121355,
           0.2317103248693539,
           0.20124995852555586,
           0.16004763127913005,
           0.1096476200446325,
           0.05200503792795912,
           -0.010617349295218181,
           -0.0757679524450742,
           -0.1409342819269669,
           -0.2036729142303004,
           -0.2617343483375656,
           -0.31317589634427284,
           -0.3564564355250057,
           -0.3905078789395116,
           -0.4147795406040892,
           -0.42925310491460716,
           -0.43442757176285574,
           -0.4312752446188071,
           -0.421171462695804,
           -0.40580225753498556,
           -0.38705535500366767,
           -0.36690087535799776,
           -0.3472686537517362,
           -0.32992927901128904,
           -0.3163857196862348,
           -0.3077817863653888,
           -0.30483270332925,
           -0.3077817863653888,
           -0.3163857196862348,
           -0.32992927901128904,
           -0.3472686537517362,
           -0.36690087535799776,
           -0.38705535500366767,
           -0.40580225753498556,
           -0.421171462695804,
           -0.4312752446188071,
           -0.43442757176285574,
           -0.42925310491460716,
           -0.4147795406040892,
           -0.3905078789395116,
           -0.3564564355250057,
           -0.31317589634427284,
           -0.2617343483375656,
           -0.2036729142303004,
           -0.1409342819269669,
           -0.0757679524450742,
           -0.010617349295218181,
           0.05200503792795912,
           0.1096476200446325,
           0.16004763127913005,
           0.20124995852555586,
           0.2317103248693539,
           0.25037713957121355,
           0.25674750760048576,
           0.2508943222213973,
           0.23346296309158113,
           0.20563779959612533,
           0.16908036038891633,
           0.1258425822940911,
           0.07825990831739421,
           0.02883009042098063,
           -0.019915691575644292,
           -0.06554239869174844,
           -0.10583439818051152,
           -0.13890582780165694,
           -0.16329221750830802
          ],
          [
           -0.1738139924448547,
           -0.15527119023634722,
           -0.1271795169340972,
           -0.0907256642328181,
           -0.04758506314163741,
           0.0001569493213448689,
           0.05010748884225075,
           0.09968670899986165,
           0.14626024334832619,
           0.18727640924644018,
           0.22040074178662336,
           0.24364050109720906,
           0.2554522819126627,
           0.2548267267047997,
           0.2413455569066888,
           0.2152076253393881,
           0.17722237538812438,
           0.12877087581897034,
           0.07173638515428266,
           0.00840808631479302,
           -0.05863687417657578,
           -0.12666669235949252,
           -0.1929363397545002,
           -0.254829433326894,
           -0.309992807249447,
           -0.3564564355250057,
           -0.39273214882544505,
           -0.417885750201407,
           -0.43157859884674826,
           -0.434076417833265,
           -0.42622489689420734,
           -0.4093935036702951,
           -0.3853906832849483,
           -0.35635521764627226,
           -0.324629843053556,
           -0.2926242127644853,
           -0.2626748843273063,
           -0.23691017597600564,
           -0.21712746254366178,
           -0.20468978410715197,
           -0.20044755867978276,
           -0.20468978410715197,
           -0.21712746254366178,
           -0.23691017597600564,
           -0.2626748843273063,
           -0.2926242127644853,
           -0.324629843053556,
           -0.35635521764627226,
           -0.3853906832849483,
           -0.4093935036702951,
           -0.42622489689420734,
           -0.434076417833265,
           -0.43157859884674826,
           -0.417885750201407,
           -0.39273214882544505,
           -0.3564564355250057,
           -0.309992807249447,
           -0.254829433326894,
           -0.1929363397545002,
           -0.12666669235949252,
           -0.05863687417657578,
           0.00840808631479302,
           0.07173638515428266,
           0.12877087581897034,
           0.17722237538812438,
           0.2152076253393881,
           0.2413455569066888,
           0.2548267267047997,
           0.2554522819126627,
           0.24364050109720906,
           0.22040074178662336,
           0.18727640924644018,
           0.14626024334832619,
           0.09968670899986165,
           0.05010748884225075,
           0.0001569493213448689,
           -0.04758506314163741,
           -0.0907256642328181,
           -0.1271795169340972,
           -0.15527119023634722
          ],
          [
           -0.16865061331126227,
           -0.14653700801271363,
           -0.11505016730310495,
           -0.07558080422426758,
           -0.030004497243790427,
           0.019407660252202565,
           0.07010183827093616,
           0.11937185506223688,
           0.16450028494360933,
           0.20290271423033404,
           0.23226729318028777,
           0.2506818889186662,
           0.2567417315441088,
           0.24963143467045815,
           0.22917661128094333,
           0.19586192453391038,
           0.15081422331281308,
           0.0957513146109,
           0.032898814044057145,
           -0.03512071345143313,
           -0.10542055787501849,
           -0.17499760171649797,
           -0.24088710992360066,
           -0.3003162506586467,
           -0.35084804028714445,
           -0.3905078789395116,
           -0.417885750201407,
           -0.43220845214435083,
           -0.4333778373354074,
           -0.42197287899622543,
           -0.39921534828629784,
           -0.36690087535799776,
           -0.32729906443176787,
           -0.28302803533990717,
           -0.23691017597600564,
           -0.19181693290541052,
           -0.15051108239111077,
           -0.11549507625799743,
           -0.08887373699192957,
           -0.0722388011028484,
           -0.06658162124929747,
           -0.0722388011028484,
           -0.08887373699192957,
           -0.11549507625799743,
           -0.15051108239111077,
           -0.19181693290541052,
           -0.23691017597600564,
           -0.28302803533990717,
           -0.32729906443176787,
           -0.36690087535799776,
           -0.39921534828629784,
           -0.42197287899622543,
           -0.4333778373354074,
           -0.43220845214435083,
           -0.417885750201407,
           -0.3905078789395116,
           -0.35084804028714445,
           -0.3003162506586467,
           -0.24088710992360066,
           -0.17499760171649797,
           -0.10542055787501849,
           -0.03512071345143313,
           0.032898814044057145,
           0.0957513146109,
           0.15081422331281308,
           0.19586192453391038,
           0.22917661128094333,
           0.24963143467045815,
           0.2567417315441088,
           0.2506818889186662,
           0.23226729318028777,
           0.20290271423033404,
           0.16450028494360933,
           0.11937185506223688,
           0.07010183827093616,
           0.019407660252202565,
           -0.030004497243790427,
           -0.07558080422426758,
           -0.11505016730310495,
           -0.14653700801271363
          ],
          [
           -0.16278435980926842,
           -0.13736985507049018,
           -0.10281030706494565,
           -0.060690608986011814,
           -0.013073952151520388,
           0.03759772656874239,
           0.08862652853638416,
           0.13719827990417027,
           0.18053174205108255,
           0.21602931256266372,
           0.24142096714711753,
           0.254893432701845,
           0.25519727019112654,
           0.24172565029557566,
           0.21456006847846779,
           0.17447999195279823,
           0.12293536517635703,
           0.06198291759831892,
           -0.005810793613848673,
           -0.07749482277960204,
           -0.14988136590815446,
           -0.21970771693043264,
           -0.2838041182964338,
           -0.3392585664190622,
           -0.3835697098652554,
           -0.4147795406040892,
           -0.43157859884674826,
           -0.4333778373354074,
           -0.4203430458705095,
           -0.39338972722403176,
           -0.3541384336243295,
           -0.30483270332925,
           -0.24822376277499153,
           -0.187427969950852,
           -0.1257644689695074,
           -0.06658162124929747,
           -0.0130814139378774,
           0.03184881503912622,
           0.0657883626364726,
           0.08691073780520595,
           0.0940800053732448,
           0.08691073780520595,
           0.0657883626364726,
           0.03184881503912622,
           -0.0130814139378774,
           -0.06658162124929747,
           -0.1257644689695074,
           -0.187427969950852,
           -0.24822376277499153,
           -0.30483270332925,
           -0.3541384336243295,
           -0.39338972722403176,
           -0.4203430458705095,
           -0.4333778373354074,
           -0.43157859884674826,
           -0.4147795406040892,
           -0.3835697098652554,
           -0.3392585664190622,
           -0.2838041182964338,
           -0.21970771693043264,
           -0.14988136590815446,
           -0.07749482277960204,
           -0.005810793613848673,
           0.06198291759831892,
           0.12293536517635703,
           0.17447999195279823,
           0.21456006847846779,
           0.24172565029557566,
           0.25519727019112654,
           0.254893432701845,
           0.24142096714711753,
           0.21602931256266372,
           0.18053174205108255,
           0.13719827990417027,
           0.08862652853638416,
           0.03759772656874239,
           -0.013073952151520388,
           -0.060690608986011814,
           -0.10281030706494565,
           -0.13736985507049018
          ],
          [
           -0.15646143337355978,
           -0.12803192632998142,
           -0.0907256642328181,
           -0.046310064114579955,
           0.0029779491154211806,
           0.054541276561040686,
           0.10555493165712146,
           0.15311446345017118,
           0.1943926655354523,
           0.22679610352037188,
           0.24811283911536614,
           0.2566430509401283,
           0.25130504004127213,
           0.2317103248693539,
           0.1982031145119569,
           0.15186131748507978,
           0.09445829662141196,
           0.02838670735216783,
           -0.043452159632214875,
           -0.1177881852505473,
           -0.19114437378651342,
           -0.26001264723920775,
           -0.3210343185560354,
           -0.37117570680030565,
           -0.407889497747319,
           -0.42925310491460716,
           -0.434076417833265,
           -0.42197287899622543,
           -0.39338972722403176,
           -0.3495953826561967,
           -0.2926242127644853,
           -0.22518118755916025,
           -0.15051108239111077,
           -0.0722388011028484,
           0.005811034304373925,
           0.07980593576993696,
           0.14609889758077332,
           0.20141317105264114,
           0.24300880867803662,
           0.2688222513075441,
           0.277571630583514,
           0.2688222513075441,
           0.24300880867803662,
           0.20141317105264114,
           0.14609889758077332,
           0.07980593576993696,
           0.005811034304373925,
           -0.0722388011028484,
           -0.15051108239111077,
           -0.22518118755916025,
           -0.2926242127644853,
           -0.3495953826561967,
           -0.39338972722403176,
           -0.42197287899622543,
           -0.434076417833265,
           -0.42925310491460716,
           -0.407889497747319,
           -0.37117570680030565,
           -0.3210343185560354,
           -0.26001264723920775,
           -0.19114437378651342,
           -0.1177881852505473,
           -0.043452159632214875,
           0.02838670735216783,
           0.09445829662141196,
           0.15186131748507978,
           0.1982031145119569,
           0.2317103248693539,
           0.25130504004127213,
           0.2566430509401283,
           0.24811283911536614,
           0.22679610352037188,
           0.1943926655354523,
           0.15311446345017118,
           0.10555493165712146,
           0.054541276561040686,
           0.0029779491154211806,
           -0.046310064114579955,
           -0.0907256642328181,
           -0.12803192632998142
          ],
          [
           -0.1499137997580331,
           -0.11876378051842666,
           -0.07903277128303789,
           -0.032657564269347995,
           0.017966041941118966,
           0.07010183827093616,
           0.12081441070397907,
           0.16712567793535366,
           0.2061784643801796,
           0.23539823538075702,
           0.25264402764959015,
           0.2563400102730029,
           0.2455799958764798,
           0.22019854657881394,
           0.18080401871815463,
           0.12877087581897034,
           0.0661907655654817,
           -0.004215913110515241,
           -0.0792240541655952,
           -0.15525760655490364,
           -0.22856545626592412,
           -0.29541051237375787,
           -0.35226222727992795,
           -0.39598244357893553,
           -0.42399466300627076,
           -0.43442757176285574,
           -0.42622489689420734,
           -0.39921534828629784,
           -0.3541384336243295,
           -0.2926242127644853,
           -0.21712746254366178,
           -0.13081912452072303,
           -0.03744017720227128,
           0.05887491198907235,
           0.1537963512162099,
           0.24300880867803662,
           0.32242214992953067,
           0.38837235101706136,
           0.43780226922078175,
           0.4684129583840573,
           0.47877771528316515,
           0.4684129583840573,
           0.43780226922078175,
           0.38837235101706136,
           0.32242214992953067,
           0.24300880867803662,
           0.1537963512162099,
           0.05887491198907235,
           -0.03744017720227128,
           -0.13081912452072303,
           -0.21712746254366178,
           -0.2926242127644853,
           -0.3541384336243295,
           -0.39921534828629784,
           -0.42622489689420734,
           -0.43442757176285574,
           -0.42399466300627076,
           -0.39598244357893553,
           -0.35226222727992795,
           -0.29541051237375787,
           -0.22856545626592412,
           -0.15525760655490364,
           -0.0792240541655952,
           -0.004215913110515241,
           0.0661907655654817,
           0.12877087581897034,
           0.18080401871815463,
           0.22019854657881394,
           0.2455799958764798,
           0.2563400102730029,
           0.25264402764959015,
           0.23539823538075702,
           0.2061784643801796,
           0.16712567793535366,
           0.12081441070397907,
           0.07010183827093616,
           0.017966041941118966,
           -0.032657564269347995,
           -0.07903277128303789,
           -0.11876378051842666
          ],
          [
           -0.14335579129849668,
           -0.10978201113265723,
           -0.06793803188546253,
           -0.019915691575644292,
           0.031745840459068614,
           0.08418731130237875,
           0.13437885433763305,
           0.1792839709402817,
           0.21602931256266372,
           0.2420710146043941,
           0.255348298963932,
           0.25441554164532254,
           0.23854497801642713,
           0.20779364608280457,
           0.1630299764243758,
           0.10591753298818528,
           0.03885568116655977,
           -0.03512071345143313,
           -0.11247819731414006,
           -0.18935183535374994,
           -0.2617343483375656,
           -0.32567778292945404,
           -0.37749737145928347,
           -0.41396693622794944,
           -0.43249545715781157,
           -0.4312752446188071,
           -0.4093935036702951,
           -0.36690087535799776,
           -0.30483270332925,
           -0.22518118755916025,
           -0.13081912452072303,
           -0.025378460035175753,
           0.08691073780520595,
           0.20141317105264114,
           0.3133036361206578,
           0.4177941096414197,
           0.5103612401471838,
           0.5869627944413911,
           0.6442321103834694,
           0.6796406846183429,
           0.69162061945593,
           0.6796406846183429,
           0.6442321103834694,
           0.5869627944413911,
           0.5103612401471838,
           0.4177941096414197,
           0.3133036361206578,
           0.20141317105264114,
           0.08691073780520595,
           -0.025378460035175753,
           -0.13081912452072303,
           -0.22518118755916025,
           -0.30483270332925,
           -0.36690087535799776,
           -0.4093935036702951,
           -0.4312752446188071,
           -0.43249545715781157,
           -0.41396693622794944,
           -0.37749737145928347,
           -0.32567778292945404,
           -0.2617343483375656,
           -0.18935183535374994,
           -0.11247819731414006,
           -0.03512071345143313,
           0.03885568116655977,
           0.10591753298818528,
           0.1630299764243758,
           0.20779364608280457,
           0.23854497801642713,
           0.25441554164532254,
           0.255348298963932,
           0.2420710146043941,
           0.21602931256266372,
           0.1792839709402817,
           0.13437885433763305,
           0.08418731130237875,
           0.031745840459068614,
           -0.019915691575644292,
           -0.06793803188546253,
           -0.10978201113265723
          ],
          [
           -0.13698176393514344,
           -0.10127808535368477,
           -0.05761803324395176,
           -0.00823327044894154,
           0.044209509361482956,
           0.09674378883254962,
           0.14626024334832619,
           0.18967745729212915,
           0.22411724822563847,
           0.24707500803079696,
           0.256575492104657,
           0.25130504004127213,
           0.23071227369415245,
           0.19507084218595108,
           0.14549969299473817,
           0.08393854575868848,
           0.013078615468659323,
           -0.06374895250625122,
           -0.1427221428215067,
           -0.21970771693043264,
           -0.29046275344788247,
           -0.35084804028714445,
           -0.3970424421347404,
           -0.42574709936268906,
           -0.43436863670247905,
           -0.421171462695804,
           -0.3853906832849483,
           -0.32729906443176787,
           -0.24822376277499153,
           -0.15051108239111077,
           -0.03744017720227128,
           0.08691073780520595,
           0.21783961811686398,
           0.35022902170777614,
           0.47877771528316515,
           0.5982441516081277,
           0.7036898157513979,
           0.7907103570985019,
           0.8556429685382863,
           0.8957396184216221,
           0.9092974268256817,
           0.8957396184216221,
           0.8556429685382863,
           0.7907103570985019,
           0.7036898157513979,
           0.5982441516081277,
           0.47877771528316515,
           0.35022902170777614,
           0.21783961811686398,
           0.08691073780520595,
           -0.03744017720227128,
           -0.15051108239111077,
           -0.24822376277499153,
           -0.32729906443176787,
           -0.3853906832849483,
           -0.421171462695804,
           -0.43436863670247905,
           -0.42574709936268906,
           -0.3970424421347404,
           -0.35084804028714445,
           -0.29046275344788247,
           -0.21970771693043264,
           -0.1427221428215067,
           -0.06374895250625122,
           0.013078615468659323,
           0.08393854575868848,
           0.14549969299473817,
           0.19507084218595108,
           0.23071227369415245,
           0.25130504004127213,
           0.256575492104657,
           0.24707500803079696,
           0.22411724822563847,
           0.18967745729212915,
           0.14626024334832619,
           0.09674378883254962,
           0.044209509361482956,
           -0.00823327044894154,
           -0.05761803324395176,
           -0.10127808535368477
          ],
          [
           -0.13096468174943518,
           -0.09341816596346665,
           -0.04822085787410071,
           0.0022716100207446164,
           0.05528095770522729,
           0.10774865812501504,
           0.15649972810645998,
           0.19841943861188654,
           0.23063350923189954,
           0.2506818889186662,
           0.2566762997375786,
           0.24743234013685533,
           0.2225680860000738,
           0.18256273925541686,
           0.12877087581897034,
           0.06339013493636744,
           -0.010617349295218181,
           -0.08964697741323371,
           -0.1696119802323752,
           -0.24613461781837798,
           -0.31475910259630246,
           -0.37117570680030565,
           -0.41144469052055266,
           -0.43220845214435083,
           -0.4308806796227811,
           -0.40580225753498556,
           -0.35635521764627226,
           -0.28302803533990717,
           -0.187427969950852,
           -0.0722388011028484,
           0.05887491198907235,
           0.20141317105264114,
           0.35022902170777614,
           0.49975144871271493,
           0.6442321103834694,
           0.7780040258931075,
           0.8957396184216221,
           0.992695449836068,
           1.0649315658049785,
           1.1094945766040856,
           1.124555367855928,
           1.1094945766040856,
           1.0649315658049785,
           0.992695449836068,
           0.8957396184216221,
           0.7780040258931075,
           0.6442321103834694,
           0.49975144871271493,
           0.35022902170777614,
           0.20141317105264114,
           0.05887491198907235,
           -0.0722388011028484,
           -0.187427969950852,
           -0.28302803533990717,
           -0.35635521764627226,
           -0.40580225753498556,
           -0.4308806796227811,
           -0.43220845214435083,
           -0.41144469052055266,
           -0.37117570680030565,
           -0.31475910259630246,
           -0.24613461781837798,
           -0.1696119802323752,
           -0.08964697741323371,
           -0.010617349295218181,
           0.06339013493636744,
           0.12877087581897034,
           0.18256273925541686,
           0.2225680860000738,
           0.24743234013685533,
           0.2566762997375786,
           0.2506818889186662,
           0.23063350923189954,
           0.19841943861188654,
           0.15649972810645998,
           0.10774865812501504,
           0.05528095770522729,
           0.0022716100207446164,
           -0.04822085787410071,
           -0.09341816596346665
          ],
          [
           -0.1254554756233313,
           -0.08634370978474622,
           -0.039868134180728126,
           0.011507919583092052,
           0.0649104168254659,
           0.11720338291232232,
           0.16515865057394133,
           0.20563779959612533,
           0.23577655069724138,
           0.2531614457800734,
           0.2559887694405144,
           0.2431963471432226,
           0.21456006847846779,
           0.17074867404778504,
           0.11333242903336226,
           0.044743679368913644,
           -0.03181017613329085,
           -0.11247819731414006,
           -0.1929363397545002,
           -0.268589046149572,
           -0.33479237619194996,
           -0.38708768931988075,
           -0.42143408131469146,
           -0.43442757176285574,
           -0.42349546556438716,
           -0.38705535500366767,
           -0.324629843053556,
           -0.23691017597600564,
           -0.1257644689695074,
           0.005811034304373925,
           0.1537963512162099,
           0.3133036361206578,
           0.47877771528316515,
           0.6442321103834694,
           0.803509484779075,
           0.9505541014891831,
           1.0796831610910465,
           1.1858438330909473,
           1.2648434125627805,
           1.3135412961886945,
           1.3299933154720727,
           1.3135412961886945,
           1.2648434125627805,
           1.1858438330909473,
           1.0796831610910465,
           0.9505541014891831,
           0.803509484779075,
           0.6442321103834694,
           0.47877771528316515,
           0.3133036361206578,
           0.1537963512162099,
           0.005811034304373925,
           -0.1257644689695074,
           -0.23691017597600564,
           -0.324629843053556,
           -0.38705535500366767,
           -0.42349546556438716,
           -0.43442757176285574,
           -0.42143408131469146,
           -0.38708768931988075,
           -0.33479237619194996,
           -0.268589046149572,
           -0.1929363397545002,
           -0.11247819731414006,
           -0.03181017613329085,
           0.044743679368913644,
           0.11333242903336226,
           0.17074867404778504,
           0.21456006847846779,
           0.2431963471432226,
           0.2559887694405144,
           0.2531614457800734,
           0.23577655069724138,
           0.20563779959612533,
           0.16515865057394133,
           0.11720338291232232,
           0.0649104168254659,
           0.011507919583092052,
           -0.039868134180728126,
           -0.08634370978474622
          ],
          [
           -0.12058300781296416,
           -0.08017262722723162,
           -0.032657564269347995,
           0.019407660252202565,
           0.07306884206017318,
           0.12512633286074154,
           0.17230988766358785,
           0.21146505144444128,
           0.23974108638511749,
           0.25477004091850136,
           0.2548267267047997,
           0.23896010343988033,
           0.2070878465419809,
           0.16004763127913005,
           0.09960082298540655,
           0.02838670735216783,
           -0.050171999808914604,
           -0.132008995765264,
           -0.2125937105436689,
           -0.28714197491104243,
           -0.35084804028714445,
           -0.3991265770886398,
           -0.42785247459104203,
           -0.4335860886421158,
           -0.4137720534188708,
           -0.36690087535799776,
           -0.2926242127644853,
           -0.19181693290541052,
           -0.06658162124929747,
           0.07980593576993696,
           0.24300880867803662,
           0.4177941096414197,
           0.5982441516081277,
           0.7780040258931075,
           0.9505541014891831,
           1.1094945766040856,
           1.2488284837498442,
           1.3632295064019535,
           1.4482816142111579,
           1.500678835049543,
           1.518375390968938,
           1.500678835049543,
           1.4482816142111579,
           1.3632295064019535,
           1.2488284837498442,
           1.1094945766040856,
           0.9505541014891831,
           0.7780040258931075,
           0.5982441516081277,
           0.4177941096414197,
           0.24300880867803662,
           0.07980593576993696,
           -0.06658162124929747,
           -0.19181693290541052,
           -0.2926242127644853,
           -0.36690087535799776,
           -0.4137720534188708,
           -0.4335860886421158,
           -0.42785247459104203,
           -0.3991265770886398,
           -0.35084804028714445,
           -0.28714197491104243,
           -0.2125937105436689,
           -0.132008995765264,
           -0.050171999808914604,
           0.02838670735216783,
           0.09960082298540655,
           0.16004763127913005,
           0.2070878465419809,
           0.23896010343988033,
           0.2548267267047997,
           0.25477004091850136,
           0.23974108638511749,
           0.21146505144444128,
           0.17230988766358785,
           0.12512633286074154,
           0.07306884206017318,
           0.019407660252202565,
           -0.032657564269347995,
           -0.08017262722723162
          ],
          [
           -0.1164544699167505,
           -0.0750007897964791,
           -0.026665677985416577,
           0.025921773001301992,
           0.07974244535617742,
           0.13154597877649798,
           0.17802983029511174,
           0.21602931256266372,
           0.242708395806646,
           0.2557406839380664,
           0.25347017586536014,
           0.23504220166614895,
           0.20049625055173417,
           0.15081422331281308,
           0.08791985781076668,
           0.014627580006334946,
           -0.06545830501430487,
           -0.14809048863531396,
           -0.22856545626592412,
           -0.30194177876754097,
           -0.3632795822101567,
           -0.407889497747319,
           -0.43157859884674826,
           -0.4308806796227811,
           -0.40325873487122593,
           -0.3472686537517362,
           -0.2626748843273063,
           -0.15051108239111077,
           -0.0130814139378774,
           0.14609889758077332,
           0.32242214992953067,
           0.5103612401471838,
           0.7036898157513979,
           0.8957396184216221,
           1.0796831610910465,
           1.2488284837498442,
           1.3969119972732167,
           1.518375390968938,
           1.608613254431116,
           1.6641794167481594,
           1.682941969615793,
           1.6641794167481594,
           1.608613254431116,
           1.518375390968938,
           1.3969119972732167,
           1.2488284837498442,
           1.0796831610910465,
           0.8957396184216221,
           0.7036898157513979,
           0.5103612401471838,
           0.32242214992953067,
           0.14609889758077332,
           -0.0130814139378774,
           -0.15051108239111077,
           -0.2626748843273063,
           -0.3472686537517362,
           -0.40325873487122593,
           -0.4308806796227811,
           -0.43157859884674826,
           -0.407889497747319,
           -0.3632795822101567,
           -0.30194177876754097,
           -0.22856545626592412,
           -0.14809048863531396,
           -0.06545830501430487,
           0.014627580006334946,
           0.08791985781076668,
           0.15081422331281308,
           0.20049625055173417,
           0.23504220166614895,
           0.25347017586536014,
           0.2557406839380664,
           0.242708395806646,
           0.21602931256266372,
           0.17802983029511174,
           0.13154597877649798,
           0.07974244535617742,
           0.025921773001301992,
           -0.026665677985416577,
           -0.0750007897964791
          ],
          [
           -0.1131560467581887,
           -0.07090368426500879,
           -0.021950582012676394,
           0.031016232090896562,
           0.08492762656935865,
           0.13649472168344115,
           0.18239124981424537,
           0.21944644111666822,
           0.24483804991090946,
           0.2562747828163765,
           0.252157618714697,
           0.2317103248693539,
           0.19507084218595108,
           0.1433370736825879,
           0.07856287339249271,
           0.0037025838949493145,
           -0.07749482277960204,
           -0.16063822727306362,
           -0.24088710992360066,
           -0.31317589634427284,
           -0.37245933283868765,
           -0.41396693622794944,
           -0.4334537754581445,
           -0.4274347075936389,
           -0.39338972722403176,
           -0.32992927901128904,
           -0.23691017597600564,
           -0.11549507625799743,
           0.03184881503912622,
           0.20141317105264114,
           0.38837235101706136,
           0.5869627944413911,
           0.7907103570985019,
           0.992695449836068,
           1.1858438330909473,
           1.3632295064019535,
           1.518375390968938,
           1.6455374774968983,
           1.7399588071171015,
           1.7980810383563555,
           1.8177033600622243,
           1.7980810383563555,
           1.7399588071171015,
           1.6455374774968983,
           1.518375390968938,
           1.3632295064019535,
           1.1858438330909473,
           0.992695449836068,
           0.7907103570985019,
           0.5869627944413911,
           0.38837235101706136,
           0.20141317105264114,
           0.03184881503912622,
           -0.11549507625799743,
           -0.23691017597600564,
           -0.32992927901128904,
           -0.39338972722403176,
           -0.4274347075936389,
           -0.4334537754581445,
           -0.41396693622794944,
           -0.37245933283868765,
           -0.31317589634427284,
           -0.24088710992360066,
           -0.16063822727306362,
           -0.07749482277960204,
           0.0037025838949493145,
           0.07856287339249271,
           0.1433370736825879,
           0.19507084218595108,
           0.2317103248693539,
           0.252157618714697,
           0.2562747828163765,
           0.24483804991090946,
           0.21944644111666822,
           0.18239124981424537,
           0.13649472168344115,
           0.08492762656935865,
           0.031016232090896562,
           -0.021950582012676394,
           -0.07090368426500879
          ],
          [
           -0.1107536917561867,
           -0.06793803188546253,
           -0.01855449981019833,
           0.03466854669458865,
           0.08862652853638416,
           0.14000357308347133,
           0.18545724476618586,
           0.22181346801290225,
           0.24626113579560338,
           0.25653555744366946,
           0.25108014921898075,
           0.22917661128094333,
           0.19103523332295086,
           0.13783886506830845,
           0.07173638515428266,
           -0.004215913110515241,
           -0.08616386191642225,
           -0.1696119802323752,
           -0.24962054293732017,
           -0.3210343185560354,
           -0.3787322233669178,
           -0.417885750201407,
           -0.434213248547002,
           -0.42421701152445723,
           -0.3853906832849483,
           -0.3163857196862348,
           -0.21712746254366178,
           -0.08887373699192957,
           0.0657883626364726,
           0.24300880867803662,
           0.43780226922078175,
           0.6442321103834694,
           0.8556429685382863,
           1.0649315658049785,
           1.2648434125627805,
           1.4482816142111579,
           1.608613254431116,
           1.7399588071171015,
           1.8374507397311368,
           1.8974488797623419,
           1.917702154416812,
           1.8974488797623419,
           1.8374507397311368,
           1.7399588071171015,
           1.608613254431116,
           1.4482816142111579,
           1.2648434125627805,
           1.0649315658049785,
           0.8556429685382863,
           0.6442321103834694,
           0.43780226922078175,
           0.24300880867803662,
           0.0657883626364726,
           -0.08887373699192957,
           -0.21712746254366178,
           -0.3163857196862348,
           -0.3853906832849483,
           -0.42421701152445723,
           -0.434213248547002,
           -0.417885750201407,
           -0.3787322233669178,
           -0.3210343185560354,
           -0.24962054293732017,
           -0.1696119802323752,
           -0.08616386191642225,
           -0.004215913110515241,
           0.07173638515428266,
           0.13783886506830845,
           0.19103523332295086,
           0.22917661128094333,
           0.25108014921898075,
           0.25653555744366946,
           0.24626113579560338,
           0.22181346801290225,
           0.18545724476618586,
           0.14000357308347133,
           0.08862652853638416,
           0.03466854669458865,
           -0.01855449981019833,
           -0.06793803188546253
          ],
          [
           -0.10929387900894774,
           -0.06614321685638791,
           -0.016505930263581485,
           0.03686485131708162,
           0.09084339726921295,
           0.14209785531573388,
           0.18727640924644018,
           0.2232034254780841,
           0.24707500803079696,
           0.2566430509401283,
           0.25037713957121355,
           0.22759450814784551,
           0.18854967763954522,
           0.134477311926808,
           0.06758414818694233,
           -0.009011537058698997,
           -0.09139170665445415,
           -0.17499760171649797,
           -0.254829433326894,
           -0.32567778292945404,
           -0.382375848005458,
           -0.4200602785751461,
           -0.43442757176285574,
           -0.42197287899622543,
           -0.3801986514917913,
           -0.3077817863653888,
           -0.20468978410715197,
           -0.0722388011028484,
           0.08691073780520595,
           0.2688222513075441,
           0.4684129583840573,
           0.6796406846183429,
           0.8957396184216221,
           1.1094945766040856,
           1.3135412961886945,
           1.500678835049543,
           1.6641794167481594,
           1.7980810383563555,
           1.8974488797623419,
           1.9585929762944412,
           1.9792316740361835,
           1.9585929762944412,
           1.8974488797623419,
           1.7980810383563555,
           1.6641794167481594,
           1.500678835049543,
           1.3135412961886945,
           1.1094945766040856,
           0.8957396184216221,
           0.6796406846183429,
           0.4684129583840573,
           0.2688222513075441,
           0.08691073780520595,
           -0.0722388011028484,
           -0.20468978410715197,
           -0.3077817863653888,
           -0.3801986514917913,
           -0.42197287899622543,
           -0.43442757176285574,
           -0.4200602785751461,
           -0.382375848005458,
           -0.32567778292945404,
           -0.254829433326894,
           -0.17499760171649797,
           -0.09139170665445415,
           -0.009011537058698997,
           0.06758414818694233,
           0.134477311926808,
           0.18854967763954522,
           0.22759450814784551,
           0.25037713957121355,
           0.2566430509401283,
           0.24707500803079696,
           0.2232034254780841,
           0.18727640924644018,
           0.14209785531573388,
           0.09084339726921295,
           0.03686485131708162,
           -0.016505930263581485,
           -0.06614321685638791
          ],
          [
           -0.10880422217787396,
           -0.06554239869174844,
           -0.015821288518275644,
           0.03759772656874239,
           0.09158188560927924,
           0.14279404657238684,
           0.18787932061729182,
           0.22366162672468853,
           0.24733956165584545,
           0.2566706526738519,
           0.25013332713993036,
           0.2270567942100705,
           0.18771045677679687,
           0.1333463922312941,
           0.0661907655654817,
           -0.010617349295218181,
           -0.09313849939964196,
           -0.17679272260843765,
           -0.2565601183892334,
           -0.32721314035298743,
           -0.3835697098652554,
           -0.4207548585159486,
           -0.43445783007337646,
           -0.421171462695804,
           -0.3784012476539641,
           -0.30483270332925,
           -0.20044755867978276,
           -0.06658162124929747,
           0.0940800053732448,
           0.277571630583514,
           0.47877771528316515,
           0.69162061945593,
           0.9092974268256817,
           1.124555367855928,
           1.3299933154720727,
           1.518375390968938,
           1.682941969615793,
           1.8177033600622243,
           1.917702154416812,
           1.9792316740361835,
           null,
           1.9792316740361835,
           1.917702154416812,
           1.8177033600622243,
           1.682941969615793,
           1.518375390968938,
           1.3299933154720727,
           1.124555367855928,
           0.9092974268256817,
           0.69162061945593,
           0.47877771528316515,
           0.277571630583514,
           0.0940800053732448,
           -0.06658162124929747,
           -0.20044755867978276,
           -0.30483270332925,
           -0.3784012476539641,
           -0.421171462695804,
           -0.43445783007337646,
           -0.4207548585159486,
           -0.3835697098652554,
           -0.32721314035298743,
           -0.2565601183892334,
           -0.17679272260843765,
           -0.09313849939964196,
           -0.010617349295218181,
           0.0661907655654817,
           0.1333463922312941,
           0.18771045677679687,
           0.2270567942100705,
           0.25013332713993036,
           0.2566706526738519,
           0.24733956165584545,
           0.22366162672468853,
           0.18787932061729182,
           0.14279404657238684,
           0.09158188560927924,
           0.03759772656874239,
           -0.015821288518275644,
           -0.06554239869174844
          ],
          [
           -0.10929387900894774,
           -0.06614321685638791,
           -0.016505930263581485,
           0.03686485131708162,
           0.09084339726921295,
           0.14209785531573388,
           0.18727640924644018,
           0.2232034254780841,
           0.24707500803079696,
           0.2566430509401283,
           0.25037713957121355,
           0.22759450814784551,
           0.18854967763954522,
           0.134477311926808,
           0.06758414818694233,
           -0.009011537058698997,
           -0.09139170665445415,
           -0.17499760171649797,
           -0.254829433326894,
           -0.32567778292945404,
           -0.382375848005458,
           -0.4200602785751461,
           -0.43442757176285574,
           -0.42197287899622543,
           -0.3801986514917913,
           -0.3077817863653888,
           -0.20468978410715197,
           -0.0722388011028484,
           0.08691073780520595,
           0.2688222513075441,
           0.4684129583840573,
           0.6796406846183429,
           0.8957396184216221,
           1.1094945766040856,
           1.3135412961886945,
           1.500678835049543,
           1.6641794167481594,
           1.7980810383563555,
           1.8974488797623419,
           1.9585929762944412,
           1.9792316740361835,
           1.9585929762944412,
           1.8974488797623419,
           1.7980810383563555,
           1.6641794167481594,
           1.500678835049543,
           1.3135412961886945,
           1.1094945766040856,
           0.8957396184216221,
           0.6796406846183429,
           0.4684129583840573,
           0.2688222513075441,
           0.08691073780520595,
           -0.0722388011028484,
           -0.20468978410715197,
           -0.3077817863653888,
           -0.3801986514917913,
           -0.42197287899622543,
           -0.43442757176285574,
           -0.4200602785751461,
           -0.382375848005458,
           -0.32567778292945404,
           -0.254829433326894,
           -0.17499760171649797,
           -0.09139170665445415,
           -0.009011537058698997,
           0.06758414818694233,
           0.134477311926808,
           0.18854967763954522,
           0.22759450814784551,
           0.25037713957121355,
           0.2566430509401283,
           0.24707500803079696,
           0.2232034254780841,
           0.18727640924644018,
           0.14209785531573388,
           0.09084339726921295,
           0.03686485131708162,
           -0.016505930263581485,
           -0.06614321685638791
          ],
          [
           -0.1107536917561867,
           -0.06793803188546253,
           -0.01855449981019833,
           0.03466854669458865,
           0.08862652853638416,
           0.14000357308347133,
           0.18545724476618586,
           0.22181346801290225,
           0.24626113579560338,
           0.25653555744366946,
           0.25108014921898075,
           0.22917661128094333,
           0.19103523332295086,
           0.13783886506830845,
           0.07173638515428266,
           -0.004215913110515241,
           -0.08616386191642225,
           -0.1696119802323752,
           -0.24962054293732017,
           -0.3210343185560354,
           -0.3787322233669178,
           -0.417885750201407,
           -0.434213248547002,
           -0.42421701152445723,
           -0.3853906832849483,
           -0.3163857196862348,
           -0.21712746254366178,
           -0.08887373699192957,
           0.0657883626364726,
           0.24300880867803662,
           0.43780226922078175,
           0.6442321103834694,
           0.8556429685382863,
           1.0649315658049785,
           1.2648434125627805,
           1.4482816142111579,
           1.608613254431116,
           1.7399588071171015,
           1.8374507397311368,
           1.8974488797623419,
           1.917702154416812,
           1.8974488797623419,
           1.8374507397311368,
           1.7399588071171015,
           1.608613254431116,
           1.4482816142111579,
           1.2648434125627805,
           1.0649315658049785,
           0.8556429685382863,
           0.6442321103834694,
           0.43780226922078175,
           0.24300880867803662,
           0.0657883626364726,
           -0.08887373699192957,
           -0.21712746254366178,
           -0.3163857196862348,
           -0.3853906832849483,
           -0.42421701152445723,
           -0.434213248547002,
           -0.417885750201407,
           -0.3787322233669178,
           -0.3210343185560354,
           -0.24962054293732017,
           -0.1696119802323752,
           -0.08616386191642225,
           -0.004215913110515241,
           0.07173638515428266,
           0.13783886506830845,
           0.19103523332295086,
           0.22917661128094333,
           0.25108014921898075,
           0.25653555744366946,
           0.24626113579560338,
           0.22181346801290225,
           0.18545724476618586,
           0.14000357308347133,
           0.08862652853638416,
           0.03466854669458865,
           -0.01855449981019833,
           -0.06793803188546253
          ],
          [
           -0.1131560467581887,
           -0.07090368426500879,
           -0.021950582012676394,
           0.031016232090896562,
           0.08492762656935865,
           0.13649472168344115,
           0.18239124981424537,
           0.21944644111666822,
           0.24483804991090946,
           0.2562747828163765,
           0.252157618714697,
           0.2317103248693539,
           0.19507084218595108,
           0.1433370736825879,
           0.07856287339249271,
           0.0037025838949493145,
           -0.07749482277960204,
           -0.16063822727306362,
           -0.24088710992360066,
           -0.31317589634427284,
           -0.37245933283868765,
           -0.41396693622794944,
           -0.4334537754581445,
           -0.4274347075936389,
           -0.39338972722403176,
           -0.32992927901128904,
           -0.23691017597600564,
           -0.11549507625799743,
           0.03184881503912622,
           0.20141317105264114,
           0.38837235101706136,
           0.5869627944413911,
           0.7907103570985019,
           0.992695449836068,
           1.1858438330909473,
           1.3632295064019535,
           1.518375390968938,
           1.6455374774968983,
           1.7399588071171015,
           1.7980810383563555,
           1.8177033600622243,
           1.7980810383563555,
           1.7399588071171015,
           1.6455374774968983,
           1.518375390968938,
           1.3632295064019535,
           1.1858438330909473,
           0.992695449836068,
           0.7907103570985019,
           0.5869627944413911,
           0.38837235101706136,
           0.20141317105264114,
           0.03184881503912622,
           -0.11549507625799743,
           -0.23691017597600564,
           -0.32992927901128904,
           -0.39338972722403176,
           -0.4274347075936389,
           -0.4334537754581445,
           -0.41396693622794944,
           -0.37245933283868765,
           -0.31317589634427284,
           -0.24088710992360066,
           -0.16063822727306362,
           -0.07749482277960204,
           0.0037025838949493145,
           0.07856287339249271,
           0.1433370736825879,
           0.19507084218595108,
           0.2317103248693539,
           0.252157618714697,
           0.2562747828163765,
           0.24483804991090946,
           0.21944644111666822,
           0.18239124981424537,
           0.13649472168344115,
           0.08492762656935865,
           0.031016232090896562,
           -0.021950582012676394,
           -0.07090368426500879
          ],
          [
           -0.1164544699167505,
           -0.0750007897964791,
           -0.026665677985416577,
           0.025921773001301992,
           0.07974244535617742,
           0.13154597877649798,
           0.17802983029511174,
           0.21602931256266372,
           0.242708395806646,
           0.2557406839380664,
           0.25347017586536014,
           0.23504220166614895,
           0.20049625055173417,
           0.15081422331281308,
           0.08791985781076668,
           0.014627580006334946,
           -0.06545830501430487,
           -0.14809048863531396,
           -0.22856545626592412,
           -0.30194177876754097,
           -0.3632795822101567,
           -0.407889497747319,
           -0.43157859884674826,
           -0.4308806796227811,
           -0.40325873487122593,
           -0.3472686537517362,
           -0.2626748843273063,
           -0.15051108239111077,
           -0.0130814139378774,
           0.14609889758077332,
           0.32242214992953067,
           0.5103612401471838,
           0.7036898157513979,
           0.8957396184216221,
           1.0796831610910465,
           1.2488284837498442,
           1.3969119972732167,
           1.518375390968938,
           1.608613254431116,
           1.6641794167481594,
           1.682941969615793,
           1.6641794167481594,
           1.608613254431116,
           1.518375390968938,
           1.3969119972732167,
           1.2488284837498442,
           1.0796831610910465,
           0.8957396184216221,
           0.7036898157513979,
           0.5103612401471838,
           0.32242214992953067,
           0.14609889758077332,
           -0.0130814139378774,
           -0.15051108239111077,
           -0.2626748843273063,
           -0.3472686537517362,
           -0.40325873487122593,
           -0.4308806796227811,
           -0.43157859884674826,
           -0.407889497747319,
           -0.3632795822101567,
           -0.30194177876754097,
           -0.22856545626592412,
           -0.14809048863531396,
           -0.06545830501430487,
           0.014627580006334946,
           0.08791985781076668,
           0.15081422331281308,
           0.20049625055173417,
           0.23504220166614895,
           0.25347017586536014,
           0.2557406839380664,
           0.242708395806646,
           0.21602931256266372,
           0.17802983029511174,
           0.13154597877649798,
           0.07974244535617742,
           0.025921773001301992,
           -0.026665677985416577,
           -0.0750007897964791
          ],
          [
           -0.12058300781296416,
           -0.08017262722723162,
           -0.032657564269347995,
           0.019407660252202565,
           0.07306884206017318,
           0.12512633286074154,
           0.17230988766358785,
           0.21146505144444128,
           0.23974108638511749,
           0.25477004091850136,
           0.2548267267047997,
           0.23896010343988033,
           0.2070878465419809,
           0.16004763127913005,
           0.09960082298540655,
           0.02838670735216783,
           -0.050171999808914604,
           -0.132008995765264,
           -0.2125937105436689,
           -0.28714197491104243,
           -0.35084804028714445,
           -0.3991265770886398,
           -0.42785247459104203,
           -0.4335860886421158,
           -0.4137720534188708,
           -0.36690087535799776,
           -0.2926242127644853,
           -0.19181693290541052,
           -0.06658162124929747,
           0.07980593576993696,
           0.24300880867803662,
           0.4177941096414197,
           0.5982441516081277,
           0.7780040258931075,
           0.9505541014891831,
           1.1094945766040856,
           1.2488284837498442,
           1.3632295064019535,
           1.4482816142111579,
           1.500678835049543,
           1.518375390968938,
           1.500678835049543,
           1.4482816142111579,
           1.3632295064019535,
           1.2488284837498442,
           1.1094945766040856,
           0.9505541014891831,
           0.7780040258931075,
           0.5982441516081277,
           0.4177941096414197,
           0.24300880867803662,
           0.07980593576993696,
           -0.06658162124929747,
           -0.19181693290541052,
           -0.2926242127644853,
           -0.36690087535799776,
           -0.4137720534188708,
           -0.4335860886421158,
           -0.42785247459104203,
           -0.3991265770886398,
           -0.35084804028714445,
           -0.28714197491104243,
           -0.2125937105436689,
           -0.132008995765264,
           -0.050171999808914604,
           0.02838670735216783,
           0.09960082298540655,
           0.16004763127913005,
           0.2070878465419809,
           0.23896010343988033,
           0.2548267267047997,
           0.25477004091850136,
           0.23974108638511749,
           0.21146505144444128,
           0.17230988766358785,
           0.12512633286074154,
           0.07306884206017318,
           0.019407660252202565,
           -0.032657564269347995,
           -0.08017262722723162
          ],
          [
           -0.1254554756233313,
           -0.08634370978474622,
           -0.039868134180728126,
           0.011507919583092052,
           0.0649104168254659,
           0.11720338291232232,
           0.16515865057394133,
           0.20563779959612533,
           0.23577655069724138,
           0.2531614457800734,
           0.2559887694405144,
           0.2431963471432226,
           0.21456006847846779,
           0.17074867404778504,
           0.11333242903336226,
           0.044743679368913644,
           -0.03181017613329085,
           -0.11247819731414006,
           -0.1929363397545002,
           -0.268589046149572,
           -0.33479237619194996,
           -0.38708768931988075,
           -0.42143408131469146,
           -0.43442757176285574,
           -0.42349546556438716,
           -0.38705535500366767,
           -0.324629843053556,
           -0.23691017597600564,
           -0.1257644689695074,
           0.005811034304373925,
           0.1537963512162099,
           0.3133036361206578,
           0.47877771528316515,
           0.6442321103834694,
           0.803509484779075,
           0.9505541014891831,
           1.0796831610910465,
           1.1858438330909473,
           1.2648434125627805,
           1.3135412961886945,
           1.3299933154720727,
           1.3135412961886945,
           1.2648434125627805,
           1.1858438330909473,
           1.0796831610910465,
           0.9505541014891831,
           0.803509484779075,
           0.6442321103834694,
           0.47877771528316515,
           0.3133036361206578,
           0.1537963512162099,
           0.005811034304373925,
           -0.1257644689695074,
           -0.23691017597600564,
           -0.324629843053556,
           -0.38705535500366767,
           -0.42349546556438716,
           -0.43442757176285574,
           -0.42143408131469146,
           -0.38708768931988075,
           -0.33479237619194996,
           -0.268589046149572,
           -0.1929363397545002,
           -0.11247819731414006,
           -0.03181017613329085,
           0.044743679368913644,
           0.11333242903336226,
           0.17074867404778504,
           0.21456006847846779,
           0.2431963471432226,
           0.2559887694405144,
           0.2531614457800734,
           0.23577655069724138,
           0.20563779959612533,
           0.16515865057394133,
           0.11720338291232232,
           0.0649104168254659,
           0.011507919583092052,
           -0.039868134180728126,
           -0.08634370978474622
          ],
          [
           -0.13096468174943518,
           -0.09341816596346665,
           -0.04822085787410071,
           0.0022716100207446164,
           0.05528095770522729,
           0.10774865812501504,
           0.15649972810645998,
           0.19841943861188654,
           0.23063350923189954,
           0.2506818889186662,
           0.2566762997375786,
           0.24743234013685533,
           0.2225680860000738,
           0.18256273925541686,
           0.12877087581897034,
           0.06339013493636744,
           -0.010617349295218181,
           -0.08964697741323371,
           -0.1696119802323752,
           -0.24613461781837798,
           -0.31475910259630246,
           -0.37117570680030565,
           -0.41144469052055266,
           -0.43220845214435083,
           -0.4308806796227811,
           -0.40580225753498556,
           -0.35635521764627226,
           -0.28302803533990717,
           -0.187427969950852,
           -0.0722388011028484,
           0.05887491198907235,
           0.20141317105264114,
           0.35022902170777614,
           0.49975144871271493,
           0.6442321103834694,
           0.7780040258931075,
           0.8957396184216221,
           0.992695449836068,
           1.0649315658049785,
           1.1094945766040856,
           1.124555367855928,
           1.1094945766040856,
           1.0649315658049785,
           0.992695449836068,
           0.8957396184216221,
           0.7780040258931075,
           0.6442321103834694,
           0.49975144871271493,
           0.35022902170777614,
           0.20141317105264114,
           0.05887491198907235,
           -0.0722388011028484,
           -0.187427969950852,
           -0.28302803533990717,
           -0.35635521764627226,
           -0.40580225753498556,
           -0.4308806796227811,
           -0.43220845214435083,
           -0.41144469052055266,
           -0.37117570680030565,
           -0.31475910259630246,
           -0.24613461781837798,
           -0.1696119802323752,
           -0.08964697741323371,
           -0.010617349295218181,
           0.06339013493636744,
           0.12877087581897034,
           0.18256273925541686,
           0.2225680860000738,
           0.24743234013685533,
           0.2566762997375786,
           0.2506818889186662,
           0.23063350923189954,
           0.19841943861188654,
           0.15649972810645998,
           0.10774865812501504,
           0.05528095770522729,
           0.0022716100207446164,
           -0.04822085787410071,
           -0.09341816596346665
          ],
          [
           -0.13698176393514344,
           -0.10127808535368477,
           -0.05761803324395176,
           -0.00823327044894154,
           0.044209509361482956,
           0.09674378883254962,
           0.14626024334832619,
           0.18967745729212915,
           0.22411724822563847,
           0.24707500803079696,
           0.256575492104657,
           0.25130504004127213,
           0.23071227369415245,
           0.19507084218595108,
           0.14549969299473817,
           0.08393854575868848,
           0.013078615468659323,
           -0.06374895250625122,
           -0.1427221428215067,
           -0.21970771693043264,
           -0.29046275344788247,
           -0.35084804028714445,
           -0.3970424421347404,
           -0.42574709936268906,
           -0.43436863670247905,
           -0.421171462695804,
           -0.3853906832849483,
           -0.32729906443176787,
           -0.24822376277499153,
           -0.15051108239111077,
           -0.03744017720227128,
           0.08691073780520595,
           0.21783961811686398,
           0.35022902170777614,
           0.47877771528316515,
           0.5982441516081277,
           0.7036898157513979,
           0.7907103570985019,
           0.8556429685382863,
           0.8957396184216221,
           0.9092974268256817,
           0.8957396184216221,
           0.8556429685382863,
           0.7907103570985019,
           0.7036898157513979,
           0.5982441516081277,
           0.47877771528316515,
           0.35022902170777614,
           0.21783961811686398,
           0.08691073780520595,
           -0.03744017720227128,
           -0.15051108239111077,
           -0.24822376277499153,
           -0.32729906443176787,
           -0.3853906832849483,
           -0.421171462695804,
           -0.43436863670247905,
           -0.42574709936268906,
           -0.3970424421347404,
           -0.35084804028714445,
           -0.29046275344788247,
           -0.21970771693043264,
           -0.1427221428215067,
           -0.06374895250625122,
           0.013078615468659323,
           0.08393854575868848,
           0.14549969299473817,
           0.19507084218595108,
           0.23071227369415245,
           0.25130504004127213,
           0.256575492104657,
           0.24707500803079696,
           0.22411724822563847,
           0.18967745729212915,
           0.14626024334832619,
           0.09674378883254962,
           0.044209509361482956,
           -0.00823327044894154,
           -0.05761803324395176,
           -0.10127808535368477
          ],
          [
           -0.14335579129849668,
           -0.10978201113265723,
           -0.06793803188546253,
           -0.019915691575644292,
           0.031745840459068614,
           0.08418731130237875,
           0.13437885433763305,
           0.1792839709402817,
           0.21602931256266372,
           0.2420710146043941,
           0.255348298963932,
           0.25441554164532254,
           0.23854497801642713,
           0.20779364608280457,
           0.1630299764243758,
           0.10591753298818528,
           0.03885568116655977,
           -0.03512071345143313,
           -0.11247819731414006,
           -0.18935183535374994,
           -0.2617343483375656,
           -0.32567778292945404,
           -0.37749737145928347,
           -0.41396693622794944,
           -0.43249545715781157,
           -0.4312752446188071,
           -0.4093935036702951,
           -0.36690087535799776,
           -0.30483270332925,
           -0.22518118755916025,
           -0.13081912452072303,
           -0.025378460035175753,
           0.08691073780520595,
           0.20141317105264114,
           0.3133036361206578,
           0.4177941096414197,
           0.5103612401471838,
           0.5869627944413911,
           0.6442321103834694,
           0.6796406846183429,
           0.69162061945593,
           0.6796406846183429,
           0.6442321103834694,
           0.5869627944413911,
           0.5103612401471838,
           0.4177941096414197,
           0.3133036361206578,
           0.20141317105264114,
           0.08691073780520595,
           -0.025378460035175753,
           -0.13081912452072303,
           -0.22518118755916025,
           -0.30483270332925,
           -0.36690087535799776,
           -0.4093935036702951,
           -0.4312752446188071,
           -0.43249545715781157,
           -0.41396693622794944,
           -0.37749737145928347,
           -0.32567778292945404,
           -0.2617343483375656,
           -0.18935183535374994,
           -0.11247819731414006,
           -0.03512071345143313,
           0.03885568116655977,
           0.10591753298818528,
           0.1630299764243758,
           0.20779364608280457,
           0.23854497801642713,
           0.25441554164532254,
           0.255348298963932,
           0.2420710146043941,
           0.21602931256266372,
           0.1792839709402817,
           0.13437885433763305,
           0.08418731130237875,
           0.031745840459068614,
           -0.019915691575644292,
           -0.06793803188546253,
           -0.10978201113265723
          ],
          [
           -0.1499137997580331,
           -0.11876378051842666,
           -0.07903277128303789,
           -0.032657564269347995,
           0.017966041941118966,
           0.07010183827093616,
           0.12081441070397907,
           0.16712567793535366,
           0.2061784643801796,
           0.23539823538075702,
           0.25264402764959015,
           0.2563400102730029,
           0.2455799958764798,
           0.22019854657881394,
           0.18080401871815463,
           0.12877087581897034,
           0.0661907655654817,
           -0.004215913110515241,
           -0.0792240541655952,
           -0.15525760655490364,
           -0.22856545626592412,
           -0.29541051237375787,
           -0.35226222727992795,
           -0.39598244357893553,
           -0.42399466300627076,
           -0.43442757176285574,
           -0.42622489689420734,
           -0.39921534828629784,
           -0.3541384336243295,
           -0.2926242127644853,
           -0.21712746254366178,
           -0.13081912452072303,
           -0.03744017720227128,
           0.05887491198907235,
           0.1537963512162099,
           0.24300880867803662,
           0.32242214992953067,
           0.38837235101706136,
           0.43780226922078175,
           0.4684129583840573,
           0.47877771528316515,
           0.4684129583840573,
           0.43780226922078175,
           0.38837235101706136,
           0.32242214992953067,
           0.24300880867803662,
           0.1537963512162099,
           0.05887491198907235,
           -0.03744017720227128,
           -0.13081912452072303,
           -0.21712746254366178,
           -0.2926242127644853,
           -0.3541384336243295,
           -0.39921534828629784,
           -0.42622489689420734,
           -0.43442757176285574,
           -0.42399466300627076,
           -0.39598244357893553,
           -0.35226222727992795,
           -0.29541051237375787,
           -0.22856545626592412,
           -0.15525760655490364,
           -0.0792240541655952,
           -0.004215913110515241,
           0.0661907655654817,
           0.12877087581897034,
           0.18080401871815463,
           0.22019854657881394,
           0.2455799958764798,
           0.2563400102730029,
           0.25264402764959015,
           0.23539823538075702,
           0.2061784643801796,
           0.16712567793535366,
           0.12081441070397907,
           0.07010183827093616,
           0.017966041941118966,
           -0.032657564269347995,
           -0.07903277128303789,
           -0.11876378051842666
          ],
          [
           -0.15646143337355978,
           -0.12803192632998142,
           -0.0907256642328181,
           -0.046310064114579955,
           0.0029779491154211806,
           0.054541276561040686,
           0.10555493165712146,
           0.15311446345017118,
           0.1943926655354523,
           0.22679610352037188,
           0.24811283911536614,
           0.2566430509401283,
           0.25130504004127213,
           0.2317103248693539,
           0.1982031145119569,
           0.15186131748507978,
           0.09445829662141196,
           0.02838670735216783,
           -0.043452159632214875,
           -0.1177881852505473,
           -0.19114437378651342,
           -0.26001264723920775,
           -0.3210343185560354,
           -0.37117570680030565,
           -0.407889497747319,
           -0.42925310491460716,
           -0.434076417833265,
           -0.42197287899622543,
           -0.39338972722403176,
           -0.3495953826561967,
           -0.2926242127644853,
           -0.22518118755916025,
           -0.15051108239111077,
           -0.0722388011028484,
           0.005811034304373925,
           0.07980593576993696,
           0.14609889758077332,
           0.20141317105264114,
           0.24300880867803662,
           0.2688222513075441,
           0.277571630583514,
           0.2688222513075441,
           0.24300880867803662,
           0.20141317105264114,
           0.14609889758077332,
           0.07980593576993696,
           0.005811034304373925,
           -0.0722388011028484,
           -0.15051108239111077,
           -0.22518118755916025,
           -0.2926242127644853,
           -0.3495953826561967,
           -0.39338972722403176,
           -0.42197287899622543,
           -0.434076417833265,
           -0.42925310491460716,
           -0.407889497747319,
           -0.37117570680030565,
           -0.3210343185560354,
           -0.26001264723920775,
           -0.19114437378651342,
           -0.1177881852505473,
           -0.043452159632214875,
           0.02838670735216783,
           0.09445829662141196,
           0.15186131748507978,
           0.1982031145119569,
           0.2317103248693539,
           0.25130504004127213,
           0.2566430509401283,
           0.24811283911536614,
           0.22679610352037188,
           0.1943926655354523,
           0.15311446345017118,
           0.10555493165712146,
           0.054541276561040686,
           0.0029779491154211806,
           -0.046310064114579955,
           -0.0907256642328181,
           -0.12803192632998142
          ],
          [
           -0.16278435980926842,
           -0.13736985507049018,
           -0.10281030706494565,
           -0.060690608986011814,
           -0.013073952151520388,
           0.03759772656874239,
           0.08862652853638416,
           0.13719827990417027,
           0.18053174205108255,
           0.21602931256266372,
           0.24142096714711753,
           0.254893432701845,
           0.25519727019112654,
           0.24172565029557566,
           0.21456006847846779,
           0.17447999195279823,
           0.12293536517635703,
           0.06198291759831892,
           -0.005810793613848673,
           -0.07749482277960204,
           -0.14988136590815446,
           -0.21970771693043264,
           -0.2838041182964338,
           -0.3392585664190622,
           -0.3835697098652554,
           -0.4147795406040892,
           -0.43157859884674826,
           -0.4333778373354074,
           -0.4203430458705095,
           -0.39338972722403176,
           -0.3541384336243295,
           -0.30483270332925,
           -0.24822376277499153,
           -0.187427969950852,
           -0.1257644689695074,
           -0.06658162124929747,
           -0.0130814139378774,
           0.03184881503912622,
           0.0657883626364726,
           0.08691073780520595,
           0.0940800053732448,
           0.08691073780520595,
           0.0657883626364726,
           0.03184881503912622,
           -0.0130814139378774,
           -0.06658162124929747,
           -0.1257644689695074,
           -0.187427969950852,
           -0.24822376277499153,
           -0.30483270332925,
           -0.3541384336243295,
           -0.39338972722403176,
           -0.4203430458705095,
           -0.4333778373354074,
           -0.43157859884674826,
           -0.4147795406040892,
           -0.3835697098652554,
           -0.3392585664190622,
           -0.2838041182964338,
           -0.21970771693043264,
           -0.14988136590815446,
           -0.07749482277960204,
           -0.005810793613848673,
           0.06198291759831892,
           0.12293536517635703,
           0.17447999195279823,
           0.21456006847846779,
           0.24172565029557566,
           0.25519727019112654,
           0.254893432701845,
           0.24142096714711753,
           0.21602931256266372,
           0.18053174205108255,
           0.13719827990417027,
           0.08862652853638416,
           0.03759772656874239,
           -0.013073952151520388,
           -0.060690608986011814,
           -0.10281030706494565,
           -0.13736985507049018
          ],
          [
           -0.16865061331126227,
           -0.14653700801271363,
           -0.11505016730310495,
           -0.07558080422426758,
           -0.030004497243790427,
           0.019407660252202565,
           0.07010183827093616,
           0.11937185506223688,
           0.16450028494360933,
           0.20290271423033404,
           0.23226729318028777,
           0.2506818889186662,
           0.2567417315441088,
           0.24963143467045815,
           0.22917661128094333,
           0.19586192453391038,
           0.15081422331281308,
           0.0957513146109,
           0.032898814044057145,
           -0.03512071345143313,
           -0.10542055787501849,
           -0.17499760171649797,
           -0.24088710992360066,
           -0.3003162506586467,
           -0.35084804028714445,
           -0.3905078789395116,
           -0.417885750201407,
           -0.43220845214435083,
           -0.4333778373354074,
           -0.42197287899622543,
           -0.39921534828629784,
           -0.36690087535799776,
           -0.32729906443176787,
           -0.28302803533990717,
           -0.23691017597600564,
           -0.19181693290541052,
           -0.15051108239111077,
           -0.11549507625799743,
           -0.08887373699192957,
           -0.0722388011028484,
           -0.06658162124929747,
           -0.0722388011028484,
           -0.08887373699192957,
           -0.11549507625799743,
           -0.15051108239111077,
           -0.19181693290541052,
           -0.23691017597600564,
           -0.28302803533990717,
           -0.32729906443176787,
           -0.36690087535799776,
           -0.39921534828629784,
           -0.42197287899622543,
           -0.4333778373354074,
           -0.43220845214435083,
           -0.417885750201407,
           -0.3905078789395116,
           -0.35084804028714445,
           -0.3003162506586467,
           -0.24088710992360066,
           -0.17499760171649797,
           -0.10542055787501849,
           -0.03512071345143313,
           0.032898814044057145,
           0.0957513146109,
           0.15081422331281308,
           0.19586192453391038,
           0.22917661128094333,
           0.24963143467045815,
           0.2567417315441088,
           0.2506818889186662,
           0.23226729318028777,
           0.20290271423033404,
           0.16450028494360933,
           0.11937185506223688,
           0.07010183827093616,
           0.019407660252202565,
           -0.030004497243790427,
           -0.07558080422426758,
           -0.11505016730310495,
           -0.14653700801271363
          ],
          [
           -0.1738139924448547,
           -0.15527119023634722,
           -0.1271795169340972,
           -0.0907256642328181,
           -0.04758506314163741,
           0.0001569493213448689,
           0.05010748884225075,
           0.09968670899986165,
           0.14626024334832619,
           0.18727640924644018,
           0.22040074178662336,
           0.24364050109720906,
           0.2554522819126627,
           0.2548267267047997,
           0.2413455569066888,
           0.2152076253393881,
           0.17722237538812438,
           0.12877087581897034,
           0.07173638515428266,
           0.00840808631479302,
           -0.05863687417657578,
           -0.12666669235949252,
           -0.1929363397545002,
           -0.254829433326894,
           -0.309992807249447,
           -0.3564564355250057,
           -0.39273214882544505,
           -0.417885750201407,
           -0.43157859884674826,
           -0.434076417833265,
           -0.42622489689420734,
           -0.4093935036702951,
           -0.3853906832849483,
           -0.35635521764627226,
           -0.324629843053556,
           -0.2926242127644853,
           -0.2626748843273063,
           -0.23691017597600564,
           -0.21712746254366178,
           -0.20468978410715197,
           -0.20044755867978276,
           -0.20468978410715197,
           -0.21712746254366178,
           -0.23691017597600564,
           -0.2626748843273063,
           -0.2926242127644853,
           -0.324629843053556,
           -0.35635521764627226,
           -0.3853906832849483,
           -0.4093935036702951,
           -0.42622489689420734,
           -0.434076417833265,
           -0.43157859884674826,
           -0.417885750201407,
           -0.39273214882544505,
           -0.3564564355250057,
           -0.309992807249447,
           -0.254829433326894,
           -0.1929363397545002,
           -0.12666669235949252,
           -0.05863687417657578,
           0.00840808631479302,
           0.07173638515428266,
           0.12877087581897034,
           0.17722237538812438,
           0.2152076253393881,
           0.2413455569066888,
           0.2548267267047997,
           0.2554522819126627,
           0.24364050109720906,
           0.22040074178662336,
           0.18727640924644018,
           0.14626024334832619,
           0.09968670899986165,
           0.05010748884225075,
           0.0001569493213448689,
           -0.04758506314163741,
           -0.0907256642328181,
           -0.1271795169340972,
           -0.15527119023634722
          ],
          [
           -0.17801860199902664,
           -0.16329221750830802,
           -0.13890582780165694,
           -0.10583439818051152,
           -0.06554239869174844,
           -0.019915691575644292,
           0.02883009042098063,
           0.07825990831739421,
           0.1258425822940911,
           0.16908036038891633,
           0.20563779959612533,
           0.23346296309158113,
           0.2508943222213973,
           0.25674750760048576,
           0.25037713957121355,
           0.2317103248693539,
           0.20124995852555586,
           0.16004763127913005,
           0.1096476200446325,
           0.05200503792795912,
           -0.010617349295218181,
           -0.0757679524450742,
           -0.1409342819269669,
           -0.2036729142303004,
           -0.2617343483375656,
           -0.31317589634427284,
           -0.3564564355250057,
           -0.3905078789395116,
           -0.4147795406040892,
           -0.42925310491460716,
           -0.43442757176285574,
           -0.4312752446188071,
           -0.421171462695804,
           -0.40580225753498556,
           -0.38705535500366767,
           -0.36690087535799776,
           -0.3472686537517362,
           -0.32992927901128904,
           -0.3163857196862348,
           -0.3077817863653888,
           -0.30483270332925,
           -0.3077817863653888,
           -0.3163857196862348,
           -0.32992927901128904,
           -0.3472686537517362,
           -0.36690087535799776,
           -0.38705535500366767,
           -0.40580225753498556,
           -0.421171462695804,
           -0.4312752446188071,
           -0.43442757176285574,
           -0.42925310491460716,
           -0.4147795406040892,
           -0.3905078789395116,
           -0.3564564355250057,
           -0.31317589634427284,
           -0.2617343483375656,
           -0.2036729142303004,
           -0.1409342819269669,
           -0.0757679524450742,
           -0.010617349295218181,
           0.05200503792795912,
           0.1096476200446325,
           0.16004763127913005,
           0.20124995852555586,
           0.2317103248693539,
           0.25037713957121355,
           0.25674750760048576,
           0.2508943222213973,
           0.23346296309158113,
           0.20563779959612533,
           0.16908036038891633,
           0.1258425822940911,
           0.07825990831739421,
           0.02883009042098063,
           -0.019915691575644292,
           -0.06554239869174844,
           -0.10583439818051152,
           -0.13890582780165694,
           -0.16329221750830802
          ],
          [
           -0.18100457917857166,
           -0.17030698199702413,
           -0.1499137997580331,
           -0.12058300781296416,
           -0.08355939645450051,
           -0.040517266401149735,
           0.0065202421682302655,
           0.05528095770522729,
           0.10335731863015635,
           0.14832776112580212,
           0.18787932061729182,
           0.21992483146863692,
           0.242708395806646,
           0.254893432701845,
           0.25562857790064414,
           0.24458792842044305,
           0.22198354690007724,
           0.18854967763954522,
           0.14549969299473817,
           0.09445829662141196,
           0.037372873633869375,
           -0.02359098016854476,
           -0.08616386191642225,
           -0.14809048863531396,
           -0.20724458052139974,
           -0.2617343483375656,
           -0.309992807249447,
           -0.35084804028714445,
           -0.3835697098652554,
           -0.407889497747319,
           -0.42399466300627076,
           -0.43249545715781157,
           -0.43436863670247905,
           -0.4308806796227811,
           -0.42349546556438716,
           -0.4137720534188708,
           -0.40325873487122593,
           -0.39338972722403176,
           -0.3853906832849483,
           -0.3801986514917913,
           -0.3784012476539641,
           -0.3801986514917913,
           -0.3853906832849483,
           -0.39338972722403176,
           -0.40325873487122593,
           -0.4137720534188708,
           -0.42349546556438716,
           -0.4308806796227811,
           -0.43436863670247905,
           -0.43249545715781157,
           -0.42399466300627076,
           -0.407889497747319,
           -0.3835697098652554,
           -0.35084804028714445,
           -0.309992807249447,
           -0.2617343483375656,
           -0.20724458052139974,
           -0.14809048863531396,
           -0.08616386191642225,
           -0.02359098016854476,
           0.037372873633869375,
           0.09445829662141196,
           0.14549969299473817,
           0.18854967763954522,
           0.22198354690007724,
           0.24458792842044305,
           0.25562857790064414,
           0.254893432701845,
           0.242708395806646,
           0.21992483146863692,
           0.18787932061729182,
           0.14832776112580212,
           0.10335731863015635,
           0.05528095770522729,
           0.0065202421682302655,
           -0.040517266401149735,
           -0.08355939645450051,
           -0.12058300781296416,
           -0.1499137997580331,
           -0.17030698199702413
          ],
          [
           -0.18251498442862385,
           -0.1760159755489718,
           -0.15987112992755653,
           -0.13461888616197776,
           -0.10127808535368477,
           -0.061301442485772274,
           -0.016505930263581485,
           0.031016232090896562,
           0.07900122348247962,
           0.12512633286074154,
           0.16712567793535366,
           0.20290271423033404,
           0.23063350923189954,
           0.24885528388828942,
           0.25653555744366946,
           0.25311832399967577,
           0.23854497801642713,
           0.21324911772700825,
           0.17812580971586786,
           0.134477311926808,
           0.08393854575868848,
           0.02838670735216783,
           -0.030159748399708135,
           -0.08964697741323371,
           -0.14809048863531396,
           -0.2036729142303004,
           -0.254829433326894,
           -0.3003162506586467,
           -0.3392585664190622,
           -0.37117570680030565,
           -0.39598244357893553,
           -0.41396693622794944,
           -0.42574709936268906,
           -0.43220845214435083,
           -0.43442757176285574,
           -0.4335860886421158,
           -0.4308806796227811,
           -0.4274347075936389,
           -0.42421701152445723,
           -0.42197287899622543,
           -0.421171462695804,
           -0.42197287899622543,
           -0.42421701152445723,
           -0.4274347075936389,
           -0.4308806796227811,
           -0.4335860886421158,
           -0.43442757176285574,
           -0.43220845214435083,
           -0.42574709936268906,
           -0.41396693622794944,
           -0.39598244357893553,
           -0.37117570680030565,
           -0.3392585664190622,
           -0.3003162506586467,
           -0.254829433326894,
           -0.2036729142303004,
           -0.14809048863531396,
           -0.08964697741323371,
           -0.030159748399708135,
           0.02838670735216783,
           0.08393854575868848,
           0.134477311926808,
           0.17812580971586786,
           0.21324911772700825,
           0.23854497801642713,
           0.25311832399967577,
           0.25653555744366946,
           0.24885528388828942,
           0.23063350923189954,
           0.20290271423033404,
           0.16712567793535366,
           0.12512633286074154,
           0.07900122348247962,
           0.031016232090896562,
           -0.016505930263581485,
           -0.061301442485772274,
           -0.10127808535368477,
           -0.13461888616197776,
           -0.15987112992755653,
           -0.1760159755489718
          ],
          [
           -0.18230376872794093,
           -0.18012123502583363,
           -0.16843605361995675,
           -0.14756752732225356,
           -0.11830504740258321,
           -0.08187218787401292,
           -0.039868134180728126,
           0.0058103924762656495,
           0.05306249567952219,
           0.09968670899986165,
           0.14348926836260514,
           0.18239124981424537,
           0.2145288714461612,
           0.2383416766936446,
           0.25264402764959015,
           0.2566762997375786,
           0.25013332713993036,
           0.23316893482082693,
           0.2063767337439853,
           0.17074867404778504,
           0.12761407121954643,
           0.07856287339249271,
           0.02535776443828009,
           -0.030159748399708135,
           -0.08616386191642225,
           -0.1409342819269669,
           -0.1929363397545002,
           -0.24088710992360066,
           -0.2838041182964338,
           -0.3210343185560354,
           -0.35226222727992795,
           -0.37749737145928347,
           -0.3970424421347404,
           -0.41144469052055266,
           -0.42143408131469146,
           -0.42785247459104203,
           -0.43157859884674826,
           -0.4334537754581445,
           -0.434213248547002,
           -0.43442757176285574,
           -0.43445783007337646,
           -0.43442757176285574,
           -0.434213248547002,
           -0.4334537754581445,
           -0.43157859884674826,
           -0.42785247459104203,
           -0.42143408131469146,
           -0.41144469052055266,
           -0.3970424421347404,
           -0.37749737145928347,
           -0.35226222727992795,
           -0.3210343185560354,
           -0.2838041182964338,
           -0.24088710992360066,
           -0.1929363397545002,
           -0.1409342819269669,
           -0.08616386191642225,
           -0.030159748399708135,
           0.02535776443828009,
           0.07856287339249271,
           0.12761407121954643,
           0.17074867404778504,
           0.2063767337439853,
           0.23316893482082693,
           0.25013332713993036,
           0.2566762997375786,
           0.25264402764959015,
           0.2383416766936446,
           0.2145288714461612,
           0.18239124981424537,
           0.14348926836260514,
           0.09968670899986165,
           0.05306249567952219,
           0.0058103924762656495,
           -0.039868134180728126,
           -0.08187218787401292,
           -0.11830504740258321,
           -0.14756752732225356,
           -0.16843605361995675,
           -0.18012123502583363
          ],
          [
           -0.1801446545297837,
           -0.18233559039097344,
           -0.1752665961050691,
           -0.15904136091487175,
           -0.13421936300715656,
           -0.10179031338845618,
           -0.0631265026963309,
           -0.019915691575644292,
           0.025921773001301992,
           0.07232710218505171,
           0.11720338291232232,
           0.15851669454452746,
           0.1943926655354523,
           0.2232034254780841,
           0.24364050109720906,
           0.25477004091850136,
           0.2560677827399544,
           0.24743234013685533,
           0.22917661128094333,
           0.20199833430642128,
           0.16693195814109418,
           0.12528500092613942,
           0.07856287339249271,
           0.02838670735216783,
           -0.02359098016854476,
           -0.0757679524450742,
           -0.12666669235949252,
           -0.17499760171649797,
           -0.21970771693043264,
           -0.26001264723920775,
           -0.29541051237375787,
           -0.32567778292945404,
           -0.35084804028714445,
           -0.37117570680030565,
           -0.38708768931988075,
           -0.3991265770886398,
           -0.407889497747319,
           -0.41396693622794944,
           -0.417885750201407,
           -0.4200602785751461,
           -0.4207548585159486,
           -0.4200602785751461,
           -0.417885750201407,
           -0.41396693622794944,
           -0.407889497747319,
           -0.3991265770886398,
           -0.38708768931988075,
           -0.37117570680030565,
           -0.35084804028714445,
           -0.32567778292945404,
           -0.29541051237375787,
           -0.26001264723920775,
           -0.21970771693043264,
           -0.17499760171649797,
           -0.12666669235949252,
           -0.0757679524450742,
           -0.02359098016854476,
           0.02838670735216783,
           0.07856287339249271,
           0.12528500092613942,
           0.16693195814109418,
           0.20199833430642128,
           0.22917661128094333,
           0.24743234013685533,
           0.2560677827399544,
           0.25477004091850136,
           0.24364050109720906,
           0.2232034254780841,
           0.1943926655354523,
           0.15851669454452746,
           0.11720338291232232,
           0.07232710218505171,
           0.025921773001301992,
           -0.019915691575644292,
           -0.0631265026963309,
           -0.10179031338845618,
           -0.13421936300715656,
           -0.15904136091487175,
           -0.1752665961050691,
           -0.18233559039097344
          ],
          [
           -0.17584069010379264,
           -0.18239300622958532,
           -0.1800313728705813,
           -0.16865061331126227,
           -0.14858307017251748,
           -0.12058300781296416,
           -0.0857896329957062,
           -0.045670869380806056,
           -0.001951040868825416,
           0.043473546354522816,
           0.08862652853638416,
           0.13154597877649798,
           0.17037647050011584,
           0.20345392533496165,
           0.22937894091767205,
           0.24707500803079696,
           0.25582893038458626,
           0.2553118000893658,
           0.2455799958764798,
           0.2270567942100705,
           0.20049625055173417,
           0.16693195814109418,
           0.12761407121954643,
           0.08393854575868848,
           0.037372873633869375,
           -0.010617349295218181,
           -0.05863687417657578,
           -0.10542055787501849,
           -0.14988136590815446,
           -0.19114437378651342,
           -0.22856545626592412,
           -0.2617343483375656,
           -0.29046275344788247,
           -0.31475910259630246,
           -0.33479237619194996,
           -0.35084804028714445,
           -0.3632795822101567,
           -0.37245933283868765,
           -0.3787322233669178,
           -0.382375848005458,
           -0.3835697098652554,
           -0.382375848005458,
           -0.3787322233669178,
           -0.37245933283868765,
           -0.3632795822101567,
           -0.35084804028714445,
           -0.33479237619194996,
           -0.31475910259630246,
           -0.29046275344788247,
           -0.2617343483375656,
           -0.22856545626592412,
           -0.19114437378651342,
           -0.14988136590815446,
           -0.10542055787501849,
           -0.05863687417657578,
           -0.010617349295218181,
           0.037372873633869375,
           0.08393854575868848,
           0.12761407121954643,
           0.16693195814109418,
           0.20049625055173417,
           0.2270567942100705,
           0.2455799958764798,
           0.2553118000893658,
           0.25582893038458626,
           0.24707500803079696,
           0.22937894091767205,
           0.20345392533496165,
           0.17037647050011584,
           0.13154597877649798,
           0.08862652853638416,
           0.043473546354522816,
           -0.001951040868825416,
           -0.045670869380806056,
           -0.0857896329957062,
           -0.12058300781296416,
           -0.14858307017251748,
           -0.16865061331126227,
           -0.1800313728705813,
           -0.18239300622958532
          ],
          [
           -0.16923416092386775,
           -0.1800597155006458,
           -0.18242166855756492,
           -0.1760159755489718,
           -0.1609539875623888,
           -0.1377563081818195,
           -0.10732612754693129,
           -0.07090368426500879,
           -0.030004497243790427,
           0.013655158230898757,
           0.058241427706856384,
           0.1018902143955224,
           0.14279404657238684,
           0.1792839709402817,
           0.20990234059772522,
           0.23346296309158113,
           0.24909585663212155,
           0.2562747828163765,
           0.2548267267047997,
           0.24492352037505036,
           0.2270567942100705,
           0.20199833430642128,
           0.17074867404778504,
           0.134477311926808,
           0.09445829662141196,
           0.05200503792795912,
           0.00840808631479302,
           -0.03512071345143313,
           -0.07749482277960204,
           -0.1177881852505473,
           -0.15525760655490364,
           -0.18935183535374994,
           -0.21970771693043264,
           -0.24613461781837798,
           -0.268589046149572,
           -0.28714197491104243,
           -0.30194177876754097,
           -0.31317589634427284,
           -0.3210343185560354,
           -0.32567778292945404,
           -0.32721314035298743,
           -0.32567778292945404,
           -0.3210343185560354,
           -0.31317589634427284,
           -0.30194177876754097,
           -0.28714197491104243,
           -0.268589046149572,
           -0.24613461781837798,
           -0.21970771693043264,
           -0.18935183535374994,
           -0.15525760655490364,
           -0.1177881852505473,
           -0.07749482277960204,
           -0.03512071345143313,
           0.00840808631479302,
           0.05200503792795912,
           0.09445829662141196,
           0.134477311926808,
           0.17074867404778504,
           0.20199833430642128,
           0.2270567942100705,
           0.24492352037505036,
           0.2548267267047997,
           0.2562747828163765,
           0.24909585663212155,
           0.23346296309158113,
           0.20990234059772522,
           0.1792839709402817,
           0.14279404657238684,
           0.1018902143955224,
           0.058241427706856384,
           0.013655158230898757,
           -0.030004497243790427,
           -0.07090368426500879,
           -0.10732612754693129,
           -0.1377563081818195,
           -0.1609539875623888,
           -0.1760159755489718,
           -0.18242166855756492,
           -0.1800597155006458
          ],
          [
           -0.16021647158282734,
           -0.1751457556394694,
           -0.1821644169794075,
           -0.18078273088932142,
           -0.17090060569317098,
           -0.1528102839666787,
           -0.1271795169340972,
           -0.0950164022704569,
           -0.05761803324395176,
           -0.016505930263581485,
           0.026648129724923395,
           0.07010183827093616,
           0.11212338767979044,
           0.15106960365711752,
           0.18545724476618586,
           0.21402402107025095,
           0.23577655069724138,
           0.25002327766855664,
           0.25639126767027576,
           0.2548267267047997,
           0.2455799958764798,
           0.22917661128094333,
           0.2063767337439853,
           0.17812580971586786,
           0.14549969299473817,
           0.1096476200446325,
           0.07173638515428266,
           0.032898814044057145,
           -0.005810793613848673,
           -0.043452159632214875,
           -0.0792240541655952,
           -0.11247819731414006,
           -0.1427221428215067,
           -0.1696119802323752,
           -0.1929363397545002,
           -0.2125937105436689,
           -0.22856545626592412,
           -0.24088710992360066,
           -0.24962054293732017,
           -0.254829433326894,
           -0.2565601183892334,
           -0.254829433326894,
           -0.24962054293732017,
           -0.24088710992360066,
           -0.22856545626592412,
           -0.2125937105436689,
           -0.1929363397545002,
           -0.1696119802323752,
           -0.1427221428215067,
           -0.11247819731414006,
           -0.0792240541655952,
           -0.043452159632214875,
           -0.005810793613848673,
           0.032898814044057145,
           0.07173638515428266,
           0.1096476200446325,
           0.14549969299473817,
           0.17812580971586786,
           0.2063767337439853,
           0.22917661128094333,
           0.2455799958764798,
           0.2548267267047997,
           0.25639126767027576,
           0.25002327766855664,
           0.23577655069724138,
           0.21402402107025095,
           0.18545724476618586,
           0.15106960365711752,
           0.11212338767979044,
           0.07010183827093616,
           0.026648129724923395,
           -0.016505930263581485,
           -0.05761803324395176,
           -0.0950164022704569,
           -0.1271795169340972,
           -0.1528102839666787,
           -0.17090060569317098,
           -0.18078273088932142,
           -0.1821644169794075,
           -0.1751457556394694
          ],
          [
           -0.1487375524385824,
           -0.16751643729146143,
           -0.17903560277058095,
           -0.1826358700412797,
           -0.17801860199902664,
           -0.16525654180237792,
           -0.14478624788034108,
           -0.11738288358628372,
           -0.08411903827788304,
           -0.046310064114579955,
           -0.005449066140771361,
           0.03686485131708162,
           0.07900122348247962,
           0.11937185506223688,
           0.15649972810645998,
           0.1890798565922851,
           0.21602931256266372,
           0.2365243422174828,
           0.25002327766855664,
           0.2562747828163765,
           0.2553118000893658,
           0.24743234013685533,
           0.23316893482082693,
           0.21324911772700825,
           0.18854967763954522,
           0.16004763127913005,
           0.12877087581897034,
           0.0957513146109,
           0.06198291759831892,
           0.02838670735216783,
           -0.004215913110515241,
           -0.03512071345143313,
           -0.06374895250625122,
           -0.08964697741323371,
           -0.11247819731414006,
           -0.132008995765264,
           -0.14809048863531396,
           -0.16063822727306362,
           -0.1696119802323752,
           -0.17499760171649797,
           -0.17679272260843765,
           -0.17499760171649797,
           -0.1696119802323752,
           -0.16063822727306362,
           -0.14809048863531396,
           -0.132008995765264,
           -0.11247819731414006,
           -0.08964697741323371,
           -0.06374895250625122,
           -0.03512071345143313,
           -0.004215913110515241,
           0.02838670735216783,
           0.06198291759831892,
           0.0957513146109,
           0.12877087581897034,
           0.16004763127913005,
           0.18854967763954522,
           0.21324911772700825,
           0.23316893482082693,
           0.24743234013685533,
           0.2553118000893658,
           0.2562747828163765,
           0.25002327766855664,
           0.2365243422174828,
           0.21602931256266372,
           0.1890798565922851,
           0.15649972810645998,
           0.11937185506223688,
           0.07900122348247962,
           0.03686485131708162,
           -0.005449066140771361,
           -0.046310064114579955,
           -0.08411903827788304,
           -0.11738288358628372,
           -0.14478624788034108,
           -0.16525654180237792,
           -0.17801860199902664,
           -0.1826358700412797,
           -0.17903560277058095,
           -0.16751643729146143
          ],
          [
           -0.13481430178982187,
           -0.15710321083861073,
           -0.17287351607260817,
           -0.18131560690315682,
           -0.18194839266053625,
           -0.17463748569481502,
           -0.15959621882048483,
           -0.13736985507049018,
           -0.10880422217787396,
           -0.0750007897964791,
           -0.03726086233570953,
           0.0029779491154211806,
           0.044209509361482956,
           0.08492762656935865,
           0.12369173187889267,
           0.15918658398472915,
           0.1902732638436695,
           0.21602931256266372,
           0.23577655069724138,
           0.24909585663212155,
           0.25582893038458626,
           0.2560677827399544,
           0.25013332713993036,
           0.23854497801642713,
           0.22198354690007724,
           0.20124995852555586,
           0.17722237538812438,
           0.15081422331281308,
           0.12293536517635703,
           0.09445829662141196,
           0.0661907655654817,
           0.03885568116655977,
           0.013078615468659323,
           -0.010617349295218181,
           -0.03181017613329085,
           -0.050171999808914604,
           -0.06545830501430487,
           -0.07749482277960204,
           -0.08616386191642225,
           -0.09139170665445415,
           -0.09313849939964196,
           -0.09139170665445415,
           -0.08616386191642225,
           -0.07749482277960204,
           -0.06545830501430487,
           -0.050171999808914604,
           -0.03181017613329085,
           -0.010617349295218181,
           0.013078615468659323,
           0.03885568116655977,
           0.0661907655654817,
           0.09445829662141196,
           0.12293536517635703,
           0.15081422331281308,
           0.17722237538812438,
           0.20124995852555586,
           0.22198354690007724,
           0.23854497801642713,
           0.25013332713993036,
           0.2560677827399544,
           0.25582893038458626,
           0.24909585663212155,
           0.23577655069724138,
           0.21602931256266372,
           0.1902732638436695,
           0.15918658398472915,
           0.12369173187889267,
           0.08492762656935865,
           0.044209509361482956,
           0.0029779491154211806,
           -0.03726086233570953,
           -0.0750007897964791,
           -0.10880422217787396,
           -0.13736985507049018,
           -0.15959621882048483,
           -0.17463748569481502,
           -0.18194839266053625,
           -0.18131560690315682,
           -0.17287351607260817,
           -0.15710321083861073
          ],
          [
           -0.11853755153953284,
           -0.14391335124448024,
           -0.163591222139663,
           -0.17663261032673944,
           -0.18239300622958532,
           -0.18054660691367944,
           -0.17109514979541934,
           -0.1543609103022869,
           -0.13096468174943518,
           -0.10179031338845618,
           -0.06793803188546253,
           -0.03066927919323432,
           0.008653858363151095,
           0.04863139306208121,
           0.0878871354792479,
           0.12512633286074154,
           0.15918658398472915,
           0.1890798565922851,
           0.21402402107025095,
           0.23346296309158113,
           0.24707500803079696,
           0.25477004091850136,
           0.2566762997375786,
           0.25311832399967577,
           0.24458792842044305,
           0.2317103248693539,
           0.2152076253393881,
           0.19586192453391038,
           0.17447999195279823,
           0.15186131748507978,
           0.12877087581897034,
           0.10591753298818528,
           0.08393854575868848,
           0.06339013493636744,
           0.044743679368913644,
           0.02838670735216783,
           0.014627580006334946,
           0.0037025838949493145,
           -0.004215913110515241,
           -0.009011537058698997,
           -0.010617349295218181,
           -0.009011537058698997,
           -0.004215913110515241,
           0.0037025838949493145,
           0.014627580006334946,
           0.02838670735216783,
           0.044743679368913644,
           0.06339013493636744,
           0.08393854575868848,
           0.10591753298818528,
           0.12877087581897034,
           0.15186131748507978,
           0.17447999195279823,
           0.19586192453391038,
           0.2152076253393881,
           0.2317103248693539,
           0.24458792842044305,
           0.25311832399967577,
           0.2566762997375786,
           0.25477004091850136,
           0.24707500803079696,
           0.23346296309158113,
           0.21402402107025095,
           0.1890798565922851,
           0.15918658398472915,
           0.12512633286074154,
           0.0878871354792479,
           0.04863139306208121,
           0.008653858363151095,
           -0.03066927919323432,
           -0.06793803188546253,
           -0.10179031338845618,
           -0.13096468174943518,
           -0.1543609103022869,
           -0.17109514979541934,
           -0.18054660691367944,
           -0.18239300622958532,
           -0.17663261032673944,
           -0.163591222139663,
           -0.14391335124448024
          ],
          [
           -0.10007704610444179,
           -0.12803786284735597,
           -0.1511875643863488,
           -0.16848219583369567,
           -0.17913546063850083,
           -0.18264893898060253,
           -0.1788278960809016,
           -0.16778234479339135,
           -0.1499137997580331,
           -0.1258888846262905,
           -0.09660159075517502,
           -0.0631265026963309,
           -0.026665677985416577,
           0.011507919583092052,
           0.05010748884225075,
           0.0878871354792479,
           0.12369173187889267,
           0.15649972810645998,
           0.18545724476618586,
           0.20990234059772522,
           0.22937894091767205,
           0.24364050109720906,
           0.25264402764959015,
           0.25653555744366946,
           0.25562857790064414,
           0.25037713957121355,
           0.2413455569066888,
           0.22917661128094333,
           0.21456006847846779,
           0.1982031145119569,
           0.18080401871815463,
           0.1630299764243758,
           0.14549969299473817,
           0.12877087581897034,
           0.11333242903336226,
           0.09960082298540655,
           0.08791985781076668,
           0.07856287339249271,
           0.07173638515428266,
           0.06758414818694233,
           0.0661907655654817,
           0.06758414818694233,
           0.07173638515428266,
           0.07856287339249271,
           0.08791985781076668,
           0.09960082298540655,
           0.11333242903336226,
           0.12877087581897034,
           0.14549969299473817,
           0.1630299764243758,
           0.18080401871815463,
           0.1982031145119569,
           0.21456006847846779,
           0.22917661128094333,
           0.2413455569066888,
           0.25037713957121355,
           0.25562857790064414,
           0.25653555744366946,
           0.25264402764959015,
           0.24364050109720906,
           0.22937894091767205,
           0.20990234059772522,
           0.18545724476618586,
           0.15649972810645998,
           0.12369173187889267,
           0.0878871354792479,
           0.05010748884225075,
           0.011507919583092052,
           -0.026665677985416577,
           -0.0631265026963309,
           -0.09660159075517502,
           -0.1258888846262905,
           -0.1499137997580331,
           -0.16778234479339135,
           -0.1788278960809016,
           -0.18264893898060253,
           -0.17913546063850083,
           -0.16848219583369567,
           -0.1511875643863488,
           -0.12803786284735597
          ],
          [
           -0.07968395387291566,
           -0.10965701691843574,
           -0.13575600794040762,
           -0.15685668268767797,
           -0.17205475511311313,
           -0.1807007071005138,
           -0.18242166855756492,
           -0.17712974307464055,
           -0.16501687105976595,
           -0.14653700801271363,
           -0.12237701362727325,
           -0.09341816596346665,
           -0.060690608986011814,
           -0.02532329427921568,
           0.011507919583092052,
           0.04863139306208121,
           0.08492762656935865,
           0.11937185506223688,
           0.15106960365711752,
           0.1792839709402817,
           0.20345392533496165,
           0.2232034254780841,
           0.2383416766936446,
           0.24885528388828942,
           0.254893432701845,
           0.25674750760048576,
           0.2548267267047997,
           0.24963143467045815,
           0.24172565029557566,
           0.2317103248693539,
           0.22019854657881394,
           0.20779364608280457,
           0.19507084218595108,
           0.18256273925541686,
           0.17074867404778504,
           0.16004763127913005,
           0.15081422331281308,
           0.1433370736825879,
           0.13783886506830845,
           0.134477311926808,
           0.1333463922312941,
           0.134477311926808,
           0.13783886506830845,
           0.1433370736825879,
           0.15081422331281308,
           0.16004763127913005,
           0.17074867404778504,
           0.18256273925541686,
           0.19507084218595108,
           0.20779364608280457,
           0.22019854657881394,
           0.2317103248693539,
           0.24172565029557566,
           0.24963143467045815,
           0.2548267267047997,
           0.25674750760048576,
           0.254893432701845,
           0.24885528388828942,
           0.2383416766936446,
           0.2232034254780841,
           0.20345392533496165,
           0.1792839709402817,
           0.15106960365711752,
           0.11937185506223688,
           0.08492762656935865,
           0.04863139306208121,
           0.011507919583092052,
           -0.02532329427921568,
           -0.060690608986011814,
           -0.09341816596346665,
           -0.12237701362727325,
           -0.14653700801271363,
           -0.16501687105976595,
           -0.17712974307464055,
           -0.18242166855756492,
           -0.1807007071005138,
           -0.17205475511311313,
           -0.15685668268767797,
           -0.13575600794040762,
           -0.10965701691843574
          ],
          [
           -0.05769048962428924,
           -0.08904297911487404,
           -0.11749065565570795,
           -0.14185512230149663,
           -0.16113955966514656,
           -0.17456713788189782,
           -0.18160802037610754,
           -0.18199408570471504,
           -0.17572115154133375,
           -0.16303912773542587,
           -0.14443111863131364,
           -0.12058300781296416,
           -0.09234546620178369,
           -0.060690608986011814,
           -0.026665677985416577,
           0.008653858363151095,
           0.044209509361482956,
           0.07900122348247962,
           0.11212338767979044,
           0.14279404657238684,
           0.17037647050011584,
           0.1943926655354523,
           0.2145288714461612,
           0.23063350923189954,
           0.242708395806646,
           0.2508943222213973,
           0.2554522819126627,
           0.2567417315441088,
           0.25519727019112654,
           0.25130504004127213,
           0.2455799958764798,
           0.23854497801642713,
           0.23071227369415245,
           0.2225680860000738,
           0.21456006847846779,
           0.2070878465419809,
           0.20049625055173417,
           0.19507084218595108,
           0.19103523332295086,
           0.18854967763954522,
           0.18771045677679687,
           0.18854967763954522,
           0.19103523332295086,
           0.19507084218595108,
           0.20049625055173417,
           0.2070878465419809,
           0.21456006847846779,
           0.2225680860000738,
           0.23071227369415245,
           0.23854497801642713,
           0.2455799958764798,
           0.25130504004127213,
           0.25519727019112654,
           0.2567417315441088,
           0.2554522819126627,
           0.2508943222213973,
           0.242708395806646,
           0.23063350923189954,
           0.2145288714461612,
           0.1943926655354523,
           0.17037647050011584,
           0.14279404657238684,
           0.11212338767979044,
           0.07900122348247962,
           0.044209509361482956,
           0.008653858363151095,
           -0.026665677985416577,
           -0.060690608986011814,
           -0.09234546620178369,
           -0.12058300781296416,
           -0.14443111863131364,
           -0.16303912773542587,
           -0.17572115154133375,
           -0.18199408570471504,
           -0.18160802037610754,
           -0.17456713788189782,
           -0.16113955966514656,
           -0.14185512230149663,
           -0.11749065565570795,
           -0.08904297911487404
          ],
          [
           -0.0345063152690242,
           -0.06655906279410359,
           -0.09668883252747353,
           -0.12368964794720452,
           -0.1464987033293174,
           -0.1642373823959323,
           -0.17624240938958516,
           -0.18208605074549258,
           -0.18158488243001691,
           -0.1747972342928682,
           -0.16200998595397612,
           -0.1437158894806465,
           -0.12058300781296416,
           -0.09341816596346665,
           -0.0631265026963309,
           -0.03066927919323432,
           0.0029779491154211806,
           0.03686485131708162,
           0.07010183827093616,
           0.1018902143955224,
           0.13154597877649798,
           0.15851669454452746,
           0.18239124981424537,
           0.20290271423033404,
           0.21992483146863692,
           0.23346296309158113,
           0.24364050109720906,
           0.2506818889186662,
           0.254893432701845,
           0.2566430509401283,
           0.2563400102730029,
           0.25441554164532254,
           0.25130504004127213,
           0.24743234013685533,
           0.2431963471432226,
           0.23896010343988033,
           0.23504220166614895,
           0.2317103248693539,
           0.22917661128094333,
           0.22759450814784551,
           0.2270567942100705,
           0.22759450814784551,
           0.22917661128094333,
           0.2317103248693539,
           0.23504220166614895,
           0.23896010343988033,
           0.2431963471432226,
           0.24743234013685533,
           0.25130504004127213,
           0.25441554164532254,
           0.2563400102730029,
           0.2566430509401283,
           0.254893432701845,
           0.2506818889186662,
           0.24364050109720906,
           0.23346296309158113,
           0.21992483146863692,
           0.20290271423033404,
           0.18239124981424537,
           0.15851669454452746,
           0.13154597877649798,
           0.1018902143955224,
           0.07010183827093616,
           0.03686485131708162,
           0.0029779491154211806,
           -0.03066927919323432,
           -0.0631265026963309,
           -0.09341816596346665,
           -0.12058300781296416,
           -0.1437158894806465,
           -0.16200998595397612,
           -0.1747972342928682,
           -0.18158488243001691,
           -0.18208605074549258,
           -0.17624240938958516,
           -0.1642373823959323,
           -0.1464987033293174,
           -0.12368964794720452,
           -0.09668883252747353,
           -0.06655906279410359
          ],
          [
           -0.01061150357619211,
           -0.042655257000177006,
           -0.07374973820785838,
           -0.10268778525178764,
           -0.1283676319466868,
           -0.14983554931501694,
           -0.16632015713858264,
           -0.17725715646546372,
           -0.18230376872794093,
           -0.18134271385500067,
           -0.17447608825271163,
           -0.16200998595397612,
           -0.14443111863131364,
           -0.12237701362727325,
           -0.09660159075517502,
           -0.06793803188546253,
           -0.03726086233570953,
           -0.005449066140771361,
           0.026648129724923395,
           0.058241427706856384,
           0.08862652853638416,
           0.11720338291232232,
           0.14348926836260514,
           0.16712567793535366,
           0.18787932061729182,
           0.20563779959612533,
           0.22040074178662336,
           0.23226729318028777,
           0.24142096714711753,
           0.24811283911536614,
           0.25264402764959015,
           0.255348298963932,
           0.256575492104657,
           0.2566762997375786,
           0.2559887694405144,
           0.2548267267047997,
           0.25347017586536014,
           0.252157618714697,
           0.25108014921898075,
           0.25037713957121355,
           0.25013332713993036,
           0.25037713957121355,
           0.25108014921898075,
           0.252157618714697,
           0.25347017586536014,
           0.2548267267047997,
           0.2559887694405144,
           0.2566762997375786,
           0.256575492104657,
           0.255348298963932,
           0.25264402764959015,
           0.24811283911536614,
           0.24142096714711753,
           0.23226729318028777,
           0.22040074178662336,
           0.20563779959612533,
           0.18787932061729182,
           0.16712567793535366,
           0.14348926836260514,
           0.11720338291232232,
           0.08862652853638416,
           0.058241427706856384,
           0.026648129724923395,
           -0.005449066140771361,
           -0.03726086233570953,
           -0.06793803188546253,
           -0.09660159075517502,
           -0.12237701362727325,
           -0.14443111863131364,
           -0.16200998595397612,
           -0.17447608825271163,
           -0.18134271385500067,
           -0.18230376872794093,
           -0.17725715646546372,
           -0.16632015713858264,
           -0.14983554931501694,
           -0.1283676319466868,
           -0.10268778525178764,
           -0.07374973820785838,
           -0.042655257000177006
          ],
          [
           0.013454008098850966,
           -0.017859822184363938,
           -0.04916880920228074,
           -0.07929019757294747,
           -0.10711012813756442,
           -0.1316269478872783,
           -0.15198770280837584,
           -0.16751643729146143,
           -0.17773339606034183,
           -0.18236471957976835,
           -0.18134271385500067,
           -0.1747972342928682,
           -0.16303912773542587,
           -0.14653700801271363,
           -0.1258888846262905,
           -0.10179031338845618,
           -0.0750007897964791,
           -0.046310064114579955,
           -0.016505930263581485,
           0.013655158230898757,
           0.043473546354522816,
           0.07232710218505171,
           0.09968670899986165,
           0.12512633286074154,
           0.14832776112580212,
           0.16908036038891633,
           0.18727640924644018,
           0.20290271423033404,
           0.21602931256266372,
           0.22679610352037188,
           0.23539823538075702,
           0.2420710146043941,
           0.24707500803079696,
           0.2506818889186662,
           0.2531614457800734,
           0.25477004091850136,
           0.2557406839380664,
           0.2562747828163765,
           0.25653555744366946,
           0.2566430509401283,
           0.2566706526738519,
           0.2566430509401283,
           0.25653555744366946,
           0.2562747828163765,
           0.2557406839380664,
           0.25477004091850136,
           0.2531614457800734,
           0.2506818889186662,
           0.24707500803079696,
           0.2420710146043941,
           0.23539823538075702,
           0.22679610352037188,
           0.21602931256266372,
           0.20290271423033404,
           0.18727640924644018,
           0.16908036038891633,
           0.14832776112580212,
           0.12512633286074154,
           0.09968670899986165,
           0.07232710218505171,
           0.043473546354522816,
           0.013655158230898757,
           -0.016505930263581485,
           -0.046310064114579955,
           -0.0750007897964791,
           -0.10179031338845618,
           -0.1258888846262905,
           -0.14653700801271363,
           -0.16303912773542587,
           -0.1747972342928682,
           -0.18134271385500067,
           -0.18236471957976835,
           -0.17773339606034183,
           -0.16751643729146143,
           -0.15198770280837584,
           -0.1316269478872783,
           -0.10711012813756442,
           -0.07929019757294747,
           -0.04916880920228074,
           -0.017859822184363938
          ],
          [
           0.037104384846577534,
           0.007233082355737275,
           -0.023527608249201665,
           -0.054043516875550875,
           -0.08321475815193494,
           -0.11001880232017779,
           -0.13354819579908725,
           -0.15304146672549196,
           -0.167906160972842,
           -0.17773339606034183,
           -0.18230376872794093,
           -0.18158488243001691,
           -0.17572115154133375,
           -0.16501687105976595,
           -0.1499137997580331,
           -0.13096468174943518,
           -0.10880422217787396,
           -0.08411903827788304,
           -0.05761803324395176,
           -0.030004497243790427,
           -0.001951040868825416,
           0.025921773001301992,
           0.05306249567952219,
           0.07900122348247962,
           0.10335731863015635,
           0.1258425822940911,
           0.14626024334832619,
           0.16450028494360933,
           0.18053174205108255,
           0.1943926655354523,
           0.2061784643801796,
           0.21602931256266372,
           0.22411724822563847,
           0.23063350923189954,
           0.23577655069724138,
           0.23974108638511749,
           0.242708395806646,
           0.24483804991090946,
           0.24626113579560338,
           0.24707500803079696,
           0.24733956165584545,
           0.24707500803079696,
           0.24626113579560338,
           0.24483804991090946,
           0.242708395806646,
           0.23974108638511749,
           0.23577655069724138,
           0.23063350923189954,
           0.22411724822563847,
           0.21602931256266372,
           0.2061784643801796,
           0.1943926655354523,
           0.18053174205108255,
           0.16450028494360933,
           0.14626024334832619,
           0.1258425822940911,
           0.10335731863015635,
           0.07900122348247962,
           0.05306249567952219,
           0.025921773001301992,
           -0.001951040868825416,
           -0.030004497243790427,
           -0.05761803324395176,
           -0.08411903827788304,
           -0.10880422217787396,
           -0.13096468174943518,
           -0.1499137997580331,
           -0.16501687105976595,
           -0.17572115154133375,
           -0.18158488243001691,
           -0.18230376872794093,
           -0.17773339606034183,
           -0.167906160972842,
           -0.15304146672549196,
           -0.13354819579908725,
           -0.11001880232017779,
           -0.08321475815193494,
           -0.054043516875550875,
           -0.023527608249201665,
           0.007233082355737275
          ],
          [
           0.059725017515438364,
           0.03197958453286062,
           0.0025207381574719806,
           -0.027588123185645037,
           -0.0572857273340844,
           -0.08555491563889543,
           -0.1114606806231028,
           -0.13418273806183595,
           -0.15304146672549196,
           -0.16751643729146143,
           -0.17725715646546372,
           -0.18208605074549258,
           -0.18199408570471504,
           -0.17712974307464055,
           -0.16778234479339135,
           -0.1543609103022869,
           -0.13736985507049018,
           -0.11738288358628372,
           -0.0950164022704569,
           -0.07090368426500879,
           -0.045670869380806056,
           -0.019915691575644292,
           0.0058103924762656495,
           0.031016232090896562,
           0.05528095770522729,
           0.07825990831739421,
           0.09968670899986165,
           0.11937185506223688,
           0.13719827990417027,
           0.15311446345017118,
           0.16712567793535366,
           0.1792839709402817,
           0.18967745729212915,
           0.19841943861188654,
           0.20563779959612533,
           0.21146505144444128,
           0.21602931256266372,
           0.21944644111666822,
           0.22181346801290225,
           0.2232034254780841,
           0.22366162672468853,
           0.2232034254780841,
           0.22181346801290225,
           0.21944644111666822,
           0.21602931256266372,
           0.21146505144444128,
           0.20563779959612533,
           0.19841943861188654,
           0.18967745729212915,
           0.1792839709402817,
           0.16712567793535366,
           0.15311446345017118,
           0.13719827990417027,
           0.11937185506223688,
           0.09968670899986165,
           0.07825990831739421,
           0.05528095770522729,
           0.031016232090896562,
           0.0058103924762656495,
           -0.019915691575644292,
           -0.045670869380806056,
           -0.07090368426500879,
           -0.0950164022704569,
           -0.11738288358628372,
           -0.13736985507049018,
           -0.1543609103022869,
           -0.16778234479339135,
           -0.17712974307464055,
           -0.18199408570471504,
           -0.18208605074549258,
           -0.17725715646546372,
           -0.16751643729146143,
           -0.15304146672549196,
           -0.13418273806183595,
           -0.1114606806231028,
           -0.08555491563889543,
           -0.0572857273340844,
           -0.027588123185645037,
           0.0025207381574719806,
           0.03197958453286062
          ],
          [
           0.08069235790121831,
           0.05570574218106777,
           0.028270310898122826,
           -0.0006409754282528475,
           -0.03002807965783915,
           -0.05890402451081101,
           -0.08633239590937543,
           -0.1114606806231028,
           -0.13354819579908725,
           -0.15198770280837584,
           -0.16632015713858264,
           -0.17624240938958516,
           -0.18160802037610754,
           -0.18242166855756492,
           -0.1788278960809016,
           -0.17109514979541934,
           -0.15959621882048483,
           -0.14478624788034108,
           -0.1271795169340972,
           -0.10732612754693129,
           -0.0857896329957062,
           -0.0631265026963309,
           -0.039868134180728126,
           -0.016505930263581485,
           0.0065202421682302655,
           0.02883009042098063,
           0.05010748884225075,
           0.07010183827093616,
           0.08862652853638416,
           0.10555493165712146,
           0.12081441070397907,
           0.13437885433763305,
           0.14626024334832619,
           0.15649972810645998,
           0.16515865057394133,
           0.17230988766358785,
           0.17802983029511174,
           0.18239124981424537,
           0.18545724476618586,
           0.18727640924644018,
           0.18787932061729182,
           0.18727640924644018,
           0.18545724476618586,
           0.18239124981424537,
           0.17802983029511174,
           0.17230988766358785,
           0.16515865057394133,
           0.15649972810645998,
           0.14626024334832619,
           0.13437885433763305,
           0.12081441070397907,
           0.10555493165712146,
           0.08862652853638416,
           0.07010183827093616,
           0.05010748884225075,
           0.02883009042098063,
           0.0065202421682302655,
           -0.016505930263581485,
           -0.039868134180728126,
           -0.0631265026963309,
           -0.0857896329957062,
           -0.10732612754693129,
           -0.1271795169340972,
           -0.14478624788034108,
           -0.15959621882048483,
           -0.17109514979541934,
           -0.1788278960809016,
           -0.18242166855756492,
           -0.18160802037610754,
           -0.17624240938958516,
           -0.16632015713858264,
           -0.15198770280837584,
           -0.13354819579908725,
           -0.1114606806231028,
           -0.08633239590937543,
           -0.05890402451081101,
           -0.03002807965783915,
           -0.0006409754282528475,
           0.028270310898122826,
           0.05570574218106777
          ],
          [
           0.0993958462307399,
           0.07773008237271903,
           0.05298490441364873,
           0.026026147564044762,
           -0.0022274559793407315,
           -0.030841885736018544,
           -0.05890402451081101,
           -0.08555491563889543,
           -0.11001880232017779,
           -0.1316269478872783,
           -0.14983554931501694,
           -0.1642373823959323,
           -0.17456713788189782,
           -0.1807007071005138,
           -0.18264893898060253,
           -0.18054660691367944,
           -0.17463748569481502,
           -0.16525654180237792,
           -0.1528102839666787,
           -0.1377563081818195,
           -0.12058300781296416,
           -0.10179031338845618,
           -0.08187218787401292,
           -0.061301442485772274,
           -0.040517266401149735,
           -0.019915691575644292,
           0.0001569493213448689,
           0.019407660252202565,
           0.03759772656874239,
           0.054541276561040686,
           0.07010183827093616,
           0.08418731130237875,
           0.09674378883254962,
           0.10774865812501504,
           0.11720338291232232,
           0.12512633286074154,
           0.13154597877649798,
           0.13649472168344115,
           0.14000357308347133,
           0.14209785531573388,
           0.14279404657238684,
           0.14209785531573388,
           0.14000357308347133,
           0.13649472168344115,
           0.13154597877649798,
           0.12512633286074154,
           0.11720338291232232,
           0.10774865812501504,
           0.09674378883254962,
           0.08418731130237875,
           0.07010183827093616,
           0.054541276561040686,
           0.03759772656874239,
           0.019407660252202565,
           0.0001569493213448689,
           -0.019915691575644292,
           -0.040517266401149735,
           -0.061301442485772274,
           -0.08187218787401292,
           -0.10179031338845618,
           -0.12058300781296416,
           -0.1377563081818195,
           -0.1528102839666787,
           -0.16525654180237792,
           -0.17463748569481502,
           -0.18054660691367944,
           -0.18264893898060253,
           -0.1807007071005138,
           -0.17456713788189782,
           -0.1642373823959323,
           -0.14983554931501694,
           -0.1316269478872783,
           -0.11001880232017779,
           -0.08555491563889543,
           -0.05890402451081101,
           -0.030841885736018544,
           -0.0022274559793407315,
           0.026026147564044762,
           0.05298490441364873,
           0.07773008237271903
          ],
          [
           0.11526115097856117,
           0.09738828403656238,
           0.0759235678781371,
           0.05161237775613617,
           0.025275083284098894,
           -0.0022274559793407315,
           -0.03002807965783915,
           -0.0572857273340844,
           -0.08321475815193494,
           -0.10711012813756442,
           -0.1283676319466868,
           -0.1464987033293174,
           -0.16113955966514656,
           -0.17205475511311313,
           -0.17913546063850083,
           -0.18239300622958532,
           -0.18194839266053625,
           -0.17801860199902664,
           -0.17090060569317098,
           -0.1609539875623888,
           -0.14858307017251748,
           -0.13421936300715656,
           -0.11830504740258321,
           -0.10127808535368477,
           -0.08355939645450051,
           -0.06554239869174844,
           -0.04758506314163741,
           -0.030004497243790427,
           -0.013073952151520388,
           0.0029779491154211806,
           0.017966041941118966,
           0.031745840459068614,
           0.044209509361482956,
           0.05528095770522729,
           0.0649104168254659,
           0.07306884206017318,
           0.07974244535617742,
           0.08492762656935865,
           0.08862652853638416,
           0.09084339726921295,
           0.09158188560927924,
           0.09084339726921295,
           0.08862652853638416,
           0.08492762656935865,
           0.07974244535617742,
           0.07306884206017318,
           0.0649104168254659,
           0.05528095770522729,
           0.044209509361482956,
           0.031745840459068614,
           0.017966041941118966,
           0.0029779491154211806,
           -0.013073952151520388,
           -0.030004497243790427,
           -0.04758506314163741,
           -0.06554239869174844,
           -0.08355939645450051,
           -0.10127808535368477,
           -0.11830504740258321,
           -0.13421936300715656,
           -0.14858307017251748,
           -0.1609539875623888,
           -0.17090060569317098,
           -0.17801860199902664,
           -0.18194839266053625,
           -0.18239300622958532,
           -0.17913546063850083,
           -0.17205475511311313,
           -0.16113955966514656,
           -0.1464987033293174,
           -0.1283676319466868,
           -0.10711012813756442,
           -0.08321475815193494,
           -0.0572857273340844,
           -0.03002807965783915,
           -0.0022274559793407315,
           0.025275083284098894,
           0.05161237775613617,
           0.0759235678781371,
           0.09738828403656238
          ],
          [
           0.12777380562398274,
           0.11405907878471819,
           0.09636827159298987,
           0.07531659368730659,
           0.05161237775613617,
           0.026026147564044762,
           -0.0006409754282528475,
           -0.027588123185645037,
           -0.054043516875550875,
           -0.07929019757294747,
           -0.10268778525178764,
           -0.12368964794720452,
           -0.14185512230149663,
           -0.15685668268767797,
           -0.16848219583369567,
           -0.17663261032673944,
           -0.18131560690315682,
           -0.1826358700412797,
           -0.18078273088932142,
           -0.1760159755489718,
           -0.16865061331126227,
           -0.15904136091487175,
           -0.14756752732225356,
           -0.13461888616197776,
           -0.12058300781296416,
           -0.10583439818051152,
           -0.0907256642328181,
           -0.07558080422426758,
           -0.060690608986011814,
           -0.046310064114579955,
           -0.032657564269347995,
           -0.019915691575644292,
           -0.00823327044894154,
           0.0022716100207446164,
           0.011507919583092052,
           0.019407660252202565,
           0.025921773001301992,
           0.031016232090896562,
           0.03466854669458865,
           0.03686485131708162,
           0.03759772656874239,
           0.03686485131708162,
           0.03466854669458865,
           0.031016232090896562,
           0.025921773001301992,
           0.019407660252202565,
           0.011507919583092052,
           0.0022716100207446164,
           -0.00823327044894154,
           -0.019915691575644292,
           -0.032657564269347995,
           -0.046310064114579955,
           -0.060690608986011814,
           -0.07558080422426758,
           -0.0907256642328181,
           -0.10583439818051152,
           -0.12058300781296416,
           -0.13461888616197776,
           -0.14756752732225356,
           -0.15904136091487175,
           -0.16865061331126227,
           -0.1760159755489718,
           -0.18078273088932142,
           -0.1826358700412797,
           -0.18131560690315682,
           -0.17663261032673944,
           -0.16848219583369567,
           -0.15685668268767797,
           -0.14185512230149663,
           -0.12368964794720452,
           -0.10268778525178764,
           -0.07929019757294747,
           -0.054043516875550875,
           -0.027588123185645037,
           -0.0006409754282528475,
           0.026026147564044762,
           0.05161237775613617,
           0.07531659368730659,
           0.09636827159298987,
           0.11405907878471819
          ],
          [
           0.13650222610828716,
           0.12719030582037316,
           0.1136526088802527,
           0.09636827159298987,
           0.0759235678781371,
           0.05298490441364873,
           0.028270310898122826,
           0.0025207381574719806,
           -0.023527608249201665,
           -0.04916880920228074,
           -0.07374973820785838,
           -0.09668883252747353,
           -0.11749065565570795,
           -0.13575600794040762,
           -0.1511875643863488,
           -0.163591222139663,
           -0.17287351607260817,
           -0.17903560277058095,
           -0.1821644169794075,
           -0.18242166855756492,
           -0.1800313728705813,
           -0.1752665961050691,
           -0.16843605361995675,
           -0.15987112992755653,
           -0.1499137997580331,
           -0.13890582780165694,
           -0.1271795169340972,
           -0.11505016730310495,
           -0.10281030706494565,
           -0.0907256642328181,
           -0.07903277128303789,
           -0.06793803188546253,
           -0.05761803324395176,
           -0.04822085787410071,
           -0.039868134180728126,
           -0.032657564269347995,
           -0.026665677985416577,
           -0.021950582012676394,
           -0.01855449981019833,
           -0.016505930263581485,
           -0.015821288518275644,
           -0.016505930263581485,
           -0.01855449981019833,
           -0.021950582012676394,
           -0.026665677985416577,
           -0.032657564269347995,
           -0.039868134180728126,
           -0.04822085787410071,
           -0.05761803324395176,
           -0.06793803188546253,
           -0.07903277128303789,
           -0.0907256642328181,
           -0.10281030706494565,
           -0.11505016730310495,
           -0.1271795169340972,
           -0.13890582780165694,
           -0.1499137997580331,
           -0.15987112992755653,
           -0.16843605361995675,
           -0.1752665961050691,
           -0.1800313728705813,
           -0.18242166855756492,
           -0.1821644169794075,
           -0.17903560277058095,
           -0.17287351607260817,
           -0.163591222139663,
           -0.1511875643863488,
           -0.13575600794040762,
           -0.11749065565570795,
           -0.09668883252747353,
           -0.07374973820785838,
           -0.04916880920228074,
           -0.023527608249201665,
           0.0025207381574719806,
           0.028270310898122826,
           0.05298490441364873,
           0.0759235678781371,
           0.09636827159298987,
           0.1136526088802527,
           0.12719030582037316
          ],
          [
           0.14111903500315878,
           0.13632396086944565,
           0.12719030582037316,
           0.11405907878471819,
           0.09738828403656238,
           0.07773008237271903,
           0.05570574218106777,
           0.03197958453286062,
           0.007233082355737275,
           -0.017859822184363938,
           -0.042655257000177006,
           -0.06655906279410359,
           -0.08904297911487404,
           -0.10965701691843574,
           -0.12803786284735597,
           -0.14391335124448024,
           -0.15710321083861073,
           -0.16751643729146143,
           -0.1751457556394694,
           -0.1800597155006458,
           -0.18239300622958532,
           -0.18233559039097344,
           -0.18012123502583363,
           -0.1760159755489718,
           -0.17030698199702413,
           -0.16329221750830802,
           -0.15527119023634722,
           -0.14653700801271363,
           -0.13736985507049018,
           -0.12803192632998142,
           -0.11876378051842666,
           -0.10978201113265723,
           -0.10127808535368477,
           -0.09341816596346665,
           -0.08634370978474622,
           -0.08017262722723162,
           -0.0750007897964791,
           -0.07090368426500879,
           -0.06793803188546253,
           -0.06614321685638791,
           -0.06554239869174844,
           -0.06614321685638791,
           -0.06793803188546253,
           -0.07090368426500879,
           -0.0750007897964791,
           -0.08017262722723162,
           -0.08634370978474622,
           -0.09341816596346665,
           -0.10127808535368477,
           -0.10978201113265723,
           -0.11876378051842666,
           -0.12803192632998142,
           -0.13736985507049018,
           -0.14653700801271363,
           -0.15527119023634722,
           -0.16329221750830802,
           -0.17030698199702413,
           -0.1760159755489718,
           -0.18012123502583363,
           -0.18233559039097344,
           -0.18239300622958532,
           -0.1800597155006458,
           -0.1751457556394694,
           -0.16751643729146143,
           -0.15710321083861073,
           -0.14391335124448024,
           -0.12803786284735597,
           -0.10965701691843574,
           -0.08904297911487404,
           -0.06655906279410359,
           -0.042655257000177006,
           -0.017859822184363938,
           0.007233082355737275,
           0.03197958453286062,
           0.05570574218106777,
           0.07773008237271903,
           0.09738828403656238,
           0.11405907878471819,
           0.12719030582037316,
           0.13632396086944565
          ]
         ],
         "zmax": null,
         "zmin": null
        }
       ],
       "layout": {
        "legend": {
         "bgcolor": "#F5F6F9",
         "font": {
          "color": "#4D5663"
         }
        },
        "paper_bgcolor": "#F5F6F9",
        "plot_bgcolor": "#F5F6F9",
        "titlefont": {
         "color": "#4D5663"
        },
        "xaxis1": {
         "gridcolor": "#E1E5ED",
         "showgrid": true,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        },
        "yaxis1": {
         "gridcolor": "#E1E5ED",
         "showgrid": true,
         "tickfont": {
          "color": "#4D5663"
         },
         "title": "",
         "titlefont": {
          "color": "#4D5663"
         },
         "zerolinecolor": "#E1E5ED"
        }
       }
      },
      "text/html": [
       "<div id=\"5a71391d-7d6c-4d80-b22d-ecf4c4f63824\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"5a71391d-7d6c-4d80-b22d-ecf4c4f63824\", [{\"type\": \"surface\", \"z\": [[0.14141961054935853, 0.14111903500315878, 0.13650222610828716, 0.12777380562398274, 0.11526115097856117, 0.0993958462307399, 0.08069235790121831, 0.059725017515438364, 0.037104384846577534, 0.013454008098850966, -0.01061150357619211, -0.0345063152690242, -0.05769048962428924, -0.07968395387291566, -0.10007704610444179, -0.11853755153953284, -0.13481430178982187, -0.1487375524385824, -0.16021647158282734, -0.16923416092386775, -0.17584069010379264, -0.1801446545297837, -0.18230376872794093, -0.18251498442862385, -0.18100457917857166, -0.17801860199902664, -0.1738139924448547, -0.16865061331126227, -0.16278435980926842, -0.15646143337355978, -0.1499137997580331, -0.14335579129849668, -0.13698176393514344, -0.13096468174943518, -0.1254554756233313, -0.12058300781296416, -0.1164544699167505, -0.1131560467581887, -0.1107536917561867, -0.10929387900894774, -0.10880422217787396, -0.10929387900894774, -0.1107536917561867, -0.1131560467581887, -0.1164544699167505, -0.12058300781296416, -0.1254554756233313, -0.13096468174943518, -0.13698176393514344, -0.14335579129849668, -0.1499137997580331, -0.15646143337355978, -0.16278435980926842, -0.16865061331126227, -0.1738139924448547, -0.17801860199902664, -0.18100457917857166, -0.18251498442862385, -0.18230376872794093, -0.1801446545297837, -0.17584069010379264, -0.16923416092386775, -0.16021647158282734, -0.1487375524385824, -0.13481430178982187, -0.11853755153953284, -0.10007704610444179, -0.07968395387291566, -0.05769048962428924, -0.0345063152690242, -0.01061150357619211, 0.013454008098850966, 0.037104384846577534, 0.059725017515438364, 0.08069235790121831, 0.0993958462307399, 0.11526115097856117, 0.12777380562398274, 0.13650222610828716, 0.14111903500315878], [0.14111903500315878, 0.13632396086944565, 0.12719030582037316, 0.11405907878471819, 0.09738828403656238, 0.07773008237271903, 0.05570574218106777, 0.03197958453286062, 0.007233082355737275, -0.017859822184363938, -0.042655257000177006, -0.06655906279410359, -0.08904297911487404, -0.10965701691843574, -0.12803786284735597, -0.14391335124448024, -0.15710321083861073, -0.16751643729146143, -0.1751457556394694, -0.1800597155006458, -0.18239300622958532, -0.18233559039097344, -0.18012123502583363, -0.1760159755489718, -0.17030698199702413, -0.16329221750830802, -0.15527119023634722, -0.14653700801271363, -0.13736985507049018, -0.12803192632998142, -0.11876378051842666, -0.10978201113265723, -0.10127808535368477, -0.09341816596346665, -0.08634370978474622, -0.08017262722723162, -0.0750007897964791, -0.07090368426500879, -0.06793803188546253, -0.06614321685638791, -0.06554239869174844, -0.06614321685638791, -0.06793803188546253, -0.07090368426500879, -0.0750007897964791, -0.08017262722723162, -0.08634370978474622, -0.09341816596346665, -0.10127808535368477, -0.10978201113265723, -0.11876378051842666, -0.12803192632998142, -0.13736985507049018, -0.14653700801271363, -0.15527119023634722, -0.16329221750830802, -0.17030698199702413, -0.1760159755489718, -0.18012123502583363, -0.18233559039097344, -0.18239300622958532, -0.1800597155006458, -0.1751457556394694, -0.16751643729146143, -0.15710321083861073, -0.14391335124448024, -0.12803786284735597, -0.10965701691843574, -0.08904297911487404, -0.06655906279410359, -0.042655257000177006, -0.017859822184363938, 0.007233082355737275, 0.03197958453286062, 0.05570574218106777, 0.07773008237271903, 0.09738828403656238, 0.11405907878471819, 0.12719030582037316, 0.13632396086944565], [0.13650222610828716, 0.12719030582037316, 0.1136526088802527, 0.09636827159298987, 0.0759235678781371, 0.05298490441364873, 0.028270310898122826, 0.0025207381574719806, -0.023527608249201665, -0.04916880920228074, -0.07374973820785838, -0.09668883252747353, -0.11749065565570795, -0.13575600794040762, -0.1511875643863488, -0.163591222139663, -0.17287351607260817, -0.17903560277058095, -0.1821644169794075, -0.18242166855756492, -0.1800313728705813, -0.1752665961050691, -0.16843605361995675, -0.15987112992755653, -0.1499137997580331, -0.13890582780165694, -0.1271795169340972, -0.11505016730310495, -0.10281030706494565, -0.0907256642328181, -0.07903277128303789, -0.06793803188546253, -0.05761803324395176, -0.04822085787410071, -0.039868134180728126, -0.032657564269347995, -0.026665677985416577, -0.021950582012676394, -0.01855449981019833, -0.016505930263581485, -0.015821288518275644, -0.016505930263581485, -0.01855449981019833, -0.021950582012676394, -0.026665677985416577, -0.032657564269347995, -0.039868134180728126, -0.04822085787410071, -0.05761803324395176, -0.06793803188546253, -0.07903277128303789, -0.0907256642328181, -0.10281030706494565, -0.11505016730310495, -0.1271795169340972, -0.13890582780165694, -0.1499137997580331, -0.15987112992755653, -0.16843605361995675, -0.1752665961050691, -0.1800313728705813, -0.18242166855756492, -0.1821644169794075, -0.17903560277058095, -0.17287351607260817, -0.163591222139663, -0.1511875643863488, -0.13575600794040762, -0.11749065565570795, -0.09668883252747353, -0.07374973820785838, -0.04916880920228074, -0.023527608249201665, 0.0025207381574719806, 0.028270310898122826, 0.05298490441364873, 0.0759235678781371, 0.09636827159298987, 0.1136526088802527, 0.12719030582037316], [0.12777380562398274, 0.11405907878471819, 0.09636827159298987, 0.07531659368730659, 0.05161237775613617, 0.026026147564044762, -0.0006409754282528475, -0.027588123185645037, -0.054043516875550875, -0.07929019757294747, -0.10268778525178764, -0.12368964794720452, -0.14185512230149663, -0.15685668268767797, -0.16848219583369567, -0.17663261032673944, -0.18131560690315682, -0.1826358700412797, -0.18078273088932142, -0.1760159755489718, -0.16865061331126227, -0.15904136091487175, -0.14756752732225356, -0.13461888616197776, -0.12058300781296416, -0.10583439818051152, -0.0907256642328181, -0.07558080422426758, -0.060690608986011814, -0.046310064114579955, -0.032657564269347995, -0.019915691575644292, -0.00823327044894154, 0.0022716100207446164, 0.011507919583092052, 0.019407660252202565, 0.025921773001301992, 0.031016232090896562, 0.03466854669458865, 0.03686485131708162, 0.03759772656874239, 0.03686485131708162, 0.03466854669458865, 0.031016232090896562, 0.025921773001301992, 0.019407660252202565, 0.011507919583092052, 0.0022716100207446164, -0.00823327044894154, -0.019915691575644292, -0.032657564269347995, -0.046310064114579955, -0.060690608986011814, -0.07558080422426758, -0.0907256642328181, -0.10583439818051152, -0.12058300781296416, -0.13461888616197776, -0.14756752732225356, -0.15904136091487175, -0.16865061331126227, -0.1760159755489718, -0.18078273088932142, -0.1826358700412797, -0.18131560690315682, -0.17663261032673944, -0.16848219583369567, -0.15685668268767797, -0.14185512230149663, -0.12368964794720452, -0.10268778525178764, -0.07929019757294747, -0.054043516875550875, -0.027588123185645037, -0.0006409754282528475, 0.026026147564044762, 0.05161237775613617, 0.07531659368730659, 0.09636827159298987, 0.11405907878471819], [0.11526115097856117, 0.09738828403656238, 0.0759235678781371, 0.05161237775613617, 0.025275083284098894, -0.0022274559793407315, -0.03002807965783915, -0.0572857273340844, -0.08321475815193494, -0.10711012813756442, -0.1283676319466868, -0.1464987033293174, -0.16113955966514656, -0.17205475511311313, -0.17913546063850083, -0.18239300622958532, -0.18194839266053625, -0.17801860199902664, -0.17090060569317098, -0.1609539875623888, -0.14858307017251748, -0.13421936300715656, -0.11830504740258321, -0.10127808535368477, -0.08355939645450051, -0.06554239869174844, -0.04758506314163741, -0.030004497243790427, -0.013073952151520388, 0.0029779491154211806, 0.017966041941118966, 0.031745840459068614, 0.044209509361482956, 0.05528095770522729, 0.0649104168254659, 0.07306884206017318, 0.07974244535617742, 0.08492762656935865, 0.08862652853638416, 0.09084339726921295, 0.09158188560927924, 0.09084339726921295, 0.08862652853638416, 0.08492762656935865, 0.07974244535617742, 0.07306884206017318, 0.0649104168254659, 0.05528095770522729, 0.044209509361482956, 0.031745840459068614, 0.017966041941118966, 0.0029779491154211806, -0.013073952151520388, -0.030004497243790427, -0.04758506314163741, -0.06554239869174844, -0.08355939645450051, -0.10127808535368477, -0.11830504740258321, -0.13421936300715656, -0.14858307017251748, -0.1609539875623888, -0.17090060569317098, -0.17801860199902664, -0.18194839266053625, -0.18239300622958532, -0.17913546063850083, -0.17205475511311313, -0.16113955966514656, -0.1464987033293174, -0.1283676319466868, -0.10711012813756442, -0.08321475815193494, -0.0572857273340844, -0.03002807965783915, -0.0022274559793407315, 0.025275083284098894, 0.05161237775613617, 0.0759235678781371, 0.09738828403656238], [0.0993958462307399, 0.07773008237271903, 0.05298490441364873, 0.026026147564044762, -0.0022274559793407315, -0.030841885736018544, -0.05890402451081101, -0.08555491563889543, -0.11001880232017779, -0.1316269478872783, -0.14983554931501694, -0.1642373823959323, -0.17456713788189782, -0.1807007071005138, -0.18264893898060253, -0.18054660691367944, -0.17463748569481502, -0.16525654180237792, -0.1528102839666787, -0.1377563081818195, -0.12058300781296416, -0.10179031338845618, -0.08187218787401292, -0.061301442485772274, -0.040517266401149735, -0.019915691575644292, 0.0001569493213448689, 0.019407660252202565, 0.03759772656874239, 0.054541276561040686, 0.07010183827093616, 0.08418731130237875, 0.09674378883254962, 0.10774865812501504, 0.11720338291232232, 0.12512633286074154, 0.13154597877649798, 0.13649472168344115, 0.14000357308347133, 0.14209785531573388, 0.14279404657238684, 0.14209785531573388, 0.14000357308347133, 0.13649472168344115, 0.13154597877649798, 0.12512633286074154, 0.11720338291232232, 0.10774865812501504, 0.09674378883254962, 0.08418731130237875, 0.07010183827093616, 0.054541276561040686, 0.03759772656874239, 0.019407660252202565, 0.0001569493213448689, -0.019915691575644292, -0.040517266401149735, -0.061301442485772274, -0.08187218787401292, -0.10179031338845618, -0.12058300781296416, -0.1377563081818195, -0.1528102839666787, -0.16525654180237792, -0.17463748569481502, -0.18054660691367944, -0.18264893898060253, -0.1807007071005138, -0.17456713788189782, -0.1642373823959323, -0.14983554931501694, -0.1316269478872783, -0.11001880232017779, -0.08555491563889543, -0.05890402451081101, -0.030841885736018544, -0.0022274559793407315, 0.026026147564044762, 0.05298490441364873, 0.07773008237271903], [0.08069235790121831, 0.05570574218106777, 0.028270310898122826, -0.0006409754282528475, -0.03002807965783915, -0.05890402451081101, -0.08633239590937543, -0.1114606806231028, -0.13354819579908725, -0.15198770280837584, -0.16632015713858264, -0.17624240938958516, -0.18160802037610754, -0.18242166855756492, -0.1788278960809016, -0.17109514979541934, -0.15959621882048483, -0.14478624788034108, -0.1271795169340972, -0.10732612754693129, -0.0857896329957062, -0.0631265026963309, -0.039868134180728126, -0.016505930263581485, 0.0065202421682302655, 0.02883009042098063, 0.05010748884225075, 0.07010183827093616, 0.08862652853638416, 0.10555493165712146, 0.12081441070397907, 0.13437885433763305, 0.14626024334832619, 0.15649972810645998, 0.16515865057394133, 0.17230988766358785, 0.17802983029511174, 0.18239124981424537, 0.18545724476618586, 0.18727640924644018, 0.18787932061729182, 0.18727640924644018, 0.18545724476618586, 0.18239124981424537, 0.17802983029511174, 0.17230988766358785, 0.16515865057394133, 0.15649972810645998, 0.14626024334832619, 0.13437885433763305, 0.12081441070397907, 0.10555493165712146, 0.08862652853638416, 0.07010183827093616, 0.05010748884225075, 0.02883009042098063, 0.0065202421682302655, -0.016505930263581485, -0.039868134180728126, -0.0631265026963309, -0.0857896329957062, -0.10732612754693129, -0.1271795169340972, -0.14478624788034108, -0.15959621882048483, -0.17109514979541934, -0.1788278960809016, -0.18242166855756492, -0.18160802037610754, -0.17624240938958516, -0.16632015713858264, -0.15198770280837584, -0.13354819579908725, -0.1114606806231028, -0.08633239590937543, -0.05890402451081101, -0.03002807965783915, -0.0006409754282528475, 0.028270310898122826, 0.05570574218106777], [0.059725017515438364, 0.03197958453286062, 0.0025207381574719806, -0.027588123185645037, -0.0572857273340844, -0.08555491563889543, -0.1114606806231028, -0.13418273806183595, -0.15304146672549196, -0.16751643729146143, -0.17725715646546372, -0.18208605074549258, -0.18199408570471504, -0.17712974307464055, -0.16778234479339135, -0.1543609103022869, -0.13736985507049018, -0.11738288358628372, -0.0950164022704569, -0.07090368426500879, -0.045670869380806056, -0.019915691575644292, 0.0058103924762656495, 0.031016232090896562, 0.05528095770522729, 0.07825990831739421, 0.09968670899986165, 0.11937185506223688, 0.13719827990417027, 0.15311446345017118, 0.16712567793535366, 0.1792839709402817, 0.18967745729212915, 0.19841943861188654, 0.20563779959612533, 0.21146505144444128, 0.21602931256266372, 0.21944644111666822, 0.22181346801290225, 0.2232034254780841, 0.22366162672468853, 0.2232034254780841, 0.22181346801290225, 0.21944644111666822, 0.21602931256266372, 0.21146505144444128, 0.20563779959612533, 0.19841943861188654, 0.18967745729212915, 0.1792839709402817, 0.16712567793535366, 0.15311446345017118, 0.13719827990417027, 0.11937185506223688, 0.09968670899986165, 0.07825990831739421, 0.05528095770522729, 0.031016232090896562, 0.0058103924762656495, -0.019915691575644292, -0.045670869380806056, -0.07090368426500879, -0.0950164022704569, -0.11738288358628372, -0.13736985507049018, -0.1543609103022869, -0.16778234479339135, -0.17712974307464055, -0.18199408570471504, -0.18208605074549258, -0.17725715646546372, -0.16751643729146143, -0.15304146672549196, -0.13418273806183595, -0.1114606806231028, -0.08555491563889543, -0.0572857273340844, -0.027588123185645037, 0.0025207381574719806, 0.03197958453286062], [0.037104384846577534, 0.007233082355737275, -0.023527608249201665, -0.054043516875550875, -0.08321475815193494, -0.11001880232017779, -0.13354819579908725, -0.15304146672549196, -0.167906160972842, -0.17773339606034183, -0.18230376872794093, -0.18158488243001691, -0.17572115154133375, -0.16501687105976595, -0.1499137997580331, -0.13096468174943518, -0.10880422217787396, -0.08411903827788304, -0.05761803324395176, -0.030004497243790427, -0.001951040868825416, 0.025921773001301992, 0.05306249567952219, 0.07900122348247962, 0.10335731863015635, 0.1258425822940911, 0.14626024334832619, 0.16450028494360933, 0.18053174205108255, 0.1943926655354523, 0.2061784643801796, 0.21602931256266372, 0.22411724822563847, 0.23063350923189954, 0.23577655069724138, 0.23974108638511749, 0.242708395806646, 0.24483804991090946, 0.24626113579560338, 0.24707500803079696, 0.24733956165584545, 0.24707500803079696, 0.24626113579560338, 0.24483804991090946, 0.242708395806646, 0.23974108638511749, 0.23577655069724138, 0.23063350923189954, 0.22411724822563847, 0.21602931256266372, 0.2061784643801796, 0.1943926655354523, 0.18053174205108255, 0.16450028494360933, 0.14626024334832619, 0.1258425822940911, 0.10335731863015635, 0.07900122348247962, 0.05306249567952219, 0.025921773001301992, -0.001951040868825416, -0.030004497243790427, -0.05761803324395176, -0.08411903827788304, -0.10880422217787396, -0.13096468174943518, -0.1499137997580331, -0.16501687105976595, -0.17572115154133375, -0.18158488243001691, -0.18230376872794093, -0.17773339606034183, -0.167906160972842, -0.15304146672549196, -0.13354819579908725, -0.11001880232017779, -0.08321475815193494, -0.054043516875550875, -0.023527608249201665, 0.007233082355737275], [0.013454008098850966, -0.017859822184363938, -0.04916880920228074, -0.07929019757294747, -0.10711012813756442, -0.1316269478872783, -0.15198770280837584, -0.16751643729146143, -0.17773339606034183, -0.18236471957976835, -0.18134271385500067, -0.1747972342928682, -0.16303912773542587, -0.14653700801271363, -0.1258888846262905, -0.10179031338845618, -0.0750007897964791, -0.046310064114579955, -0.016505930263581485, 0.013655158230898757, 0.043473546354522816, 0.07232710218505171, 0.09968670899986165, 0.12512633286074154, 0.14832776112580212, 0.16908036038891633, 0.18727640924644018, 0.20290271423033404, 0.21602931256266372, 0.22679610352037188, 0.23539823538075702, 0.2420710146043941, 0.24707500803079696, 0.2506818889186662, 0.2531614457800734, 0.25477004091850136, 0.2557406839380664, 0.2562747828163765, 0.25653555744366946, 0.2566430509401283, 0.2566706526738519, 0.2566430509401283, 0.25653555744366946, 0.2562747828163765, 0.2557406839380664, 0.25477004091850136, 0.2531614457800734, 0.2506818889186662, 0.24707500803079696, 0.2420710146043941, 0.23539823538075702, 0.22679610352037188, 0.21602931256266372, 0.20290271423033404, 0.18727640924644018, 0.16908036038891633, 0.14832776112580212, 0.12512633286074154, 0.09968670899986165, 0.07232710218505171, 0.043473546354522816, 0.013655158230898757, -0.016505930263581485, -0.046310064114579955, -0.0750007897964791, -0.10179031338845618, -0.1258888846262905, -0.14653700801271363, -0.16303912773542587, -0.1747972342928682, -0.18134271385500067, -0.18236471957976835, -0.17773339606034183, -0.16751643729146143, -0.15198770280837584, -0.1316269478872783, -0.10711012813756442, -0.07929019757294747, -0.04916880920228074, -0.017859822184363938], [-0.01061150357619211, -0.042655257000177006, -0.07374973820785838, -0.10268778525178764, -0.1283676319466868, -0.14983554931501694, -0.16632015713858264, -0.17725715646546372, -0.18230376872794093, -0.18134271385500067, -0.17447608825271163, -0.16200998595397612, -0.14443111863131364, -0.12237701362727325, -0.09660159075517502, -0.06793803188546253, -0.03726086233570953, -0.005449066140771361, 0.026648129724923395, 0.058241427706856384, 0.08862652853638416, 0.11720338291232232, 0.14348926836260514, 0.16712567793535366, 0.18787932061729182, 0.20563779959612533, 0.22040074178662336, 0.23226729318028777, 0.24142096714711753, 0.24811283911536614, 0.25264402764959015, 0.255348298963932, 0.256575492104657, 0.2566762997375786, 0.2559887694405144, 0.2548267267047997, 0.25347017586536014, 0.252157618714697, 0.25108014921898075, 0.25037713957121355, 0.25013332713993036, 0.25037713957121355, 0.25108014921898075, 0.252157618714697, 0.25347017586536014, 0.2548267267047997, 0.2559887694405144, 0.2566762997375786, 0.256575492104657, 0.255348298963932, 0.25264402764959015, 0.24811283911536614, 0.24142096714711753, 0.23226729318028777, 0.22040074178662336, 0.20563779959612533, 0.18787932061729182, 0.16712567793535366, 0.14348926836260514, 0.11720338291232232, 0.08862652853638416, 0.058241427706856384, 0.026648129724923395, -0.005449066140771361, -0.03726086233570953, -0.06793803188546253, -0.09660159075517502, -0.12237701362727325, -0.14443111863131364, -0.16200998595397612, -0.17447608825271163, -0.18134271385500067, -0.18230376872794093, -0.17725715646546372, -0.16632015713858264, -0.14983554931501694, -0.1283676319466868, -0.10268778525178764, -0.07374973820785838, -0.042655257000177006], [-0.0345063152690242, -0.06655906279410359, -0.09668883252747353, -0.12368964794720452, -0.1464987033293174, -0.1642373823959323, -0.17624240938958516, -0.18208605074549258, -0.18158488243001691, -0.1747972342928682, -0.16200998595397612, -0.1437158894806465, -0.12058300781296416, -0.09341816596346665, -0.0631265026963309, -0.03066927919323432, 0.0029779491154211806, 0.03686485131708162, 0.07010183827093616, 0.1018902143955224, 0.13154597877649798, 0.15851669454452746, 0.18239124981424537, 0.20290271423033404, 0.21992483146863692, 0.23346296309158113, 0.24364050109720906, 0.2506818889186662, 0.254893432701845, 0.2566430509401283, 0.2563400102730029, 0.25441554164532254, 0.25130504004127213, 0.24743234013685533, 0.2431963471432226, 0.23896010343988033, 0.23504220166614895, 0.2317103248693539, 0.22917661128094333, 0.22759450814784551, 0.2270567942100705, 0.22759450814784551, 0.22917661128094333, 0.2317103248693539, 0.23504220166614895, 0.23896010343988033, 0.2431963471432226, 0.24743234013685533, 0.25130504004127213, 0.25441554164532254, 0.2563400102730029, 0.2566430509401283, 0.254893432701845, 0.2506818889186662, 0.24364050109720906, 0.23346296309158113, 0.21992483146863692, 0.20290271423033404, 0.18239124981424537, 0.15851669454452746, 0.13154597877649798, 0.1018902143955224, 0.07010183827093616, 0.03686485131708162, 0.0029779491154211806, -0.03066927919323432, -0.0631265026963309, -0.09341816596346665, -0.12058300781296416, -0.1437158894806465, -0.16200998595397612, -0.1747972342928682, -0.18158488243001691, -0.18208605074549258, -0.17624240938958516, -0.1642373823959323, -0.1464987033293174, -0.12368964794720452, -0.09668883252747353, -0.06655906279410359], [-0.05769048962428924, -0.08904297911487404, -0.11749065565570795, -0.14185512230149663, -0.16113955966514656, -0.17456713788189782, -0.18160802037610754, -0.18199408570471504, -0.17572115154133375, -0.16303912773542587, -0.14443111863131364, -0.12058300781296416, -0.09234546620178369, -0.060690608986011814, -0.026665677985416577, 0.008653858363151095, 0.044209509361482956, 0.07900122348247962, 0.11212338767979044, 0.14279404657238684, 0.17037647050011584, 0.1943926655354523, 0.2145288714461612, 0.23063350923189954, 0.242708395806646, 0.2508943222213973, 0.2554522819126627, 0.2567417315441088, 0.25519727019112654, 0.25130504004127213, 0.2455799958764798, 0.23854497801642713, 0.23071227369415245, 0.2225680860000738, 0.21456006847846779, 0.2070878465419809, 0.20049625055173417, 0.19507084218595108, 0.19103523332295086, 0.18854967763954522, 0.18771045677679687, 0.18854967763954522, 0.19103523332295086, 0.19507084218595108, 0.20049625055173417, 0.2070878465419809, 0.21456006847846779, 0.2225680860000738, 0.23071227369415245, 0.23854497801642713, 0.2455799958764798, 0.25130504004127213, 0.25519727019112654, 0.2567417315441088, 0.2554522819126627, 0.2508943222213973, 0.242708395806646, 0.23063350923189954, 0.2145288714461612, 0.1943926655354523, 0.17037647050011584, 0.14279404657238684, 0.11212338767979044, 0.07900122348247962, 0.044209509361482956, 0.008653858363151095, -0.026665677985416577, -0.060690608986011814, -0.09234546620178369, -0.12058300781296416, -0.14443111863131364, -0.16303912773542587, -0.17572115154133375, -0.18199408570471504, -0.18160802037610754, -0.17456713788189782, -0.16113955966514656, -0.14185512230149663, -0.11749065565570795, -0.08904297911487404], [-0.07968395387291566, -0.10965701691843574, -0.13575600794040762, -0.15685668268767797, -0.17205475511311313, -0.1807007071005138, -0.18242166855756492, -0.17712974307464055, -0.16501687105976595, -0.14653700801271363, -0.12237701362727325, -0.09341816596346665, -0.060690608986011814, -0.02532329427921568, 0.011507919583092052, 0.04863139306208121, 0.08492762656935865, 0.11937185506223688, 0.15106960365711752, 0.1792839709402817, 0.20345392533496165, 0.2232034254780841, 0.2383416766936446, 0.24885528388828942, 0.254893432701845, 0.25674750760048576, 0.2548267267047997, 0.24963143467045815, 0.24172565029557566, 0.2317103248693539, 0.22019854657881394, 0.20779364608280457, 0.19507084218595108, 0.18256273925541686, 0.17074867404778504, 0.16004763127913005, 0.15081422331281308, 0.1433370736825879, 0.13783886506830845, 0.134477311926808, 0.1333463922312941, 0.134477311926808, 0.13783886506830845, 0.1433370736825879, 0.15081422331281308, 0.16004763127913005, 0.17074867404778504, 0.18256273925541686, 0.19507084218595108, 0.20779364608280457, 0.22019854657881394, 0.2317103248693539, 0.24172565029557566, 0.24963143467045815, 0.2548267267047997, 0.25674750760048576, 0.254893432701845, 0.24885528388828942, 0.2383416766936446, 0.2232034254780841, 0.20345392533496165, 0.1792839709402817, 0.15106960365711752, 0.11937185506223688, 0.08492762656935865, 0.04863139306208121, 0.011507919583092052, -0.02532329427921568, -0.060690608986011814, -0.09341816596346665, -0.12237701362727325, -0.14653700801271363, -0.16501687105976595, -0.17712974307464055, -0.18242166855756492, -0.1807007071005138, -0.17205475511311313, -0.15685668268767797, -0.13575600794040762, -0.10965701691843574], [-0.10007704610444179, -0.12803786284735597, -0.1511875643863488, -0.16848219583369567, -0.17913546063850083, -0.18264893898060253, -0.1788278960809016, -0.16778234479339135, -0.1499137997580331, -0.1258888846262905, -0.09660159075517502, -0.0631265026963309, -0.026665677985416577, 0.011507919583092052, 0.05010748884225075, 0.0878871354792479, 0.12369173187889267, 0.15649972810645998, 0.18545724476618586, 0.20990234059772522, 0.22937894091767205, 0.24364050109720906, 0.25264402764959015, 0.25653555744366946, 0.25562857790064414, 0.25037713957121355, 0.2413455569066888, 0.22917661128094333, 0.21456006847846779, 0.1982031145119569, 0.18080401871815463, 0.1630299764243758, 0.14549969299473817, 0.12877087581897034, 0.11333242903336226, 0.09960082298540655, 0.08791985781076668, 0.07856287339249271, 0.07173638515428266, 0.06758414818694233, 0.0661907655654817, 0.06758414818694233, 0.07173638515428266, 0.07856287339249271, 0.08791985781076668, 0.09960082298540655, 0.11333242903336226, 0.12877087581897034, 0.14549969299473817, 0.1630299764243758, 0.18080401871815463, 0.1982031145119569, 0.21456006847846779, 0.22917661128094333, 0.2413455569066888, 0.25037713957121355, 0.25562857790064414, 0.25653555744366946, 0.25264402764959015, 0.24364050109720906, 0.22937894091767205, 0.20990234059772522, 0.18545724476618586, 0.15649972810645998, 0.12369173187889267, 0.0878871354792479, 0.05010748884225075, 0.011507919583092052, -0.026665677985416577, -0.0631265026963309, -0.09660159075517502, -0.1258888846262905, -0.1499137997580331, -0.16778234479339135, -0.1788278960809016, -0.18264893898060253, -0.17913546063850083, -0.16848219583369567, -0.1511875643863488, -0.12803786284735597], [-0.11853755153953284, -0.14391335124448024, -0.163591222139663, -0.17663261032673944, -0.18239300622958532, -0.18054660691367944, -0.17109514979541934, -0.1543609103022869, -0.13096468174943518, -0.10179031338845618, -0.06793803188546253, -0.03066927919323432, 0.008653858363151095, 0.04863139306208121, 0.0878871354792479, 0.12512633286074154, 0.15918658398472915, 0.1890798565922851, 0.21402402107025095, 0.23346296309158113, 0.24707500803079696, 0.25477004091850136, 0.2566762997375786, 0.25311832399967577, 0.24458792842044305, 0.2317103248693539, 0.2152076253393881, 0.19586192453391038, 0.17447999195279823, 0.15186131748507978, 0.12877087581897034, 0.10591753298818528, 0.08393854575868848, 0.06339013493636744, 0.044743679368913644, 0.02838670735216783, 0.014627580006334946, 0.0037025838949493145, -0.004215913110515241, -0.009011537058698997, -0.010617349295218181, -0.009011537058698997, -0.004215913110515241, 0.0037025838949493145, 0.014627580006334946, 0.02838670735216783, 0.044743679368913644, 0.06339013493636744, 0.08393854575868848, 0.10591753298818528, 0.12877087581897034, 0.15186131748507978, 0.17447999195279823, 0.19586192453391038, 0.2152076253393881, 0.2317103248693539, 0.24458792842044305, 0.25311832399967577, 0.2566762997375786, 0.25477004091850136, 0.24707500803079696, 0.23346296309158113, 0.21402402107025095, 0.1890798565922851, 0.15918658398472915, 0.12512633286074154, 0.0878871354792479, 0.04863139306208121, 0.008653858363151095, -0.03066927919323432, -0.06793803188546253, -0.10179031338845618, -0.13096468174943518, -0.1543609103022869, -0.17109514979541934, -0.18054660691367944, -0.18239300622958532, -0.17663261032673944, -0.163591222139663, -0.14391335124448024], [-0.13481430178982187, -0.15710321083861073, -0.17287351607260817, -0.18131560690315682, -0.18194839266053625, -0.17463748569481502, -0.15959621882048483, -0.13736985507049018, -0.10880422217787396, -0.0750007897964791, -0.03726086233570953, 0.0029779491154211806, 0.044209509361482956, 0.08492762656935865, 0.12369173187889267, 0.15918658398472915, 0.1902732638436695, 0.21602931256266372, 0.23577655069724138, 0.24909585663212155, 0.25582893038458626, 0.2560677827399544, 0.25013332713993036, 0.23854497801642713, 0.22198354690007724, 0.20124995852555586, 0.17722237538812438, 0.15081422331281308, 0.12293536517635703, 0.09445829662141196, 0.0661907655654817, 0.03885568116655977, 0.013078615468659323, -0.010617349295218181, -0.03181017613329085, -0.050171999808914604, -0.06545830501430487, -0.07749482277960204, -0.08616386191642225, -0.09139170665445415, -0.09313849939964196, -0.09139170665445415, -0.08616386191642225, -0.07749482277960204, -0.06545830501430487, -0.050171999808914604, -0.03181017613329085, -0.010617349295218181, 0.013078615468659323, 0.03885568116655977, 0.0661907655654817, 0.09445829662141196, 0.12293536517635703, 0.15081422331281308, 0.17722237538812438, 0.20124995852555586, 0.22198354690007724, 0.23854497801642713, 0.25013332713993036, 0.2560677827399544, 0.25582893038458626, 0.24909585663212155, 0.23577655069724138, 0.21602931256266372, 0.1902732638436695, 0.15918658398472915, 0.12369173187889267, 0.08492762656935865, 0.044209509361482956, 0.0029779491154211806, -0.03726086233570953, -0.0750007897964791, -0.10880422217787396, -0.13736985507049018, -0.15959621882048483, -0.17463748569481502, -0.18194839266053625, -0.18131560690315682, -0.17287351607260817, -0.15710321083861073], [-0.1487375524385824, -0.16751643729146143, -0.17903560277058095, -0.1826358700412797, -0.17801860199902664, -0.16525654180237792, -0.14478624788034108, -0.11738288358628372, -0.08411903827788304, -0.046310064114579955, -0.005449066140771361, 0.03686485131708162, 0.07900122348247962, 0.11937185506223688, 0.15649972810645998, 0.1890798565922851, 0.21602931256266372, 0.2365243422174828, 0.25002327766855664, 0.2562747828163765, 0.2553118000893658, 0.24743234013685533, 0.23316893482082693, 0.21324911772700825, 0.18854967763954522, 0.16004763127913005, 0.12877087581897034, 0.0957513146109, 0.06198291759831892, 0.02838670735216783, -0.004215913110515241, -0.03512071345143313, -0.06374895250625122, -0.08964697741323371, -0.11247819731414006, -0.132008995765264, -0.14809048863531396, -0.16063822727306362, -0.1696119802323752, -0.17499760171649797, -0.17679272260843765, -0.17499760171649797, -0.1696119802323752, -0.16063822727306362, -0.14809048863531396, -0.132008995765264, -0.11247819731414006, -0.08964697741323371, -0.06374895250625122, -0.03512071345143313, -0.004215913110515241, 0.02838670735216783, 0.06198291759831892, 0.0957513146109, 0.12877087581897034, 0.16004763127913005, 0.18854967763954522, 0.21324911772700825, 0.23316893482082693, 0.24743234013685533, 0.2553118000893658, 0.2562747828163765, 0.25002327766855664, 0.2365243422174828, 0.21602931256266372, 0.1890798565922851, 0.15649972810645998, 0.11937185506223688, 0.07900122348247962, 0.03686485131708162, -0.005449066140771361, -0.046310064114579955, -0.08411903827788304, -0.11738288358628372, -0.14478624788034108, -0.16525654180237792, -0.17801860199902664, -0.1826358700412797, -0.17903560277058095, -0.16751643729146143], [-0.16021647158282734, -0.1751457556394694, -0.1821644169794075, -0.18078273088932142, -0.17090060569317098, -0.1528102839666787, -0.1271795169340972, -0.0950164022704569, -0.05761803324395176, -0.016505930263581485, 0.026648129724923395, 0.07010183827093616, 0.11212338767979044, 0.15106960365711752, 0.18545724476618586, 0.21402402107025095, 0.23577655069724138, 0.25002327766855664, 0.25639126767027576, 0.2548267267047997, 0.2455799958764798, 0.22917661128094333, 0.2063767337439853, 0.17812580971586786, 0.14549969299473817, 0.1096476200446325, 0.07173638515428266, 0.032898814044057145, -0.005810793613848673, -0.043452159632214875, -0.0792240541655952, -0.11247819731414006, -0.1427221428215067, -0.1696119802323752, -0.1929363397545002, -0.2125937105436689, -0.22856545626592412, -0.24088710992360066, -0.24962054293732017, -0.254829433326894, -0.2565601183892334, -0.254829433326894, -0.24962054293732017, -0.24088710992360066, -0.22856545626592412, -0.2125937105436689, -0.1929363397545002, -0.1696119802323752, -0.1427221428215067, -0.11247819731414006, -0.0792240541655952, -0.043452159632214875, -0.005810793613848673, 0.032898814044057145, 0.07173638515428266, 0.1096476200446325, 0.14549969299473817, 0.17812580971586786, 0.2063767337439853, 0.22917661128094333, 0.2455799958764798, 0.2548267267047997, 0.25639126767027576, 0.25002327766855664, 0.23577655069724138, 0.21402402107025095, 0.18545724476618586, 0.15106960365711752, 0.11212338767979044, 0.07010183827093616, 0.026648129724923395, -0.016505930263581485, -0.05761803324395176, -0.0950164022704569, -0.1271795169340972, -0.1528102839666787, -0.17090060569317098, -0.18078273088932142, -0.1821644169794075, -0.1751457556394694], [-0.16923416092386775, -0.1800597155006458, -0.18242166855756492, -0.1760159755489718, -0.1609539875623888, -0.1377563081818195, -0.10732612754693129, -0.07090368426500879, -0.030004497243790427, 0.013655158230898757, 0.058241427706856384, 0.1018902143955224, 0.14279404657238684, 0.1792839709402817, 0.20990234059772522, 0.23346296309158113, 0.24909585663212155, 0.2562747828163765, 0.2548267267047997, 0.24492352037505036, 0.2270567942100705, 0.20199833430642128, 0.17074867404778504, 0.134477311926808, 0.09445829662141196, 0.05200503792795912, 0.00840808631479302, -0.03512071345143313, -0.07749482277960204, -0.1177881852505473, -0.15525760655490364, -0.18935183535374994, -0.21970771693043264, -0.24613461781837798, -0.268589046149572, -0.28714197491104243, -0.30194177876754097, -0.31317589634427284, -0.3210343185560354, -0.32567778292945404, -0.32721314035298743, -0.32567778292945404, -0.3210343185560354, -0.31317589634427284, -0.30194177876754097, -0.28714197491104243, -0.268589046149572, -0.24613461781837798, -0.21970771693043264, -0.18935183535374994, -0.15525760655490364, -0.1177881852505473, -0.07749482277960204, -0.03512071345143313, 0.00840808631479302, 0.05200503792795912, 0.09445829662141196, 0.134477311926808, 0.17074867404778504, 0.20199833430642128, 0.2270567942100705, 0.24492352037505036, 0.2548267267047997, 0.2562747828163765, 0.24909585663212155, 0.23346296309158113, 0.20990234059772522, 0.1792839709402817, 0.14279404657238684, 0.1018902143955224, 0.058241427706856384, 0.013655158230898757, -0.030004497243790427, -0.07090368426500879, -0.10732612754693129, -0.1377563081818195, -0.1609539875623888, -0.1760159755489718, -0.18242166855756492, -0.1800597155006458], [-0.17584069010379264, -0.18239300622958532, -0.1800313728705813, -0.16865061331126227, -0.14858307017251748, -0.12058300781296416, -0.0857896329957062, -0.045670869380806056, -0.001951040868825416, 0.043473546354522816, 0.08862652853638416, 0.13154597877649798, 0.17037647050011584, 0.20345392533496165, 0.22937894091767205, 0.24707500803079696, 0.25582893038458626, 0.2553118000893658, 0.2455799958764798, 0.2270567942100705, 0.20049625055173417, 0.16693195814109418, 0.12761407121954643, 0.08393854575868848, 0.037372873633869375, -0.010617349295218181, -0.05863687417657578, -0.10542055787501849, -0.14988136590815446, -0.19114437378651342, -0.22856545626592412, -0.2617343483375656, -0.29046275344788247, -0.31475910259630246, -0.33479237619194996, -0.35084804028714445, -0.3632795822101567, -0.37245933283868765, -0.3787322233669178, -0.382375848005458, -0.3835697098652554, -0.382375848005458, -0.3787322233669178, -0.37245933283868765, -0.3632795822101567, -0.35084804028714445, -0.33479237619194996, -0.31475910259630246, -0.29046275344788247, -0.2617343483375656, -0.22856545626592412, -0.19114437378651342, -0.14988136590815446, -0.10542055787501849, -0.05863687417657578, -0.010617349295218181, 0.037372873633869375, 0.08393854575868848, 0.12761407121954643, 0.16693195814109418, 0.20049625055173417, 0.2270567942100705, 0.2455799958764798, 0.2553118000893658, 0.25582893038458626, 0.24707500803079696, 0.22937894091767205, 0.20345392533496165, 0.17037647050011584, 0.13154597877649798, 0.08862652853638416, 0.043473546354522816, -0.001951040868825416, -0.045670869380806056, -0.0857896329957062, -0.12058300781296416, -0.14858307017251748, -0.16865061331126227, -0.1800313728705813, -0.18239300622958532], [-0.1801446545297837, -0.18233559039097344, -0.1752665961050691, -0.15904136091487175, -0.13421936300715656, -0.10179031338845618, -0.0631265026963309, -0.019915691575644292, 0.025921773001301992, 0.07232710218505171, 0.11720338291232232, 0.15851669454452746, 0.1943926655354523, 0.2232034254780841, 0.24364050109720906, 0.25477004091850136, 0.2560677827399544, 0.24743234013685533, 0.22917661128094333, 0.20199833430642128, 0.16693195814109418, 0.12528500092613942, 0.07856287339249271, 0.02838670735216783, -0.02359098016854476, -0.0757679524450742, -0.12666669235949252, -0.17499760171649797, -0.21970771693043264, -0.26001264723920775, -0.29541051237375787, -0.32567778292945404, -0.35084804028714445, -0.37117570680030565, -0.38708768931988075, -0.3991265770886398, -0.407889497747319, -0.41396693622794944, -0.417885750201407, -0.4200602785751461, -0.4207548585159486, -0.4200602785751461, -0.417885750201407, -0.41396693622794944, -0.407889497747319, -0.3991265770886398, -0.38708768931988075, -0.37117570680030565, -0.35084804028714445, -0.32567778292945404, -0.29541051237375787, -0.26001264723920775, -0.21970771693043264, -0.17499760171649797, -0.12666669235949252, -0.0757679524450742, -0.02359098016854476, 0.02838670735216783, 0.07856287339249271, 0.12528500092613942, 0.16693195814109418, 0.20199833430642128, 0.22917661128094333, 0.24743234013685533, 0.2560677827399544, 0.25477004091850136, 0.24364050109720906, 0.2232034254780841, 0.1943926655354523, 0.15851669454452746, 0.11720338291232232, 0.07232710218505171, 0.025921773001301992, -0.019915691575644292, -0.0631265026963309, -0.10179031338845618, -0.13421936300715656, -0.15904136091487175, -0.1752665961050691, -0.18233559039097344], [-0.18230376872794093, -0.18012123502583363, -0.16843605361995675, -0.14756752732225356, -0.11830504740258321, -0.08187218787401292, -0.039868134180728126, 0.0058103924762656495, 0.05306249567952219, 0.09968670899986165, 0.14348926836260514, 0.18239124981424537, 0.2145288714461612, 0.2383416766936446, 0.25264402764959015, 0.2566762997375786, 0.25013332713993036, 0.23316893482082693, 0.2063767337439853, 0.17074867404778504, 0.12761407121954643, 0.07856287339249271, 0.02535776443828009, -0.030159748399708135, -0.08616386191642225, -0.1409342819269669, -0.1929363397545002, -0.24088710992360066, -0.2838041182964338, -0.3210343185560354, -0.35226222727992795, -0.37749737145928347, -0.3970424421347404, -0.41144469052055266, -0.42143408131469146, -0.42785247459104203, -0.43157859884674826, -0.4334537754581445, -0.434213248547002, -0.43442757176285574, -0.43445783007337646, -0.43442757176285574, -0.434213248547002, -0.4334537754581445, -0.43157859884674826, -0.42785247459104203, -0.42143408131469146, -0.41144469052055266, -0.3970424421347404, -0.37749737145928347, -0.35226222727992795, -0.3210343185560354, -0.2838041182964338, -0.24088710992360066, -0.1929363397545002, -0.1409342819269669, -0.08616386191642225, -0.030159748399708135, 0.02535776443828009, 0.07856287339249271, 0.12761407121954643, 0.17074867404778504, 0.2063767337439853, 0.23316893482082693, 0.25013332713993036, 0.2566762997375786, 0.25264402764959015, 0.2383416766936446, 0.2145288714461612, 0.18239124981424537, 0.14348926836260514, 0.09968670899986165, 0.05306249567952219, 0.0058103924762656495, -0.039868134180728126, -0.08187218787401292, -0.11830504740258321, -0.14756752732225356, -0.16843605361995675, -0.18012123502583363], [-0.18251498442862385, -0.1760159755489718, -0.15987112992755653, -0.13461888616197776, -0.10127808535368477, -0.061301442485772274, -0.016505930263581485, 0.031016232090896562, 0.07900122348247962, 0.12512633286074154, 0.16712567793535366, 0.20290271423033404, 0.23063350923189954, 0.24885528388828942, 0.25653555744366946, 0.25311832399967577, 0.23854497801642713, 0.21324911772700825, 0.17812580971586786, 0.134477311926808, 0.08393854575868848, 0.02838670735216783, -0.030159748399708135, -0.08964697741323371, -0.14809048863531396, -0.2036729142303004, -0.254829433326894, -0.3003162506586467, -0.3392585664190622, -0.37117570680030565, -0.39598244357893553, -0.41396693622794944, -0.42574709936268906, -0.43220845214435083, -0.43442757176285574, -0.4335860886421158, -0.4308806796227811, -0.4274347075936389, -0.42421701152445723, -0.42197287899622543, -0.421171462695804, -0.42197287899622543, -0.42421701152445723, -0.4274347075936389, -0.4308806796227811, -0.4335860886421158, -0.43442757176285574, -0.43220845214435083, -0.42574709936268906, -0.41396693622794944, -0.39598244357893553, -0.37117570680030565, -0.3392585664190622, -0.3003162506586467, -0.254829433326894, -0.2036729142303004, -0.14809048863531396, -0.08964697741323371, -0.030159748399708135, 0.02838670735216783, 0.08393854575868848, 0.134477311926808, 0.17812580971586786, 0.21324911772700825, 0.23854497801642713, 0.25311832399967577, 0.25653555744366946, 0.24885528388828942, 0.23063350923189954, 0.20290271423033404, 0.16712567793535366, 0.12512633286074154, 0.07900122348247962, 0.031016232090896562, -0.016505930263581485, -0.061301442485772274, -0.10127808535368477, -0.13461888616197776, -0.15987112992755653, -0.1760159755489718], [-0.18100457917857166, -0.17030698199702413, -0.1499137997580331, -0.12058300781296416, -0.08355939645450051, -0.040517266401149735, 0.0065202421682302655, 0.05528095770522729, 0.10335731863015635, 0.14832776112580212, 0.18787932061729182, 0.21992483146863692, 0.242708395806646, 0.254893432701845, 0.25562857790064414, 0.24458792842044305, 0.22198354690007724, 0.18854967763954522, 0.14549969299473817, 0.09445829662141196, 0.037372873633869375, -0.02359098016854476, -0.08616386191642225, -0.14809048863531396, -0.20724458052139974, -0.2617343483375656, -0.309992807249447, -0.35084804028714445, -0.3835697098652554, -0.407889497747319, -0.42399466300627076, -0.43249545715781157, -0.43436863670247905, -0.4308806796227811, -0.42349546556438716, -0.4137720534188708, -0.40325873487122593, -0.39338972722403176, -0.3853906832849483, -0.3801986514917913, -0.3784012476539641, -0.3801986514917913, -0.3853906832849483, -0.39338972722403176, -0.40325873487122593, -0.4137720534188708, -0.42349546556438716, -0.4308806796227811, -0.43436863670247905, -0.43249545715781157, -0.42399466300627076, -0.407889497747319, -0.3835697098652554, -0.35084804028714445, -0.309992807249447, -0.2617343483375656, -0.20724458052139974, -0.14809048863531396, -0.08616386191642225, -0.02359098016854476, 0.037372873633869375, 0.09445829662141196, 0.14549969299473817, 0.18854967763954522, 0.22198354690007724, 0.24458792842044305, 0.25562857790064414, 0.254893432701845, 0.242708395806646, 0.21992483146863692, 0.18787932061729182, 0.14832776112580212, 0.10335731863015635, 0.05528095770522729, 0.0065202421682302655, -0.040517266401149735, -0.08355939645450051, -0.12058300781296416, -0.1499137997580331, -0.17030698199702413], [-0.17801860199902664, -0.16329221750830802, -0.13890582780165694, -0.10583439818051152, -0.06554239869174844, -0.019915691575644292, 0.02883009042098063, 0.07825990831739421, 0.1258425822940911, 0.16908036038891633, 0.20563779959612533, 0.23346296309158113, 0.2508943222213973, 0.25674750760048576, 0.25037713957121355, 0.2317103248693539, 0.20124995852555586, 0.16004763127913005, 0.1096476200446325, 0.05200503792795912, -0.010617349295218181, -0.0757679524450742, -0.1409342819269669, -0.2036729142303004, -0.2617343483375656, -0.31317589634427284, -0.3564564355250057, -0.3905078789395116, -0.4147795406040892, -0.42925310491460716, -0.43442757176285574, -0.4312752446188071, -0.421171462695804, -0.40580225753498556, -0.38705535500366767, -0.36690087535799776, -0.3472686537517362, -0.32992927901128904, -0.3163857196862348, -0.3077817863653888, -0.30483270332925, -0.3077817863653888, -0.3163857196862348, -0.32992927901128904, -0.3472686537517362, -0.36690087535799776, -0.38705535500366767, -0.40580225753498556, -0.421171462695804, -0.4312752446188071, -0.43442757176285574, -0.42925310491460716, -0.4147795406040892, -0.3905078789395116, -0.3564564355250057, -0.31317589634427284, -0.2617343483375656, -0.2036729142303004, -0.1409342819269669, -0.0757679524450742, -0.010617349295218181, 0.05200503792795912, 0.1096476200446325, 0.16004763127913005, 0.20124995852555586, 0.2317103248693539, 0.25037713957121355, 0.25674750760048576, 0.2508943222213973, 0.23346296309158113, 0.20563779959612533, 0.16908036038891633, 0.1258425822940911, 0.07825990831739421, 0.02883009042098063, -0.019915691575644292, -0.06554239869174844, -0.10583439818051152, -0.13890582780165694, -0.16329221750830802], [-0.1738139924448547, -0.15527119023634722, -0.1271795169340972, -0.0907256642328181, -0.04758506314163741, 0.0001569493213448689, 0.05010748884225075, 0.09968670899986165, 0.14626024334832619, 0.18727640924644018, 0.22040074178662336, 0.24364050109720906, 0.2554522819126627, 0.2548267267047997, 0.2413455569066888, 0.2152076253393881, 0.17722237538812438, 0.12877087581897034, 0.07173638515428266, 0.00840808631479302, -0.05863687417657578, -0.12666669235949252, -0.1929363397545002, -0.254829433326894, -0.309992807249447, -0.3564564355250057, -0.39273214882544505, -0.417885750201407, -0.43157859884674826, -0.434076417833265, -0.42622489689420734, -0.4093935036702951, -0.3853906832849483, -0.35635521764627226, -0.324629843053556, -0.2926242127644853, -0.2626748843273063, -0.23691017597600564, -0.21712746254366178, -0.20468978410715197, -0.20044755867978276, -0.20468978410715197, -0.21712746254366178, -0.23691017597600564, -0.2626748843273063, -0.2926242127644853, -0.324629843053556, -0.35635521764627226, -0.3853906832849483, -0.4093935036702951, -0.42622489689420734, -0.434076417833265, -0.43157859884674826, -0.417885750201407, -0.39273214882544505, -0.3564564355250057, -0.309992807249447, -0.254829433326894, -0.1929363397545002, -0.12666669235949252, -0.05863687417657578, 0.00840808631479302, 0.07173638515428266, 0.12877087581897034, 0.17722237538812438, 0.2152076253393881, 0.2413455569066888, 0.2548267267047997, 0.2554522819126627, 0.24364050109720906, 0.22040074178662336, 0.18727640924644018, 0.14626024334832619, 0.09968670899986165, 0.05010748884225075, 0.0001569493213448689, -0.04758506314163741, -0.0907256642328181, -0.1271795169340972, -0.15527119023634722], [-0.16865061331126227, -0.14653700801271363, -0.11505016730310495, -0.07558080422426758, -0.030004497243790427, 0.019407660252202565, 0.07010183827093616, 0.11937185506223688, 0.16450028494360933, 0.20290271423033404, 0.23226729318028777, 0.2506818889186662, 0.2567417315441088, 0.24963143467045815, 0.22917661128094333, 0.19586192453391038, 0.15081422331281308, 0.0957513146109, 0.032898814044057145, -0.03512071345143313, -0.10542055787501849, -0.17499760171649797, -0.24088710992360066, -0.3003162506586467, -0.35084804028714445, -0.3905078789395116, -0.417885750201407, -0.43220845214435083, -0.4333778373354074, -0.42197287899622543, -0.39921534828629784, -0.36690087535799776, -0.32729906443176787, -0.28302803533990717, -0.23691017597600564, -0.19181693290541052, -0.15051108239111077, -0.11549507625799743, -0.08887373699192957, -0.0722388011028484, -0.06658162124929747, -0.0722388011028484, -0.08887373699192957, -0.11549507625799743, -0.15051108239111077, -0.19181693290541052, -0.23691017597600564, -0.28302803533990717, -0.32729906443176787, -0.36690087535799776, -0.39921534828629784, -0.42197287899622543, -0.4333778373354074, -0.43220845214435083, -0.417885750201407, -0.3905078789395116, -0.35084804028714445, -0.3003162506586467, -0.24088710992360066, -0.17499760171649797, -0.10542055787501849, -0.03512071345143313, 0.032898814044057145, 0.0957513146109, 0.15081422331281308, 0.19586192453391038, 0.22917661128094333, 0.24963143467045815, 0.2567417315441088, 0.2506818889186662, 0.23226729318028777, 0.20290271423033404, 0.16450028494360933, 0.11937185506223688, 0.07010183827093616, 0.019407660252202565, -0.030004497243790427, -0.07558080422426758, -0.11505016730310495, -0.14653700801271363], [-0.16278435980926842, -0.13736985507049018, -0.10281030706494565, -0.060690608986011814, -0.013073952151520388, 0.03759772656874239, 0.08862652853638416, 0.13719827990417027, 0.18053174205108255, 0.21602931256266372, 0.24142096714711753, 0.254893432701845, 0.25519727019112654, 0.24172565029557566, 0.21456006847846779, 0.17447999195279823, 0.12293536517635703, 0.06198291759831892, -0.005810793613848673, -0.07749482277960204, -0.14988136590815446, -0.21970771693043264, -0.2838041182964338, -0.3392585664190622, -0.3835697098652554, -0.4147795406040892, -0.43157859884674826, -0.4333778373354074, -0.4203430458705095, -0.39338972722403176, -0.3541384336243295, -0.30483270332925, -0.24822376277499153, -0.187427969950852, -0.1257644689695074, -0.06658162124929747, -0.0130814139378774, 0.03184881503912622, 0.0657883626364726, 0.08691073780520595, 0.0940800053732448, 0.08691073780520595, 0.0657883626364726, 0.03184881503912622, -0.0130814139378774, -0.06658162124929747, -0.1257644689695074, -0.187427969950852, -0.24822376277499153, -0.30483270332925, -0.3541384336243295, -0.39338972722403176, -0.4203430458705095, -0.4333778373354074, -0.43157859884674826, -0.4147795406040892, -0.3835697098652554, -0.3392585664190622, -0.2838041182964338, -0.21970771693043264, -0.14988136590815446, -0.07749482277960204, -0.005810793613848673, 0.06198291759831892, 0.12293536517635703, 0.17447999195279823, 0.21456006847846779, 0.24172565029557566, 0.25519727019112654, 0.254893432701845, 0.24142096714711753, 0.21602931256266372, 0.18053174205108255, 0.13719827990417027, 0.08862652853638416, 0.03759772656874239, -0.013073952151520388, -0.060690608986011814, -0.10281030706494565, -0.13736985507049018], [-0.15646143337355978, -0.12803192632998142, -0.0907256642328181, -0.046310064114579955, 0.0029779491154211806, 0.054541276561040686, 0.10555493165712146, 0.15311446345017118, 0.1943926655354523, 0.22679610352037188, 0.24811283911536614, 0.2566430509401283, 0.25130504004127213, 0.2317103248693539, 0.1982031145119569, 0.15186131748507978, 0.09445829662141196, 0.02838670735216783, -0.043452159632214875, -0.1177881852505473, -0.19114437378651342, -0.26001264723920775, -0.3210343185560354, -0.37117570680030565, -0.407889497747319, -0.42925310491460716, -0.434076417833265, -0.42197287899622543, -0.39338972722403176, -0.3495953826561967, -0.2926242127644853, -0.22518118755916025, -0.15051108239111077, -0.0722388011028484, 0.005811034304373925, 0.07980593576993696, 0.14609889758077332, 0.20141317105264114, 0.24300880867803662, 0.2688222513075441, 0.277571630583514, 0.2688222513075441, 0.24300880867803662, 0.20141317105264114, 0.14609889758077332, 0.07980593576993696, 0.005811034304373925, -0.0722388011028484, -0.15051108239111077, -0.22518118755916025, -0.2926242127644853, -0.3495953826561967, -0.39338972722403176, -0.42197287899622543, -0.434076417833265, -0.42925310491460716, -0.407889497747319, -0.37117570680030565, -0.3210343185560354, -0.26001264723920775, -0.19114437378651342, -0.1177881852505473, -0.043452159632214875, 0.02838670735216783, 0.09445829662141196, 0.15186131748507978, 0.1982031145119569, 0.2317103248693539, 0.25130504004127213, 0.2566430509401283, 0.24811283911536614, 0.22679610352037188, 0.1943926655354523, 0.15311446345017118, 0.10555493165712146, 0.054541276561040686, 0.0029779491154211806, -0.046310064114579955, -0.0907256642328181, -0.12803192632998142], [-0.1499137997580331, -0.11876378051842666, -0.07903277128303789, -0.032657564269347995, 0.017966041941118966, 0.07010183827093616, 0.12081441070397907, 0.16712567793535366, 0.2061784643801796, 0.23539823538075702, 0.25264402764959015, 0.2563400102730029, 0.2455799958764798, 0.22019854657881394, 0.18080401871815463, 0.12877087581897034, 0.0661907655654817, -0.004215913110515241, -0.0792240541655952, -0.15525760655490364, -0.22856545626592412, -0.29541051237375787, -0.35226222727992795, -0.39598244357893553, -0.42399466300627076, -0.43442757176285574, -0.42622489689420734, -0.39921534828629784, -0.3541384336243295, -0.2926242127644853, -0.21712746254366178, -0.13081912452072303, -0.03744017720227128, 0.05887491198907235, 0.1537963512162099, 0.24300880867803662, 0.32242214992953067, 0.38837235101706136, 0.43780226922078175, 0.4684129583840573, 0.47877771528316515, 0.4684129583840573, 0.43780226922078175, 0.38837235101706136, 0.32242214992953067, 0.24300880867803662, 0.1537963512162099, 0.05887491198907235, -0.03744017720227128, -0.13081912452072303, -0.21712746254366178, -0.2926242127644853, -0.3541384336243295, -0.39921534828629784, -0.42622489689420734, -0.43442757176285574, -0.42399466300627076, -0.39598244357893553, -0.35226222727992795, -0.29541051237375787, -0.22856545626592412, -0.15525760655490364, -0.0792240541655952, -0.004215913110515241, 0.0661907655654817, 0.12877087581897034, 0.18080401871815463, 0.22019854657881394, 0.2455799958764798, 0.2563400102730029, 0.25264402764959015, 0.23539823538075702, 0.2061784643801796, 0.16712567793535366, 0.12081441070397907, 0.07010183827093616, 0.017966041941118966, -0.032657564269347995, -0.07903277128303789, -0.11876378051842666], [-0.14335579129849668, -0.10978201113265723, -0.06793803188546253, -0.019915691575644292, 0.031745840459068614, 0.08418731130237875, 0.13437885433763305, 0.1792839709402817, 0.21602931256266372, 0.2420710146043941, 0.255348298963932, 0.25441554164532254, 0.23854497801642713, 0.20779364608280457, 0.1630299764243758, 0.10591753298818528, 0.03885568116655977, -0.03512071345143313, -0.11247819731414006, -0.18935183535374994, -0.2617343483375656, -0.32567778292945404, -0.37749737145928347, -0.41396693622794944, -0.43249545715781157, -0.4312752446188071, -0.4093935036702951, -0.36690087535799776, -0.30483270332925, -0.22518118755916025, -0.13081912452072303, -0.025378460035175753, 0.08691073780520595, 0.20141317105264114, 0.3133036361206578, 0.4177941096414197, 0.5103612401471838, 0.5869627944413911, 0.6442321103834694, 0.6796406846183429, 0.69162061945593, 0.6796406846183429, 0.6442321103834694, 0.5869627944413911, 0.5103612401471838, 0.4177941096414197, 0.3133036361206578, 0.20141317105264114, 0.08691073780520595, -0.025378460035175753, -0.13081912452072303, -0.22518118755916025, -0.30483270332925, -0.36690087535799776, -0.4093935036702951, -0.4312752446188071, -0.43249545715781157, -0.41396693622794944, -0.37749737145928347, -0.32567778292945404, -0.2617343483375656, -0.18935183535374994, -0.11247819731414006, -0.03512071345143313, 0.03885568116655977, 0.10591753298818528, 0.1630299764243758, 0.20779364608280457, 0.23854497801642713, 0.25441554164532254, 0.255348298963932, 0.2420710146043941, 0.21602931256266372, 0.1792839709402817, 0.13437885433763305, 0.08418731130237875, 0.031745840459068614, -0.019915691575644292, -0.06793803188546253, -0.10978201113265723], [-0.13698176393514344, -0.10127808535368477, -0.05761803324395176, -0.00823327044894154, 0.044209509361482956, 0.09674378883254962, 0.14626024334832619, 0.18967745729212915, 0.22411724822563847, 0.24707500803079696, 0.256575492104657, 0.25130504004127213, 0.23071227369415245, 0.19507084218595108, 0.14549969299473817, 0.08393854575868848, 0.013078615468659323, -0.06374895250625122, -0.1427221428215067, -0.21970771693043264, -0.29046275344788247, -0.35084804028714445, -0.3970424421347404, -0.42574709936268906, -0.43436863670247905, -0.421171462695804, -0.3853906832849483, -0.32729906443176787, -0.24822376277499153, -0.15051108239111077, -0.03744017720227128, 0.08691073780520595, 0.21783961811686398, 0.35022902170777614, 0.47877771528316515, 0.5982441516081277, 0.7036898157513979, 0.7907103570985019, 0.8556429685382863, 0.8957396184216221, 0.9092974268256817, 0.8957396184216221, 0.8556429685382863, 0.7907103570985019, 0.7036898157513979, 0.5982441516081277, 0.47877771528316515, 0.35022902170777614, 0.21783961811686398, 0.08691073780520595, -0.03744017720227128, -0.15051108239111077, -0.24822376277499153, -0.32729906443176787, -0.3853906832849483, -0.421171462695804, -0.43436863670247905, -0.42574709936268906, -0.3970424421347404, -0.35084804028714445, -0.29046275344788247, -0.21970771693043264, -0.1427221428215067, -0.06374895250625122, 0.013078615468659323, 0.08393854575868848, 0.14549969299473817, 0.19507084218595108, 0.23071227369415245, 0.25130504004127213, 0.256575492104657, 0.24707500803079696, 0.22411724822563847, 0.18967745729212915, 0.14626024334832619, 0.09674378883254962, 0.044209509361482956, -0.00823327044894154, -0.05761803324395176, -0.10127808535368477], [-0.13096468174943518, -0.09341816596346665, -0.04822085787410071, 0.0022716100207446164, 0.05528095770522729, 0.10774865812501504, 0.15649972810645998, 0.19841943861188654, 0.23063350923189954, 0.2506818889186662, 0.2566762997375786, 0.24743234013685533, 0.2225680860000738, 0.18256273925541686, 0.12877087581897034, 0.06339013493636744, -0.010617349295218181, -0.08964697741323371, -0.1696119802323752, -0.24613461781837798, -0.31475910259630246, -0.37117570680030565, -0.41144469052055266, -0.43220845214435083, -0.4308806796227811, -0.40580225753498556, -0.35635521764627226, -0.28302803533990717, -0.187427969950852, -0.0722388011028484, 0.05887491198907235, 0.20141317105264114, 0.35022902170777614, 0.49975144871271493, 0.6442321103834694, 0.7780040258931075, 0.8957396184216221, 0.992695449836068, 1.0649315658049785, 1.1094945766040856, 1.124555367855928, 1.1094945766040856, 1.0649315658049785, 0.992695449836068, 0.8957396184216221, 0.7780040258931075, 0.6442321103834694, 0.49975144871271493, 0.35022902170777614, 0.20141317105264114, 0.05887491198907235, -0.0722388011028484, -0.187427969950852, -0.28302803533990717, -0.35635521764627226, -0.40580225753498556, -0.4308806796227811, -0.43220845214435083, -0.41144469052055266, -0.37117570680030565, -0.31475910259630246, -0.24613461781837798, -0.1696119802323752, -0.08964697741323371, -0.010617349295218181, 0.06339013493636744, 0.12877087581897034, 0.18256273925541686, 0.2225680860000738, 0.24743234013685533, 0.2566762997375786, 0.2506818889186662, 0.23063350923189954, 0.19841943861188654, 0.15649972810645998, 0.10774865812501504, 0.05528095770522729, 0.0022716100207446164, -0.04822085787410071, -0.09341816596346665], [-0.1254554756233313, -0.08634370978474622, -0.039868134180728126, 0.011507919583092052, 0.0649104168254659, 0.11720338291232232, 0.16515865057394133, 0.20563779959612533, 0.23577655069724138, 0.2531614457800734, 0.2559887694405144, 0.2431963471432226, 0.21456006847846779, 0.17074867404778504, 0.11333242903336226, 0.044743679368913644, -0.03181017613329085, -0.11247819731414006, -0.1929363397545002, -0.268589046149572, -0.33479237619194996, -0.38708768931988075, -0.42143408131469146, -0.43442757176285574, -0.42349546556438716, -0.38705535500366767, -0.324629843053556, -0.23691017597600564, -0.1257644689695074, 0.005811034304373925, 0.1537963512162099, 0.3133036361206578, 0.47877771528316515, 0.6442321103834694, 0.803509484779075, 0.9505541014891831, 1.0796831610910465, 1.1858438330909473, 1.2648434125627805, 1.3135412961886945, 1.3299933154720727, 1.3135412961886945, 1.2648434125627805, 1.1858438330909473, 1.0796831610910465, 0.9505541014891831, 0.803509484779075, 0.6442321103834694, 0.47877771528316515, 0.3133036361206578, 0.1537963512162099, 0.005811034304373925, -0.1257644689695074, -0.23691017597600564, -0.324629843053556, -0.38705535500366767, -0.42349546556438716, -0.43442757176285574, -0.42143408131469146, -0.38708768931988075, -0.33479237619194996, -0.268589046149572, -0.1929363397545002, -0.11247819731414006, -0.03181017613329085, 0.044743679368913644, 0.11333242903336226, 0.17074867404778504, 0.21456006847846779, 0.2431963471432226, 0.2559887694405144, 0.2531614457800734, 0.23577655069724138, 0.20563779959612533, 0.16515865057394133, 0.11720338291232232, 0.0649104168254659, 0.011507919583092052, -0.039868134180728126, -0.08634370978474622], [-0.12058300781296416, -0.08017262722723162, -0.032657564269347995, 0.019407660252202565, 0.07306884206017318, 0.12512633286074154, 0.17230988766358785, 0.21146505144444128, 0.23974108638511749, 0.25477004091850136, 0.2548267267047997, 0.23896010343988033, 0.2070878465419809, 0.16004763127913005, 0.09960082298540655, 0.02838670735216783, -0.050171999808914604, -0.132008995765264, -0.2125937105436689, -0.28714197491104243, -0.35084804028714445, -0.3991265770886398, -0.42785247459104203, -0.4335860886421158, -0.4137720534188708, -0.36690087535799776, -0.2926242127644853, -0.19181693290541052, -0.06658162124929747, 0.07980593576993696, 0.24300880867803662, 0.4177941096414197, 0.5982441516081277, 0.7780040258931075, 0.9505541014891831, 1.1094945766040856, 1.2488284837498442, 1.3632295064019535, 1.4482816142111579, 1.500678835049543, 1.518375390968938, 1.500678835049543, 1.4482816142111579, 1.3632295064019535, 1.2488284837498442, 1.1094945766040856, 0.9505541014891831, 0.7780040258931075, 0.5982441516081277, 0.4177941096414197, 0.24300880867803662, 0.07980593576993696, -0.06658162124929747, -0.19181693290541052, -0.2926242127644853, -0.36690087535799776, -0.4137720534188708, -0.4335860886421158, -0.42785247459104203, -0.3991265770886398, -0.35084804028714445, -0.28714197491104243, -0.2125937105436689, -0.132008995765264, -0.050171999808914604, 0.02838670735216783, 0.09960082298540655, 0.16004763127913005, 0.2070878465419809, 0.23896010343988033, 0.2548267267047997, 0.25477004091850136, 0.23974108638511749, 0.21146505144444128, 0.17230988766358785, 0.12512633286074154, 0.07306884206017318, 0.019407660252202565, -0.032657564269347995, -0.08017262722723162], [-0.1164544699167505, -0.0750007897964791, -0.026665677985416577, 0.025921773001301992, 0.07974244535617742, 0.13154597877649798, 0.17802983029511174, 0.21602931256266372, 0.242708395806646, 0.2557406839380664, 0.25347017586536014, 0.23504220166614895, 0.20049625055173417, 0.15081422331281308, 0.08791985781076668, 0.014627580006334946, -0.06545830501430487, -0.14809048863531396, -0.22856545626592412, -0.30194177876754097, -0.3632795822101567, -0.407889497747319, -0.43157859884674826, -0.4308806796227811, -0.40325873487122593, -0.3472686537517362, -0.2626748843273063, -0.15051108239111077, -0.0130814139378774, 0.14609889758077332, 0.32242214992953067, 0.5103612401471838, 0.7036898157513979, 0.8957396184216221, 1.0796831610910465, 1.2488284837498442, 1.3969119972732167, 1.518375390968938, 1.608613254431116, 1.6641794167481594, 1.682941969615793, 1.6641794167481594, 1.608613254431116, 1.518375390968938, 1.3969119972732167, 1.2488284837498442, 1.0796831610910465, 0.8957396184216221, 0.7036898157513979, 0.5103612401471838, 0.32242214992953067, 0.14609889758077332, -0.0130814139378774, -0.15051108239111077, -0.2626748843273063, -0.3472686537517362, -0.40325873487122593, -0.4308806796227811, -0.43157859884674826, -0.407889497747319, -0.3632795822101567, -0.30194177876754097, -0.22856545626592412, -0.14809048863531396, -0.06545830501430487, 0.014627580006334946, 0.08791985781076668, 0.15081422331281308, 0.20049625055173417, 0.23504220166614895, 0.25347017586536014, 0.2557406839380664, 0.242708395806646, 0.21602931256266372, 0.17802983029511174, 0.13154597877649798, 0.07974244535617742, 0.025921773001301992, -0.026665677985416577, -0.0750007897964791], [-0.1131560467581887, -0.07090368426500879, -0.021950582012676394, 0.031016232090896562, 0.08492762656935865, 0.13649472168344115, 0.18239124981424537, 0.21944644111666822, 0.24483804991090946, 0.2562747828163765, 0.252157618714697, 0.2317103248693539, 0.19507084218595108, 0.1433370736825879, 0.07856287339249271, 0.0037025838949493145, -0.07749482277960204, -0.16063822727306362, -0.24088710992360066, -0.31317589634427284, -0.37245933283868765, -0.41396693622794944, -0.4334537754581445, -0.4274347075936389, -0.39338972722403176, -0.32992927901128904, -0.23691017597600564, -0.11549507625799743, 0.03184881503912622, 0.20141317105264114, 0.38837235101706136, 0.5869627944413911, 0.7907103570985019, 0.992695449836068, 1.1858438330909473, 1.3632295064019535, 1.518375390968938, 1.6455374774968983, 1.7399588071171015, 1.7980810383563555, 1.8177033600622243, 1.7980810383563555, 1.7399588071171015, 1.6455374774968983, 1.518375390968938, 1.3632295064019535, 1.1858438330909473, 0.992695449836068, 0.7907103570985019, 0.5869627944413911, 0.38837235101706136, 0.20141317105264114, 0.03184881503912622, -0.11549507625799743, -0.23691017597600564, -0.32992927901128904, -0.39338972722403176, -0.4274347075936389, -0.4334537754581445, -0.41396693622794944, -0.37245933283868765, -0.31317589634427284, -0.24088710992360066, -0.16063822727306362, -0.07749482277960204, 0.0037025838949493145, 0.07856287339249271, 0.1433370736825879, 0.19507084218595108, 0.2317103248693539, 0.252157618714697, 0.2562747828163765, 0.24483804991090946, 0.21944644111666822, 0.18239124981424537, 0.13649472168344115, 0.08492762656935865, 0.031016232090896562, -0.021950582012676394, -0.07090368426500879], [-0.1107536917561867, -0.06793803188546253, -0.01855449981019833, 0.03466854669458865, 0.08862652853638416, 0.14000357308347133, 0.18545724476618586, 0.22181346801290225, 0.24626113579560338, 0.25653555744366946, 0.25108014921898075, 0.22917661128094333, 0.19103523332295086, 0.13783886506830845, 0.07173638515428266, -0.004215913110515241, -0.08616386191642225, -0.1696119802323752, -0.24962054293732017, -0.3210343185560354, -0.3787322233669178, -0.417885750201407, -0.434213248547002, -0.42421701152445723, -0.3853906832849483, -0.3163857196862348, -0.21712746254366178, -0.08887373699192957, 0.0657883626364726, 0.24300880867803662, 0.43780226922078175, 0.6442321103834694, 0.8556429685382863, 1.0649315658049785, 1.2648434125627805, 1.4482816142111579, 1.608613254431116, 1.7399588071171015, 1.8374507397311368, 1.8974488797623419, 1.917702154416812, 1.8974488797623419, 1.8374507397311368, 1.7399588071171015, 1.608613254431116, 1.4482816142111579, 1.2648434125627805, 1.0649315658049785, 0.8556429685382863, 0.6442321103834694, 0.43780226922078175, 0.24300880867803662, 0.0657883626364726, -0.08887373699192957, -0.21712746254366178, -0.3163857196862348, -0.3853906832849483, -0.42421701152445723, -0.434213248547002, -0.417885750201407, -0.3787322233669178, -0.3210343185560354, -0.24962054293732017, -0.1696119802323752, -0.08616386191642225, -0.004215913110515241, 0.07173638515428266, 0.13783886506830845, 0.19103523332295086, 0.22917661128094333, 0.25108014921898075, 0.25653555744366946, 0.24626113579560338, 0.22181346801290225, 0.18545724476618586, 0.14000357308347133, 0.08862652853638416, 0.03466854669458865, -0.01855449981019833, -0.06793803188546253], [-0.10929387900894774, -0.06614321685638791, -0.016505930263581485, 0.03686485131708162, 0.09084339726921295, 0.14209785531573388, 0.18727640924644018, 0.2232034254780841, 0.24707500803079696, 0.2566430509401283, 0.25037713957121355, 0.22759450814784551, 0.18854967763954522, 0.134477311926808, 0.06758414818694233, -0.009011537058698997, -0.09139170665445415, -0.17499760171649797, -0.254829433326894, -0.32567778292945404, -0.382375848005458, -0.4200602785751461, -0.43442757176285574, -0.42197287899622543, -0.3801986514917913, -0.3077817863653888, -0.20468978410715197, -0.0722388011028484, 0.08691073780520595, 0.2688222513075441, 0.4684129583840573, 0.6796406846183429, 0.8957396184216221, 1.1094945766040856, 1.3135412961886945, 1.500678835049543, 1.6641794167481594, 1.7980810383563555, 1.8974488797623419, 1.9585929762944412, 1.9792316740361835, 1.9585929762944412, 1.8974488797623419, 1.7980810383563555, 1.6641794167481594, 1.500678835049543, 1.3135412961886945, 1.1094945766040856, 0.8957396184216221, 0.6796406846183429, 0.4684129583840573, 0.2688222513075441, 0.08691073780520595, -0.0722388011028484, -0.20468978410715197, -0.3077817863653888, -0.3801986514917913, -0.42197287899622543, -0.43442757176285574, -0.4200602785751461, -0.382375848005458, -0.32567778292945404, -0.254829433326894, -0.17499760171649797, -0.09139170665445415, -0.009011537058698997, 0.06758414818694233, 0.134477311926808, 0.18854967763954522, 0.22759450814784551, 0.25037713957121355, 0.2566430509401283, 0.24707500803079696, 0.2232034254780841, 0.18727640924644018, 0.14209785531573388, 0.09084339726921295, 0.03686485131708162, -0.016505930263581485, -0.06614321685638791], [-0.10880422217787396, -0.06554239869174844, -0.015821288518275644, 0.03759772656874239, 0.09158188560927924, 0.14279404657238684, 0.18787932061729182, 0.22366162672468853, 0.24733956165584545, 0.2566706526738519, 0.25013332713993036, 0.2270567942100705, 0.18771045677679687, 0.1333463922312941, 0.0661907655654817, -0.010617349295218181, -0.09313849939964196, -0.17679272260843765, -0.2565601183892334, -0.32721314035298743, -0.3835697098652554, -0.4207548585159486, -0.43445783007337646, -0.421171462695804, -0.3784012476539641, -0.30483270332925, -0.20044755867978276, -0.06658162124929747, 0.0940800053732448, 0.277571630583514, 0.47877771528316515, 0.69162061945593, 0.9092974268256817, 1.124555367855928, 1.3299933154720727, 1.518375390968938, 1.682941969615793, 1.8177033600622243, 1.917702154416812, 1.9792316740361835, null, 1.9792316740361835, 1.917702154416812, 1.8177033600622243, 1.682941969615793, 1.518375390968938, 1.3299933154720727, 1.124555367855928, 0.9092974268256817, 0.69162061945593, 0.47877771528316515, 0.277571630583514, 0.0940800053732448, -0.06658162124929747, -0.20044755867978276, -0.30483270332925, -0.3784012476539641, -0.421171462695804, -0.43445783007337646, -0.4207548585159486, -0.3835697098652554, -0.32721314035298743, -0.2565601183892334, -0.17679272260843765, -0.09313849939964196, -0.010617349295218181, 0.0661907655654817, 0.1333463922312941, 0.18771045677679687, 0.2270567942100705, 0.25013332713993036, 0.2566706526738519, 0.24733956165584545, 0.22366162672468853, 0.18787932061729182, 0.14279404657238684, 0.09158188560927924, 0.03759772656874239, -0.015821288518275644, -0.06554239869174844], [-0.10929387900894774, -0.06614321685638791, -0.016505930263581485, 0.03686485131708162, 0.09084339726921295, 0.14209785531573388, 0.18727640924644018, 0.2232034254780841, 0.24707500803079696, 0.2566430509401283, 0.25037713957121355, 0.22759450814784551, 0.18854967763954522, 0.134477311926808, 0.06758414818694233, -0.009011537058698997, -0.09139170665445415, -0.17499760171649797, -0.254829433326894, -0.32567778292945404, -0.382375848005458, -0.4200602785751461, -0.43442757176285574, -0.42197287899622543, -0.3801986514917913, -0.3077817863653888, -0.20468978410715197, -0.0722388011028484, 0.08691073780520595, 0.2688222513075441, 0.4684129583840573, 0.6796406846183429, 0.8957396184216221, 1.1094945766040856, 1.3135412961886945, 1.500678835049543, 1.6641794167481594, 1.7980810383563555, 1.8974488797623419, 1.9585929762944412, 1.9792316740361835, 1.9585929762944412, 1.8974488797623419, 1.7980810383563555, 1.6641794167481594, 1.500678835049543, 1.3135412961886945, 1.1094945766040856, 0.8957396184216221, 0.6796406846183429, 0.4684129583840573, 0.2688222513075441, 0.08691073780520595, -0.0722388011028484, -0.20468978410715197, -0.3077817863653888, -0.3801986514917913, -0.42197287899622543, -0.43442757176285574, -0.4200602785751461, -0.382375848005458, -0.32567778292945404, -0.254829433326894, -0.17499760171649797, -0.09139170665445415, -0.009011537058698997, 0.06758414818694233, 0.134477311926808, 0.18854967763954522, 0.22759450814784551, 0.25037713957121355, 0.2566430509401283, 0.24707500803079696, 0.2232034254780841, 0.18727640924644018, 0.14209785531573388, 0.09084339726921295, 0.03686485131708162, -0.016505930263581485, -0.06614321685638791], [-0.1107536917561867, -0.06793803188546253, -0.01855449981019833, 0.03466854669458865, 0.08862652853638416, 0.14000357308347133, 0.18545724476618586, 0.22181346801290225, 0.24626113579560338, 0.25653555744366946, 0.25108014921898075, 0.22917661128094333, 0.19103523332295086, 0.13783886506830845, 0.07173638515428266, -0.004215913110515241, -0.08616386191642225, -0.1696119802323752, -0.24962054293732017, -0.3210343185560354, -0.3787322233669178, -0.417885750201407, -0.434213248547002, -0.42421701152445723, -0.3853906832849483, -0.3163857196862348, -0.21712746254366178, -0.08887373699192957, 0.0657883626364726, 0.24300880867803662, 0.43780226922078175, 0.6442321103834694, 0.8556429685382863, 1.0649315658049785, 1.2648434125627805, 1.4482816142111579, 1.608613254431116, 1.7399588071171015, 1.8374507397311368, 1.8974488797623419, 1.917702154416812, 1.8974488797623419, 1.8374507397311368, 1.7399588071171015, 1.608613254431116, 1.4482816142111579, 1.2648434125627805, 1.0649315658049785, 0.8556429685382863, 0.6442321103834694, 0.43780226922078175, 0.24300880867803662, 0.0657883626364726, -0.08887373699192957, -0.21712746254366178, -0.3163857196862348, -0.3853906832849483, -0.42421701152445723, -0.434213248547002, -0.417885750201407, -0.3787322233669178, -0.3210343185560354, -0.24962054293732017, -0.1696119802323752, -0.08616386191642225, -0.004215913110515241, 0.07173638515428266, 0.13783886506830845, 0.19103523332295086, 0.22917661128094333, 0.25108014921898075, 0.25653555744366946, 0.24626113579560338, 0.22181346801290225, 0.18545724476618586, 0.14000357308347133, 0.08862652853638416, 0.03466854669458865, -0.01855449981019833, -0.06793803188546253], [-0.1131560467581887, -0.07090368426500879, -0.021950582012676394, 0.031016232090896562, 0.08492762656935865, 0.13649472168344115, 0.18239124981424537, 0.21944644111666822, 0.24483804991090946, 0.2562747828163765, 0.252157618714697, 0.2317103248693539, 0.19507084218595108, 0.1433370736825879, 0.07856287339249271, 0.0037025838949493145, -0.07749482277960204, -0.16063822727306362, -0.24088710992360066, -0.31317589634427284, -0.37245933283868765, -0.41396693622794944, -0.4334537754581445, -0.4274347075936389, -0.39338972722403176, -0.32992927901128904, -0.23691017597600564, -0.11549507625799743, 0.03184881503912622, 0.20141317105264114, 0.38837235101706136, 0.5869627944413911, 0.7907103570985019, 0.992695449836068, 1.1858438330909473, 1.3632295064019535, 1.518375390968938, 1.6455374774968983, 1.7399588071171015, 1.7980810383563555, 1.8177033600622243, 1.7980810383563555, 1.7399588071171015, 1.6455374774968983, 1.518375390968938, 1.3632295064019535, 1.1858438330909473, 0.992695449836068, 0.7907103570985019, 0.5869627944413911, 0.38837235101706136, 0.20141317105264114, 0.03184881503912622, -0.11549507625799743, -0.23691017597600564, -0.32992927901128904, -0.39338972722403176, -0.4274347075936389, -0.4334537754581445, -0.41396693622794944, -0.37245933283868765, -0.31317589634427284, -0.24088710992360066, -0.16063822727306362, -0.07749482277960204, 0.0037025838949493145, 0.07856287339249271, 0.1433370736825879, 0.19507084218595108, 0.2317103248693539, 0.252157618714697, 0.2562747828163765, 0.24483804991090946, 0.21944644111666822, 0.18239124981424537, 0.13649472168344115, 0.08492762656935865, 0.031016232090896562, -0.021950582012676394, -0.07090368426500879], [-0.1164544699167505, -0.0750007897964791, -0.026665677985416577, 0.025921773001301992, 0.07974244535617742, 0.13154597877649798, 0.17802983029511174, 0.21602931256266372, 0.242708395806646, 0.2557406839380664, 0.25347017586536014, 0.23504220166614895, 0.20049625055173417, 0.15081422331281308, 0.08791985781076668, 0.014627580006334946, -0.06545830501430487, -0.14809048863531396, -0.22856545626592412, -0.30194177876754097, -0.3632795822101567, -0.407889497747319, -0.43157859884674826, -0.4308806796227811, -0.40325873487122593, -0.3472686537517362, -0.2626748843273063, -0.15051108239111077, -0.0130814139378774, 0.14609889758077332, 0.32242214992953067, 0.5103612401471838, 0.7036898157513979, 0.8957396184216221, 1.0796831610910465, 1.2488284837498442, 1.3969119972732167, 1.518375390968938, 1.608613254431116, 1.6641794167481594, 1.682941969615793, 1.6641794167481594, 1.608613254431116, 1.518375390968938, 1.3969119972732167, 1.2488284837498442, 1.0796831610910465, 0.8957396184216221, 0.7036898157513979, 0.5103612401471838, 0.32242214992953067, 0.14609889758077332, -0.0130814139378774, -0.15051108239111077, -0.2626748843273063, -0.3472686537517362, -0.40325873487122593, -0.4308806796227811, -0.43157859884674826, -0.407889497747319, -0.3632795822101567, -0.30194177876754097, -0.22856545626592412, -0.14809048863531396, -0.06545830501430487, 0.014627580006334946, 0.08791985781076668, 0.15081422331281308, 0.20049625055173417, 0.23504220166614895, 0.25347017586536014, 0.2557406839380664, 0.242708395806646, 0.21602931256266372, 0.17802983029511174, 0.13154597877649798, 0.07974244535617742, 0.025921773001301992, -0.026665677985416577, -0.0750007897964791], [-0.12058300781296416, -0.08017262722723162, -0.032657564269347995, 0.019407660252202565, 0.07306884206017318, 0.12512633286074154, 0.17230988766358785, 0.21146505144444128, 0.23974108638511749, 0.25477004091850136, 0.2548267267047997, 0.23896010343988033, 0.2070878465419809, 0.16004763127913005, 0.09960082298540655, 0.02838670735216783, -0.050171999808914604, -0.132008995765264, -0.2125937105436689, -0.28714197491104243, -0.35084804028714445, -0.3991265770886398, -0.42785247459104203, -0.4335860886421158, -0.4137720534188708, -0.36690087535799776, -0.2926242127644853, -0.19181693290541052, -0.06658162124929747, 0.07980593576993696, 0.24300880867803662, 0.4177941096414197, 0.5982441516081277, 0.7780040258931075, 0.9505541014891831, 1.1094945766040856, 1.2488284837498442, 1.3632295064019535, 1.4482816142111579, 1.500678835049543, 1.518375390968938, 1.500678835049543, 1.4482816142111579, 1.3632295064019535, 1.2488284837498442, 1.1094945766040856, 0.9505541014891831, 0.7780040258931075, 0.5982441516081277, 0.4177941096414197, 0.24300880867803662, 0.07980593576993696, -0.06658162124929747, -0.19181693290541052, -0.2926242127644853, -0.36690087535799776, -0.4137720534188708, -0.4335860886421158, -0.42785247459104203, -0.3991265770886398, -0.35084804028714445, -0.28714197491104243, -0.2125937105436689, -0.132008995765264, -0.050171999808914604, 0.02838670735216783, 0.09960082298540655, 0.16004763127913005, 0.2070878465419809, 0.23896010343988033, 0.2548267267047997, 0.25477004091850136, 0.23974108638511749, 0.21146505144444128, 0.17230988766358785, 0.12512633286074154, 0.07306884206017318, 0.019407660252202565, -0.032657564269347995, -0.08017262722723162], [-0.1254554756233313, -0.08634370978474622, -0.039868134180728126, 0.011507919583092052, 0.0649104168254659, 0.11720338291232232, 0.16515865057394133, 0.20563779959612533, 0.23577655069724138, 0.2531614457800734, 0.2559887694405144, 0.2431963471432226, 0.21456006847846779, 0.17074867404778504, 0.11333242903336226, 0.044743679368913644, -0.03181017613329085, -0.11247819731414006, -0.1929363397545002, -0.268589046149572, -0.33479237619194996, -0.38708768931988075, -0.42143408131469146, -0.43442757176285574, -0.42349546556438716, -0.38705535500366767, -0.324629843053556, -0.23691017597600564, -0.1257644689695074, 0.005811034304373925, 0.1537963512162099, 0.3133036361206578, 0.47877771528316515, 0.6442321103834694, 0.803509484779075, 0.9505541014891831, 1.0796831610910465, 1.1858438330909473, 1.2648434125627805, 1.3135412961886945, 1.3299933154720727, 1.3135412961886945, 1.2648434125627805, 1.1858438330909473, 1.0796831610910465, 0.9505541014891831, 0.803509484779075, 0.6442321103834694, 0.47877771528316515, 0.3133036361206578, 0.1537963512162099, 0.005811034304373925, -0.1257644689695074, -0.23691017597600564, -0.324629843053556, -0.38705535500366767, -0.42349546556438716, -0.43442757176285574, -0.42143408131469146, -0.38708768931988075, -0.33479237619194996, -0.268589046149572, -0.1929363397545002, -0.11247819731414006, -0.03181017613329085, 0.044743679368913644, 0.11333242903336226, 0.17074867404778504, 0.21456006847846779, 0.2431963471432226, 0.2559887694405144, 0.2531614457800734, 0.23577655069724138, 0.20563779959612533, 0.16515865057394133, 0.11720338291232232, 0.0649104168254659, 0.011507919583092052, -0.039868134180728126, -0.08634370978474622], [-0.13096468174943518, -0.09341816596346665, -0.04822085787410071, 0.0022716100207446164, 0.05528095770522729, 0.10774865812501504, 0.15649972810645998, 0.19841943861188654, 0.23063350923189954, 0.2506818889186662, 0.2566762997375786, 0.24743234013685533, 0.2225680860000738, 0.18256273925541686, 0.12877087581897034, 0.06339013493636744, -0.010617349295218181, -0.08964697741323371, -0.1696119802323752, -0.24613461781837798, -0.31475910259630246, -0.37117570680030565, -0.41144469052055266, -0.43220845214435083, -0.4308806796227811, -0.40580225753498556, -0.35635521764627226, -0.28302803533990717, -0.187427969950852, -0.0722388011028484, 0.05887491198907235, 0.20141317105264114, 0.35022902170777614, 0.49975144871271493, 0.6442321103834694, 0.7780040258931075, 0.8957396184216221, 0.992695449836068, 1.0649315658049785, 1.1094945766040856, 1.124555367855928, 1.1094945766040856, 1.0649315658049785, 0.992695449836068, 0.8957396184216221, 0.7780040258931075, 0.6442321103834694, 0.49975144871271493, 0.35022902170777614, 0.20141317105264114, 0.05887491198907235, -0.0722388011028484, -0.187427969950852, -0.28302803533990717, -0.35635521764627226, -0.40580225753498556, -0.4308806796227811, -0.43220845214435083, -0.41144469052055266, -0.37117570680030565, -0.31475910259630246, -0.24613461781837798, -0.1696119802323752, -0.08964697741323371, -0.010617349295218181, 0.06339013493636744, 0.12877087581897034, 0.18256273925541686, 0.2225680860000738, 0.24743234013685533, 0.2566762997375786, 0.2506818889186662, 0.23063350923189954, 0.19841943861188654, 0.15649972810645998, 0.10774865812501504, 0.05528095770522729, 0.0022716100207446164, -0.04822085787410071, -0.09341816596346665], [-0.13698176393514344, -0.10127808535368477, -0.05761803324395176, -0.00823327044894154, 0.044209509361482956, 0.09674378883254962, 0.14626024334832619, 0.18967745729212915, 0.22411724822563847, 0.24707500803079696, 0.256575492104657, 0.25130504004127213, 0.23071227369415245, 0.19507084218595108, 0.14549969299473817, 0.08393854575868848, 0.013078615468659323, -0.06374895250625122, -0.1427221428215067, -0.21970771693043264, -0.29046275344788247, -0.35084804028714445, -0.3970424421347404, -0.42574709936268906, -0.43436863670247905, -0.421171462695804, -0.3853906832849483, -0.32729906443176787, -0.24822376277499153, -0.15051108239111077, -0.03744017720227128, 0.08691073780520595, 0.21783961811686398, 0.35022902170777614, 0.47877771528316515, 0.5982441516081277, 0.7036898157513979, 0.7907103570985019, 0.8556429685382863, 0.8957396184216221, 0.9092974268256817, 0.8957396184216221, 0.8556429685382863, 0.7907103570985019, 0.7036898157513979, 0.5982441516081277, 0.47877771528316515, 0.35022902170777614, 0.21783961811686398, 0.08691073780520595, -0.03744017720227128, -0.15051108239111077, -0.24822376277499153, -0.32729906443176787, -0.3853906832849483, -0.421171462695804, -0.43436863670247905, -0.42574709936268906, -0.3970424421347404, -0.35084804028714445, -0.29046275344788247, -0.21970771693043264, -0.1427221428215067, -0.06374895250625122, 0.013078615468659323, 0.08393854575868848, 0.14549969299473817, 0.19507084218595108, 0.23071227369415245, 0.25130504004127213, 0.256575492104657, 0.24707500803079696, 0.22411724822563847, 0.18967745729212915, 0.14626024334832619, 0.09674378883254962, 0.044209509361482956, -0.00823327044894154, -0.05761803324395176, -0.10127808535368477], [-0.14335579129849668, -0.10978201113265723, -0.06793803188546253, -0.019915691575644292, 0.031745840459068614, 0.08418731130237875, 0.13437885433763305, 0.1792839709402817, 0.21602931256266372, 0.2420710146043941, 0.255348298963932, 0.25441554164532254, 0.23854497801642713, 0.20779364608280457, 0.1630299764243758, 0.10591753298818528, 0.03885568116655977, -0.03512071345143313, -0.11247819731414006, -0.18935183535374994, -0.2617343483375656, -0.32567778292945404, -0.37749737145928347, -0.41396693622794944, -0.43249545715781157, -0.4312752446188071, -0.4093935036702951, -0.36690087535799776, -0.30483270332925, -0.22518118755916025, -0.13081912452072303, -0.025378460035175753, 0.08691073780520595, 0.20141317105264114, 0.3133036361206578, 0.4177941096414197, 0.5103612401471838, 0.5869627944413911, 0.6442321103834694, 0.6796406846183429, 0.69162061945593, 0.6796406846183429, 0.6442321103834694, 0.5869627944413911, 0.5103612401471838, 0.4177941096414197, 0.3133036361206578, 0.20141317105264114, 0.08691073780520595, -0.025378460035175753, -0.13081912452072303, -0.22518118755916025, -0.30483270332925, -0.36690087535799776, -0.4093935036702951, -0.4312752446188071, -0.43249545715781157, -0.41396693622794944, -0.37749737145928347, -0.32567778292945404, -0.2617343483375656, -0.18935183535374994, -0.11247819731414006, -0.03512071345143313, 0.03885568116655977, 0.10591753298818528, 0.1630299764243758, 0.20779364608280457, 0.23854497801642713, 0.25441554164532254, 0.255348298963932, 0.2420710146043941, 0.21602931256266372, 0.1792839709402817, 0.13437885433763305, 0.08418731130237875, 0.031745840459068614, -0.019915691575644292, -0.06793803188546253, -0.10978201113265723], [-0.1499137997580331, -0.11876378051842666, -0.07903277128303789, -0.032657564269347995, 0.017966041941118966, 0.07010183827093616, 0.12081441070397907, 0.16712567793535366, 0.2061784643801796, 0.23539823538075702, 0.25264402764959015, 0.2563400102730029, 0.2455799958764798, 0.22019854657881394, 0.18080401871815463, 0.12877087581897034, 0.0661907655654817, -0.004215913110515241, -0.0792240541655952, -0.15525760655490364, -0.22856545626592412, -0.29541051237375787, -0.35226222727992795, -0.39598244357893553, -0.42399466300627076, -0.43442757176285574, -0.42622489689420734, -0.39921534828629784, -0.3541384336243295, -0.2926242127644853, -0.21712746254366178, -0.13081912452072303, -0.03744017720227128, 0.05887491198907235, 0.1537963512162099, 0.24300880867803662, 0.32242214992953067, 0.38837235101706136, 0.43780226922078175, 0.4684129583840573, 0.47877771528316515, 0.4684129583840573, 0.43780226922078175, 0.38837235101706136, 0.32242214992953067, 0.24300880867803662, 0.1537963512162099, 0.05887491198907235, -0.03744017720227128, -0.13081912452072303, -0.21712746254366178, -0.2926242127644853, -0.3541384336243295, -0.39921534828629784, -0.42622489689420734, -0.43442757176285574, -0.42399466300627076, -0.39598244357893553, -0.35226222727992795, -0.29541051237375787, -0.22856545626592412, -0.15525760655490364, -0.0792240541655952, -0.004215913110515241, 0.0661907655654817, 0.12877087581897034, 0.18080401871815463, 0.22019854657881394, 0.2455799958764798, 0.2563400102730029, 0.25264402764959015, 0.23539823538075702, 0.2061784643801796, 0.16712567793535366, 0.12081441070397907, 0.07010183827093616, 0.017966041941118966, -0.032657564269347995, -0.07903277128303789, -0.11876378051842666], [-0.15646143337355978, -0.12803192632998142, -0.0907256642328181, -0.046310064114579955, 0.0029779491154211806, 0.054541276561040686, 0.10555493165712146, 0.15311446345017118, 0.1943926655354523, 0.22679610352037188, 0.24811283911536614, 0.2566430509401283, 0.25130504004127213, 0.2317103248693539, 0.1982031145119569, 0.15186131748507978, 0.09445829662141196, 0.02838670735216783, -0.043452159632214875, -0.1177881852505473, -0.19114437378651342, -0.26001264723920775, -0.3210343185560354, -0.37117570680030565, -0.407889497747319, -0.42925310491460716, -0.434076417833265, -0.42197287899622543, -0.39338972722403176, -0.3495953826561967, -0.2926242127644853, -0.22518118755916025, -0.15051108239111077, -0.0722388011028484, 0.005811034304373925, 0.07980593576993696, 0.14609889758077332, 0.20141317105264114, 0.24300880867803662, 0.2688222513075441, 0.277571630583514, 0.2688222513075441, 0.24300880867803662, 0.20141317105264114, 0.14609889758077332, 0.07980593576993696, 0.005811034304373925, -0.0722388011028484, -0.15051108239111077, -0.22518118755916025, -0.2926242127644853, -0.3495953826561967, -0.39338972722403176, -0.42197287899622543, -0.434076417833265, -0.42925310491460716, -0.407889497747319, -0.37117570680030565, -0.3210343185560354, -0.26001264723920775, -0.19114437378651342, -0.1177881852505473, -0.043452159632214875, 0.02838670735216783, 0.09445829662141196, 0.15186131748507978, 0.1982031145119569, 0.2317103248693539, 0.25130504004127213, 0.2566430509401283, 0.24811283911536614, 0.22679610352037188, 0.1943926655354523, 0.15311446345017118, 0.10555493165712146, 0.054541276561040686, 0.0029779491154211806, -0.046310064114579955, -0.0907256642328181, -0.12803192632998142], [-0.16278435980926842, -0.13736985507049018, -0.10281030706494565, -0.060690608986011814, -0.013073952151520388, 0.03759772656874239, 0.08862652853638416, 0.13719827990417027, 0.18053174205108255, 0.21602931256266372, 0.24142096714711753, 0.254893432701845, 0.25519727019112654, 0.24172565029557566, 0.21456006847846779, 0.17447999195279823, 0.12293536517635703, 0.06198291759831892, -0.005810793613848673, -0.07749482277960204, -0.14988136590815446, -0.21970771693043264, -0.2838041182964338, -0.3392585664190622, -0.3835697098652554, -0.4147795406040892, -0.43157859884674826, -0.4333778373354074, -0.4203430458705095, -0.39338972722403176, -0.3541384336243295, -0.30483270332925, -0.24822376277499153, -0.187427969950852, -0.1257644689695074, -0.06658162124929747, -0.0130814139378774, 0.03184881503912622, 0.0657883626364726, 0.08691073780520595, 0.0940800053732448, 0.08691073780520595, 0.0657883626364726, 0.03184881503912622, -0.0130814139378774, -0.06658162124929747, -0.1257644689695074, -0.187427969950852, -0.24822376277499153, -0.30483270332925, -0.3541384336243295, -0.39338972722403176, -0.4203430458705095, -0.4333778373354074, -0.43157859884674826, -0.4147795406040892, -0.3835697098652554, -0.3392585664190622, -0.2838041182964338, -0.21970771693043264, -0.14988136590815446, -0.07749482277960204, -0.005810793613848673, 0.06198291759831892, 0.12293536517635703, 0.17447999195279823, 0.21456006847846779, 0.24172565029557566, 0.25519727019112654, 0.254893432701845, 0.24142096714711753, 0.21602931256266372, 0.18053174205108255, 0.13719827990417027, 0.08862652853638416, 0.03759772656874239, -0.013073952151520388, -0.060690608986011814, -0.10281030706494565, -0.13736985507049018], [-0.16865061331126227, -0.14653700801271363, -0.11505016730310495, -0.07558080422426758, -0.030004497243790427, 0.019407660252202565, 0.07010183827093616, 0.11937185506223688, 0.16450028494360933, 0.20290271423033404, 0.23226729318028777, 0.2506818889186662, 0.2567417315441088, 0.24963143467045815, 0.22917661128094333, 0.19586192453391038, 0.15081422331281308, 0.0957513146109, 0.032898814044057145, -0.03512071345143313, -0.10542055787501849, -0.17499760171649797, -0.24088710992360066, -0.3003162506586467, -0.35084804028714445, -0.3905078789395116, -0.417885750201407, -0.43220845214435083, -0.4333778373354074, -0.42197287899622543, -0.39921534828629784, -0.36690087535799776, -0.32729906443176787, -0.28302803533990717, -0.23691017597600564, -0.19181693290541052, -0.15051108239111077, -0.11549507625799743, -0.08887373699192957, -0.0722388011028484, -0.06658162124929747, -0.0722388011028484, -0.08887373699192957, -0.11549507625799743, -0.15051108239111077, -0.19181693290541052, -0.23691017597600564, -0.28302803533990717, -0.32729906443176787, -0.36690087535799776, -0.39921534828629784, -0.42197287899622543, -0.4333778373354074, -0.43220845214435083, -0.417885750201407, -0.3905078789395116, -0.35084804028714445, -0.3003162506586467, -0.24088710992360066, -0.17499760171649797, -0.10542055787501849, -0.03512071345143313, 0.032898814044057145, 0.0957513146109, 0.15081422331281308, 0.19586192453391038, 0.22917661128094333, 0.24963143467045815, 0.2567417315441088, 0.2506818889186662, 0.23226729318028777, 0.20290271423033404, 0.16450028494360933, 0.11937185506223688, 0.07010183827093616, 0.019407660252202565, -0.030004497243790427, -0.07558080422426758, -0.11505016730310495, -0.14653700801271363], [-0.1738139924448547, -0.15527119023634722, -0.1271795169340972, -0.0907256642328181, -0.04758506314163741, 0.0001569493213448689, 0.05010748884225075, 0.09968670899986165, 0.14626024334832619, 0.18727640924644018, 0.22040074178662336, 0.24364050109720906, 0.2554522819126627, 0.2548267267047997, 0.2413455569066888, 0.2152076253393881, 0.17722237538812438, 0.12877087581897034, 0.07173638515428266, 0.00840808631479302, -0.05863687417657578, -0.12666669235949252, -0.1929363397545002, -0.254829433326894, -0.309992807249447, -0.3564564355250057, -0.39273214882544505, -0.417885750201407, -0.43157859884674826, -0.434076417833265, -0.42622489689420734, -0.4093935036702951, -0.3853906832849483, -0.35635521764627226, -0.324629843053556, -0.2926242127644853, -0.2626748843273063, -0.23691017597600564, -0.21712746254366178, -0.20468978410715197, -0.20044755867978276, -0.20468978410715197, -0.21712746254366178, -0.23691017597600564, -0.2626748843273063, -0.2926242127644853, -0.324629843053556, -0.35635521764627226, -0.3853906832849483, -0.4093935036702951, -0.42622489689420734, -0.434076417833265, -0.43157859884674826, -0.417885750201407, -0.39273214882544505, -0.3564564355250057, -0.309992807249447, -0.254829433326894, -0.1929363397545002, -0.12666669235949252, -0.05863687417657578, 0.00840808631479302, 0.07173638515428266, 0.12877087581897034, 0.17722237538812438, 0.2152076253393881, 0.2413455569066888, 0.2548267267047997, 0.2554522819126627, 0.24364050109720906, 0.22040074178662336, 0.18727640924644018, 0.14626024334832619, 0.09968670899986165, 0.05010748884225075, 0.0001569493213448689, -0.04758506314163741, -0.0907256642328181, -0.1271795169340972, -0.15527119023634722], [-0.17801860199902664, -0.16329221750830802, -0.13890582780165694, -0.10583439818051152, -0.06554239869174844, -0.019915691575644292, 0.02883009042098063, 0.07825990831739421, 0.1258425822940911, 0.16908036038891633, 0.20563779959612533, 0.23346296309158113, 0.2508943222213973, 0.25674750760048576, 0.25037713957121355, 0.2317103248693539, 0.20124995852555586, 0.16004763127913005, 0.1096476200446325, 0.05200503792795912, -0.010617349295218181, -0.0757679524450742, -0.1409342819269669, -0.2036729142303004, -0.2617343483375656, -0.31317589634427284, -0.3564564355250057, -0.3905078789395116, -0.4147795406040892, -0.42925310491460716, -0.43442757176285574, -0.4312752446188071, -0.421171462695804, -0.40580225753498556, -0.38705535500366767, -0.36690087535799776, -0.3472686537517362, -0.32992927901128904, -0.3163857196862348, -0.3077817863653888, -0.30483270332925, -0.3077817863653888, -0.3163857196862348, -0.32992927901128904, -0.3472686537517362, -0.36690087535799776, -0.38705535500366767, -0.40580225753498556, -0.421171462695804, -0.4312752446188071, -0.43442757176285574, -0.42925310491460716, -0.4147795406040892, -0.3905078789395116, -0.3564564355250057, -0.31317589634427284, -0.2617343483375656, -0.2036729142303004, -0.1409342819269669, -0.0757679524450742, -0.010617349295218181, 0.05200503792795912, 0.1096476200446325, 0.16004763127913005, 0.20124995852555586, 0.2317103248693539, 0.25037713957121355, 0.25674750760048576, 0.2508943222213973, 0.23346296309158113, 0.20563779959612533, 0.16908036038891633, 0.1258425822940911, 0.07825990831739421, 0.02883009042098063, -0.019915691575644292, -0.06554239869174844, -0.10583439818051152, -0.13890582780165694, -0.16329221750830802], [-0.18100457917857166, -0.17030698199702413, -0.1499137997580331, -0.12058300781296416, -0.08355939645450051, -0.040517266401149735, 0.0065202421682302655, 0.05528095770522729, 0.10335731863015635, 0.14832776112580212, 0.18787932061729182, 0.21992483146863692, 0.242708395806646, 0.254893432701845, 0.25562857790064414, 0.24458792842044305, 0.22198354690007724, 0.18854967763954522, 0.14549969299473817, 0.09445829662141196, 0.037372873633869375, -0.02359098016854476, -0.08616386191642225, -0.14809048863531396, -0.20724458052139974, -0.2617343483375656, -0.309992807249447, -0.35084804028714445, -0.3835697098652554, -0.407889497747319, -0.42399466300627076, -0.43249545715781157, -0.43436863670247905, -0.4308806796227811, -0.42349546556438716, -0.4137720534188708, -0.40325873487122593, -0.39338972722403176, -0.3853906832849483, -0.3801986514917913, -0.3784012476539641, -0.3801986514917913, -0.3853906832849483, -0.39338972722403176, -0.40325873487122593, -0.4137720534188708, -0.42349546556438716, -0.4308806796227811, -0.43436863670247905, -0.43249545715781157, -0.42399466300627076, -0.407889497747319, -0.3835697098652554, -0.35084804028714445, -0.309992807249447, -0.2617343483375656, -0.20724458052139974, -0.14809048863531396, -0.08616386191642225, -0.02359098016854476, 0.037372873633869375, 0.09445829662141196, 0.14549969299473817, 0.18854967763954522, 0.22198354690007724, 0.24458792842044305, 0.25562857790064414, 0.254893432701845, 0.242708395806646, 0.21992483146863692, 0.18787932061729182, 0.14832776112580212, 0.10335731863015635, 0.05528095770522729, 0.0065202421682302655, -0.040517266401149735, -0.08355939645450051, -0.12058300781296416, -0.1499137997580331, -0.17030698199702413], [-0.18251498442862385, -0.1760159755489718, -0.15987112992755653, -0.13461888616197776, -0.10127808535368477, -0.061301442485772274, -0.016505930263581485, 0.031016232090896562, 0.07900122348247962, 0.12512633286074154, 0.16712567793535366, 0.20290271423033404, 0.23063350923189954, 0.24885528388828942, 0.25653555744366946, 0.25311832399967577, 0.23854497801642713, 0.21324911772700825, 0.17812580971586786, 0.134477311926808, 0.08393854575868848, 0.02838670735216783, -0.030159748399708135, -0.08964697741323371, -0.14809048863531396, -0.2036729142303004, -0.254829433326894, -0.3003162506586467, -0.3392585664190622, -0.37117570680030565, -0.39598244357893553, -0.41396693622794944, -0.42574709936268906, -0.43220845214435083, -0.43442757176285574, -0.4335860886421158, -0.4308806796227811, -0.4274347075936389, -0.42421701152445723, -0.42197287899622543, -0.421171462695804, -0.42197287899622543, -0.42421701152445723, -0.4274347075936389, -0.4308806796227811, -0.4335860886421158, -0.43442757176285574, -0.43220845214435083, -0.42574709936268906, -0.41396693622794944, -0.39598244357893553, -0.37117570680030565, -0.3392585664190622, -0.3003162506586467, -0.254829433326894, -0.2036729142303004, -0.14809048863531396, -0.08964697741323371, -0.030159748399708135, 0.02838670735216783, 0.08393854575868848, 0.134477311926808, 0.17812580971586786, 0.21324911772700825, 0.23854497801642713, 0.25311832399967577, 0.25653555744366946, 0.24885528388828942, 0.23063350923189954, 0.20290271423033404, 0.16712567793535366, 0.12512633286074154, 0.07900122348247962, 0.031016232090896562, -0.016505930263581485, -0.061301442485772274, -0.10127808535368477, -0.13461888616197776, -0.15987112992755653, -0.1760159755489718], [-0.18230376872794093, -0.18012123502583363, -0.16843605361995675, -0.14756752732225356, -0.11830504740258321, -0.08187218787401292, -0.039868134180728126, 0.0058103924762656495, 0.05306249567952219, 0.09968670899986165, 0.14348926836260514, 0.18239124981424537, 0.2145288714461612, 0.2383416766936446, 0.25264402764959015, 0.2566762997375786, 0.25013332713993036, 0.23316893482082693, 0.2063767337439853, 0.17074867404778504, 0.12761407121954643, 0.07856287339249271, 0.02535776443828009, -0.030159748399708135, -0.08616386191642225, -0.1409342819269669, -0.1929363397545002, -0.24088710992360066, -0.2838041182964338, -0.3210343185560354, -0.35226222727992795, -0.37749737145928347, -0.3970424421347404, -0.41144469052055266, -0.42143408131469146, -0.42785247459104203, -0.43157859884674826, -0.4334537754581445, -0.434213248547002, -0.43442757176285574, -0.43445783007337646, -0.43442757176285574, -0.434213248547002, -0.4334537754581445, -0.43157859884674826, -0.42785247459104203, -0.42143408131469146, -0.41144469052055266, -0.3970424421347404, -0.37749737145928347, -0.35226222727992795, -0.3210343185560354, -0.2838041182964338, -0.24088710992360066, -0.1929363397545002, -0.1409342819269669, -0.08616386191642225, -0.030159748399708135, 0.02535776443828009, 0.07856287339249271, 0.12761407121954643, 0.17074867404778504, 0.2063767337439853, 0.23316893482082693, 0.25013332713993036, 0.2566762997375786, 0.25264402764959015, 0.2383416766936446, 0.2145288714461612, 0.18239124981424537, 0.14348926836260514, 0.09968670899986165, 0.05306249567952219, 0.0058103924762656495, -0.039868134180728126, -0.08187218787401292, -0.11830504740258321, -0.14756752732225356, -0.16843605361995675, -0.18012123502583363], [-0.1801446545297837, -0.18233559039097344, -0.1752665961050691, -0.15904136091487175, -0.13421936300715656, -0.10179031338845618, -0.0631265026963309, -0.019915691575644292, 0.025921773001301992, 0.07232710218505171, 0.11720338291232232, 0.15851669454452746, 0.1943926655354523, 0.2232034254780841, 0.24364050109720906, 0.25477004091850136, 0.2560677827399544, 0.24743234013685533, 0.22917661128094333, 0.20199833430642128, 0.16693195814109418, 0.12528500092613942, 0.07856287339249271, 0.02838670735216783, -0.02359098016854476, -0.0757679524450742, -0.12666669235949252, -0.17499760171649797, -0.21970771693043264, -0.26001264723920775, -0.29541051237375787, -0.32567778292945404, -0.35084804028714445, -0.37117570680030565, -0.38708768931988075, -0.3991265770886398, -0.407889497747319, -0.41396693622794944, -0.417885750201407, -0.4200602785751461, -0.4207548585159486, -0.4200602785751461, -0.417885750201407, -0.41396693622794944, -0.407889497747319, -0.3991265770886398, -0.38708768931988075, -0.37117570680030565, -0.35084804028714445, -0.32567778292945404, -0.29541051237375787, -0.26001264723920775, -0.21970771693043264, -0.17499760171649797, -0.12666669235949252, -0.0757679524450742, -0.02359098016854476, 0.02838670735216783, 0.07856287339249271, 0.12528500092613942, 0.16693195814109418, 0.20199833430642128, 0.22917661128094333, 0.24743234013685533, 0.2560677827399544, 0.25477004091850136, 0.24364050109720906, 0.2232034254780841, 0.1943926655354523, 0.15851669454452746, 0.11720338291232232, 0.07232710218505171, 0.025921773001301992, -0.019915691575644292, -0.0631265026963309, -0.10179031338845618, -0.13421936300715656, -0.15904136091487175, -0.1752665961050691, -0.18233559039097344], [-0.17584069010379264, -0.18239300622958532, -0.1800313728705813, -0.16865061331126227, -0.14858307017251748, -0.12058300781296416, -0.0857896329957062, -0.045670869380806056, -0.001951040868825416, 0.043473546354522816, 0.08862652853638416, 0.13154597877649798, 0.17037647050011584, 0.20345392533496165, 0.22937894091767205, 0.24707500803079696, 0.25582893038458626, 0.2553118000893658, 0.2455799958764798, 0.2270567942100705, 0.20049625055173417, 0.16693195814109418, 0.12761407121954643, 0.08393854575868848, 0.037372873633869375, -0.010617349295218181, -0.05863687417657578, -0.10542055787501849, -0.14988136590815446, -0.19114437378651342, -0.22856545626592412, -0.2617343483375656, -0.29046275344788247, -0.31475910259630246, -0.33479237619194996, -0.35084804028714445, -0.3632795822101567, -0.37245933283868765, -0.3787322233669178, -0.382375848005458, -0.3835697098652554, -0.382375848005458, -0.3787322233669178, -0.37245933283868765, -0.3632795822101567, -0.35084804028714445, -0.33479237619194996, -0.31475910259630246, -0.29046275344788247, -0.2617343483375656, -0.22856545626592412, -0.19114437378651342, -0.14988136590815446, -0.10542055787501849, -0.05863687417657578, -0.010617349295218181, 0.037372873633869375, 0.08393854575868848, 0.12761407121954643, 0.16693195814109418, 0.20049625055173417, 0.2270567942100705, 0.2455799958764798, 0.2553118000893658, 0.25582893038458626, 0.24707500803079696, 0.22937894091767205, 0.20345392533496165, 0.17037647050011584, 0.13154597877649798, 0.08862652853638416, 0.043473546354522816, -0.001951040868825416, -0.045670869380806056, -0.0857896329957062, -0.12058300781296416, -0.14858307017251748, -0.16865061331126227, -0.1800313728705813, -0.18239300622958532], [-0.16923416092386775, -0.1800597155006458, -0.18242166855756492, -0.1760159755489718, -0.1609539875623888, -0.1377563081818195, -0.10732612754693129, -0.07090368426500879, -0.030004497243790427, 0.013655158230898757, 0.058241427706856384, 0.1018902143955224, 0.14279404657238684, 0.1792839709402817, 0.20990234059772522, 0.23346296309158113, 0.24909585663212155, 0.2562747828163765, 0.2548267267047997, 0.24492352037505036, 0.2270567942100705, 0.20199833430642128, 0.17074867404778504, 0.134477311926808, 0.09445829662141196, 0.05200503792795912, 0.00840808631479302, -0.03512071345143313, -0.07749482277960204, -0.1177881852505473, -0.15525760655490364, -0.18935183535374994, -0.21970771693043264, -0.24613461781837798, -0.268589046149572, -0.28714197491104243, -0.30194177876754097, -0.31317589634427284, -0.3210343185560354, -0.32567778292945404, -0.32721314035298743, -0.32567778292945404, -0.3210343185560354, -0.31317589634427284, -0.30194177876754097, -0.28714197491104243, -0.268589046149572, -0.24613461781837798, -0.21970771693043264, -0.18935183535374994, -0.15525760655490364, -0.1177881852505473, -0.07749482277960204, -0.03512071345143313, 0.00840808631479302, 0.05200503792795912, 0.09445829662141196, 0.134477311926808, 0.17074867404778504, 0.20199833430642128, 0.2270567942100705, 0.24492352037505036, 0.2548267267047997, 0.2562747828163765, 0.24909585663212155, 0.23346296309158113, 0.20990234059772522, 0.1792839709402817, 0.14279404657238684, 0.1018902143955224, 0.058241427706856384, 0.013655158230898757, -0.030004497243790427, -0.07090368426500879, -0.10732612754693129, -0.1377563081818195, -0.1609539875623888, -0.1760159755489718, -0.18242166855756492, -0.1800597155006458], [-0.16021647158282734, -0.1751457556394694, -0.1821644169794075, -0.18078273088932142, -0.17090060569317098, -0.1528102839666787, -0.1271795169340972, -0.0950164022704569, -0.05761803324395176, -0.016505930263581485, 0.026648129724923395, 0.07010183827093616, 0.11212338767979044, 0.15106960365711752, 0.18545724476618586, 0.21402402107025095, 0.23577655069724138, 0.25002327766855664, 0.25639126767027576, 0.2548267267047997, 0.2455799958764798, 0.22917661128094333, 0.2063767337439853, 0.17812580971586786, 0.14549969299473817, 0.1096476200446325, 0.07173638515428266, 0.032898814044057145, -0.005810793613848673, -0.043452159632214875, -0.0792240541655952, -0.11247819731414006, -0.1427221428215067, -0.1696119802323752, -0.1929363397545002, -0.2125937105436689, -0.22856545626592412, -0.24088710992360066, -0.24962054293732017, -0.254829433326894, -0.2565601183892334, -0.254829433326894, -0.24962054293732017, -0.24088710992360066, -0.22856545626592412, -0.2125937105436689, -0.1929363397545002, -0.1696119802323752, -0.1427221428215067, -0.11247819731414006, -0.0792240541655952, -0.043452159632214875, -0.005810793613848673, 0.032898814044057145, 0.07173638515428266, 0.1096476200446325, 0.14549969299473817, 0.17812580971586786, 0.2063767337439853, 0.22917661128094333, 0.2455799958764798, 0.2548267267047997, 0.25639126767027576, 0.25002327766855664, 0.23577655069724138, 0.21402402107025095, 0.18545724476618586, 0.15106960365711752, 0.11212338767979044, 0.07010183827093616, 0.026648129724923395, -0.016505930263581485, -0.05761803324395176, -0.0950164022704569, -0.1271795169340972, -0.1528102839666787, -0.17090060569317098, -0.18078273088932142, -0.1821644169794075, -0.1751457556394694], [-0.1487375524385824, -0.16751643729146143, -0.17903560277058095, -0.1826358700412797, -0.17801860199902664, -0.16525654180237792, -0.14478624788034108, -0.11738288358628372, -0.08411903827788304, -0.046310064114579955, -0.005449066140771361, 0.03686485131708162, 0.07900122348247962, 0.11937185506223688, 0.15649972810645998, 0.1890798565922851, 0.21602931256266372, 0.2365243422174828, 0.25002327766855664, 0.2562747828163765, 0.2553118000893658, 0.24743234013685533, 0.23316893482082693, 0.21324911772700825, 0.18854967763954522, 0.16004763127913005, 0.12877087581897034, 0.0957513146109, 0.06198291759831892, 0.02838670735216783, -0.004215913110515241, -0.03512071345143313, -0.06374895250625122, -0.08964697741323371, -0.11247819731414006, -0.132008995765264, -0.14809048863531396, -0.16063822727306362, -0.1696119802323752, -0.17499760171649797, -0.17679272260843765, -0.17499760171649797, -0.1696119802323752, -0.16063822727306362, -0.14809048863531396, -0.132008995765264, -0.11247819731414006, -0.08964697741323371, -0.06374895250625122, -0.03512071345143313, -0.004215913110515241, 0.02838670735216783, 0.06198291759831892, 0.0957513146109, 0.12877087581897034, 0.16004763127913005, 0.18854967763954522, 0.21324911772700825, 0.23316893482082693, 0.24743234013685533, 0.2553118000893658, 0.2562747828163765, 0.25002327766855664, 0.2365243422174828, 0.21602931256266372, 0.1890798565922851, 0.15649972810645998, 0.11937185506223688, 0.07900122348247962, 0.03686485131708162, -0.005449066140771361, -0.046310064114579955, -0.08411903827788304, -0.11738288358628372, -0.14478624788034108, -0.16525654180237792, -0.17801860199902664, -0.1826358700412797, -0.17903560277058095, -0.16751643729146143], [-0.13481430178982187, -0.15710321083861073, -0.17287351607260817, -0.18131560690315682, -0.18194839266053625, -0.17463748569481502, -0.15959621882048483, -0.13736985507049018, -0.10880422217787396, -0.0750007897964791, -0.03726086233570953, 0.0029779491154211806, 0.044209509361482956, 0.08492762656935865, 0.12369173187889267, 0.15918658398472915, 0.1902732638436695, 0.21602931256266372, 0.23577655069724138, 0.24909585663212155, 0.25582893038458626, 0.2560677827399544, 0.25013332713993036, 0.23854497801642713, 0.22198354690007724, 0.20124995852555586, 0.17722237538812438, 0.15081422331281308, 0.12293536517635703, 0.09445829662141196, 0.0661907655654817, 0.03885568116655977, 0.013078615468659323, -0.010617349295218181, -0.03181017613329085, -0.050171999808914604, -0.06545830501430487, -0.07749482277960204, -0.08616386191642225, -0.09139170665445415, -0.09313849939964196, -0.09139170665445415, -0.08616386191642225, -0.07749482277960204, -0.06545830501430487, -0.050171999808914604, -0.03181017613329085, -0.010617349295218181, 0.013078615468659323, 0.03885568116655977, 0.0661907655654817, 0.09445829662141196, 0.12293536517635703, 0.15081422331281308, 0.17722237538812438, 0.20124995852555586, 0.22198354690007724, 0.23854497801642713, 0.25013332713993036, 0.2560677827399544, 0.25582893038458626, 0.24909585663212155, 0.23577655069724138, 0.21602931256266372, 0.1902732638436695, 0.15918658398472915, 0.12369173187889267, 0.08492762656935865, 0.044209509361482956, 0.0029779491154211806, -0.03726086233570953, -0.0750007897964791, -0.10880422217787396, -0.13736985507049018, -0.15959621882048483, -0.17463748569481502, -0.18194839266053625, -0.18131560690315682, -0.17287351607260817, -0.15710321083861073], [-0.11853755153953284, -0.14391335124448024, -0.163591222139663, -0.17663261032673944, -0.18239300622958532, -0.18054660691367944, -0.17109514979541934, -0.1543609103022869, -0.13096468174943518, -0.10179031338845618, -0.06793803188546253, -0.03066927919323432, 0.008653858363151095, 0.04863139306208121, 0.0878871354792479, 0.12512633286074154, 0.15918658398472915, 0.1890798565922851, 0.21402402107025095, 0.23346296309158113, 0.24707500803079696, 0.25477004091850136, 0.2566762997375786, 0.25311832399967577, 0.24458792842044305, 0.2317103248693539, 0.2152076253393881, 0.19586192453391038, 0.17447999195279823, 0.15186131748507978, 0.12877087581897034, 0.10591753298818528, 0.08393854575868848, 0.06339013493636744, 0.044743679368913644, 0.02838670735216783, 0.014627580006334946, 0.0037025838949493145, -0.004215913110515241, -0.009011537058698997, -0.010617349295218181, -0.009011537058698997, -0.004215913110515241, 0.0037025838949493145, 0.014627580006334946, 0.02838670735216783, 0.044743679368913644, 0.06339013493636744, 0.08393854575868848, 0.10591753298818528, 0.12877087581897034, 0.15186131748507978, 0.17447999195279823, 0.19586192453391038, 0.2152076253393881, 0.2317103248693539, 0.24458792842044305, 0.25311832399967577, 0.2566762997375786, 0.25477004091850136, 0.24707500803079696, 0.23346296309158113, 0.21402402107025095, 0.1890798565922851, 0.15918658398472915, 0.12512633286074154, 0.0878871354792479, 0.04863139306208121, 0.008653858363151095, -0.03066927919323432, -0.06793803188546253, -0.10179031338845618, -0.13096468174943518, -0.1543609103022869, -0.17109514979541934, -0.18054660691367944, -0.18239300622958532, -0.17663261032673944, -0.163591222139663, -0.14391335124448024], [-0.10007704610444179, -0.12803786284735597, -0.1511875643863488, -0.16848219583369567, -0.17913546063850083, -0.18264893898060253, -0.1788278960809016, -0.16778234479339135, -0.1499137997580331, -0.1258888846262905, -0.09660159075517502, -0.0631265026963309, -0.026665677985416577, 0.011507919583092052, 0.05010748884225075, 0.0878871354792479, 0.12369173187889267, 0.15649972810645998, 0.18545724476618586, 0.20990234059772522, 0.22937894091767205, 0.24364050109720906, 0.25264402764959015, 0.25653555744366946, 0.25562857790064414, 0.25037713957121355, 0.2413455569066888, 0.22917661128094333, 0.21456006847846779, 0.1982031145119569, 0.18080401871815463, 0.1630299764243758, 0.14549969299473817, 0.12877087581897034, 0.11333242903336226, 0.09960082298540655, 0.08791985781076668, 0.07856287339249271, 0.07173638515428266, 0.06758414818694233, 0.0661907655654817, 0.06758414818694233, 0.07173638515428266, 0.07856287339249271, 0.08791985781076668, 0.09960082298540655, 0.11333242903336226, 0.12877087581897034, 0.14549969299473817, 0.1630299764243758, 0.18080401871815463, 0.1982031145119569, 0.21456006847846779, 0.22917661128094333, 0.2413455569066888, 0.25037713957121355, 0.25562857790064414, 0.25653555744366946, 0.25264402764959015, 0.24364050109720906, 0.22937894091767205, 0.20990234059772522, 0.18545724476618586, 0.15649972810645998, 0.12369173187889267, 0.0878871354792479, 0.05010748884225075, 0.011507919583092052, -0.026665677985416577, -0.0631265026963309, -0.09660159075517502, -0.1258888846262905, -0.1499137997580331, -0.16778234479339135, -0.1788278960809016, -0.18264893898060253, -0.17913546063850083, -0.16848219583369567, -0.1511875643863488, -0.12803786284735597], [-0.07968395387291566, -0.10965701691843574, -0.13575600794040762, -0.15685668268767797, -0.17205475511311313, -0.1807007071005138, -0.18242166855756492, -0.17712974307464055, -0.16501687105976595, -0.14653700801271363, -0.12237701362727325, -0.09341816596346665, -0.060690608986011814, -0.02532329427921568, 0.011507919583092052, 0.04863139306208121, 0.08492762656935865, 0.11937185506223688, 0.15106960365711752, 0.1792839709402817, 0.20345392533496165, 0.2232034254780841, 0.2383416766936446, 0.24885528388828942, 0.254893432701845, 0.25674750760048576, 0.2548267267047997, 0.24963143467045815, 0.24172565029557566, 0.2317103248693539, 0.22019854657881394, 0.20779364608280457, 0.19507084218595108, 0.18256273925541686, 0.17074867404778504, 0.16004763127913005, 0.15081422331281308, 0.1433370736825879, 0.13783886506830845, 0.134477311926808, 0.1333463922312941, 0.134477311926808, 0.13783886506830845, 0.1433370736825879, 0.15081422331281308, 0.16004763127913005, 0.17074867404778504, 0.18256273925541686, 0.19507084218595108, 0.20779364608280457, 0.22019854657881394, 0.2317103248693539, 0.24172565029557566, 0.24963143467045815, 0.2548267267047997, 0.25674750760048576, 0.254893432701845, 0.24885528388828942, 0.2383416766936446, 0.2232034254780841, 0.20345392533496165, 0.1792839709402817, 0.15106960365711752, 0.11937185506223688, 0.08492762656935865, 0.04863139306208121, 0.011507919583092052, -0.02532329427921568, -0.060690608986011814, -0.09341816596346665, -0.12237701362727325, -0.14653700801271363, -0.16501687105976595, -0.17712974307464055, -0.18242166855756492, -0.1807007071005138, -0.17205475511311313, -0.15685668268767797, -0.13575600794040762, -0.10965701691843574], [-0.05769048962428924, -0.08904297911487404, -0.11749065565570795, -0.14185512230149663, -0.16113955966514656, -0.17456713788189782, -0.18160802037610754, -0.18199408570471504, -0.17572115154133375, -0.16303912773542587, -0.14443111863131364, -0.12058300781296416, -0.09234546620178369, -0.060690608986011814, -0.026665677985416577, 0.008653858363151095, 0.044209509361482956, 0.07900122348247962, 0.11212338767979044, 0.14279404657238684, 0.17037647050011584, 0.1943926655354523, 0.2145288714461612, 0.23063350923189954, 0.242708395806646, 0.2508943222213973, 0.2554522819126627, 0.2567417315441088, 0.25519727019112654, 0.25130504004127213, 0.2455799958764798, 0.23854497801642713, 0.23071227369415245, 0.2225680860000738, 0.21456006847846779, 0.2070878465419809, 0.20049625055173417, 0.19507084218595108, 0.19103523332295086, 0.18854967763954522, 0.18771045677679687, 0.18854967763954522, 0.19103523332295086, 0.19507084218595108, 0.20049625055173417, 0.2070878465419809, 0.21456006847846779, 0.2225680860000738, 0.23071227369415245, 0.23854497801642713, 0.2455799958764798, 0.25130504004127213, 0.25519727019112654, 0.2567417315441088, 0.2554522819126627, 0.2508943222213973, 0.242708395806646, 0.23063350923189954, 0.2145288714461612, 0.1943926655354523, 0.17037647050011584, 0.14279404657238684, 0.11212338767979044, 0.07900122348247962, 0.044209509361482956, 0.008653858363151095, -0.026665677985416577, -0.060690608986011814, -0.09234546620178369, -0.12058300781296416, -0.14443111863131364, -0.16303912773542587, -0.17572115154133375, -0.18199408570471504, -0.18160802037610754, -0.17456713788189782, -0.16113955966514656, -0.14185512230149663, -0.11749065565570795, -0.08904297911487404], [-0.0345063152690242, -0.06655906279410359, -0.09668883252747353, -0.12368964794720452, -0.1464987033293174, -0.1642373823959323, -0.17624240938958516, -0.18208605074549258, -0.18158488243001691, -0.1747972342928682, -0.16200998595397612, -0.1437158894806465, -0.12058300781296416, -0.09341816596346665, -0.0631265026963309, -0.03066927919323432, 0.0029779491154211806, 0.03686485131708162, 0.07010183827093616, 0.1018902143955224, 0.13154597877649798, 0.15851669454452746, 0.18239124981424537, 0.20290271423033404, 0.21992483146863692, 0.23346296309158113, 0.24364050109720906, 0.2506818889186662, 0.254893432701845, 0.2566430509401283, 0.2563400102730029, 0.25441554164532254, 0.25130504004127213, 0.24743234013685533, 0.2431963471432226, 0.23896010343988033, 0.23504220166614895, 0.2317103248693539, 0.22917661128094333, 0.22759450814784551, 0.2270567942100705, 0.22759450814784551, 0.22917661128094333, 0.2317103248693539, 0.23504220166614895, 0.23896010343988033, 0.2431963471432226, 0.24743234013685533, 0.25130504004127213, 0.25441554164532254, 0.2563400102730029, 0.2566430509401283, 0.254893432701845, 0.2506818889186662, 0.24364050109720906, 0.23346296309158113, 0.21992483146863692, 0.20290271423033404, 0.18239124981424537, 0.15851669454452746, 0.13154597877649798, 0.1018902143955224, 0.07010183827093616, 0.03686485131708162, 0.0029779491154211806, -0.03066927919323432, -0.0631265026963309, -0.09341816596346665, -0.12058300781296416, -0.1437158894806465, -0.16200998595397612, -0.1747972342928682, -0.18158488243001691, -0.18208605074549258, -0.17624240938958516, -0.1642373823959323, -0.1464987033293174, -0.12368964794720452, -0.09668883252747353, -0.06655906279410359], [-0.01061150357619211, -0.042655257000177006, -0.07374973820785838, -0.10268778525178764, -0.1283676319466868, -0.14983554931501694, -0.16632015713858264, -0.17725715646546372, -0.18230376872794093, -0.18134271385500067, -0.17447608825271163, -0.16200998595397612, -0.14443111863131364, -0.12237701362727325, -0.09660159075517502, -0.06793803188546253, -0.03726086233570953, -0.005449066140771361, 0.026648129724923395, 0.058241427706856384, 0.08862652853638416, 0.11720338291232232, 0.14348926836260514, 0.16712567793535366, 0.18787932061729182, 0.20563779959612533, 0.22040074178662336, 0.23226729318028777, 0.24142096714711753, 0.24811283911536614, 0.25264402764959015, 0.255348298963932, 0.256575492104657, 0.2566762997375786, 0.2559887694405144, 0.2548267267047997, 0.25347017586536014, 0.252157618714697, 0.25108014921898075, 0.25037713957121355, 0.25013332713993036, 0.25037713957121355, 0.25108014921898075, 0.252157618714697, 0.25347017586536014, 0.2548267267047997, 0.2559887694405144, 0.2566762997375786, 0.256575492104657, 0.255348298963932, 0.25264402764959015, 0.24811283911536614, 0.24142096714711753, 0.23226729318028777, 0.22040074178662336, 0.20563779959612533, 0.18787932061729182, 0.16712567793535366, 0.14348926836260514, 0.11720338291232232, 0.08862652853638416, 0.058241427706856384, 0.026648129724923395, -0.005449066140771361, -0.03726086233570953, -0.06793803188546253, -0.09660159075517502, -0.12237701362727325, -0.14443111863131364, -0.16200998595397612, -0.17447608825271163, -0.18134271385500067, -0.18230376872794093, -0.17725715646546372, -0.16632015713858264, -0.14983554931501694, -0.1283676319466868, -0.10268778525178764, -0.07374973820785838, -0.042655257000177006], [0.013454008098850966, -0.017859822184363938, -0.04916880920228074, -0.07929019757294747, -0.10711012813756442, -0.1316269478872783, -0.15198770280837584, -0.16751643729146143, -0.17773339606034183, -0.18236471957976835, -0.18134271385500067, -0.1747972342928682, -0.16303912773542587, -0.14653700801271363, -0.1258888846262905, -0.10179031338845618, -0.0750007897964791, -0.046310064114579955, -0.016505930263581485, 0.013655158230898757, 0.043473546354522816, 0.07232710218505171, 0.09968670899986165, 0.12512633286074154, 0.14832776112580212, 0.16908036038891633, 0.18727640924644018, 0.20290271423033404, 0.21602931256266372, 0.22679610352037188, 0.23539823538075702, 0.2420710146043941, 0.24707500803079696, 0.2506818889186662, 0.2531614457800734, 0.25477004091850136, 0.2557406839380664, 0.2562747828163765, 0.25653555744366946, 0.2566430509401283, 0.2566706526738519, 0.2566430509401283, 0.25653555744366946, 0.2562747828163765, 0.2557406839380664, 0.25477004091850136, 0.2531614457800734, 0.2506818889186662, 0.24707500803079696, 0.2420710146043941, 0.23539823538075702, 0.22679610352037188, 0.21602931256266372, 0.20290271423033404, 0.18727640924644018, 0.16908036038891633, 0.14832776112580212, 0.12512633286074154, 0.09968670899986165, 0.07232710218505171, 0.043473546354522816, 0.013655158230898757, -0.016505930263581485, -0.046310064114579955, -0.0750007897964791, -0.10179031338845618, -0.1258888846262905, -0.14653700801271363, -0.16303912773542587, -0.1747972342928682, -0.18134271385500067, -0.18236471957976835, -0.17773339606034183, -0.16751643729146143, -0.15198770280837584, -0.1316269478872783, -0.10711012813756442, -0.07929019757294747, -0.04916880920228074, -0.017859822184363938], [0.037104384846577534, 0.007233082355737275, -0.023527608249201665, -0.054043516875550875, -0.08321475815193494, -0.11001880232017779, -0.13354819579908725, -0.15304146672549196, -0.167906160972842, -0.17773339606034183, -0.18230376872794093, -0.18158488243001691, -0.17572115154133375, -0.16501687105976595, -0.1499137997580331, -0.13096468174943518, -0.10880422217787396, -0.08411903827788304, -0.05761803324395176, -0.030004497243790427, -0.001951040868825416, 0.025921773001301992, 0.05306249567952219, 0.07900122348247962, 0.10335731863015635, 0.1258425822940911, 0.14626024334832619, 0.16450028494360933, 0.18053174205108255, 0.1943926655354523, 0.2061784643801796, 0.21602931256266372, 0.22411724822563847, 0.23063350923189954, 0.23577655069724138, 0.23974108638511749, 0.242708395806646, 0.24483804991090946, 0.24626113579560338, 0.24707500803079696, 0.24733956165584545, 0.24707500803079696, 0.24626113579560338, 0.24483804991090946, 0.242708395806646, 0.23974108638511749, 0.23577655069724138, 0.23063350923189954, 0.22411724822563847, 0.21602931256266372, 0.2061784643801796, 0.1943926655354523, 0.18053174205108255, 0.16450028494360933, 0.14626024334832619, 0.1258425822940911, 0.10335731863015635, 0.07900122348247962, 0.05306249567952219, 0.025921773001301992, -0.001951040868825416, -0.030004497243790427, -0.05761803324395176, -0.08411903827788304, -0.10880422217787396, -0.13096468174943518, -0.1499137997580331, -0.16501687105976595, -0.17572115154133375, -0.18158488243001691, -0.18230376872794093, -0.17773339606034183, -0.167906160972842, -0.15304146672549196, -0.13354819579908725, -0.11001880232017779, -0.08321475815193494, -0.054043516875550875, -0.023527608249201665, 0.007233082355737275], [0.059725017515438364, 0.03197958453286062, 0.0025207381574719806, -0.027588123185645037, -0.0572857273340844, -0.08555491563889543, -0.1114606806231028, -0.13418273806183595, -0.15304146672549196, -0.16751643729146143, -0.17725715646546372, -0.18208605074549258, -0.18199408570471504, -0.17712974307464055, -0.16778234479339135, -0.1543609103022869, -0.13736985507049018, -0.11738288358628372, -0.0950164022704569, -0.07090368426500879, -0.045670869380806056, -0.019915691575644292, 0.0058103924762656495, 0.031016232090896562, 0.05528095770522729, 0.07825990831739421, 0.09968670899986165, 0.11937185506223688, 0.13719827990417027, 0.15311446345017118, 0.16712567793535366, 0.1792839709402817, 0.18967745729212915, 0.19841943861188654, 0.20563779959612533, 0.21146505144444128, 0.21602931256266372, 0.21944644111666822, 0.22181346801290225, 0.2232034254780841, 0.22366162672468853, 0.2232034254780841, 0.22181346801290225, 0.21944644111666822, 0.21602931256266372, 0.21146505144444128, 0.20563779959612533, 0.19841943861188654, 0.18967745729212915, 0.1792839709402817, 0.16712567793535366, 0.15311446345017118, 0.13719827990417027, 0.11937185506223688, 0.09968670899986165, 0.07825990831739421, 0.05528095770522729, 0.031016232090896562, 0.0058103924762656495, -0.019915691575644292, -0.045670869380806056, -0.07090368426500879, -0.0950164022704569, -0.11738288358628372, -0.13736985507049018, -0.1543609103022869, -0.16778234479339135, -0.17712974307464055, -0.18199408570471504, -0.18208605074549258, -0.17725715646546372, -0.16751643729146143, -0.15304146672549196, -0.13418273806183595, -0.1114606806231028, -0.08555491563889543, -0.0572857273340844, -0.027588123185645037, 0.0025207381574719806, 0.03197958453286062], [0.08069235790121831, 0.05570574218106777, 0.028270310898122826, -0.0006409754282528475, -0.03002807965783915, -0.05890402451081101, -0.08633239590937543, -0.1114606806231028, -0.13354819579908725, -0.15198770280837584, -0.16632015713858264, -0.17624240938958516, -0.18160802037610754, -0.18242166855756492, -0.1788278960809016, -0.17109514979541934, -0.15959621882048483, -0.14478624788034108, -0.1271795169340972, -0.10732612754693129, -0.0857896329957062, -0.0631265026963309, -0.039868134180728126, -0.016505930263581485, 0.0065202421682302655, 0.02883009042098063, 0.05010748884225075, 0.07010183827093616, 0.08862652853638416, 0.10555493165712146, 0.12081441070397907, 0.13437885433763305, 0.14626024334832619, 0.15649972810645998, 0.16515865057394133, 0.17230988766358785, 0.17802983029511174, 0.18239124981424537, 0.18545724476618586, 0.18727640924644018, 0.18787932061729182, 0.18727640924644018, 0.18545724476618586, 0.18239124981424537, 0.17802983029511174, 0.17230988766358785, 0.16515865057394133, 0.15649972810645998, 0.14626024334832619, 0.13437885433763305, 0.12081441070397907, 0.10555493165712146, 0.08862652853638416, 0.07010183827093616, 0.05010748884225075, 0.02883009042098063, 0.0065202421682302655, -0.016505930263581485, -0.039868134180728126, -0.0631265026963309, -0.0857896329957062, -0.10732612754693129, -0.1271795169340972, -0.14478624788034108, -0.15959621882048483, -0.17109514979541934, -0.1788278960809016, -0.18242166855756492, -0.18160802037610754, -0.17624240938958516, -0.16632015713858264, -0.15198770280837584, -0.13354819579908725, -0.1114606806231028, -0.08633239590937543, -0.05890402451081101, -0.03002807965783915, -0.0006409754282528475, 0.028270310898122826, 0.05570574218106777], [0.0993958462307399, 0.07773008237271903, 0.05298490441364873, 0.026026147564044762, -0.0022274559793407315, -0.030841885736018544, -0.05890402451081101, -0.08555491563889543, -0.11001880232017779, -0.1316269478872783, -0.14983554931501694, -0.1642373823959323, -0.17456713788189782, -0.1807007071005138, -0.18264893898060253, -0.18054660691367944, -0.17463748569481502, -0.16525654180237792, -0.1528102839666787, -0.1377563081818195, -0.12058300781296416, -0.10179031338845618, -0.08187218787401292, -0.061301442485772274, -0.040517266401149735, -0.019915691575644292, 0.0001569493213448689, 0.019407660252202565, 0.03759772656874239, 0.054541276561040686, 0.07010183827093616, 0.08418731130237875, 0.09674378883254962, 0.10774865812501504, 0.11720338291232232, 0.12512633286074154, 0.13154597877649798, 0.13649472168344115, 0.14000357308347133, 0.14209785531573388, 0.14279404657238684, 0.14209785531573388, 0.14000357308347133, 0.13649472168344115, 0.13154597877649798, 0.12512633286074154, 0.11720338291232232, 0.10774865812501504, 0.09674378883254962, 0.08418731130237875, 0.07010183827093616, 0.054541276561040686, 0.03759772656874239, 0.019407660252202565, 0.0001569493213448689, -0.019915691575644292, -0.040517266401149735, -0.061301442485772274, -0.08187218787401292, -0.10179031338845618, -0.12058300781296416, -0.1377563081818195, -0.1528102839666787, -0.16525654180237792, -0.17463748569481502, -0.18054660691367944, -0.18264893898060253, -0.1807007071005138, -0.17456713788189782, -0.1642373823959323, -0.14983554931501694, -0.1316269478872783, -0.11001880232017779, -0.08555491563889543, -0.05890402451081101, -0.030841885736018544, -0.0022274559793407315, 0.026026147564044762, 0.05298490441364873, 0.07773008237271903], [0.11526115097856117, 0.09738828403656238, 0.0759235678781371, 0.05161237775613617, 0.025275083284098894, -0.0022274559793407315, -0.03002807965783915, -0.0572857273340844, -0.08321475815193494, -0.10711012813756442, -0.1283676319466868, -0.1464987033293174, -0.16113955966514656, -0.17205475511311313, -0.17913546063850083, -0.18239300622958532, -0.18194839266053625, -0.17801860199902664, -0.17090060569317098, -0.1609539875623888, -0.14858307017251748, -0.13421936300715656, -0.11830504740258321, -0.10127808535368477, -0.08355939645450051, -0.06554239869174844, -0.04758506314163741, -0.030004497243790427, -0.013073952151520388, 0.0029779491154211806, 0.017966041941118966, 0.031745840459068614, 0.044209509361482956, 0.05528095770522729, 0.0649104168254659, 0.07306884206017318, 0.07974244535617742, 0.08492762656935865, 0.08862652853638416, 0.09084339726921295, 0.09158188560927924, 0.09084339726921295, 0.08862652853638416, 0.08492762656935865, 0.07974244535617742, 0.07306884206017318, 0.0649104168254659, 0.05528095770522729, 0.044209509361482956, 0.031745840459068614, 0.017966041941118966, 0.0029779491154211806, -0.013073952151520388, -0.030004497243790427, -0.04758506314163741, -0.06554239869174844, -0.08355939645450051, -0.10127808535368477, -0.11830504740258321, -0.13421936300715656, -0.14858307017251748, -0.1609539875623888, -0.17090060569317098, -0.17801860199902664, -0.18194839266053625, -0.18239300622958532, -0.17913546063850083, -0.17205475511311313, -0.16113955966514656, -0.1464987033293174, -0.1283676319466868, -0.10711012813756442, -0.08321475815193494, -0.0572857273340844, -0.03002807965783915, -0.0022274559793407315, 0.025275083284098894, 0.05161237775613617, 0.0759235678781371, 0.09738828403656238], [0.12777380562398274, 0.11405907878471819, 0.09636827159298987, 0.07531659368730659, 0.05161237775613617, 0.026026147564044762, -0.0006409754282528475, -0.027588123185645037, -0.054043516875550875, -0.07929019757294747, -0.10268778525178764, -0.12368964794720452, -0.14185512230149663, -0.15685668268767797, -0.16848219583369567, -0.17663261032673944, -0.18131560690315682, -0.1826358700412797, -0.18078273088932142, -0.1760159755489718, -0.16865061331126227, -0.15904136091487175, -0.14756752732225356, -0.13461888616197776, -0.12058300781296416, -0.10583439818051152, -0.0907256642328181, -0.07558080422426758, -0.060690608986011814, -0.046310064114579955, -0.032657564269347995, -0.019915691575644292, -0.00823327044894154, 0.0022716100207446164, 0.011507919583092052, 0.019407660252202565, 0.025921773001301992, 0.031016232090896562, 0.03466854669458865, 0.03686485131708162, 0.03759772656874239, 0.03686485131708162, 0.03466854669458865, 0.031016232090896562, 0.025921773001301992, 0.019407660252202565, 0.011507919583092052, 0.0022716100207446164, -0.00823327044894154, -0.019915691575644292, -0.032657564269347995, -0.046310064114579955, -0.060690608986011814, -0.07558080422426758, -0.0907256642328181, -0.10583439818051152, -0.12058300781296416, -0.13461888616197776, -0.14756752732225356, -0.15904136091487175, -0.16865061331126227, -0.1760159755489718, -0.18078273088932142, -0.1826358700412797, -0.18131560690315682, -0.17663261032673944, -0.16848219583369567, -0.15685668268767797, -0.14185512230149663, -0.12368964794720452, -0.10268778525178764, -0.07929019757294747, -0.054043516875550875, -0.027588123185645037, -0.0006409754282528475, 0.026026147564044762, 0.05161237775613617, 0.07531659368730659, 0.09636827159298987, 0.11405907878471819], [0.13650222610828716, 0.12719030582037316, 0.1136526088802527, 0.09636827159298987, 0.0759235678781371, 0.05298490441364873, 0.028270310898122826, 0.0025207381574719806, -0.023527608249201665, -0.04916880920228074, -0.07374973820785838, -0.09668883252747353, -0.11749065565570795, -0.13575600794040762, -0.1511875643863488, -0.163591222139663, -0.17287351607260817, -0.17903560277058095, -0.1821644169794075, -0.18242166855756492, -0.1800313728705813, -0.1752665961050691, -0.16843605361995675, -0.15987112992755653, -0.1499137997580331, -0.13890582780165694, -0.1271795169340972, -0.11505016730310495, -0.10281030706494565, -0.0907256642328181, -0.07903277128303789, -0.06793803188546253, -0.05761803324395176, -0.04822085787410071, -0.039868134180728126, -0.032657564269347995, -0.026665677985416577, -0.021950582012676394, -0.01855449981019833, -0.016505930263581485, -0.015821288518275644, -0.016505930263581485, -0.01855449981019833, -0.021950582012676394, -0.026665677985416577, -0.032657564269347995, -0.039868134180728126, -0.04822085787410071, -0.05761803324395176, -0.06793803188546253, -0.07903277128303789, -0.0907256642328181, -0.10281030706494565, -0.11505016730310495, -0.1271795169340972, -0.13890582780165694, -0.1499137997580331, -0.15987112992755653, -0.16843605361995675, -0.1752665961050691, -0.1800313728705813, -0.18242166855756492, -0.1821644169794075, -0.17903560277058095, -0.17287351607260817, -0.163591222139663, -0.1511875643863488, -0.13575600794040762, -0.11749065565570795, -0.09668883252747353, -0.07374973820785838, -0.04916880920228074, -0.023527608249201665, 0.0025207381574719806, 0.028270310898122826, 0.05298490441364873, 0.0759235678781371, 0.09636827159298987, 0.1136526088802527, 0.12719030582037316], [0.14111903500315878, 0.13632396086944565, 0.12719030582037316, 0.11405907878471819, 0.09738828403656238, 0.07773008237271903, 0.05570574218106777, 0.03197958453286062, 0.007233082355737275, -0.017859822184363938, -0.042655257000177006, -0.06655906279410359, -0.08904297911487404, -0.10965701691843574, -0.12803786284735597, -0.14391335124448024, -0.15710321083861073, -0.16751643729146143, -0.1751457556394694, -0.1800597155006458, -0.18239300622958532, -0.18233559039097344, -0.18012123502583363, -0.1760159755489718, -0.17030698199702413, -0.16329221750830802, -0.15527119023634722, -0.14653700801271363, -0.13736985507049018, -0.12803192632998142, -0.11876378051842666, -0.10978201113265723, -0.10127808535368477, -0.09341816596346665, -0.08634370978474622, -0.08017262722723162, -0.0750007897964791, -0.07090368426500879, -0.06793803188546253, -0.06614321685638791, -0.06554239869174844, -0.06614321685638791, -0.06793803188546253, -0.07090368426500879, -0.0750007897964791, -0.08017262722723162, -0.08634370978474622, -0.09341816596346665, -0.10127808535368477, -0.10978201113265723, -0.11876378051842666, -0.12803192632998142, -0.13736985507049018, -0.14653700801271363, -0.15527119023634722, -0.16329221750830802, -0.17030698199702413, -0.1760159755489718, -0.18012123502583363, -0.18233559039097344, -0.18239300622958532, -0.1800597155006458, -0.1751457556394694, -0.16751643729146143, -0.15710321083861073, -0.14391335124448024, -0.12803786284735597, -0.10965701691843574, -0.08904297911487404, -0.06655906279410359, -0.042655257000177006, -0.017859822184363938, 0.007233082355737275, 0.03197958453286062, 0.05570574218106777, 0.07773008237271903, 0.09738828403656238, 0.11405907878471819, 0.12719030582037316, 0.13632396086944565]], \"x\": [-10.0, -9.75, -9.5, -9.25, -9.0, -8.75, -8.5, -8.25, -8.0, -7.75, -7.5, -7.25, -7.0, -6.75, -6.5, -6.25, -6.0, -5.75, -5.5, -5.25, -5.0, -4.75, -4.5, -4.25, -4.0, -3.75, -3.5, -3.25, -3.0, -2.75, -2.5, -2.25, -2.0, -1.75, -1.5, -1.25, -1.0, -0.75, -0.5, -0.25, 0.0, 0.25, 0.5, 0.75, 1.0, 1.25, 1.5, 1.75, 2.0, 2.25, 2.5, 2.75, 3.0, 3.25, 3.5, 3.75, 4.0, 4.25, 4.5, 4.75, 5.0, 5.25, 5.5, 5.75, 6.0, 6.25, 6.5, 6.75, 7.0, 7.25, 7.5, 7.75, 8.0, 8.25, 8.5, 8.75, 9.0, 9.25, 9.5, 9.75], \"y\": [-10.0, -9.75, -9.5, -9.25, -9.0, -8.75, -8.5, -8.25, -8.0, -7.75, -7.5, -7.25, -7.0, -6.75, -6.5, -6.25, -6.0, -5.75, -5.5, -5.25, -5.0, -4.75, -4.5, -4.25, -4.0, -3.75, -3.5, -3.25, -3.0, -2.75, -2.5, -2.25, -2.0, -1.75, -1.5, -1.25, -1.0, -0.75, -0.5, -0.25, 0.0, 0.25, 0.5, 0.75, 1.0, 1.25, 1.5, 1.75, 2.0, 2.25, 2.5, 2.75, 3.0, 3.25, 3.5, 3.75, 4.0, 4.25, 4.5, 4.75, 5.0, 5.25, 5.5, 5.75, 6.0, 6.25, 6.5, 6.75, 7.0, 7.25, 7.5, 7.75, 8.0, 8.25, 8.5, 8.75, 9.0, 9.25, 9.5, 9.75], \"zmin\": null, \"zmax\": null, \"colorscale\": [[0.0, \"rgb(255, 153, 51)\"], [0.1111111111111111, \"rgb(55, 128, 191)\"], [0.2222222222222222, \"rgb(50, 171, 96)\"], [0.3333333333333333, \"rgb(128, 0, 128)\"], [0.4444444444444444, \"rgb(219, 64, 82)\"], [0.5555555555555556, \"rgb(0, 128, 128)\"], [0.6666666666666666, \"rgb(255, 255, 51)\"], [0.7777777777777778, \"rgb(128, 128, 0)\"], [0.8888888888888888, \"rgb(251, 128, 114)\"], [1.0, \"rgb(128, 177, 211)\"]]}], {\"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"yaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"xaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"titlefont\": {\"color\": \"#4D5663\"}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ],
      "text/vnd.plotly.v1+html": [
       "<div id=\"5a71391d-7d6c-4d80-b22d-ecf4c4f63824\" style=\"height: 525px; width: 100%;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">require([\"plotly\"], function(Plotly) { window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"5a71391d-7d6c-4d80-b22d-ecf4c4f63824\", [{\"type\": \"surface\", \"z\": [[0.14141961054935853, 0.14111903500315878, 0.13650222610828716, 0.12777380562398274, 0.11526115097856117, 0.0993958462307399, 0.08069235790121831, 0.059725017515438364, 0.037104384846577534, 0.013454008098850966, -0.01061150357619211, -0.0345063152690242, -0.05769048962428924, -0.07968395387291566, -0.10007704610444179, -0.11853755153953284, -0.13481430178982187, -0.1487375524385824, -0.16021647158282734, -0.16923416092386775, -0.17584069010379264, -0.1801446545297837, -0.18230376872794093, -0.18251498442862385, -0.18100457917857166, -0.17801860199902664, -0.1738139924448547, -0.16865061331126227, -0.16278435980926842, -0.15646143337355978, -0.1499137997580331, -0.14335579129849668, -0.13698176393514344, -0.13096468174943518, -0.1254554756233313, -0.12058300781296416, -0.1164544699167505, -0.1131560467581887, -0.1107536917561867, -0.10929387900894774, -0.10880422217787396, -0.10929387900894774, -0.1107536917561867, -0.1131560467581887, -0.1164544699167505, -0.12058300781296416, -0.1254554756233313, -0.13096468174943518, -0.13698176393514344, -0.14335579129849668, -0.1499137997580331, -0.15646143337355978, -0.16278435980926842, -0.16865061331126227, -0.1738139924448547, -0.17801860199902664, -0.18100457917857166, -0.18251498442862385, -0.18230376872794093, -0.1801446545297837, -0.17584069010379264, -0.16923416092386775, -0.16021647158282734, -0.1487375524385824, -0.13481430178982187, -0.11853755153953284, -0.10007704610444179, -0.07968395387291566, -0.05769048962428924, -0.0345063152690242, -0.01061150357619211, 0.013454008098850966, 0.037104384846577534, 0.059725017515438364, 0.08069235790121831, 0.0993958462307399, 0.11526115097856117, 0.12777380562398274, 0.13650222610828716, 0.14111903500315878], [0.14111903500315878, 0.13632396086944565, 0.12719030582037316, 0.11405907878471819, 0.09738828403656238, 0.07773008237271903, 0.05570574218106777, 0.03197958453286062, 0.007233082355737275, -0.017859822184363938, -0.042655257000177006, -0.06655906279410359, -0.08904297911487404, -0.10965701691843574, -0.12803786284735597, -0.14391335124448024, -0.15710321083861073, -0.16751643729146143, -0.1751457556394694, -0.1800597155006458, -0.18239300622958532, -0.18233559039097344, -0.18012123502583363, -0.1760159755489718, -0.17030698199702413, -0.16329221750830802, -0.15527119023634722, -0.14653700801271363, -0.13736985507049018, -0.12803192632998142, -0.11876378051842666, -0.10978201113265723, -0.10127808535368477, -0.09341816596346665, -0.08634370978474622, -0.08017262722723162, -0.0750007897964791, -0.07090368426500879, -0.06793803188546253, -0.06614321685638791, -0.06554239869174844, -0.06614321685638791, -0.06793803188546253, -0.07090368426500879, -0.0750007897964791, -0.08017262722723162, -0.08634370978474622, -0.09341816596346665, -0.10127808535368477, -0.10978201113265723, -0.11876378051842666, -0.12803192632998142, -0.13736985507049018, -0.14653700801271363, -0.15527119023634722, -0.16329221750830802, -0.17030698199702413, -0.1760159755489718, -0.18012123502583363, -0.18233559039097344, -0.18239300622958532, -0.1800597155006458, -0.1751457556394694, -0.16751643729146143, -0.15710321083861073, -0.14391335124448024, -0.12803786284735597, -0.10965701691843574, -0.08904297911487404, -0.06655906279410359, -0.042655257000177006, -0.017859822184363938, 0.007233082355737275, 0.03197958453286062, 0.05570574218106777, 0.07773008237271903, 0.09738828403656238, 0.11405907878471819, 0.12719030582037316, 0.13632396086944565], [0.13650222610828716, 0.12719030582037316, 0.1136526088802527, 0.09636827159298987, 0.0759235678781371, 0.05298490441364873, 0.028270310898122826, 0.0025207381574719806, -0.023527608249201665, -0.04916880920228074, -0.07374973820785838, -0.09668883252747353, -0.11749065565570795, -0.13575600794040762, -0.1511875643863488, -0.163591222139663, -0.17287351607260817, -0.17903560277058095, -0.1821644169794075, -0.18242166855756492, -0.1800313728705813, -0.1752665961050691, -0.16843605361995675, -0.15987112992755653, -0.1499137997580331, -0.13890582780165694, -0.1271795169340972, -0.11505016730310495, -0.10281030706494565, -0.0907256642328181, -0.07903277128303789, -0.06793803188546253, -0.05761803324395176, -0.04822085787410071, -0.039868134180728126, -0.032657564269347995, -0.026665677985416577, -0.021950582012676394, -0.01855449981019833, -0.016505930263581485, -0.015821288518275644, -0.016505930263581485, -0.01855449981019833, -0.021950582012676394, -0.026665677985416577, -0.032657564269347995, -0.039868134180728126, -0.04822085787410071, -0.05761803324395176, -0.06793803188546253, -0.07903277128303789, -0.0907256642328181, -0.10281030706494565, -0.11505016730310495, -0.1271795169340972, -0.13890582780165694, -0.1499137997580331, -0.15987112992755653, -0.16843605361995675, -0.1752665961050691, -0.1800313728705813, -0.18242166855756492, -0.1821644169794075, -0.17903560277058095, -0.17287351607260817, -0.163591222139663, -0.1511875643863488, -0.13575600794040762, -0.11749065565570795, -0.09668883252747353, -0.07374973820785838, -0.04916880920228074, -0.023527608249201665, 0.0025207381574719806, 0.028270310898122826, 0.05298490441364873, 0.0759235678781371, 0.09636827159298987, 0.1136526088802527, 0.12719030582037316], [0.12777380562398274, 0.11405907878471819, 0.09636827159298987, 0.07531659368730659, 0.05161237775613617, 0.026026147564044762, -0.0006409754282528475, -0.027588123185645037, -0.054043516875550875, -0.07929019757294747, -0.10268778525178764, -0.12368964794720452, -0.14185512230149663, -0.15685668268767797, -0.16848219583369567, -0.17663261032673944, -0.18131560690315682, -0.1826358700412797, -0.18078273088932142, -0.1760159755489718, -0.16865061331126227, -0.15904136091487175, -0.14756752732225356, -0.13461888616197776, -0.12058300781296416, -0.10583439818051152, -0.0907256642328181, -0.07558080422426758, -0.060690608986011814, -0.046310064114579955, -0.032657564269347995, -0.019915691575644292, -0.00823327044894154, 0.0022716100207446164, 0.011507919583092052, 0.019407660252202565, 0.025921773001301992, 0.031016232090896562, 0.03466854669458865, 0.03686485131708162, 0.03759772656874239, 0.03686485131708162, 0.03466854669458865, 0.031016232090896562, 0.025921773001301992, 0.019407660252202565, 0.011507919583092052, 0.0022716100207446164, -0.00823327044894154, -0.019915691575644292, -0.032657564269347995, -0.046310064114579955, -0.060690608986011814, -0.07558080422426758, -0.0907256642328181, -0.10583439818051152, -0.12058300781296416, -0.13461888616197776, -0.14756752732225356, -0.15904136091487175, -0.16865061331126227, -0.1760159755489718, -0.18078273088932142, -0.1826358700412797, -0.18131560690315682, -0.17663261032673944, -0.16848219583369567, -0.15685668268767797, -0.14185512230149663, -0.12368964794720452, -0.10268778525178764, -0.07929019757294747, -0.054043516875550875, -0.027588123185645037, -0.0006409754282528475, 0.026026147564044762, 0.05161237775613617, 0.07531659368730659, 0.09636827159298987, 0.11405907878471819], [0.11526115097856117, 0.09738828403656238, 0.0759235678781371, 0.05161237775613617, 0.025275083284098894, -0.0022274559793407315, -0.03002807965783915, -0.0572857273340844, -0.08321475815193494, -0.10711012813756442, -0.1283676319466868, -0.1464987033293174, -0.16113955966514656, -0.17205475511311313, -0.17913546063850083, -0.18239300622958532, -0.18194839266053625, -0.17801860199902664, -0.17090060569317098, -0.1609539875623888, -0.14858307017251748, -0.13421936300715656, -0.11830504740258321, -0.10127808535368477, -0.08355939645450051, -0.06554239869174844, -0.04758506314163741, -0.030004497243790427, -0.013073952151520388, 0.0029779491154211806, 0.017966041941118966, 0.031745840459068614, 0.044209509361482956, 0.05528095770522729, 0.0649104168254659, 0.07306884206017318, 0.07974244535617742, 0.08492762656935865, 0.08862652853638416, 0.09084339726921295, 0.09158188560927924, 0.09084339726921295, 0.08862652853638416, 0.08492762656935865, 0.07974244535617742, 0.07306884206017318, 0.0649104168254659, 0.05528095770522729, 0.044209509361482956, 0.031745840459068614, 0.017966041941118966, 0.0029779491154211806, -0.013073952151520388, -0.030004497243790427, -0.04758506314163741, -0.06554239869174844, -0.08355939645450051, -0.10127808535368477, -0.11830504740258321, -0.13421936300715656, -0.14858307017251748, -0.1609539875623888, -0.17090060569317098, -0.17801860199902664, -0.18194839266053625, -0.18239300622958532, -0.17913546063850083, -0.17205475511311313, -0.16113955966514656, -0.1464987033293174, -0.1283676319466868, -0.10711012813756442, -0.08321475815193494, -0.0572857273340844, -0.03002807965783915, -0.0022274559793407315, 0.025275083284098894, 0.05161237775613617, 0.0759235678781371, 0.09738828403656238], [0.0993958462307399, 0.07773008237271903, 0.05298490441364873, 0.026026147564044762, -0.0022274559793407315, -0.030841885736018544, -0.05890402451081101, -0.08555491563889543, -0.11001880232017779, -0.1316269478872783, -0.14983554931501694, -0.1642373823959323, -0.17456713788189782, -0.1807007071005138, -0.18264893898060253, -0.18054660691367944, -0.17463748569481502, -0.16525654180237792, -0.1528102839666787, -0.1377563081818195, -0.12058300781296416, -0.10179031338845618, -0.08187218787401292, -0.061301442485772274, -0.040517266401149735, -0.019915691575644292, 0.0001569493213448689, 0.019407660252202565, 0.03759772656874239, 0.054541276561040686, 0.07010183827093616, 0.08418731130237875, 0.09674378883254962, 0.10774865812501504, 0.11720338291232232, 0.12512633286074154, 0.13154597877649798, 0.13649472168344115, 0.14000357308347133, 0.14209785531573388, 0.14279404657238684, 0.14209785531573388, 0.14000357308347133, 0.13649472168344115, 0.13154597877649798, 0.12512633286074154, 0.11720338291232232, 0.10774865812501504, 0.09674378883254962, 0.08418731130237875, 0.07010183827093616, 0.054541276561040686, 0.03759772656874239, 0.019407660252202565, 0.0001569493213448689, -0.019915691575644292, -0.040517266401149735, -0.061301442485772274, -0.08187218787401292, -0.10179031338845618, -0.12058300781296416, -0.1377563081818195, -0.1528102839666787, -0.16525654180237792, -0.17463748569481502, -0.18054660691367944, -0.18264893898060253, -0.1807007071005138, -0.17456713788189782, -0.1642373823959323, -0.14983554931501694, -0.1316269478872783, -0.11001880232017779, -0.08555491563889543, -0.05890402451081101, -0.030841885736018544, -0.0022274559793407315, 0.026026147564044762, 0.05298490441364873, 0.07773008237271903], [0.08069235790121831, 0.05570574218106777, 0.028270310898122826, -0.0006409754282528475, -0.03002807965783915, -0.05890402451081101, -0.08633239590937543, -0.1114606806231028, -0.13354819579908725, -0.15198770280837584, -0.16632015713858264, -0.17624240938958516, -0.18160802037610754, -0.18242166855756492, -0.1788278960809016, -0.17109514979541934, -0.15959621882048483, -0.14478624788034108, -0.1271795169340972, -0.10732612754693129, -0.0857896329957062, -0.0631265026963309, -0.039868134180728126, -0.016505930263581485, 0.0065202421682302655, 0.02883009042098063, 0.05010748884225075, 0.07010183827093616, 0.08862652853638416, 0.10555493165712146, 0.12081441070397907, 0.13437885433763305, 0.14626024334832619, 0.15649972810645998, 0.16515865057394133, 0.17230988766358785, 0.17802983029511174, 0.18239124981424537, 0.18545724476618586, 0.18727640924644018, 0.18787932061729182, 0.18727640924644018, 0.18545724476618586, 0.18239124981424537, 0.17802983029511174, 0.17230988766358785, 0.16515865057394133, 0.15649972810645998, 0.14626024334832619, 0.13437885433763305, 0.12081441070397907, 0.10555493165712146, 0.08862652853638416, 0.07010183827093616, 0.05010748884225075, 0.02883009042098063, 0.0065202421682302655, -0.016505930263581485, -0.039868134180728126, -0.0631265026963309, -0.0857896329957062, -0.10732612754693129, -0.1271795169340972, -0.14478624788034108, -0.15959621882048483, -0.17109514979541934, -0.1788278960809016, -0.18242166855756492, -0.18160802037610754, -0.17624240938958516, -0.16632015713858264, -0.15198770280837584, -0.13354819579908725, -0.1114606806231028, -0.08633239590937543, -0.05890402451081101, -0.03002807965783915, -0.0006409754282528475, 0.028270310898122826, 0.05570574218106777], [0.059725017515438364, 0.03197958453286062, 0.0025207381574719806, -0.027588123185645037, -0.0572857273340844, -0.08555491563889543, -0.1114606806231028, -0.13418273806183595, -0.15304146672549196, -0.16751643729146143, -0.17725715646546372, -0.18208605074549258, -0.18199408570471504, -0.17712974307464055, -0.16778234479339135, -0.1543609103022869, -0.13736985507049018, -0.11738288358628372, -0.0950164022704569, -0.07090368426500879, -0.045670869380806056, -0.019915691575644292, 0.0058103924762656495, 0.031016232090896562, 0.05528095770522729, 0.07825990831739421, 0.09968670899986165, 0.11937185506223688, 0.13719827990417027, 0.15311446345017118, 0.16712567793535366, 0.1792839709402817, 0.18967745729212915, 0.19841943861188654, 0.20563779959612533, 0.21146505144444128, 0.21602931256266372, 0.21944644111666822, 0.22181346801290225, 0.2232034254780841, 0.22366162672468853, 0.2232034254780841, 0.22181346801290225, 0.21944644111666822, 0.21602931256266372, 0.21146505144444128, 0.20563779959612533, 0.19841943861188654, 0.18967745729212915, 0.1792839709402817, 0.16712567793535366, 0.15311446345017118, 0.13719827990417027, 0.11937185506223688, 0.09968670899986165, 0.07825990831739421, 0.05528095770522729, 0.031016232090896562, 0.0058103924762656495, -0.019915691575644292, -0.045670869380806056, -0.07090368426500879, -0.0950164022704569, -0.11738288358628372, -0.13736985507049018, -0.1543609103022869, -0.16778234479339135, -0.17712974307464055, -0.18199408570471504, -0.18208605074549258, -0.17725715646546372, -0.16751643729146143, -0.15304146672549196, -0.13418273806183595, -0.1114606806231028, -0.08555491563889543, -0.0572857273340844, -0.027588123185645037, 0.0025207381574719806, 0.03197958453286062], [0.037104384846577534, 0.007233082355737275, -0.023527608249201665, -0.054043516875550875, -0.08321475815193494, -0.11001880232017779, -0.13354819579908725, -0.15304146672549196, -0.167906160972842, -0.17773339606034183, -0.18230376872794093, -0.18158488243001691, -0.17572115154133375, -0.16501687105976595, -0.1499137997580331, -0.13096468174943518, -0.10880422217787396, -0.08411903827788304, -0.05761803324395176, -0.030004497243790427, -0.001951040868825416, 0.025921773001301992, 0.05306249567952219, 0.07900122348247962, 0.10335731863015635, 0.1258425822940911, 0.14626024334832619, 0.16450028494360933, 0.18053174205108255, 0.1943926655354523, 0.2061784643801796, 0.21602931256266372, 0.22411724822563847, 0.23063350923189954, 0.23577655069724138, 0.23974108638511749, 0.242708395806646, 0.24483804991090946, 0.24626113579560338, 0.24707500803079696, 0.24733956165584545, 0.24707500803079696, 0.24626113579560338, 0.24483804991090946, 0.242708395806646, 0.23974108638511749, 0.23577655069724138, 0.23063350923189954, 0.22411724822563847, 0.21602931256266372, 0.2061784643801796, 0.1943926655354523, 0.18053174205108255, 0.16450028494360933, 0.14626024334832619, 0.1258425822940911, 0.10335731863015635, 0.07900122348247962, 0.05306249567952219, 0.025921773001301992, -0.001951040868825416, -0.030004497243790427, -0.05761803324395176, -0.08411903827788304, -0.10880422217787396, -0.13096468174943518, -0.1499137997580331, -0.16501687105976595, -0.17572115154133375, -0.18158488243001691, -0.18230376872794093, -0.17773339606034183, -0.167906160972842, -0.15304146672549196, -0.13354819579908725, -0.11001880232017779, -0.08321475815193494, -0.054043516875550875, -0.023527608249201665, 0.007233082355737275], [0.013454008098850966, -0.017859822184363938, -0.04916880920228074, -0.07929019757294747, -0.10711012813756442, -0.1316269478872783, -0.15198770280837584, -0.16751643729146143, -0.17773339606034183, -0.18236471957976835, -0.18134271385500067, -0.1747972342928682, -0.16303912773542587, -0.14653700801271363, -0.1258888846262905, -0.10179031338845618, -0.0750007897964791, -0.046310064114579955, -0.016505930263581485, 0.013655158230898757, 0.043473546354522816, 0.07232710218505171, 0.09968670899986165, 0.12512633286074154, 0.14832776112580212, 0.16908036038891633, 0.18727640924644018, 0.20290271423033404, 0.21602931256266372, 0.22679610352037188, 0.23539823538075702, 0.2420710146043941, 0.24707500803079696, 0.2506818889186662, 0.2531614457800734, 0.25477004091850136, 0.2557406839380664, 0.2562747828163765, 0.25653555744366946, 0.2566430509401283, 0.2566706526738519, 0.2566430509401283, 0.25653555744366946, 0.2562747828163765, 0.2557406839380664, 0.25477004091850136, 0.2531614457800734, 0.2506818889186662, 0.24707500803079696, 0.2420710146043941, 0.23539823538075702, 0.22679610352037188, 0.21602931256266372, 0.20290271423033404, 0.18727640924644018, 0.16908036038891633, 0.14832776112580212, 0.12512633286074154, 0.09968670899986165, 0.07232710218505171, 0.043473546354522816, 0.013655158230898757, -0.016505930263581485, -0.046310064114579955, -0.0750007897964791, -0.10179031338845618, -0.1258888846262905, -0.14653700801271363, -0.16303912773542587, -0.1747972342928682, -0.18134271385500067, -0.18236471957976835, -0.17773339606034183, -0.16751643729146143, -0.15198770280837584, -0.1316269478872783, -0.10711012813756442, -0.07929019757294747, -0.04916880920228074, -0.017859822184363938], [-0.01061150357619211, -0.042655257000177006, -0.07374973820785838, -0.10268778525178764, -0.1283676319466868, -0.14983554931501694, -0.16632015713858264, -0.17725715646546372, -0.18230376872794093, -0.18134271385500067, -0.17447608825271163, -0.16200998595397612, -0.14443111863131364, -0.12237701362727325, -0.09660159075517502, -0.06793803188546253, -0.03726086233570953, -0.005449066140771361, 0.026648129724923395, 0.058241427706856384, 0.08862652853638416, 0.11720338291232232, 0.14348926836260514, 0.16712567793535366, 0.18787932061729182, 0.20563779959612533, 0.22040074178662336, 0.23226729318028777, 0.24142096714711753, 0.24811283911536614, 0.25264402764959015, 0.255348298963932, 0.256575492104657, 0.2566762997375786, 0.2559887694405144, 0.2548267267047997, 0.25347017586536014, 0.252157618714697, 0.25108014921898075, 0.25037713957121355, 0.25013332713993036, 0.25037713957121355, 0.25108014921898075, 0.252157618714697, 0.25347017586536014, 0.2548267267047997, 0.2559887694405144, 0.2566762997375786, 0.256575492104657, 0.255348298963932, 0.25264402764959015, 0.24811283911536614, 0.24142096714711753, 0.23226729318028777, 0.22040074178662336, 0.20563779959612533, 0.18787932061729182, 0.16712567793535366, 0.14348926836260514, 0.11720338291232232, 0.08862652853638416, 0.058241427706856384, 0.026648129724923395, -0.005449066140771361, -0.03726086233570953, -0.06793803188546253, -0.09660159075517502, -0.12237701362727325, -0.14443111863131364, -0.16200998595397612, -0.17447608825271163, -0.18134271385500067, -0.18230376872794093, -0.17725715646546372, -0.16632015713858264, -0.14983554931501694, -0.1283676319466868, -0.10268778525178764, -0.07374973820785838, -0.042655257000177006], [-0.0345063152690242, -0.06655906279410359, -0.09668883252747353, -0.12368964794720452, -0.1464987033293174, -0.1642373823959323, -0.17624240938958516, -0.18208605074549258, -0.18158488243001691, -0.1747972342928682, -0.16200998595397612, -0.1437158894806465, -0.12058300781296416, -0.09341816596346665, -0.0631265026963309, -0.03066927919323432, 0.0029779491154211806, 0.03686485131708162, 0.07010183827093616, 0.1018902143955224, 0.13154597877649798, 0.15851669454452746, 0.18239124981424537, 0.20290271423033404, 0.21992483146863692, 0.23346296309158113, 0.24364050109720906, 0.2506818889186662, 0.254893432701845, 0.2566430509401283, 0.2563400102730029, 0.25441554164532254, 0.25130504004127213, 0.24743234013685533, 0.2431963471432226, 0.23896010343988033, 0.23504220166614895, 0.2317103248693539, 0.22917661128094333, 0.22759450814784551, 0.2270567942100705, 0.22759450814784551, 0.22917661128094333, 0.2317103248693539, 0.23504220166614895, 0.23896010343988033, 0.2431963471432226, 0.24743234013685533, 0.25130504004127213, 0.25441554164532254, 0.2563400102730029, 0.2566430509401283, 0.254893432701845, 0.2506818889186662, 0.24364050109720906, 0.23346296309158113, 0.21992483146863692, 0.20290271423033404, 0.18239124981424537, 0.15851669454452746, 0.13154597877649798, 0.1018902143955224, 0.07010183827093616, 0.03686485131708162, 0.0029779491154211806, -0.03066927919323432, -0.0631265026963309, -0.09341816596346665, -0.12058300781296416, -0.1437158894806465, -0.16200998595397612, -0.1747972342928682, -0.18158488243001691, -0.18208605074549258, -0.17624240938958516, -0.1642373823959323, -0.1464987033293174, -0.12368964794720452, -0.09668883252747353, -0.06655906279410359], [-0.05769048962428924, -0.08904297911487404, -0.11749065565570795, -0.14185512230149663, -0.16113955966514656, -0.17456713788189782, -0.18160802037610754, -0.18199408570471504, -0.17572115154133375, -0.16303912773542587, -0.14443111863131364, -0.12058300781296416, -0.09234546620178369, -0.060690608986011814, -0.026665677985416577, 0.008653858363151095, 0.044209509361482956, 0.07900122348247962, 0.11212338767979044, 0.14279404657238684, 0.17037647050011584, 0.1943926655354523, 0.2145288714461612, 0.23063350923189954, 0.242708395806646, 0.2508943222213973, 0.2554522819126627, 0.2567417315441088, 0.25519727019112654, 0.25130504004127213, 0.2455799958764798, 0.23854497801642713, 0.23071227369415245, 0.2225680860000738, 0.21456006847846779, 0.2070878465419809, 0.20049625055173417, 0.19507084218595108, 0.19103523332295086, 0.18854967763954522, 0.18771045677679687, 0.18854967763954522, 0.19103523332295086, 0.19507084218595108, 0.20049625055173417, 0.2070878465419809, 0.21456006847846779, 0.2225680860000738, 0.23071227369415245, 0.23854497801642713, 0.2455799958764798, 0.25130504004127213, 0.25519727019112654, 0.2567417315441088, 0.2554522819126627, 0.2508943222213973, 0.242708395806646, 0.23063350923189954, 0.2145288714461612, 0.1943926655354523, 0.17037647050011584, 0.14279404657238684, 0.11212338767979044, 0.07900122348247962, 0.044209509361482956, 0.008653858363151095, -0.026665677985416577, -0.060690608986011814, -0.09234546620178369, -0.12058300781296416, -0.14443111863131364, -0.16303912773542587, -0.17572115154133375, -0.18199408570471504, -0.18160802037610754, -0.17456713788189782, -0.16113955966514656, -0.14185512230149663, -0.11749065565570795, -0.08904297911487404], [-0.07968395387291566, -0.10965701691843574, -0.13575600794040762, -0.15685668268767797, -0.17205475511311313, -0.1807007071005138, -0.18242166855756492, -0.17712974307464055, -0.16501687105976595, -0.14653700801271363, -0.12237701362727325, -0.09341816596346665, -0.060690608986011814, -0.02532329427921568, 0.011507919583092052, 0.04863139306208121, 0.08492762656935865, 0.11937185506223688, 0.15106960365711752, 0.1792839709402817, 0.20345392533496165, 0.2232034254780841, 0.2383416766936446, 0.24885528388828942, 0.254893432701845, 0.25674750760048576, 0.2548267267047997, 0.24963143467045815, 0.24172565029557566, 0.2317103248693539, 0.22019854657881394, 0.20779364608280457, 0.19507084218595108, 0.18256273925541686, 0.17074867404778504, 0.16004763127913005, 0.15081422331281308, 0.1433370736825879, 0.13783886506830845, 0.134477311926808, 0.1333463922312941, 0.134477311926808, 0.13783886506830845, 0.1433370736825879, 0.15081422331281308, 0.16004763127913005, 0.17074867404778504, 0.18256273925541686, 0.19507084218595108, 0.20779364608280457, 0.22019854657881394, 0.2317103248693539, 0.24172565029557566, 0.24963143467045815, 0.2548267267047997, 0.25674750760048576, 0.254893432701845, 0.24885528388828942, 0.2383416766936446, 0.2232034254780841, 0.20345392533496165, 0.1792839709402817, 0.15106960365711752, 0.11937185506223688, 0.08492762656935865, 0.04863139306208121, 0.011507919583092052, -0.02532329427921568, -0.060690608986011814, -0.09341816596346665, -0.12237701362727325, -0.14653700801271363, -0.16501687105976595, -0.17712974307464055, -0.18242166855756492, -0.1807007071005138, -0.17205475511311313, -0.15685668268767797, -0.13575600794040762, -0.10965701691843574], [-0.10007704610444179, -0.12803786284735597, -0.1511875643863488, -0.16848219583369567, -0.17913546063850083, -0.18264893898060253, -0.1788278960809016, -0.16778234479339135, -0.1499137997580331, -0.1258888846262905, -0.09660159075517502, -0.0631265026963309, -0.026665677985416577, 0.011507919583092052, 0.05010748884225075, 0.0878871354792479, 0.12369173187889267, 0.15649972810645998, 0.18545724476618586, 0.20990234059772522, 0.22937894091767205, 0.24364050109720906, 0.25264402764959015, 0.25653555744366946, 0.25562857790064414, 0.25037713957121355, 0.2413455569066888, 0.22917661128094333, 0.21456006847846779, 0.1982031145119569, 0.18080401871815463, 0.1630299764243758, 0.14549969299473817, 0.12877087581897034, 0.11333242903336226, 0.09960082298540655, 0.08791985781076668, 0.07856287339249271, 0.07173638515428266, 0.06758414818694233, 0.0661907655654817, 0.06758414818694233, 0.07173638515428266, 0.07856287339249271, 0.08791985781076668, 0.09960082298540655, 0.11333242903336226, 0.12877087581897034, 0.14549969299473817, 0.1630299764243758, 0.18080401871815463, 0.1982031145119569, 0.21456006847846779, 0.22917661128094333, 0.2413455569066888, 0.25037713957121355, 0.25562857790064414, 0.25653555744366946, 0.25264402764959015, 0.24364050109720906, 0.22937894091767205, 0.20990234059772522, 0.18545724476618586, 0.15649972810645998, 0.12369173187889267, 0.0878871354792479, 0.05010748884225075, 0.011507919583092052, -0.026665677985416577, -0.0631265026963309, -0.09660159075517502, -0.1258888846262905, -0.1499137997580331, -0.16778234479339135, -0.1788278960809016, -0.18264893898060253, -0.17913546063850083, -0.16848219583369567, -0.1511875643863488, -0.12803786284735597], [-0.11853755153953284, -0.14391335124448024, -0.163591222139663, -0.17663261032673944, -0.18239300622958532, -0.18054660691367944, -0.17109514979541934, -0.1543609103022869, -0.13096468174943518, -0.10179031338845618, -0.06793803188546253, -0.03066927919323432, 0.008653858363151095, 0.04863139306208121, 0.0878871354792479, 0.12512633286074154, 0.15918658398472915, 0.1890798565922851, 0.21402402107025095, 0.23346296309158113, 0.24707500803079696, 0.25477004091850136, 0.2566762997375786, 0.25311832399967577, 0.24458792842044305, 0.2317103248693539, 0.2152076253393881, 0.19586192453391038, 0.17447999195279823, 0.15186131748507978, 0.12877087581897034, 0.10591753298818528, 0.08393854575868848, 0.06339013493636744, 0.044743679368913644, 0.02838670735216783, 0.014627580006334946, 0.0037025838949493145, -0.004215913110515241, -0.009011537058698997, -0.010617349295218181, -0.009011537058698997, -0.004215913110515241, 0.0037025838949493145, 0.014627580006334946, 0.02838670735216783, 0.044743679368913644, 0.06339013493636744, 0.08393854575868848, 0.10591753298818528, 0.12877087581897034, 0.15186131748507978, 0.17447999195279823, 0.19586192453391038, 0.2152076253393881, 0.2317103248693539, 0.24458792842044305, 0.25311832399967577, 0.2566762997375786, 0.25477004091850136, 0.24707500803079696, 0.23346296309158113, 0.21402402107025095, 0.1890798565922851, 0.15918658398472915, 0.12512633286074154, 0.0878871354792479, 0.04863139306208121, 0.008653858363151095, -0.03066927919323432, -0.06793803188546253, -0.10179031338845618, -0.13096468174943518, -0.1543609103022869, -0.17109514979541934, -0.18054660691367944, -0.18239300622958532, -0.17663261032673944, -0.163591222139663, -0.14391335124448024], [-0.13481430178982187, -0.15710321083861073, -0.17287351607260817, -0.18131560690315682, -0.18194839266053625, -0.17463748569481502, -0.15959621882048483, -0.13736985507049018, -0.10880422217787396, -0.0750007897964791, -0.03726086233570953, 0.0029779491154211806, 0.044209509361482956, 0.08492762656935865, 0.12369173187889267, 0.15918658398472915, 0.1902732638436695, 0.21602931256266372, 0.23577655069724138, 0.24909585663212155, 0.25582893038458626, 0.2560677827399544, 0.25013332713993036, 0.23854497801642713, 0.22198354690007724, 0.20124995852555586, 0.17722237538812438, 0.15081422331281308, 0.12293536517635703, 0.09445829662141196, 0.0661907655654817, 0.03885568116655977, 0.013078615468659323, -0.010617349295218181, -0.03181017613329085, -0.050171999808914604, -0.06545830501430487, -0.07749482277960204, -0.08616386191642225, -0.09139170665445415, -0.09313849939964196, -0.09139170665445415, -0.08616386191642225, -0.07749482277960204, -0.06545830501430487, -0.050171999808914604, -0.03181017613329085, -0.010617349295218181, 0.013078615468659323, 0.03885568116655977, 0.0661907655654817, 0.09445829662141196, 0.12293536517635703, 0.15081422331281308, 0.17722237538812438, 0.20124995852555586, 0.22198354690007724, 0.23854497801642713, 0.25013332713993036, 0.2560677827399544, 0.25582893038458626, 0.24909585663212155, 0.23577655069724138, 0.21602931256266372, 0.1902732638436695, 0.15918658398472915, 0.12369173187889267, 0.08492762656935865, 0.044209509361482956, 0.0029779491154211806, -0.03726086233570953, -0.0750007897964791, -0.10880422217787396, -0.13736985507049018, -0.15959621882048483, -0.17463748569481502, -0.18194839266053625, -0.18131560690315682, -0.17287351607260817, -0.15710321083861073], [-0.1487375524385824, -0.16751643729146143, -0.17903560277058095, -0.1826358700412797, -0.17801860199902664, -0.16525654180237792, -0.14478624788034108, -0.11738288358628372, -0.08411903827788304, -0.046310064114579955, -0.005449066140771361, 0.03686485131708162, 0.07900122348247962, 0.11937185506223688, 0.15649972810645998, 0.1890798565922851, 0.21602931256266372, 0.2365243422174828, 0.25002327766855664, 0.2562747828163765, 0.2553118000893658, 0.24743234013685533, 0.23316893482082693, 0.21324911772700825, 0.18854967763954522, 0.16004763127913005, 0.12877087581897034, 0.0957513146109, 0.06198291759831892, 0.02838670735216783, -0.004215913110515241, -0.03512071345143313, -0.06374895250625122, -0.08964697741323371, -0.11247819731414006, -0.132008995765264, -0.14809048863531396, -0.16063822727306362, -0.1696119802323752, -0.17499760171649797, -0.17679272260843765, -0.17499760171649797, -0.1696119802323752, -0.16063822727306362, -0.14809048863531396, -0.132008995765264, -0.11247819731414006, -0.08964697741323371, -0.06374895250625122, -0.03512071345143313, -0.004215913110515241, 0.02838670735216783, 0.06198291759831892, 0.0957513146109, 0.12877087581897034, 0.16004763127913005, 0.18854967763954522, 0.21324911772700825, 0.23316893482082693, 0.24743234013685533, 0.2553118000893658, 0.2562747828163765, 0.25002327766855664, 0.2365243422174828, 0.21602931256266372, 0.1890798565922851, 0.15649972810645998, 0.11937185506223688, 0.07900122348247962, 0.03686485131708162, -0.005449066140771361, -0.046310064114579955, -0.08411903827788304, -0.11738288358628372, -0.14478624788034108, -0.16525654180237792, -0.17801860199902664, -0.1826358700412797, -0.17903560277058095, -0.16751643729146143], [-0.16021647158282734, -0.1751457556394694, -0.1821644169794075, -0.18078273088932142, -0.17090060569317098, -0.1528102839666787, -0.1271795169340972, -0.0950164022704569, -0.05761803324395176, -0.016505930263581485, 0.026648129724923395, 0.07010183827093616, 0.11212338767979044, 0.15106960365711752, 0.18545724476618586, 0.21402402107025095, 0.23577655069724138, 0.25002327766855664, 0.25639126767027576, 0.2548267267047997, 0.2455799958764798, 0.22917661128094333, 0.2063767337439853, 0.17812580971586786, 0.14549969299473817, 0.1096476200446325, 0.07173638515428266, 0.032898814044057145, -0.005810793613848673, -0.043452159632214875, -0.0792240541655952, -0.11247819731414006, -0.1427221428215067, -0.1696119802323752, -0.1929363397545002, -0.2125937105436689, -0.22856545626592412, -0.24088710992360066, -0.24962054293732017, -0.254829433326894, -0.2565601183892334, -0.254829433326894, -0.24962054293732017, -0.24088710992360066, -0.22856545626592412, -0.2125937105436689, -0.1929363397545002, -0.1696119802323752, -0.1427221428215067, -0.11247819731414006, -0.0792240541655952, -0.043452159632214875, -0.005810793613848673, 0.032898814044057145, 0.07173638515428266, 0.1096476200446325, 0.14549969299473817, 0.17812580971586786, 0.2063767337439853, 0.22917661128094333, 0.2455799958764798, 0.2548267267047997, 0.25639126767027576, 0.25002327766855664, 0.23577655069724138, 0.21402402107025095, 0.18545724476618586, 0.15106960365711752, 0.11212338767979044, 0.07010183827093616, 0.026648129724923395, -0.016505930263581485, -0.05761803324395176, -0.0950164022704569, -0.1271795169340972, -0.1528102839666787, -0.17090060569317098, -0.18078273088932142, -0.1821644169794075, -0.1751457556394694], [-0.16923416092386775, -0.1800597155006458, -0.18242166855756492, -0.1760159755489718, -0.1609539875623888, -0.1377563081818195, -0.10732612754693129, -0.07090368426500879, -0.030004497243790427, 0.013655158230898757, 0.058241427706856384, 0.1018902143955224, 0.14279404657238684, 0.1792839709402817, 0.20990234059772522, 0.23346296309158113, 0.24909585663212155, 0.2562747828163765, 0.2548267267047997, 0.24492352037505036, 0.2270567942100705, 0.20199833430642128, 0.17074867404778504, 0.134477311926808, 0.09445829662141196, 0.05200503792795912, 0.00840808631479302, -0.03512071345143313, -0.07749482277960204, -0.1177881852505473, -0.15525760655490364, -0.18935183535374994, -0.21970771693043264, -0.24613461781837798, -0.268589046149572, -0.28714197491104243, -0.30194177876754097, -0.31317589634427284, -0.3210343185560354, -0.32567778292945404, -0.32721314035298743, -0.32567778292945404, -0.3210343185560354, -0.31317589634427284, -0.30194177876754097, -0.28714197491104243, -0.268589046149572, -0.24613461781837798, -0.21970771693043264, -0.18935183535374994, -0.15525760655490364, -0.1177881852505473, -0.07749482277960204, -0.03512071345143313, 0.00840808631479302, 0.05200503792795912, 0.09445829662141196, 0.134477311926808, 0.17074867404778504, 0.20199833430642128, 0.2270567942100705, 0.24492352037505036, 0.2548267267047997, 0.2562747828163765, 0.24909585663212155, 0.23346296309158113, 0.20990234059772522, 0.1792839709402817, 0.14279404657238684, 0.1018902143955224, 0.058241427706856384, 0.013655158230898757, -0.030004497243790427, -0.07090368426500879, -0.10732612754693129, -0.1377563081818195, -0.1609539875623888, -0.1760159755489718, -0.18242166855756492, -0.1800597155006458], [-0.17584069010379264, -0.18239300622958532, -0.1800313728705813, -0.16865061331126227, -0.14858307017251748, -0.12058300781296416, -0.0857896329957062, -0.045670869380806056, -0.001951040868825416, 0.043473546354522816, 0.08862652853638416, 0.13154597877649798, 0.17037647050011584, 0.20345392533496165, 0.22937894091767205, 0.24707500803079696, 0.25582893038458626, 0.2553118000893658, 0.2455799958764798, 0.2270567942100705, 0.20049625055173417, 0.16693195814109418, 0.12761407121954643, 0.08393854575868848, 0.037372873633869375, -0.010617349295218181, -0.05863687417657578, -0.10542055787501849, -0.14988136590815446, -0.19114437378651342, -0.22856545626592412, -0.2617343483375656, -0.29046275344788247, -0.31475910259630246, -0.33479237619194996, -0.35084804028714445, -0.3632795822101567, -0.37245933283868765, -0.3787322233669178, -0.382375848005458, -0.3835697098652554, -0.382375848005458, -0.3787322233669178, -0.37245933283868765, -0.3632795822101567, -0.35084804028714445, -0.33479237619194996, -0.31475910259630246, -0.29046275344788247, -0.2617343483375656, -0.22856545626592412, -0.19114437378651342, -0.14988136590815446, -0.10542055787501849, -0.05863687417657578, -0.010617349295218181, 0.037372873633869375, 0.08393854575868848, 0.12761407121954643, 0.16693195814109418, 0.20049625055173417, 0.2270567942100705, 0.2455799958764798, 0.2553118000893658, 0.25582893038458626, 0.24707500803079696, 0.22937894091767205, 0.20345392533496165, 0.17037647050011584, 0.13154597877649798, 0.08862652853638416, 0.043473546354522816, -0.001951040868825416, -0.045670869380806056, -0.0857896329957062, -0.12058300781296416, -0.14858307017251748, -0.16865061331126227, -0.1800313728705813, -0.18239300622958532], [-0.1801446545297837, -0.18233559039097344, -0.1752665961050691, -0.15904136091487175, -0.13421936300715656, -0.10179031338845618, -0.0631265026963309, -0.019915691575644292, 0.025921773001301992, 0.07232710218505171, 0.11720338291232232, 0.15851669454452746, 0.1943926655354523, 0.2232034254780841, 0.24364050109720906, 0.25477004091850136, 0.2560677827399544, 0.24743234013685533, 0.22917661128094333, 0.20199833430642128, 0.16693195814109418, 0.12528500092613942, 0.07856287339249271, 0.02838670735216783, -0.02359098016854476, -0.0757679524450742, -0.12666669235949252, -0.17499760171649797, -0.21970771693043264, -0.26001264723920775, -0.29541051237375787, -0.32567778292945404, -0.35084804028714445, -0.37117570680030565, -0.38708768931988075, -0.3991265770886398, -0.407889497747319, -0.41396693622794944, -0.417885750201407, -0.4200602785751461, -0.4207548585159486, -0.4200602785751461, -0.417885750201407, -0.41396693622794944, -0.407889497747319, -0.3991265770886398, -0.38708768931988075, -0.37117570680030565, -0.35084804028714445, -0.32567778292945404, -0.29541051237375787, -0.26001264723920775, -0.21970771693043264, -0.17499760171649797, -0.12666669235949252, -0.0757679524450742, -0.02359098016854476, 0.02838670735216783, 0.07856287339249271, 0.12528500092613942, 0.16693195814109418, 0.20199833430642128, 0.22917661128094333, 0.24743234013685533, 0.2560677827399544, 0.25477004091850136, 0.24364050109720906, 0.2232034254780841, 0.1943926655354523, 0.15851669454452746, 0.11720338291232232, 0.07232710218505171, 0.025921773001301992, -0.019915691575644292, -0.0631265026963309, -0.10179031338845618, -0.13421936300715656, -0.15904136091487175, -0.1752665961050691, -0.18233559039097344], [-0.18230376872794093, -0.18012123502583363, -0.16843605361995675, -0.14756752732225356, -0.11830504740258321, -0.08187218787401292, -0.039868134180728126, 0.0058103924762656495, 0.05306249567952219, 0.09968670899986165, 0.14348926836260514, 0.18239124981424537, 0.2145288714461612, 0.2383416766936446, 0.25264402764959015, 0.2566762997375786, 0.25013332713993036, 0.23316893482082693, 0.2063767337439853, 0.17074867404778504, 0.12761407121954643, 0.07856287339249271, 0.02535776443828009, -0.030159748399708135, -0.08616386191642225, -0.1409342819269669, -0.1929363397545002, -0.24088710992360066, -0.2838041182964338, -0.3210343185560354, -0.35226222727992795, -0.37749737145928347, -0.3970424421347404, -0.41144469052055266, -0.42143408131469146, -0.42785247459104203, -0.43157859884674826, -0.4334537754581445, -0.434213248547002, -0.43442757176285574, -0.43445783007337646, -0.43442757176285574, -0.434213248547002, -0.4334537754581445, -0.43157859884674826, -0.42785247459104203, -0.42143408131469146, -0.41144469052055266, -0.3970424421347404, -0.37749737145928347, -0.35226222727992795, -0.3210343185560354, -0.2838041182964338, -0.24088710992360066, -0.1929363397545002, -0.1409342819269669, -0.08616386191642225, -0.030159748399708135, 0.02535776443828009, 0.07856287339249271, 0.12761407121954643, 0.17074867404778504, 0.2063767337439853, 0.23316893482082693, 0.25013332713993036, 0.2566762997375786, 0.25264402764959015, 0.2383416766936446, 0.2145288714461612, 0.18239124981424537, 0.14348926836260514, 0.09968670899986165, 0.05306249567952219, 0.0058103924762656495, -0.039868134180728126, -0.08187218787401292, -0.11830504740258321, -0.14756752732225356, -0.16843605361995675, -0.18012123502583363], [-0.18251498442862385, -0.1760159755489718, -0.15987112992755653, -0.13461888616197776, -0.10127808535368477, -0.061301442485772274, -0.016505930263581485, 0.031016232090896562, 0.07900122348247962, 0.12512633286074154, 0.16712567793535366, 0.20290271423033404, 0.23063350923189954, 0.24885528388828942, 0.25653555744366946, 0.25311832399967577, 0.23854497801642713, 0.21324911772700825, 0.17812580971586786, 0.134477311926808, 0.08393854575868848, 0.02838670735216783, -0.030159748399708135, -0.08964697741323371, -0.14809048863531396, -0.2036729142303004, -0.254829433326894, -0.3003162506586467, -0.3392585664190622, -0.37117570680030565, -0.39598244357893553, -0.41396693622794944, -0.42574709936268906, -0.43220845214435083, -0.43442757176285574, -0.4335860886421158, -0.4308806796227811, -0.4274347075936389, -0.42421701152445723, -0.42197287899622543, -0.421171462695804, -0.42197287899622543, -0.42421701152445723, -0.4274347075936389, -0.4308806796227811, -0.4335860886421158, -0.43442757176285574, -0.43220845214435083, -0.42574709936268906, -0.41396693622794944, -0.39598244357893553, -0.37117570680030565, -0.3392585664190622, -0.3003162506586467, -0.254829433326894, -0.2036729142303004, -0.14809048863531396, -0.08964697741323371, -0.030159748399708135, 0.02838670735216783, 0.08393854575868848, 0.134477311926808, 0.17812580971586786, 0.21324911772700825, 0.23854497801642713, 0.25311832399967577, 0.25653555744366946, 0.24885528388828942, 0.23063350923189954, 0.20290271423033404, 0.16712567793535366, 0.12512633286074154, 0.07900122348247962, 0.031016232090896562, -0.016505930263581485, -0.061301442485772274, -0.10127808535368477, -0.13461888616197776, -0.15987112992755653, -0.1760159755489718], [-0.18100457917857166, -0.17030698199702413, -0.1499137997580331, -0.12058300781296416, -0.08355939645450051, -0.040517266401149735, 0.0065202421682302655, 0.05528095770522729, 0.10335731863015635, 0.14832776112580212, 0.18787932061729182, 0.21992483146863692, 0.242708395806646, 0.254893432701845, 0.25562857790064414, 0.24458792842044305, 0.22198354690007724, 0.18854967763954522, 0.14549969299473817, 0.09445829662141196, 0.037372873633869375, -0.02359098016854476, -0.08616386191642225, -0.14809048863531396, -0.20724458052139974, -0.2617343483375656, -0.309992807249447, -0.35084804028714445, -0.3835697098652554, -0.407889497747319, -0.42399466300627076, -0.43249545715781157, -0.43436863670247905, -0.4308806796227811, -0.42349546556438716, -0.4137720534188708, -0.40325873487122593, -0.39338972722403176, -0.3853906832849483, -0.3801986514917913, -0.3784012476539641, -0.3801986514917913, -0.3853906832849483, -0.39338972722403176, -0.40325873487122593, -0.4137720534188708, -0.42349546556438716, -0.4308806796227811, -0.43436863670247905, -0.43249545715781157, -0.42399466300627076, -0.407889497747319, -0.3835697098652554, -0.35084804028714445, -0.309992807249447, -0.2617343483375656, -0.20724458052139974, -0.14809048863531396, -0.08616386191642225, -0.02359098016854476, 0.037372873633869375, 0.09445829662141196, 0.14549969299473817, 0.18854967763954522, 0.22198354690007724, 0.24458792842044305, 0.25562857790064414, 0.254893432701845, 0.242708395806646, 0.21992483146863692, 0.18787932061729182, 0.14832776112580212, 0.10335731863015635, 0.05528095770522729, 0.0065202421682302655, -0.040517266401149735, -0.08355939645450051, -0.12058300781296416, -0.1499137997580331, -0.17030698199702413], [-0.17801860199902664, -0.16329221750830802, -0.13890582780165694, -0.10583439818051152, -0.06554239869174844, -0.019915691575644292, 0.02883009042098063, 0.07825990831739421, 0.1258425822940911, 0.16908036038891633, 0.20563779959612533, 0.23346296309158113, 0.2508943222213973, 0.25674750760048576, 0.25037713957121355, 0.2317103248693539, 0.20124995852555586, 0.16004763127913005, 0.1096476200446325, 0.05200503792795912, -0.010617349295218181, -0.0757679524450742, -0.1409342819269669, -0.2036729142303004, -0.2617343483375656, -0.31317589634427284, -0.3564564355250057, -0.3905078789395116, -0.4147795406040892, -0.42925310491460716, -0.43442757176285574, -0.4312752446188071, -0.421171462695804, -0.40580225753498556, -0.38705535500366767, -0.36690087535799776, -0.3472686537517362, -0.32992927901128904, -0.3163857196862348, -0.3077817863653888, -0.30483270332925, -0.3077817863653888, -0.3163857196862348, -0.32992927901128904, -0.3472686537517362, -0.36690087535799776, -0.38705535500366767, -0.40580225753498556, -0.421171462695804, -0.4312752446188071, -0.43442757176285574, -0.42925310491460716, -0.4147795406040892, -0.3905078789395116, -0.3564564355250057, -0.31317589634427284, -0.2617343483375656, -0.2036729142303004, -0.1409342819269669, -0.0757679524450742, -0.010617349295218181, 0.05200503792795912, 0.1096476200446325, 0.16004763127913005, 0.20124995852555586, 0.2317103248693539, 0.25037713957121355, 0.25674750760048576, 0.2508943222213973, 0.23346296309158113, 0.20563779959612533, 0.16908036038891633, 0.1258425822940911, 0.07825990831739421, 0.02883009042098063, -0.019915691575644292, -0.06554239869174844, -0.10583439818051152, -0.13890582780165694, -0.16329221750830802], [-0.1738139924448547, -0.15527119023634722, -0.1271795169340972, -0.0907256642328181, -0.04758506314163741, 0.0001569493213448689, 0.05010748884225075, 0.09968670899986165, 0.14626024334832619, 0.18727640924644018, 0.22040074178662336, 0.24364050109720906, 0.2554522819126627, 0.2548267267047997, 0.2413455569066888, 0.2152076253393881, 0.17722237538812438, 0.12877087581897034, 0.07173638515428266, 0.00840808631479302, -0.05863687417657578, -0.12666669235949252, -0.1929363397545002, -0.254829433326894, -0.309992807249447, -0.3564564355250057, -0.39273214882544505, -0.417885750201407, -0.43157859884674826, -0.434076417833265, -0.42622489689420734, -0.4093935036702951, -0.3853906832849483, -0.35635521764627226, -0.324629843053556, -0.2926242127644853, -0.2626748843273063, -0.23691017597600564, -0.21712746254366178, -0.20468978410715197, -0.20044755867978276, -0.20468978410715197, -0.21712746254366178, -0.23691017597600564, -0.2626748843273063, -0.2926242127644853, -0.324629843053556, -0.35635521764627226, -0.3853906832849483, -0.4093935036702951, -0.42622489689420734, -0.434076417833265, -0.43157859884674826, -0.417885750201407, -0.39273214882544505, -0.3564564355250057, -0.309992807249447, -0.254829433326894, -0.1929363397545002, -0.12666669235949252, -0.05863687417657578, 0.00840808631479302, 0.07173638515428266, 0.12877087581897034, 0.17722237538812438, 0.2152076253393881, 0.2413455569066888, 0.2548267267047997, 0.2554522819126627, 0.24364050109720906, 0.22040074178662336, 0.18727640924644018, 0.14626024334832619, 0.09968670899986165, 0.05010748884225075, 0.0001569493213448689, -0.04758506314163741, -0.0907256642328181, -0.1271795169340972, -0.15527119023634722], [-0.16865061331126227, -0.14653700801271363, -0.11505016730310495, -0.07558080422426758, -0.030004497243790427, 0.019407660252202565, 0.07010183827093616, 0.11937185506223688, 0.16450028494360933, 0.20290271423033404, 0.23226729318028777, 0.2506818889186662, 0.2567417315441088, 0.24963143467045815, 0.22917661128094333, 0.19586192453391038, 0.15081422331281308, 0.0957513146109, 0.032898814044057145, -0.03512071345143313, -0.10542055787501849, -0.17499760171649797, -0.24088710992360066, -0.3003162506586467, -0.35084804028714445, -0.3905078789395116, -0.417885750201407, -0.43220845214435083, -0.4333778373354074, -0.42197287899622543, -0.39921534828629784, -0.36690087535799776, -0.32729906443176787, -0.28302803533990717, -0.23691017597600564, -0.19181693290541052, -0.15051108239111077, -0.11549507625799743, -0.08887373699192957, -0.0722388011028484, -0.06658162124929747, -0.0722388011028484, -0.08887373699192957, -0.11549507625799743, -0.15051108239111077, -0.19181693290541052, -0.23691017597600564, -0.28302803533990717, -0.32729906443176787, -0.36690087535799776, -0.39921534828629784, -0.42197287899622543, -0.4333778373354074, -0.43220845214435083, -0.417885750201407, -0.3905078789395116, -0.35084804028714445, -0.3003162506586467, -0.24088710992360066, -0.17499760171649797, -0.10542055787501849, -0.03512071345143313, 0.032898814044057145, 0.0957513146109, 0.15081422331281308, 0.19586192453391038, 0.22917661128094333, 0.24963143467045815, 0.2567417315441088, 0.2506818889186662, 0.23226729318028777, 0.20290271423033404, 0.16450028494360933, 0.11937185506223688, 0.07010183827093616, 0.019407660252202565, -0.030004497243790427, -0.07558080422426758, -0.11505016730310495, -0.14653700801271363], [-0.16278435980926842, -0.13736985507049018, -0.10281030706494565, -0.060690608986011814, -0.013073952151520388, 0.03759772656874239, 0.08862652853638416, 0.13719827990417027, 0.18053174205108255, 0.21602931256266372, 0.24142096714711753, 0.254893432701845, 0.25519727019112654, 0.24172565029557566, 0.21456006847846779, 0.17447999195279823, 0.12293536517635703, 0.06198291759831892, -0.005810793613848673, -0.07749482277960204, -0.14988136590815446, -0.21970771693043264, -0.2838041182964338, -0.3392585664190622, -0.3835697098652554, -0.4147795406040892, -0.43157859884674826, -0.4333778373354074, -0.4203430458705095, -0.39338972722403176, -0.3541384336243295, -0.30483270332925, -0.24822376277499153, -0.187427969950852, -0.1257644689695074, -0.06658162124929747, -0.0130814139378774, 0.03184881503912622, 0.0657883626364726, 0.08691073780520595, 0.0940800053732448, 0.08691073780520595, 0.0657883626364726, 0.03184881503912622, -0.0130814139378774, -0.06658162124929747, -0.1257644689695074, -0.187427969950852, -0.24822376277499153, -0.30483270332925, -0.3541384336243295, -0.39338972722403176, -0.4203430458705095, -0.4333778373354074, -0.43157859884674826, -0.4147795406040892, -0.3835697098652554, -0.3392585664190622, -0.2838041182964338, -0.21970771693043264, -0.14988136590815446, -0.07749482277960204, -0.005810793613848673, 0.06198291759831892, 0.12293536517635703, 0.17447999195279823, 0.21456006847846779, 0.24172565029557566, 0.25519727019112654, 0.254893432701845, 0.24142096714711753, 0.21602931256266372, 0.18053174205108255, 0.13719827990417027, 0.08862652853638416, 0.03759772656874239, -0.013073952151520388, -0.060690608986011814, -0.10281030706494565, -0.13736985507049018], [-0.15646143337355978, -0.12803192632998142, -0.0907256642328181, -0.046310064114579955, 0.0029779491154211806, 0.054541276561040686, 0.10555493165712146, 0.15311446345017118, 0.1943926655354523, 0.22679610352037188, 0.24811283911536614, 0.2566430509401283, 0.25130504004127213, 0.2317103248693539, 0.1982031145119569, 0.15186131748507978, 0.09445829662141196, 0.02838670735216783, -0.043452159632214875, -0.1177881852505473, -0.19114437378651342, -0.26001264723920775, -0.3210343185560354, -0.37117570680030565, -0.407889497747319, -0.42925310491460716, -0.434076417833265, -0.42197287899622543, -0.39338972722403176, -0.3495953826561967, -0.2926242127644853, -0.22518118755916025, -0.15051108239111077, -0.0722388011028484, 0.005811034304373925, 0.07980593576993696, 0.14609889758077332, 0.20141317105264114, 0.24300880867803662, 0.2688222513075441, 0.277571630583514, 0.2688222513075441, 0.24300880867803662, 0.20141317105264114, 0.14609889758077332, 0.07980593576993696, 0.005811034304373925, -0.0722388011028484, -0.15051108239111077, -0.22518118755916025, -0.2926242127644853, -0.3495953826561967, -0.39338972722403176, -0.42197287899622543, -0.434076417833265, -0.42925310491460716, -0.407889497747319, -0.37117570680030565, -0.3210343185560354, -0.26001264723920775, -0.19114437378651342, -0.1177881852505473, -0.043452159632214875, 0.02838670735216783, 0.09445829662141196, 0.15186131748507978, 0.1982031145119569, 0.2317103248693539, 0.25130504004127213, 0.2566430509401283, 0.24811283911536614, 0.22679610352037188, 0.1943926655354523, 0.15311446345017118, 0.10555493165712146, 0.054541276561040686, 0.0029779491154211806, -0.046310064114579955, -0.0907256642328181, -0.12803192632998142], [-0.1499137997580331, -0.11876378051842666, -0.07903277128303789, -0.032657564269347995, 0.017966041941118966, 0.07010183827093616, 0.12081441070397907, 0.16712567793535366, 0.2061784643801796, 0.23539823538075702, 0.25264402764959015, 0.2563400102730029, 0.2455799958764798, 0.22019854657881394, 0.18080401871815463, 0.12877087581897034, 0.0661907655654817, -0.004215913110515241, -0.0792240541655952, -0.15525760655490364, -0.22856545626592412, -0.29541051237375787, -0.35226222727992795, -0.39598244357893553, -0.42399466300627076, -0.43442757176285574, -0.42622489689420734, -0.39921534828629784, -0.3541384336243295, -0.2926242127644853, -0.21712746254366178, -0.13081912452072303, -0.03744017720227128, 0.05887491198907235, 0.1537963512162099, 0.24300880867803662, 0.32242214992953067, 0.38837235101706136, 0.43780226922078175, 0.4684129583840573, 0.47877771528316515, 0.4684129583840573, 0.43780226922078175, 0.38837235101706136, 0.32242214992953067, 0.24300880867803662, 0.1537963512162099, 0.05887491198907235, -0.03744017720227128, -0.13081912452072303, -0.21712746254366178, -0.2926242127644853, -0.3541384336243295, -0.39921534828629784, -0.42622489689420734, -0.43442757176285574, -0.42399466300627076, -0.39598244357893553, -0.35226222727992795, -0.29541051237375787, -0.22856545626592412, -0.15525760655490364, -0.0792240541655952, -0.004215913110515241, 0.0661907655654817, 0.12877087581897034, 0.18080401871815463, 0.22019854657881394, 0.2455799958764798, 0.2563400102730029, 0.25264402764959015, 0.23539823538075702, 0.2061784643801796, 0.16712567793535366, 0.12081441070397907, 0.07010183827093616, 0.017966041941118966, -0.032657564269347995, -0.07903277128303789, -0.11876378051842666], [-0.14335579129849668, -0.10978201113265723, -0.06793803188546253, -0.019915691575644292, 0.031745840459068614, 0.08418731130237875, 0.13437885433763305, 0.1792839709402817, 0.21602931256266372, 0.2420710146043941, 0.255348298963932, 0.25441554164532254, 0.23854497801642713, 0.20779364608280457, 0.1630299764243758, 0.10591753298818528, 0.03885568116655977, -0.03512071345143313, -0.11247819731414006, -0.18935183535374994, -0.2617343483375656, -0.32567778292945404, -0.37749737145928347, -0.41396693622794944, -0.43249545715781157, -0.4312752446188071, -0.4093935036702951, -0.36690087535799776, -0.30483270332925, -0.22518118755916025, -0.13081912452072303, -0.025378460035175753, 0.08691073780520595, 0.20141317105264114, 0.3133036361206578, 0.4177941096414197, 0.5103612401471838, 0.5869627944413911, 0.6442321103834694, 0.6796406846183429, 0.69162061945593, 0.6796406846183429, 0.6442321103834694, 0.5869627944413911, 0.5103612401471838, 0.4177941096414197, 0.3133036361206578, 0.20141317105264114, 0.08691073780520595, -0.025378460035175753, -0.13081912452072303, -0.22518118755916025, -0.30483270332925, -0.36690087535799776, -0.4093935036702951, -0.4312752446188071, -0.43249545715781157, -0.41396693622794944, -0.37749737145928347, -0.32567778292945404, -0.2617343483375656, -0.18935183535374994, -0.11247819731414006, -0.03512071345143313, 0.03885568116655977, 0.10591753298818528, 0.1630299764243758, 0.20779364608280457, 0.23854497801642713, 0.25441554164532254, 0.255348298963932, 0.2420710146043941, 0.21602931256266372, 0.1792839709402817, 0.13437885433763305, 0.08418731130237875, 0.031745840459068614, -0.019915691575644292, -0.06793803188546253, -0.10978201113265723], [-0.13698176393514344, -0.10127808535368477, -0.05761803324395176, -0.00823327044894154, 0.044209509361482956, 0.09674378883254962, 0.14626024334832619, 0.18967745729212915, 0.22411724822563847, 0.24707500803079696, 0.256575492104657, 0.25130504004127213, 0.23071227369415245, 0.19507084218595108, 0.14549969299473817, 0.08393854575868848, 0.013078615468659323, -0.06374895250625122, -0.1427221428215067, -0.21970771693043264, -0.29046275344788247, -0.35084804028714445, -0.3970424421347404, -0.42574709936268906, -0.43436863670247905, -0.421171462695804, -0.3853906832849483, -0.32729906443176787, -0.24822376277499153, -0.15051108239111077, -0.03744017720227128, 0.08691073780520595, 0.21783961811686398, 0.35022902170777614, 0.47877771528316515, 0.5982441516081277, 0.7036898157513979, 0.7907103570985019, 0.8556429685382863, 0.8957396184216221, 0.9092974268256817, 0.8957396184216221, 0.8556429685382863, 0.7907103570985019, 0.7036898157513979, 0.5982441516081277, 0.47877771528316515, 0.35022902170777614, 0.21783961811686398, 0.08691073780520595, -0.03744017720227128, -0.15051108239111077, -0.24822376277499153, -0.32729906443176787, -0.3853906832849483, -0.421171462695804, -0.43436863670247905, -0.42574709936268906, -0.3970424421347404, -0.35084804028714445, -0.29046275344788247, -0.21970771693043264, -0.1427221428215067, -0.06374895250625122, 0.013078615468659323, 0.08393854575868848, 0.14549969299473817, 0.19507084218595108, 0.23071227369415245, 0.25130504004127213, 0.256575492104657, 0.24707500803079696, 0.22411724822563847, 0.18967745729212915, 0.14626024334832619, 0.09674378883254962, 0.044209509361482956, -0.00823327044894154, -0.05761803324395176, -0.10127808535368477], [-0.13096468174943518, -0.09341816596346665, -0.04822085787410071, 0.0022716100207446164, 0.05528095770522729, 0.10774865812501504, 0.15649972810645998, 0.19841943861188654, 0.23063350923189954, 0.2506818889186662, 0.2566762997375786, 0.24743234013685533, 0.2225680860000738, 0.18256273925541686, 0.12877087581897034, 0.06339013493636744, -0.010617349295218181, -0.08964697741323371, -0.1696119802323752, -0.24613461781837798, -0.31475910259630246, -0.37117570680030565, -0.41144469052055266, -0.43220845214435083, -0.4308806796227811, -0.40580225753498556, -0.35635521764627226, -0.28302803533990717, -0.187427969950852, -0.0722388011028484, 0.05887491198907235, 0.20141317105264114, 0.35022902170777614, 0.49975144871271493, 0.6442321103834694, 0.7780040258931075, 0.8957396184216221, 0.992695449836068, 1.0649315658049785, 1.1094945766040856, 1.124555367855928, 1.1094945766040856, 1.0649315658049785, 0.992695449836068, 0.8957396184216221, 0.7780040258931075, 0.6442321103834694, 0.49975144871271493, 0.35022902170777614, 0.20141317105264114, 0.05887491198907235, -0.0722388011028484, -0.187427969950852, -0.28302803533990717, -0.35635521764627226, -0.40580225753498556, -0.4308806796227811, -0.43220845214435083, -0.41144469052055266, -0.37117570680030565, -0.31475910259630246, -0.24613461781837798, -0.1696119802323752, -0.08964697741323371, -0.010617349295218181, 0.06339013493636744, 0.12877087581897034, 0.18256273925541686, 0.2225680860000738, 0.24743234013685533, 0.2566762997375786, 0.2506818889186662, 0.23063350923189954, 0.19841943861188654, 0.15649972810645998, 0.10774865812501504, 0.05528095770522729, 0.0022716100207446164, -0.04822085787410071, -0.09341816596346665], [-0.1254554756233313, -0.08634370978474622, -0.039868134180728126, 0.011507919583092052, 0.0649104168254659, 0.11720338291232232, 0.16515865057394133, 0.20563779959612533, 0.23577655069724138, 0.2531614457800734, 0.2559887694405144, 0.2431963471432226, 0.21456006847846779, 0.17074867404778504, 0.11333242903336226, 0.044743679368913644, -0.03181017613329085, -0.11247819731414006, -0.1929363397545002, -0.268589046149572, -0.33479237619194996, -0.38708768931988075, -0.42143408131469146, -0.43442757176285574, -0.42349546556438716, -0.38705535500366767, -0.324629843053556, -0.23691017597600564, -0.1257644689695074, 0.005811034304373925, 0.1537963512162099, 0.3133036361206578, 0.47877771528316515, 0.6442321103834694, 0.803509484779075, 0.9505541014891831, 1.0796831610910465, 1.1858438330909473, 1.2648434125627805, 1.3135412961886945, 1.3299933154720727, 1.3135412961886945, 1.2648434125627805, 1.1858438330909473, 1.0796831610910465, 0.9505541014891831, 0.803509484779075, 0.6442321103834694, 0.47877771528316515, 0.3133036361206578, 0.1537963512162099, 0.005811034304373925, -0.1257644689695074, -0.23691017597600564, -0.324629843053556, -0.38705535500366767, -0.42349546556438716, -0.43442757176285574, -0.42143408131469146, -0.38708768931988075, -0.33479237619194996, -0.268589046149572, -0.1929363397545002, -0.11247819731414006, -0.03181017613329085, 0.044743679368913644, 0.11333242903336226, 0.17074867404778504, 0.21456006847846779, 0.2431963471432226, 0.2559887694405144, 0.2531614457800734, 0.23577655069724138, 0.20563779959612533, 0.16515865057394133, 0.11720338291232232, 0.0649104168254659, 0.011507919583092052, -0.039868134180728126, -0.08634370978474622], [-0.12058300781296416, -0.08017262722723162, -0.032657564269347995, 0.019407660252202565, 0.07306884206017318, 0.12512633286074154, 0.17230988766358785, 0.21146505144444128, 0.23974108638511749, 0.25477004091850136, 0.2548267267047997, 0.23896010343988033, 0.2070878465419809, 0.16004763127913005, 0.09960082298540655, 0.02838670735216783, -0.050171999808914604, -0.132008995765264, -0.2125937105436689, -0.28714197491104243, -0.35084804028714445, -0.3991265770886398, -0.42785247459104203, -0.4335860886421158, -0.4137720534188708, -0.36690087535799776, -0.2926242127644853, -0.19181693290541052, -0.06658162124929747, 0.07980593576993696, 0.24300880867803662, 0.4177941096414197, 0.5982441516081277, 0.7780040258931075, 0.9505541014891831, 1.1094945766040856, 1.2488284837498442, 1.3632295064019535, 1.4482816142111579, 1.500678835049543, 1.518375390968938, 1.500678835049543, 1.4482816142111579, 1.3632295064019535, 1.2488284837498442, 1.1094945766040856, 0.9505541014891831, 0.7780040258931075, 0.5982441516081277, 0.4177941096414197, 0.24300880867803662, 0.07980593576993696, -0.06658162124929747, -0.19181693290541052, -0.2926242127644853, -0.36690087535799776, -0.4137720534188708, -0.4335860886421158, -0.42785247459104203, -0.3991265770886398, -0.35084804028714445, -0.28714197491104243, -0.2125937105436689, -0.132008995765264, -0.050171999808914604, 0.02838670735216783, 0.09960082298540655, 0.16004763127913005, 0.2070878465419809, 0.23896010343988033, 0.2548267267047997, 0.25477004091850136, 0.23974108638511749, 0.21146505144444128, 0.17230988766358785, 0.12512633286074154, 0.07306884206017318, 0.019407660252202565, -0.032657564269347995, -0.08017262722723162], [-0.1164544699167505, -0.0750007897964791, -0.026665677985416577, 0.025921773001301992, 0.07974244535617742, 0.13154597877649798, 0.17802983029511174, 0.21602931256266372, 0.242708395806646, 0.2557406839380664, 0.25347017586536014, 0.23504220166614895, 0.20049625055173417, 0.15081422331281308, 0.08791985781076668, 0.014627580006334946, -0.06545830501430487, -0.14809048863531396, -0.22856545626592412, -0.30194177876754097, -0.3632795822101567, -0.407889497747319, -0.43157859884674826, -0.4308806796227811, -0.40325873487122593, -0.3472686537517362, -0.2626748843273063, -0.15051108239111077, -0.0130814139378774, 0.14609889758077332, 0.32242214992953067, 0.5103612401471838, 0.7036898157513979, 0.8957396184216221, 1.0796831610910465, 1.2488284837498442, 1.3969119972732167, 1.518375390968938, 1.608613254431116, 1.6641794167481594, 1.682941969615793, 1.6641794167481594, 1.608613254431116, 1.518375390968938, 1.3969119972732167, 1.2488284837498442, 1.0796831610910465, 0.8957396184216221, 0.7036898157513979, 0.5103612401471838, 0.32242214992953067, 0.14609889758077332, -0.0130814139378774, -0.15051108239111077, -0.2626748843273063, -0.3472686537517362, -0.40325873487122593, -0.4308806796227811, -0.43157859884674826, -0.407889497747319, -0.3632795822101567, -0.30194177876754097, -0.22856545626592412, -0.14809048863531396, -0.06545830501430487, 0.014627580006334946, 0.08791985781076668, 0.15081422331281308, 0.20049625055173417, 0.23504220166614895, 0.25347017586536014, 0.2557406839380664, 0.242708395806646, 0.21602931256266372, 0.17802983029511174, 0.13154597877649798, 0.07974244535617742, 0.025921773001301992, -0.026665677985416577, -0.0750007897964791], [-0.1131560467581887, -0.07090368426500879, -0.021950582012676394, 0.031016232090896562, 0.08492762656935865, 0.13649472168344115, 0.18239124981424537, 0.21944644111666822, 0.24483804991090946, 0.2562747828163765, 0.252157618714697, 0.2317103248693539, 0.19507084218595108, 0.1433370736825879, 0.07856287339249271, 0.0037025838949493145, -0.07749482277960204, -0.16063822727306362, -0.24088710992360066, -0.31317589634427284, -0.37245933283868765, -0.41396693622794944, -0.4334537754581445, -0.4274347075936389, -0.39338972722403176, -0.32992927901128904, -0.23691017597600564, -0.11549507625799743, 0.03184881503912622, 0.20141317105264114, 0.38837235101706136, 0.5869627944413911, 0.7907103570985019, 0.992695449836068, 1.1858438330909473, 1.3632295064019535, 1.518375390968938, 1.6455374774968983, 1.7399588071171015, 1.7980810383563555, 1.8177033600622243, 1.7980810383563555, 1.7399588071171015, 1.6455374774968983, 1.518375390968938, 1.3632295064019535, 1.1858438330909473, 0.992695449836068, 0.7907103570985019, 0.5869627944413911, 0.38837235101706136, 0.20141317105264114, 0.03184881503912622, -0.11549507625799743, -0.23691017597600564, -0.32992927901128904, -0.39338972722403176, -0.4274347075936389, -0.4334537754581445, -0.41396693622794944, -0.37245933283868765, -0.31317589634427284, -0.24088710992360066, -0.16063822727306362, -0.07749482277960204, 0.0037025838949493145, 0.07856287339249271, 0.1433370736825879, 0.19507084218595108, 0.2317103248693539, 0.252157618714697, 0.2562747828163765, 0.24483804991090946, 0.21944644111666822, 0.18239124981424537, 0.13649472168344115, 0.08492762656935865, 0.031016232090896562, -0.021950582012676394, -0.07090368426500879], [-0.1107536917561867, -0.06793803188546253, -0.01855449981019833, 0.03466854669458865, 0.08862652853638416, 0.14000357308347133, 0.18545724476618586, 0.22181346801290225, 0.24626113579560338, 0.25653555744366946, 0.25108014921898075, 0.22917661128094333, 0.19103523332295086, 0.13783886506830845, 0.07173638515428266, -0.004215913110515241, -0.08616386191642225, -0.1696119802323752, -0.24962054293732017, -0.3210343185560354, -0.3787322233669178, -0.417885750201407, -0.434213248547002, -0.42421701152445723, -0.3853906832849483, -0.3163857196862348, -0.21712746254366178, -0.08887373699192957, 0.0657883626364726, 0.24300880867803662, 0.43780226922078175, 0.6442321103834694, 0.8556429685382863, 1.0649315658049785, 1.2648434125627805, 1.4482816142111579, 1.608613254431116, 1.7399588071171015, 1.8374507397311368, 1.8974488797623419, 1.917702154416812, 1.8974488797623419, 1.8374507397311368, 1.7399588071171015, 1.608613254431116, 1.4482816142111579, 1.2648434125627805, 1.0649315658049785, 0.8556429685382863, 0.6442321103834694, 0.43780226922078175, 0.24300880867803662, 0.0657883626364726, -0.08887373699192957, -0.21712746254366178, -0.3163857196862348, -0.3853906832849483, -0.42421701152445723, -0.434213248547002, -0.417885750201407, -0.3787322233669178, -0.3210343185560354, -0.24962054293732017, -0.1696119802323752, -0.08616386191642225, -0.004215913110515241, 0.07173638515428266, 0.13783886506830845, 0.19103523332295086, 0.22917661128094333, 0.25108014921898075, 0.25653555744366946, 0.24626113579560338, 0.22181346801290225, 0.18545724476618586, 0.14000357308347133, 0.08862652853638416, 0.03466854669458865, -0.01855449981019833, -0.06793803188546253], [-0.10929387900894774, -0.06614321685638791, -0.016505930263581485, 0.03686485131708162, 0.09084339726921295, 0.14209785531573388, 0.18727640924644018, 0.2232034254780841, 0.24707500803079696, 0.2566430509401283, 0.25037713957121355, 0.22759450814784551, 0.18854967763954522, 0.134477311926808, 0.06758414818694233, -0.009011537058698997, -0.09139170665445415, -0.17499760171649797, -0.254829433326894, -0.32567778292945404, -0.382375848005458, -0.4200602785751461, -0.43442757176285574, -0.42197287899622543, -0.3801986514917913, -0.3077817863653888, -0.20468978410715197, -0.0722388011028484, 0.08691073780520595, 0.2688222513075441, 0.4684129583840573, 0.6796406846183429, 0.8957396184216221, 1.1094945766040856, 1.3135412961886945, 1.500678835049543, 1.6641794167481594, 1.7980810383563555, 1.8974488797623419, 1.9585929762944412, 1.9792316740361835, 1.9585929762944412, 1.8974488797623419, 1.7980810383563555, 1.6641794167481594, 1.500678835049543, 1.3135412961886945, 1.1094945766040856, 0.8957396184216221, 0.6796406846183429, 0.4684129583840573, 0.2688222513075441, 0.08691073780520595, -0.0722388011028484, -0.20468978410715197, -0.3077817863653888, -0.3801986514917913, -0.42197287899622543, -0.43442757176285574, -0.4200602785751461, -0.382375848005458, -0.32567778292945404, -0.254829433326894, -0.17499760171649797, -0.09139170665445415, -0.009011537058698997, 0.06758414818694233, 0.134477311926808, 0.18854967763954522, 0.22759450814784551, 0.25037713957121355, 0.2566430509401283, 0.24707500803079696, 0.2232034254780841, 0.18727640924644018, 0.14209785531573388, 0.09084339726921295, 0.03686485131708162, -0.016505930263581485, -0.06614321685638791], [-0.10880422217787396, -0.06554239869174844, -0.015821288518275644, 0.03759772656874239, 0.09158188560927924, 0.14279404657238684, 0.18787932061729182, 0.22366162672468853, 0.24733956165584545, 0.2566706526738519, 0.25013332713993036, 0.2270567942100705, 0.18771045677679687, 0.1333463922312941, 0.0661907655654817, -0.010617349295218181, -0.09313849939964196, -0.17679272260843765, -0.2565601183892334, -0.32721314035298743, -0.3835697098652554, -0.4207548585159486, -0.43445783007337646, -0.421171462695804, -0.3784012476539641, -0.30483270332925, -0.20044755867978276, -0.06658162124929747, 0.0940800053732448, 0.277571630583514, 0.47877771528316515, 0.69162061945593, 0.9092974268256817, 1.124555367855928, 1.3299933154720727, 1.518375390968938, 1.682941969615793, 1.8177033600622243, 1.917702154416812, 1.9792316740361835, null, 1.9792316740361835, 1.917702154416812, 1.8177033600622243, 1.682941969615793, 1.518375390968938, 1.3299933154720727, 1.124555367855928, 0.9092974268256817, 0.69162061945593, 0.47877771528316515, 0.277571630583514, 0.0940800053732448, -0.06658162124929747, -0.20044755867978276, -0.30483270332925, -0.3784012476539641, -0.421171462695804, -0.43445783007337646, -0.4207548585159486, -0.3835697098652554, -0.32721314035298743, -0.2565601183892334, -0.17679272260843765, -0.09313849939964196, -0.010617349295218181, 0.0661907655654817, 0.1333463922312941, 0.18771045677679687, 0.2270567942100705, 0.25013332713993036, 0.2566706526738519, 0.24733956165584545, 0.22366162672468853, 0.18787932061729182, 0.14279404657238684, 0.09158188560927924, 0.03759772656874239, -0.015821288518275644, -0.06554239869174844], [-0.10929387900894774, -0.06614321685638791, -0.016505930263581485, 0.03686485131708162, 0.09084339726921295, 0.14209785531573388, 0.18727640924644018, 0.2232034254780841, 0.24707500803079696, 0.2566430509401283, 0.25037713957121355, 0.22759450814784551, 0.18854967763954522, 0.134477311926808, 0.06758414818694233, -0.009011537058698997, -0.09139170665445415, -0.17499760171649797, -0.254829433326894, -0.32567778292945404, -0.382375848005458, -0.4200602785751461, -0.43442757176285574, -0.42197287899622543, -0.3801986514917913, -0.3077817863653888, -0.20468978410715197, -0.0722388011028484, 0.08691073780520595, 0.2688222513075441, 0.4684129583840573, 0.6796406846183429, 0.8957396184216221, 1.1094945766040856, 1.3135412961886945, 1.500678835049543, 1.6641794167481594, 1.7980810383563555, 1.8974488797623419, 1.9585929762944412, 1.9792316740361835, 1.9585929762944412, 1.8974488797623419, 1.7980810383563555, 1.6641794167481594, 1.500678835049543, 1.3135412961886945, 1.1094945766040856, 0.8957396184216221, 0.6796406846183429, 0.4684129583840573, 0.2688222513075441, 0.08691073780520595, -0.0722388011028484, -0.20468978410715197, -0.3077817863653888, -0.3801986514917913, -0.42197287899622543, -0.43442757176285574, -0.4200602785751461, -0.382375848005458, -0.32567778292945404, -0.254829433326894, -0.17499760171649797, -0.09139170665445415, -0.009011537058698997, 0.06758414818694233, 0.134477311926808, 0.18854967763954522, 0.22759450814784551, 0.25037713957121355, 0.2566430509401283, 0.24707500803079696, 0.2232034254780841, 0.18727640924644018, 0.14209785531573388, 0.09084339726921295, 0.03686485131708162, -0.016505930263581485, -0.06614321685638791], [-0.1107536917561867, -0.06793803188546253, -0.01855449981019833, 0.03466854669458865, 0.08862652853638416, 0.14000357308347133, 0.18545724476618586, 0.22181346801290225, 0.24626113579560338, 0.25653555744366946, 0.25108014921898075, 0.22917661128094333, 0.19103523332295086, 0.13783886506830845, 0.07173638515428266, -0.004215913110515241, -0.08616386191642225, -0.1696119802323752, -0.24962054293732017, -0.3210343185560354, -0.3787322233669178, -0.417885750201407, -0.434213248547002, -0.42421701152445723, -0.3853906832849483, -0.3163857196862348, -0.21712746254366178, -0.08887373699192957, 0.0657883626364726, 0.24300880867803662, 0.43780226922078175, 0.6442321103834694, 0.8556429685382863, 1.0649315658049785, 1.2648434125627805, 1.4482816142111579, 1.608613254431116, 1.7399588071171015, 1.8374507397311368, 1.8974488797623419, 1.917702154416812, 1.8974488797623419, 1.8374507397311368, 1.7399588071171015, 1.608613254431116, 1.4482816142111579, 1.2648434125627805, 1.0649315658049785, 0.8556429685382863, 0.6442321103834694, 0.43780226922078175, 0.24300880867803662, 0.0657883626364726, -0.08887373699192957, -0.21712746254366178, -0.3163857196862348, -0.3853906832849483, -0.42421701152445723, -0.434213248547002, -0.417885750201407, -0.3787322233669178, -0.3210343185560354, -0.24962054293732017, -0.1696119802323752, -0.08616386191642225, -0.004215913110515241, 0.07173638515428266, 0.13783886506830845, 0.19103523332295086, 0.22917661128094333, 0.25108014921898075, 0.25653555744366946, 0.24626113579560338, 0.22181346801290225, 0.18545724476618586, 0.14000357308347133, 0.08862652853638416, 0.03466854669458865, -0.01855449981019833, -0.06793803188546253], [-0.1131560467581887, -0.07090368426500879, -0.021950582012676394, 0.031016232090896562, 0.08492762656935865, 0.13649472168344115, 0.18239124981424537, 0.21944644111666822, 0.24483804991090946, 0.2562747828163765, 0.252157618714697, 0.2317103248693539, 0.19507084218595108, 0.1433370736825879, 0.07856287339249271, 0.0037025838949493145, -0.07749482277960204, -0.16063822727306362, -0.24088710992360066, -0.31317589634427284, -0.37245933283868765, -0.41396693622794944, -0.4334537754581445, -0.4274347075936389, -0.39338972722403176, -0.32992927901128904, -0.23691017597600564, -0.11549507625799743, 0.03184881503912622, 0.20141317105264114, 0.38837235101706136, 0.5869627944413911, 0.7907103570985019, 0.992695449836068, 1.1858438330909473, 1.3632295064019535, 1.518375390968938, 1.6455374774968983, 1.7399588071171015, 1.7980810383563555, 1.8177033600622243, 1.7980810383563555, 1.7399588071171015, 1.6455374774968983, 1.518375390968938, 1.3632295064019535, 1.1858438330909473, 0.992695449836068, 0.7907103570985019, 0.5869627944413911, 0.38837235101706136, 0.20141317105264114, 0.03184881503912622, -0.11549507625799743, -0.23691017597600564, -0.32992927901128904, -0.39338972722403176, -0.4274347075936389, -0.4334537754581445, -0.41396693622794944, -0.37245933283868765, -0.31317589634427284, -0.24088710992360066, -0.16063822727306362, -0.07749482277960204, 0.0037025838949493145, 0.07856287339249271, 0.1433370736825879, 0.19507084218595108, 0.2317103248693539, 0.252157618714697, 0.2562747828163765, 0.24483804991090946, 0.21944644111666822, 0.18239124981424537, 0.13649472168344115, 0.08492762656935865, 0.031016232090896562, -0.021950582012676394, -0.07090368426500879], [-0.1164544699167505, -0.0750007897964791, -0.026665677985416577, 0.025921773001301992, 0.07974244535617742, 0.13154597877649798, 0.17802983029511174, 0.21602931256266372, 0.242708395806646, 0.2557406839380664, 0.25347017586536014, 0.23504220166614895, 0.20049625055173417, 0.15081422331281308, 0.08791985781076668, 0.014627580006334946, -0.06545830501430487, -0.14809048863531396, -0.22856545626592412, -0.30194177876754097, -0.3632795822101567, -0.407889497747319, -0.43157859884674826, -0.4308806796227811, -0.40325873487122593, -0.3472686537517362, -0.2626748843273063, -0.15051108239111077, -0.0130814139378774, 0.14609889758077332, 0.32242214992953067, 0.5103612401471838, 0.7036898157513979, 0.8957396184216221, 1.0796831610910465, 1.2488284837498442, 1.3969119972732167, 1.518375390968938, 1.608613254431116, 1.6641794167481594, 1.682941969615793, 1.6641794167481594, 1.608613254431116, 1.518375390968938, 1.3969119972732167, 1.2488284837498442, 1.0796831610910465, 0.8957396184216221, 0.7036898157513979, 0.5103612401471838, 0.32242214992953067, 0.14609889758077332, -0.0130814139378774, -0.15051108239111077, -0.2626748843273063, -0.3472686537517362, -0.40325873487122593, -0.4308806796227811, -0.43157859884674826, -0.407889497747319, -0.3632795822101567, -0.30194177876754097, -0.22856545626592412, -0.14809048863531396, -0.06545830501430487, 0.014627580006334946, 0.08791985781076668, 0.15081422331281308, 0.20049625055173417, 0.23504220166614895, 0.25347017586536014, 0.2557406839380664, 0.242708395806646, 0.21602931256266372, 0.17802983029511174, 0.13154597877649798, 0.07974244535617742, 0.025921773001301992, -0.026665677985416577, -0.0750007897964791], [-0.12058300781296416, -0.08017262722723162, -0.032657564269347995, 0.019407660252202565, 0.07306884206017318, 0.12512633286074154, 0.17230988766358785, 0.21146505144444128, 0.23974108638511749, 0.25477004091850136, 0.2548267267047997, 0.23896010343988033, 0.2070878465419809, 0.16004763127913005, 0.09960082298540655, 0.02838670735216783, -0.050171999808914604, -0.132008995765264, -0.2125937105436689, -0.28714197491104243, -0.35084804028714445, -0.3991265770886398, -0.42785247459104203, -0.4335860886421158, -0.4137720534188708, -0.36690087535799776, -0.2926242127644853, -0.19181693290541052, -0.06658162124929747, 0.07980593576993696, 0.24300880867803662, 0.4177941096414197, 0.5982441516081277, 0.7780040258931075, 0.9505541014891831, 1.1094945766040856, 1.2488284837498442, 1.3632295064019535, 1.4482816142111579, 1.500678835049543, 1.518375390968938, 1.500678835049543, 1.4482816142111579, 1.3632295064019535, 1.2488284837498442, 1.1094945766040856, 0.9505541014891831, 0.7780040258931075, 0.5982441516081277, 0.4177941096414197, 0.24300880867803662, 0.07980593576993696, -0.06658162124929747, -0.19181693290541052, -0.2926242127644853, -0.36690087535799776, -0.4137720534188708, -0.4335860886421158, -0.42785247459104203, -0.3991265770886398, -0.35084804028714445, -0.28714197491104243, -0.2125937105436689, -0.132008995765264, -0.050171999808914604, 0.02838670735216783, 0.09960082298540655, 0.16004763127913005, 0.2070878465419809, 0.23896010343988033, 0.2548267267047997, 0.25477004091850136, 0.23974108638511749, 0.21146505144444128, 0.17230988766358785, 0.12512633286074154, 0.07306884206017318, 0.019407660252202565, -0.032657564269347995, -0.08017262722723162], [-0.1254554756233313, -0.08634370978474622, -0.039868134180728126, 0.011507919583092052, 0.0649104168254659, 0.11720338291232232, 0.16515865057394133, 0.20563779959612533, 0.23577655069724138, 0.2531614457800734, 0.2559887694405144, 0.2431963471432226, 0.21456006847846779, 0.17074867404778504, 0.11333242903336226, 0.044743679368913644, -0.03181017613329085, -0.11247819731414006, -0.1929363397545002, -0.268589046149572, -0.33479237619194996, -0.38708768931988075, -0.42143408131469146, -0.43442757176285574, -0.42349546556438716, -0.38705535500366767, -0.324629843053556, -0.23691017597600564, -0.1257644689695074, 0.005811034304373925, 0.1537963512162099, 0.3133036361206578, 0.47877771528316515, 0.6442321103834694, 0.803509484779075, 0.9505541014891831, 1.0796831610910465, 1.1858438330909473, 1.2648434125627805, 1.3135412961886945, 1.3299933154720727, 1.3135412961886945, 1.2648434125627805, 1.1858438330909473, 1.0796831610910465, 0.9505541014891831, 0.803509484779075, 0.6442321103834694, 0.47877771528316515, 0.3133036361206578, 0.1537963512162099, 0.005811034304373925, -0.1257644689695074, -0.23691017597600564, -0.324629843053556, -0.38705535500366767, -0.42349546556438716, -0.43442757176285574, -0.42143408131469146, -0.38708768931988075, -0.33479237619194996, -0.268589046149572, -0.1929363397545002, -0.11247819731414006, -0.03181017613329085, 0.044743679368913644, 0.11333242903336226, 0.17074867404778504, 0.21456006847846779, 0.2431963471432226, 0.2559887694405144, 0.2531614457800734, 0.23577655069724138, 0.20563779959612533, 0.16515865057394133, 0.11720338291232232, 0.0649104168254659, 0.011507919583092052, -0.039868134180728126, -0.08634370978474622], [-0.13096468174943518, -0.09341816596346665, -0.04822085787410071, 0.0022716100207446164, 0.05528095770522729, 0.10774865812501504, 0.15649972810645998, 0.19841943861188654, 0.23063350923189954, 0.2506818889186662, 0.2566762997375786, 0.24743234013685533, 0.2225680860000738, 0.18256273925541686, 0.12877087581897034, 0.06339013493636744, -0.010617349295218181, -0.08964697741323371, -0.1696119802323752, -0.24613461781837798, -0.31475910259630246, -0.37117570680030565, -0.41144469052055266, -0.43220845214435083, -0.4308806796227811, -0.40580225753498556, -0.35635521764627226, -0.28302803533990717, -0.187427969950852, -0.0722388011028484, 0.05887491198907235, 0.20141317105264114, 0.35022902170777614, 0.49975144871271493, 0.6442321103834694, 0.7780040258931075, 0.8957396184216221, 0.992695449836068, 1.0649315658049785, 1.1094945766040856, 1.124555367855928, 1.1094945766040856, 1.0649315658049785, 0.992695449836068, 0.8957396184216221, 0.7780040258931075, 0.6442321103834694, 0.49975144871271493, 0.35022902170777614, 0.20141317105264114, 0.05887491198907235, -0.0722388011028484, -0.187427969950852, -0.28302803533990717, -0.35635521764627226, -0.40580225753498556, -0.4308806796227811, -0.43220845214435083, -0.41144469052055266, -0.37117570680030565, -0.31475910259630246, -0.24613461781837798, -0.1696119802323752, -0.08964697741323371, -0.010617349295218181, 0.06339013493636744, 0.12877087581897034, 0.18256273925541686, 0.2225680860000738, 0.24743234013685533, 0.2566762997375786, 0.2506818889186662, 0.23063350923189954, 0.19841943861188654, 0.15649972810645998, 0.10774865812501504, 0.05528095770522729, 0.0022716100207446164, -0.04822085787410071, -0.09341816596346665], [-0.13698176393514344, -0.10127808535368477, -0.05761803324395176, -0.00823327044894154, 0.044209509361482956, 0.09674378883254962, 0.14626024334832619, 0.18967745729212915, 0.22411724822563847, 0.24707500803079696, 0.256575492104657, 0.25130504004127213, 0.23071227369415245, 0.19507084218595108, 0.14549969299473817, 0.08393854575868848, 0.013078615468659323, -0.06374895250625122, -0.1427221428215067, -0.21970771693043264, -0.29046275344788247, -0.35084804028714445, -0.3970424421347404, -0.42574709936268906, -0.43436863670247905, -0.421171462695804, -0.3853906832849483, -0.32729906443176787, -0.24822376277499153, -0.15051108239111077, -0.03744017720227128, 0.08691073780520595, 0.21783961811686398, 0.35022902170777614, 0.47877771528316515, 0.5982441516081277, 0.7036898157513979, 0.7907103570985019, 0.8556429685382863, 0.8957396184216221, 0.9092974268256817, 0.8957396184216221, 0.8556429685382863, 0.7907103570985019, 0.7036898157513979, 0.5982441516081277, 0.47877771528316515, 0.35022902170777614, 0.21783961811686398, 0.08691073780520595, -0.03744017720227128, -0.15051108239111077, -0.24822376277499153, -0.32729906443176787, -0.3853906832849483, -0.421171462695804, -0.43436863670247905, -0.42574709936268906, -0.3970424421347404, -0.35084804028714445, -0.29046275344788247, -0.21970771693043264, -0.1427221428215067, -0.06374895250625122, 0.013078615468659323, 0.08393854575868848, 0.14549969299473817, 0.19507084218595108, 0.23071227369415245, 0.25130504004127213, 0.256575492104657, 0.24707500803079696, 0.22411724822563847, 0.18967745729212915, 0.14626024334832619, 0.09674378883254962, 0.044209509361482956, -0.00823327044894154, -0.05761803324395176, -0.10127808535368477], [-0.14335579129849668, -0.10978201113265723, -0.06793803188546253, -0.019915691575644292, 0.031745840459068614, 0.08418731130237875, 0.13437885433763305, 0.1792839709402817, 0.21602931256266372, 0.2420710146043941, 0.255348298963932, 0.25441554164532254, 0.23854497801642713, 0.20779364608280457, 0.1630299764243758, 0.10591753298818528, 0.03885568116655977, -0.03512071345143313, -0.11247819731414006, -0.18935183535374994, -0.2617343483375656, -0.32567778292945404, -0.37749737145928347, -0.41396693622794944, -0.43249545715781157, -0.4312752446188071, -0.4093935036702951, -0.36690087535799776, -0.30483270332925, -0.22518118755916025, -0.13081912452072303, -0.025378460035175753, 0.08691073780520595, 0.20141317105264114, 0.3133036361206578, 0.4177941096414197, 0.5103612401471838, 0.5869627944413911, 0.6442321103834694, 0.6796406846183429, 0.69162061945593, 0.6796406846183429, 0.6442321103834694, 0.5869627944413911, 0.5103612401471838, 0.4177941096414197, 0.3133036361206578, 0.20141317105264114, 0.08691073780520595, -0.025378460035175753, -0.13081912452072303, -0.22518118755916025, -0.30483270332925, -0.36690087535799776, -0.4093935036702951, -0.4312752446188071, -0.43249545715781157, -0.41396693622794944, -0.37749737145928347, -0.32567778292945404, -0.2617343483375656, -0.18935183535374994, -0.11247819731414006, -0.03512071345143313, 0.03885568116655977, 0.10591753298818528, 0.1630299764243758, 0.20779364608280457, 0.23854497801642713, 0.25441554164532254, 0.255348298963932, 0.2420710146043941, 0.21602931256266372, 0.1792839709402817, 0.13437885433763305, 0.08418731130237875, 0.031745840459068614, -0.019915691575644292, -0.06793803188546253, -0.10978201113265723], [-0.1499137997580331, -0.11876378051842666, -0.07903277128303789, -0.032657564269347995, 0.017966041941118966, 0.07010183827093616, 0.12081441070397907, 0.16712567793535366, 0.2061784643801796, 0.23539823538075702, 0.25264402764959015, 0.2563400102730029, 0.2455799958764798, 0.22019854657881394, 0.18080401871815463, 0.12877087581897034, 0.0661907655654817, -0.004215913110515241, -0.0792240541655952, -0.15525760655490364, -0.22856545626592412, -0.29541051237375787, -0.35226222727992795, -0.39598244357893553, -0.42399466300627076, -0.43442757176285574, -0.42622489689420734, -0.39921534828629784, -0.3541384336243295, -0.2926242127644853, -0.21712746254366178, -0.13081912452072303, -0.03744017720227128, 0.05887491198907235, 0.1537963512162099, 0.24300880867803662, 0.32242214992953067, 0.38837235101706136, 0.43780226922078175, 0.4684129583840573, 0.47877771528316515, 0.4684129583840573, 0.43780226922078175, 0.38837235101706136, 0.32242214992953067, 0.24300880867803662, 0.1537963512162099, 0.05887491198907235, -0.03744017720227128, -0.13081912452072303, -0.21712746254366178, -0.2926242127644853, -0.3541384336243295, -0.39921534828629784, -0.42622489689420734, -0.43442757176285574, -0.42399466300627076, -0.39598244357893553, -0.35226222727992795, -0.29541051237375787, -0.22856545626592412, -0.15525760655490364, -0.0792240541655952, -0.004215913110515241, 0.0661907655654817, 0.12877087581897034, 0.18080401871815463, 0.22019854657881394, 0.2455799958764798, 0.2563400102730029, 0.25264402764959015, 0.23539823538075702, 0.2061784643801796, 0.16712567793535366, 0.12081441070397907, 0.07010183827093616, 0.017966041941118966, -0.032657564269347995, -0.07903277128303789, -0.11876378051842666], [-0.15646143337355978, -0.12803192632998142, -0.0907256642328181, -0.046310064114579955, 0.0029779491154211806, 0.054541276561040686, 0.10555493165712146, 0.15311446345017118, 0.1943926655354523, 0.22679610352037188, 0.24811283911536614, 0.2566430509401283, 0.25130504004127213, 0.2317103248693539, 0.1982031145119569, 0.15186131748507978, 0.09445829662141196, 0.02838670735216783, -0.043452159632214875, -0.1177881852505473, -0.19114437378651342, -0.26001264723920775, -0.3210343185560354, -0.37117570680030565, -0.407889497747319, -0.42925310491460716, -0.434076417833265, -0.42197287899622543, -0.39338972722403176, -0.3495953826561967, -0.2926242127644853, -0.22518118755916025, -0.15051108239111077, -0.0722388011028484, 0.005811034304373925, 0.07980593576993696, 0.14609889758077332, 0.20141317105264114, 0.24300880867803662, 0.2688222513075441, 0.277571630583514, 0.2688222513075441, 0.24300880867803662, 0.20141317105264114, 0.14609889758077332, 0.07980593576993696, 0.005811034304373925, -0.0722388011028484, -0.15051108239111077, -0.22518118755916025, -0.2926242127644853, -0.3495953826561967, -0.39338972722403176, -0.42197287899622543, -0.434076417833265, -0.42925310491460716, -0.407889497747319, -0.37117570680030565, -0.3210343185560354, -0.26001264723920775, -0.19114437378651342, -0.1177881852505473, -0.043452159632214875, 0.02838670735216783, 0.09445829662141196, 0.15186131748507978, 0.1982031145119569, 0.2317103248693539, 0.25130504004127213, 0.2566430509401283, 0.24811283911536614, 0.22679610352037188, 0.1943926655354523, 0.15311446345017118, 0.10555493165712146, 0.054541276561040686, 0.0029779491154211806, -0.046310064114579955, -0.0907256642328181, -0.12803192632998142], [-0.16278435980926842, -0.13736985507049018, -0.10281030706494565, -0.060690608986011814, -0.013073952151520388, 0.03759772656874239, 0.08862652853638416, 0.13719827990417027, 0.18053174205108255, 0.21602931256266372, 0.24142096714711753, 0.254893432701845, 0.25519727019112654, 0.24172565029557566, 0.21456006847846779, 0.17447999195279823, 0.12293536517635703, 0.06198291759831892, -0.005810793613848673, -0.07749482277960204, -0.14988136590815446, -0.21970771693043264, -0.2838041182964338, -0.3392585664190622, -0.3835697098652554, -0.4147795406040892, -0.43157859884674826, -0.4333778373354074, -0.4203430458705095, -0.39338972722403176, -0.3541384336243295, -0.30483270332925, -0.24822376277499153, -0.187427969950852, -0.1257644689695074, -0.06658162124929747, -0.0130814139378774, 0.03184881503912622, 0.0657883626364726, 0.08691073780520595, 0.0940800053732448, 0.08691073780520595, 0.0657883626364726, 0.03184881503912622, -0.0130814139378774, -0.06658162124929747, -0.1257644689695074, -0.187427969950852, -0.24822376277499153, -0.30483270332925, -0.3541384336243295, -0.39338972722403176, -0.4203430458705095, -0.4333778373354074, -0.43157859884674826, -0.4147795406040892, -0.3835697098652554, -0.3392585664190622, -0.2838041182964338, -0.21970771693043264, -0.14988136590815446, -0.07749482277960204, -0.005810793613848673, 0.06198291759831892, 0.12293536517635703, 0.17447999195279823, 0.21456006847846779, 0.24172565029557566, 0.25519727019112654, 0.254893432701845, 0.24142096714711753, 0.21602931256266372, 0.18053174205108255, 0.13719827990417027, 0.08862652853638416, 0.03759772656874239, -0.013073952151520388, -0.060690608986011814, -0.10281030706494565, -0.13736985507049018], [-0.16865061331126227, -0.14653700801271363, -0.11505016730310495, -0.07558080422426758, -0.030004497243790427, 0.019407660252202565, 0.07010183827093616, 0.11937185506223688, 0.16450028494360933, 0.20290271423033404, 0.23226729318028777, 0.2506818889186662, 0.2567417315441088, 0.24963143467045815, 0.22917661128094333, 0.19586192453391038, 0.15081422331281308, 0.0957513146109, 0.032898814044057145, -0.03512071345143313, -0.10542055787501849, -0.17499760171649797, -0.24088710992360066, -0.3003162506586467, -0.35084804028714445, -0.3905078789395116, -0.417885750201407, -0.43220845214435083, -0.4333778373354074, -0.42197287899622543, -0.39921534828629784, -0.36690087535799776, -0.32729906443176787, -0.28302803533990717, -0.23691017597600564, -0.19181693290541052, -0.15051108239111077, -0.11549507625799743, -0.08887373699192957, -0.0722388011028484, -0.06658162124929747, -0.0722388011028484, -0.08887373699192957, -0.11549507625799743, -0.15051108239111077, -0.19181693290541052, -0.23691017597600564, -0.28302803533990717, -0.32729906443176787, -0.36690087535799776, -0.39921534828629784, -0.42197287899622543, -0.4333778373354074, -0.43220845214435083, -0.417885750201407, -0.3905078789395116, -0.35084804028714445, -0.3003162506586467, -0.24088710992360066, -0.17499760171649797, -0.10542055787501849, -0.03512071345143313, 0.032898814044057145, 0.0957513146109, 0.15081422331281308, 0.19586192453391038, 0.22917661128094333, 0.24963143467045815, 0.2567417315441088, 0.2506818889186662, 0.23226729318028777, 0.20290271423033404, 0.16450028494360933, 0.11937185506223688, 0.07010183827093616, 0.019407660252202565, -0.030004497243790427, -0.07558080422426758, -0.11505016730310495, -0.14653700801271363], [-0.1738139924448547, -0.15527119023634722, -0.1271795169340972, -0.0907256642328181, -0.04758506314163741, 0.0001569493213448689, 0.05010748884225075, 0.09968670899986165, 0.14626024334832619, 0.18727640924644018, 0.22040074178662336, 0.24364050109720906, 0.2554522819126627, 0.2548267267047997, 0.2413455569066888, 0.2152076253393881, 0.17722237538812438, 0.12877087581897034, 0.07173638515428266, 0.00840808631479302, -0.05863687417657578, -0.12666669235949252, -0.1929363397545002, -0.254829433326894, -0.309992807249447, -0.3564564355250057, -0.39273214882544505, -0.417885750201407, -0.43157859884674826, -0.434076417833265, -0.42622489689420734, -0.4093935036702951, -0.3853906832849483, -0.35635521764627226, -0.324629843053556, -0.2926242127644853, -0.2626748843273063, -0.23691017597600564, -0.21712746254366178, -0.20468978410715197, -0.20044755867978276, -0.20468978410715197, -0.21712746254366178, -0.23691017597600564, -0.2626748843273063, -0.2926242127644853, -0.324629843053556, -0.35635521764627226, -0.3853906832849483, -0.4093935036702951, -0.42622489689420734, -0.434076417833265, -0.43157859884674826, -0.417885750201407, -0.39273214882544505, -0.3564564355250057, -0.309992807249447, -0.254829433326894, -0.1929363397545002, -0.12666669235949252, -0.05863687417657578, 0.00840808631479302, 0.07173638515428266, 0.12877087581897034, 0.17722237538812438, 0.2152076253393881, 0.2413455569066888, 0.2548267267047997, 0.2554522819126627, 0.24364050109720906, 0.22040074178662336, 0.18727640924644018, 0.14626024334832619, 0.09968670899986165, 0.05010748884225075, 0.0001569493213448689, -0.04758506314163741, -0.0907256642328181, -0.1271795169340972, -0.15527119023634722], [-0.17801860199902664, -0.16329221750830802, -0.13890582780165694, -0.10583439818051152, -0.06554239869174844, -0.019915691575644292, 0.02883009042098063, 0.07825990831739421, 0.1258425822940911, 0.16908036038891633, 0.20563779959612533, 0.23346296309158113, 0.2508943222213973, 0.25674750760048576, 0.25037713957121355, 0.2317103248693539, 0.20124995852555586, 0.16004763127913005, 0.1096476200446325, 0.05200503792795912, -0.010617349295218181, -0.0757679524450742, -0.1409342819269669, -0.2036729142303004, -0.2617343483375656, -0.31317589634427284, -0.3564564355250057, -0.3905078789395116, -0.4147795406040892, -0.42925310491460716, -0.43442757176285574, -0.4312752446188071, -0.421171462695804, -0.40580225753498556, -0.38705535500366767, -0.36690087535799776, -0.3472686537517362, -0.32992927901128904, -0.3163857196862348, -0.3077817863653888, -0.30483270332925, -0.3077817863653888, -0.3163857196862348, -0.32992927901128904, -0.3472686537517362, -0.36690087535799776, -0.38705535500366767, -0.40580225753498556, -0.421171462695804, -0.4312752446188071, -0.43442757176285574, -0.42925310491460716, -0.4147795406040892, -0.3905078789395116, -0.3564564355250057, -0.31317589634427284, -0.2617343483375656, -0.2036729142303004, -0.1409342819269669, -0.0757679524450742, -0.010617349295218181, 0.05200503792795912, 0.1096476200446325, 0.16004763127913005, 0.20124995852555586, 0.2317103248693539, 0.25037713957121355, 0.25674750760048576, 0.2508943222213973, 0.23346296309158113, 0.20563779959612533, 0.16908036038891633, 0.1258425822940911, 0.07825990831739421, 0.02883009042098063, -0.019915691575644292, -0.06554239869174844, -0.10583439818051152, -0.13890582780165694, -0.16329221750830802], [-0.18100457917857166, -0.17030698199702413, -0.1499137997580331, -0.12058300781296416, -0.08355939645450051, -0.040517266401149735, 0.0065202421682302655, 0.05528095770522729, 0.10335731863015635, 0.14832776112580212, 0.18787932061729182, 0.21992483146863692, 0.242708395806646, 0.254893432701845, 0.25562857790064414, 0.24458792842044305, 0.22198354690007724, 0.18854967763954522, 0.14549969299473817, 0.09445829662141196, 0.037372873633869375, -0.02359098016854476, -0.08616386191642225, -0.14809048863531396, -0.20724458052139974, -0.2617343483375656, -0.309992807249447, -0.35084804028714445, -0.3835697098652554, -0.407889497747319, -0.42399466300627076, -0.43249545715781157, -0.43436863670247905, -0.4308806796227811, -0.42349546556438716, -0.4137720534188708, -0.40325873487122593, -0.39338972722403176, -0.3853906832849483, -0.3801986514917913, -0.3784012476539641, -0.3801986514917913, -0.3853906832849483, -0.39338972722403176, -0.40325873487122593, -0.4137720534188708, -0.42349546556438716, -0.4308806796227811, -0.43436863670247905, -0.43249545715781157, -0.42399466300627076, -0.407889497747319, -0.3835697098652554, -0.35084804028714445, -0.309992807249447, -0.2617343483375656, -0.20724458052139974, -0.14809048863531396, -0.08616386191642225, -0.02359098016854476, 0.037372873633869375, 0.09445829662141196, 0.14549969299473817, 0.18854967763954522, 0.22198354690007724, 0.24458792842044305, 0.25562857790064414, 0.254893432701845, 0.242708395806646, 0.21992483146863692, 0.18787932061729182, 0.14832776112580212, 0.10335731863015635, 0.05528095770522729, 0.0065202421682302655, -0.040517266401149735, -0.08355939645450051, -0.12058300781296416, -0.1499137997580331, -0.17030698199702413], [-0.18251498442862385, -0.1760159755489718, -0.15987112992755653, -0.13461888616197776, -0.10127808535368477, -0.061301442485772274, -0.016505930263581485, 0.031016232090896562, 0.07900122348247962, 0.12512633286074154, 0.16712567793535366, 0.20290271423033404, 0.23063350923189954, 0.24885528388828942, 0.25653555744366946, 0.25311832399967577, 0.23854497801642713, 0.21324911772700825, 0.17812580971586786, 0.134477311926808, 0.08393854575868848, 0.02838670735216783, -0.030159748399708135, -0.08964697741323371, -0.14809048863531396, -0.2036729142303004, -0.254829433326894, -0.3003162506586467, -0.3392585664190622, -0.37117570680030565, -0.39598244357893553, -0.41396693622794944, -0.42574709936268906, -0.43220845214435083, -0.43442757176285574, -0.4335860886421158, -0.4308806796227811, -0.4274347075936389, -0.42421701152445723, -0.42197287899622543, -0.421171462695804, -0.42197287899622543, -0.42421701152445723, -0.4274347075936389, -0.4308806796227811, -0.4335860886421158, -0.43442757176285574, -0.43220845214435083, -0.42574709936268906, -0.41396693622794944, -0.39598244357893553, -0.37117570680030565, -0.3392585664190622, -0.3003162506586467, -0.254829433326894, -0.2036729142303004, -0.14809048863531396, -0.08964697741323371, -0.030159748399708135, 0.02838670735216783, 0.08393854575868848, 0.134477311926808, 0.17812580971586786, 0.21324911772700825, 0.23854497801642713, 0.25311832399967577, 0.25653555744366946, 0.24885528388828942, 0.23063350923189954, 0.20290271423033404, 0.16712567793535366, 0.12512633286074154, 0.07900122348247962, 0.031016232090896562, -0.016505930263581485, -0.061301442485772274, -0.10127808535368477, -0.13461888616197776, -0.15987112992755653, -0.1760159755489718], [-0.18230376872794093, -0.18012123502583363, -0.16843605361995675, -0.14756752732225356, -0.11830504740258321, -0.08187218787401292, -0.039868134180728126, 0.0058103924762656495, 0.05306249567952219, 0.09968670899986165, 0.14348926836260514, 0.18239124981424537, 0.2145288714461612, 0.2383416766936446, 0.25264402764959015, 0.2566762997375786, 0.25013332713993036, 0.23316893482082693, 0.2063767337439853, 0.17074867404778504, 0.12761407121954643, 0.07856287339249271, 0.02535776443828009, -0.030159748399708135, -0.08616386191642225, -0.1409342819269669, -0.1929363397545002, -0.24088710992360066, -0.2838041182964338, -0.3210343185560354, -0.35226222727992795, -0.37749737145928347, -0.3970424421347404, -0.41144469052055266, -0.42143408131469146, -0.42785247459104203, -0.43157859884674826, -0.4334537754581445, -0.434213248547002, -0.43442757176285574, -0.43445783007337646, -0.43442757176285574, -0.434213248547002, -0.4334537754581445, -0.43157859884674826, -0.42785247459104203, -0.42143408131469146, -0.41144469052055266, -0.3970424421347404, -0.37749737145928347, -0.35226222727992795, -0.3210343185560354, -0.2838041182964338, -0.24088710992360066, -0.1929363397545002, -0.1409342819269669, -0.08616386191642225, -0.030159748399708135, 0.02535776443828009, 0.07856287339249271, 0.12761407121954643, 0.17074867404778504, 0.2063767337439853, 0.23316893482082693, 0.25013332713993036, 0.2566762997375786, 0.25264402764959015, 0.2383416766936446, 0.2145288714461612, 0.18239124981424537, 0.14348926836260514, 0.09968670899986165, 0.05306249567952219, 0.0058103924762656495, -0.039868134180728126, -0.08187218787401292, -0.11830504740258321, -0.14756752732225356, -0.16843605361995675, -0.18012123502583363], [-0.1801446545297837, -0.18233559039097344, -0.1752665961050691, -0.15904136091487175, -0.13421936300715656, -0.10179031338845618, -0.0631265026963309, -0.019915691575644292, 0.025921773001301992, 0.07232710218505171, 0.11720338291232232, 0.15851669454452746, 0.1943926655354523, 0.2232034254780841, 0.24364050109720906, 0.25477004091850136, 0.2560677827399544, 0.24743234013685533, 0.22917661128094333, 0.20199833430642128, 0.16693195814109418, 0.12528500092613942, 0.07856287339249271, 0.02838670735216783, -0.02359098016854476, -0.0757679524450742, -0.12666669235949252, -0.17499760171649797, -0.21970771693043264, -0.26001264723920775, -0.29541051237375787, -0.32567778292945404, -0.35084804028714445, -0.37117570680030565, -0.38708768931988075, -0.3991265770886398, -0.407889497747319, -0.41396693622794944, -0.417885750201407, -0.4200602785751461, -0.4207548585159486, -0.4200602785751461, -0.417885750201407, -0.41396693622794944, -0.407889497747319, -0.3991265770886398, -0.38708768931988075, -0.37117570680030565, -0.35084804028714445, -0.32567778292945404, -0.29541051237375787, -0.26001264723920775, -0.21970771693043264, -0.17499760171649797, -0.12666669235949252, -0.0757679524450742, -0.02359098016854476, 0.02838670735216783, 0.07856287339249271, 0.12528500092613942, 0.16693195814109418, 0.20199833430642128, 0.22917661128094333, 0.24743234013685533, 0.2560677827399544, 0.25477004091850136, 0.24364050109720906, 0.2232034254780841, 0.1943926655354523, 0.15851669454452746, 0.11720338291232232, 0.07232710218505171, 0.025921773001301992, -0.019915691575644292, -0.0631265026963309, -0.10179031338845618, -0.13421936300715656, -0.15904136091487175, -0.1752665961050691, -0.18233559039097344], [-0.17584069010379264, -0.18239300622958532, -0.1800313728705813, -0.16865061331126227, -0.14858307017251748, -0.12058300781296416, -0.0857896329957062, -0.045670869380806056, -0.001951040868825416, 0.043473546354522816, 0.08862652853638416, 0.13154597877649798, 0.17037647050011584, 0.20345392533496165, 0.22937894091767205, 0.24707500803079696, 0.25582893038458626, 0.2553118000893658, 0.2455799958764798, 0.2270567942100705, 0.20049625055173417, 0.16693195814109418, 0.12761407121954643, 0.08393854575868848, 0.037372873633869375, -0.010617349295218181, -0.05863687417657578, -0.10542055787501849, -0.14988136590815446, -0.19114437378651342, -0.22856545626592412, -0.2617343483375656, -0.29046275344788247, -0.31475910259630246, -0.33479237619194996, -0.35084804028714445, -0.3632795822101567, -0.37245933283868765, -0.3787322233669178, -0.382375848005458, -0.3835697098652554, -0.382375848005458, -0.3787322233669178, -0.37245933283868765, -0.3632795822101567, -0.35084804028714445, -0.33479237619194996, -0.31475910259630246, -0.29046275344788247, -0.2617343483375656, -0.22856545626592412, -0.19114437378651342, -0.14988136590815446, -0.10542055787501849, -0.05863687417657578, -0.010617349295218181, 0.037372873633869375, 0.08393854575868848, 0.12761407121954643, 0.16693195814109418, 0.20049625055173417, 0.2270567942100705, 0.2455799958764798, 0.2553118000893658, 0.25582893038458626, 0.24707500803079696, 0.22937894091767205, 0.20345392533496165, 0.17037647050011584, 0.13154597877649798, 0.08862652853638416, 0.043473546354522816, -0.001951040868825416, -0.045670869380806056, -0.0857896329957062, -0.12058300781296416, -0.14858307017251748, -0.16865061331126227, -0.1800313728705813, -0.18239300622958532], [-0.16923416092386775, -0.1800597155006458, -0.18242166855756492, -0.1760159755489718, -0.1609539875623888, -0.1377563081818195, -0.10732612754693129, -0.07090368426500879, -0.030004497243790427, 0.013655158230898757, 0.058241427706856384, 0.1018902143955224, 0.14279404657238684, 0.1792839709402817, 0.20990234059772522, 0.23346296309158113, 0.24909585663212155, 0.2562747828163765, 0.2548267267047997, 0.24492352037505036, 0.2270567942100705, 0.20199833430642128, 0.17074867404778504, 0.134477311926808, 0.09445829662141196, 0.05200503792795912, 0.00840808631479302, -0.03512071345143313, -0.07749482277960204, -0.1177881852505473, -0.15525760655490364, -0.18935183535374994, -0.21970771693043264, -0.24613461781837798, -0.268589046149572, -0.28714197491104243, -0.30194177876754097, -0.31317589634427284, -0.3210343185560354, -0.32567778292945404, -0.32721314035298743, -0.32567778292945404, -0.3210343185560354, -0.31317589634427284, -0.30194177876754097, -0.28714197491104243, -0.268589046149572, -0.24613461781837798, -0.21970771693043264, -0.18935183535374994, -0.15525760655490364, -0.1177881852505473, -0.07749482277960204, -0.03512071345143313, 0.00840808631479302, 0.05200503792795912, 0.09445829662141196, 0.134477311926808, 0.17074867404778504, 0.20199833430642128, 0.2270567942100705, 0.24492352037505036, 0.2548267267047997, 0.2562747828163765, 0.24909585663212155, 0.23346296309158113, 0.20990234059772522, 0.1792839709402817, 0.14279404657238684, 0.1018902143955224, 0.058241427706856384, 0.013655158230898757, -0.030004497243790427, -0.07090368426500879, -0.10732612754693129, -0.1377563081818195, -0.1609539875623888, -0.1760159755489718, -0.18242166855756492, -0.1800597155006458], [-0.16021647158282734, -0.1751457556394694, -0.1821644169794075, -0.18078273088932142, -0.17090060569317098, -0.1528102839666787, -0.1271795169340972, -0.0950164022704569, -0.05761803324395176, -0.016505930263581485, 0.026648129724923395, 0.07010183827093616, 0.11212338767979044, 0.15106960365711752, 0.18545724476618586, 0.21402402107025095, 0.23577655069724138, 0.25002327766855664, 0.25639126767027576, 0.2548267267047997, 0.2455799958764798, 0.22917661128094333, 0.2063767337439853, 0.17812580971586786, 0.14549969299473817, 0.1096476200446325, 0.07173638515428266, 0.032898814044057145, -0.005810793613848673, -0.043452159632214875, -0.0792240541655952, -0.11247819731414006, -0.1427221428215067, -0.1696119802323752, -0.1929363397545002, -0.2125937105436689, -0.22856545626592412, -0.24088710992360066, -0.24962054293732017, -0.254829433326894, -0.2565601183892334, -0.254829433326894, -0.24962054293732017, -0.24088710992360066, -0.22856545626592412, -0.2125937105436689, -0.1929363397545002, -0.1696119802323752, -0.1427221428215067, -0.11247819731414006, -0.0792240541655952, -0.043452159632214875, -0.005810793613848673, 0.032898814044057145, 0.07173638515428266, 0.1096476200446325, 0.14549969299473817, 0.17812580971586786, 0.2063767337439853, 0.22917661128094333, 0.2455799958764798, 0.2548267267047997, 0.25639126767027576, 0.25002327766855664, 0.23577655069724138, 0.21402402107025095, 0.18545724476618586, 0.15106960365711752, 0.11212338767979044, 0.07010183827093616, 0.026648129724923395, -0.016505930263581485, -0.05761803324395176, -0.0950164022704569, -0.1271795169340972, -0.1528102839666787, -0.17090060569317098, -0.18078273088932142, -0.1821644169794075, -0.1751457556394694], [-0.1487375524385824, -0.16751643729146143, -0.17903560277058095, -0.1826358700412797, -0.17801860199902664, -0.16525654180237792, -0.14478624788034108, -0.11738288358628372, -0.08411903827788304, -0.046310064114579955, -0.005449066140771361, 0.03686485131708162, 0.07900122348247962, 0.11937185506223688, 0.15649972810645998, 0.1890798565922851, 0.21602931256266372, 0.2365243422174828, 0.25002327766855664, 0.2562747828163765, 0.2553118000893658, 0.24743234013685533, 0.23316893482082693, 0.21324911772700825, 0.18854967763954522, 0.16004763127913005, 0.12877087581897034, 0.0957513146109, 0.06198291759831892, 0.02838670735216783, -0.004215913110515241, -0.03512071345143313, -0.06374895250625122, -0.08964697741323371, -0.11247819731414006, -0.132008995765264, -0.14809048863531396, -0.16063822727306362, -0.1696119802323752, -0.17499760171649797, -0.17679272260843765, -0.17499760171649797, -0.1696119802323752, -0.16063822727306362, -0.14809048863531396, -0.132008995765264, -0.11247819731414006, -0.08964697741323371, -0.06374895250625122, -0.03512071345143313, -0.004215913110515241, 0.02838670735216783, 0.06198291759831892, 0.0957513146109, 0.12877087581897034, 0.16004763127913005, 0.18854967763954522, 0.21324911772700825, 0.23316893482082693, 0.24743234013685533, 0.2553118000893658, 0.2562747828163765, 0.25002327766855664, 0.2365243422174828, 0.21602931256266372, 0.1890798565922851, 0.15649972810645998, 0.11937185506223688, 0.07900122348247962, 0.03686485131708162, -0.005449066140771361, -0.046310064114579955, -0.08411903827788304, -0.11738288358628372, -0.14478624788034108, -0.16525654180237792, -0.17801860199902664, -0.1826358700412797, -0.17903560277058095, -0.16751643729146143], [-0.13481430178982187, -0.15710321083861073, -0.17287351607260817, -0.18131560690315682, -0.18194839266053625, -0.17463748569481502, -0.15959621882048483, -0.13736985507049018, -0.10880422217787396, -0.0750007897964791, -0.03726086233570953, 0.0029779491154211806, 0.044209509361482956, 0.08492762656935865, 0.12369173187889267, 0.15918658398472915, 0.1902732638436695, 0.21602931256266372, 0.23577655069724138, 0.24909585663212155, 0.25582893038458626, 0.2560677827399544, 0.25013332713993036, 0.23854497801642713, 0.22198354690007724, 0.20124995852555586, 0.17722237538812438, 0.15081422331281308, 0.12293536517635703, 0.09445829662141196, 0.0661907655654817, 0.03885568116655977, 0.013078615468659323, -0.010617349295218181, -0.03181017613329085, -0.050171999808914604, -0.06545830501430487, -0.07749482277960204, -0.08616386191642225, -0.09139170665445415, -0.09313849939964196, -0.09139170665445415, -0.08616386191642225, -0.07749482277960204, -0.06545830501430487, -0.050171999808914604, -0.03181017613329085, -0.010617349295218181, 0.013078615468659323, 0.03885568116655977, 0.0661907655654817, 0.09445829662141196, 0.12293536517635703, 0.15081422331281308, 0.17722237538812438, 0.20124995852555586, 0.22198354690007724, 0.23854497801642713, 0.25013332713993036, 0.2560677827399544, 0.25582893038458626, 0.24909585663212155, 0.23577655069724138, 0.21602931256266372, 0.1902732638436695, 0.15918658398472915, 0.12369173187889267, 0.08492762656935865, 0.044209509361482956, 0.0029779491154211806, -0.03726086233570953, -0.0750007897964791, -0.10880422217787396, -0.13736985507049018, -0.15959621882048483, -0.17463748569481502, -0.18194839266053625, -0.18131560690315682, -0.17287351607260817, -0.15710321083861073], [-0.11853755153953284, -0.14391335124448024, -0.163591222139663, -0.17663261032673944, -0.18239300622958532, -0.18054660691367944, -0.17109514979541934, -0.1543609103022869, -0.13096468174943518, -0.10179031338845618, -0.06793803188546253, -0.03066927919323432, 0.008653858363151095, 0.04863139306208121, 0.0878871354792479, 0.12512633286074154, 0.15918658398472915, 0.1890798565922851, 0.21402402107025095, 0.23346296309158113, 0.24707500803079696, 0.25477004091850136, 0.2566762997375786, 0.25311832399967577, 0.24458792842044305, 0.2317103248693539, 0.2152076253393881, 0.19586192453391038, 0.17447999195279823, 0.15186131748507978, 0.12877087581897034, 0.10591753298818528, 0.08393854575868848, 0.06339013493636744, 0.044743679368913644, 0.02838670735216783, 0.014627580006334946, 0.0037025838949493145, -0.004215913110515241, -0.009011537058698997, -0.010617349295218181, -0.009011537058698997, -0.004215913110515241, 0.0037025838949493145, 0.014627580006334946, 0.02838670735216783, 0.044743679368913644, 0.06339013493636744, 0.08393854575868848, 0.10591753298818528, 0.12877087581897034, 0.15186131748507978, 0.17447999195279823, 0.19586192453391038, 0.2152076253393881, 0.2317103248693539, 0.24458792842044305, 0.25311832399967577, 0.2566762997375786, 0.25477004091850136, 0.24707500803079696, 0.23346296309158113, 0.21402402107025095, 0.1890798565922851, 0.15918658398472915, 0.12512633286074154, 0.0878871354792479, 0.04863139306208121, 0.008653858363151095, -0.03066927919323432, -0.06793803188546253, -0.10179031338845618, -0.13096468174943518, -0.1543609103022869, -0.17109514979541934, -0.18054660691367944, -0.18239300622958532, -0.17663261032673944, -0.163591222139663, -0.14391335124448024], [-0.10007704610444179, -0.12803786284735597, -0.1511875643863488, -0.16848219583369567, -0.17913546063850083, -0.18264893898060253, -0.1788278960809016, -0.16778234479339135, -0.1499137997580331, -0.1258888846262905, -0.09660159075517502, -0.0631265026963309, -0.026665677985416577, 0.011507919583092052, 0.05010748884225075, 0.0878871354792479, 0.12369173187889267, 0.15649972810645998, 0.18545724476618586, 0.20990234059772522, 0.22937894091767205, 0.24364050109720906, 0.25264402764959015, 0.25653555744366946, 0.25562857790064414, 0.25037713957121355, 0.2413455569066888, 0.22917661128094333, 0.21456006847846779, 0.1982031145119569, 0.18080401871815463, 0.1630299764243758, 0.14549969299473817, 0.12877087581897034, 0.11333242903336226, 0.09960082298540655, 0.08791985781076668, 0.07856287339249271, 0.07173638515428266, 0.06758414818694233, 0.0661907655654817, 0.06758414818694233, 0.07173638515428266, 0.07856287339249271, 0.08791985781076668, 0.09960082298540655, 0.11333242903336226, 0.12877087581897034, 0.14549969299473817, 0.1630299764243758, 0.18080401871815463, 0.1982031145119569, 0.21456006847846779, 0.22917661128094333, 0.2413455569066888, 0.25037713957121355, 0.25562857790064414, 0.25653555744366946, 0.25264402764959015, 0.24364050109720906, 0.22937894091767205, 0.20990234059772522, 0.18545724476618586, 0.15649972810645998, 0.12369173187889267, 0.0878871354792479, 0.05010748884225075, 0.011507919583092052, -0.026665677985416577, -0.0631265026963309, -0.09660159075517502, -0.1258888846262905, -0.1499137997580331, -0.16778234479339135, -0.1788278960809016, -0.18264893898060253, -0.17913546063850083, -0.16848219583369567, -0.1511875643863488, -0.12803786284735597], [-0.07968395387291566, -0.10965701691843574, -0.13575600794040762, -0.15685668268767797, -0.17205475511311313, -0.1807007071005138, -0.18242166855756492, -0.17712974307464055, -0.16501687105976595, -0.14653700801271363, -0.12237701362727325, -0.09341816596346665, -0.060690608986011814, -0.02532329427921568, 0.011507919583092052, 0.04863139306208121, 0.08492762656935865, 0.11937185506223688, 0.15106960365711752, 0.1792839709402817, 0.20345392533496165, 0.2232034254780841, 0.2383416766936446, 0.24885528388828942, 0.254893432701845, 0.25674750760048576, 0.2548267267047997, 0.24963143467045815, 0.24172565029557566, 0.2317103248693539, 0.22019854657881394, 0.20779364608280457, 0.19507084218595108, 0.18256273925541686, 0.17074867404778504, 0.16004763127913005, 0.15081422331281308, 0.1433370736825879, 0.13783886506830845, 0.134477311926808, 0.1333463922312941, 0.134477311926808, 0.13783886506830845, 0.1433370736825879, 0.15081422331281308, 0.16004763127913005, 0.17074867404778504, 0.18256273925541686, 0.19507084218595108, 0.20779364608280457, 0.22019854657881394, 0.2317103248693539, 0.24172565029557566, 0.24963143467045815, 0.2548267267047997, 0.25674750760048576, 0.254893432701845, 0.24885528388828942, 0.2383416766936446, 0.2232034254780841, 0.20345392533496165, 0.1792839709402817, 0.15106960365711752, 0.11937185506223688, 0.08492762656935865, 0.04863139306208121, 0.011507919583092052, -0.02532329427921568, -0.060690608986011814, -0.09341816596346665, -0.12237701362727325, -0.14653700801271363, -0.16501687105976595, -0.17712974307464055, -0.18242166855756492, -0.1807007071005138, -0.17205475511311313, -0.15685668268767797, -0.13575600794040762, -0.10965701691843574], [-0.05769048962428924, -0.08904297911487404, -0.11749065565570795, -0.14185512230149663, -0.16113955966514656, -0.17456713788189782, -0.18160802037610754, -0.18199408570471504, -0.17572115154133375, -0.16303912773542587, -0.14443111863131364, -0.12058300781296416, -0.09234546620178369, -0.060690608986011814, -0.026665677985416577, 0.008653858363151095, 0.044209509361482956, 0.07900122348247962, 0.11212338767979044, 0.14279404657238684, 0.17037647050011584, 0.1943926655354523, 0.2145288714461612, 0.23063350923189954, 0.242708395806646, 0.2508943222213973, 0.2554522819126627, 0.2567417315441088, 0.25519727019112654, 0.25130504004127213, 0.2455799958764798, 0.23854497801642713, 0.23071227369415245, 0.2225680860000738, 0.21456006847846779, 0.2070878465419809, 0.20049625055173417, 0.19507084218595108, 0.19103523332295086, 0.18854967763954522, 0.18771045677679687, 0.18854967763954522, 0.19103523332295086, 0.19507084218595108, 0.20049625055173417, 0.2070878465419809, 0.21456006847846779, 0.2225680860000738, 0.23071227369415245, 0.23854497801642713, 0.2455799958764798, 0.25130504004127213, 0.25519727019112654, 0.2567417315441088, 0.2554522819126627, 0.2508943222213973, 0.242708395806646, 0.23063350923189954, 0.2145288714461612, 0.1943926655354523, 0.17037647050011584, 0.14279404657238684, 0.11212338767979044, 0.07900122348247962, 0.044209509361482956, 0.008653858363151095, -0.026665677985416577, -0.060690608986011814, -0.09234546620178369, -0.12058300781296416, -0.14443111863131364, -0.16303912773542587, -0.17572115154133375, -0.18199408570471504, -0.18160802037610754, -0.17456713788189782, -0.16113955966514656, -0.14185512230149663, -0.11749065565570795, -0.08904297911487404], [-0.0345063152690242, -0.06655906279410359, -0.09668883252747353, -0.12368964794720452, -0.1464987033293174, -0.1642373823959323, -0.17624240938958516, -0.18208605074549258, -0.18158488243001691, -0.1747972342928682, -0.16200998595397612, -0.1437158894806465, -0.12058300781296416, -0.09341816596346665, -0.0631265026963309, -0.03066927919323432, 0.0029779491154211806, 0.03686485131708162, 0.07010183827093616, 0.1018902143955224, 0.13154597877649798, 0.15851669454452746, 0.18239124981424537, 0.20290271423033404, 0.21992483146863692, 0.23346296309158113, 0.24364050109720906, 0.2506818889186662, 0.254893432701845, 0.2566430509401283, 0.2563400102730029, 0.25441554164532254, 0.25130504004127213, 0.24743234013685533, 0.2431963471432226, 0.23896010343988033, 0.23504220166614895, 0.2317103248693539, 0.22917661128094333, 0.22759450814784551, 0.2270567942100705, 0.22759450814784551, 0.22917661128094333, 0.2317103248693539, 0.23504220166614895, 0.23896010343988033, 0.2431963471432226, 0.24743234013685533, 0.25130504004127213, 0.25441554164532254, 0.2563400102730029, 0.2566430509401283, 0.254893432701845, 0.2506818889186662, 0.24364050109720906, 0.23346296309158113, 0.21992483146863692, 0.20290271423033404, 0.18239124981424537, 0.15851669454452746, 0.13154597877649798, 0.1018902143955224, 0.07010183827093616, 0.03686485131708162, 0.0029779491154211806, -0.03066927919323432, -0.0631265026963309, -0.09341816596346665, -0.12058300781296416, -0.1437158894806465, -0.16200998595397612, -0.1747972342928682, -0.18158488243001691, -0.18208605074549258, -0.17624240938958516, -0.1642373823959323, -0.1464987033293174, -0.12368964794720452, -0.09668883252747353, -0.06655906279410359], [-0.01061150357619211, -0.042655257000177006, -0.07374973820785838, -0.10268778525178764, -0.1283676319466868, -0.14983554931501694, -0.16632015713858264, -0.17725715646546372, -0.18230376872794093, -0.18134271385500067, -0.17447608825271163, -0.16200998595397612, -0.14443111863131364, -0.12237701362727325, -0.09660159075517502, -0.06793803188546253, -0.03726086233570953, -0.005449066140771361, 0.026648129724923395, 0.058241427706856384, 0.08862652853638416, 0.11720338291232232, 0.14348926836260514, 0.16712567793535366, 0.18787932061729182, 0.20563779959612533, 0.22040074178662336, 0.23226729318028777, 0.24142096714711753, 0.24811283911536614, 0.25264402764959015, 0.255348298963932, 0.256575492104657, 0.2566762997375786, 0.2559887694405144, 0.2548267267047997, 0.25347017586536014, 0.252157618714697, 0.25108014921898075, 0.25037713957121355, 0.25013332713993036, 0.25037713957121355, 0.25108014921898075, 0.252157618714697, 0.25347017586536014, 0.2548267267047997, 0.2559887694405144, 0.2566762997375786, 0.256575492104657, 0.255348298963932, 0.25264402764959015, 0.24811283911536614, 0.24142096714711753, 0.23226729318028777, 0.22040074178662336, 0.20563779959612533, 0.18787932061729182, 0.16712567793535366, 0.14348926836260514, 0.11720338291232232, 0.08862652853638416, 0.058241427706856384, 0.026648129724923395, -0.005449066140771361, -0.03726086233570953, -0.06793803188546253, -0.09660159075517502, -0.12237701362727325, -0.14443111863131364, -0.16200998595397612, -0.17447608825271163, -0.18134271385500067, -0.18230376872794093, -0.17725715646546372, -0.16632015713858264, -0.14983554931501694, -0.1283676319466868, -0.10268778525178764, -0.07374973820785838, -0.042655257000177006], [0.013454008098850966, -0.017859822184363938, -0.04916880920228074, -0.07929019757294747, -0.10711012813756442, -0.1316269478872783, -0.15198770280837584, -0.16751643729146143, -0.17773339606034183, -0.18236471957976835, -0.18134271385500067, -0.1747972342928682, -0.16303912773542587, -0.14653700801271363, -0.1258888846262905, -0.10179031338845618, -0.0750007897964791, -0.046310064114579955, -0.016505930263581485, 0.013655158230898757, 0.043473546354522816, 0.07232710218505171, 0.09968670899986165, 0.12512633286074154, 0.14832776112580212, 0.16908036038891633, 0.18727640924644018, 0.20290271423033404, 0.21602931256266372, 0.22679610352037188, 0.23539823538075702, 0.2420710146043941, 0.24707500803079696, 0.2506818889186662, 0.2531614457800734, 0.25477004091850136, 0.2557406839380664, 0.2562747828163765, 0.25653555744366946, 0.2566430509401283, 0.2566706526738519, 0.2566430509401283, 0.25653555744366946, 0.2562747828163765, 0.2557406839380664, 0.25477004091850136, 0.2531614457800734, 0.2506818889186662, 0.24707500803079696, 0.2420710146043941, 0.23539823538075702, 0.22679610352037188, 0.21602931256266372, 0.20290271423033404, 0.18727640924644018, 0.16908036038891633, 0.14832776112580212, 0.12512633286074154, 0.09968670899986165, 0.07232710218505171, 0.043473546354522816, 0.013655158230898757, -0.016505930263581485, -0.046310064114579955, -0.0750007897964791, -0.10179031338845618, -0.1258888846262905, -0.14653700801271363, -0.16303912773542587, -0.1747972342928682, -0.18134271385500067, -0.18236471957976835, -0.17773339606034183, -0.16751643729146143, -0.15198770280837584, -0.1316269478872783, -0.10711012813756442, -0.07929019757294747, -0.04916880920228074, -0.017859822184363938], [0.037104384846577534, 0.007233082355737275, -0.023527608249201665, -0.054043516875550875, -0.08321475815193494, -0.11001880232017779, -0.13354819579908725, -0.15304146672549196, -0.167906160972842, -0.17773339606034183, -0.18230376872794093, -0.18158488243001691, -0.17572115154133375, -0.16501687105976595, -0.1499137997580331, -0.13096468174943518, -0.10880422217787396, -0.08411903827788304, -0.05761803324395176, -0.030004497243790427, -0.001951040868825416, 0.025921773001301992, 0.05306249567952219, 0.07900122348247962, 0.10335731863015635, 0.1258425822940911, 0.14626024334832619, 0.16450028494360933, 0.18053174205108255, 0.1943926655354523, 0.2061784643801796, 0.21602931256266372, 0.22411724822563847, 0.23063350923189954, 0.23577655069724138, 0.23974108638511749, 0.242708395806646, 0.24483804991090946, 0.24626113579560338, 0.24707500803079696, 0.24733956165584545, 0.24707500803079696, 0.24626113579560338, 0.24483804991090946, 0.242708395806646, 0.23974108638511749, 0.23577655069724138, 0.23063350923189954, 0.22411724822563847, 0.21602931256266372, 0.2061784643801796, 0.1943926655354523, 0.18053174205108255, 0.16450028494360933, 0.14626024334832619, 0.1258425822940911, 0.10335731863015635, 0.07900122348247962, 0.05306249567952219, 0.025921773001301992, -0.001951040868825416, -0.030004497243790427, -0.05761803324395176, -0.08411903827788304, -0.10880422217787396, -0.13096468174943518, -0.1499137997580331, -0.16501687105976595, -0.17572115154133375, -0.18158488243001691, -0.18230376872794093, -0.17773339606034183, -0.167906160972842, -0.15304146672549196, -0.13354819579908725, -0.11001880232017779, -0.08321475815193494, -0.054043516875550875, -0.023527608249201665, 0.007233082355737275], [0.059725017515438364, 0.03197958453286062, 0.0025207381574719806, -0.027588123185645037, -0.0572857273340844, -0.08555491563889543, -0.1114606806231028, -0.13418273806183595, -0.15304146672549196, -0.16751643729146143, -0.17725715646546372, -0.18208605074549258, -0.18199408570471504, -0.17712974307464055, -0.16778234479339135, -0.1543609103022869, -0.13736985507049018, -0.11738288358628372, -0.0950164022704569, -0.07090368426500879, -0.045670869380806056, -0.019915691575644292, 0.0058103924762656495, 0.031016232090896562, 0.05528095770522729, 0.07825990831739421, 0.09968670899986165, 0.11937185506223688, 0.13719827990417027, 0.15311446345017118, 0.16712567793535366, 0.1792839709402817, 0.18967745729212915, 0.19841943861188654, 0.20563779959612533, 0.21146505144444128, 0.21602931256266372, 0.21944644111666822, 0.22181346801290225, 0.2232034254780841, 0.22366162672468853, 0.2232034254780841, 0.22181346801290225, 0.21944644111666822, 0.21602931256266372, 0.21146505144444128, 0.20563779959612533, 0.19841943861188654, 0.18967745729212915, 0.1792839709402817, 0.16712567793535366, 0.15311446345017118, 0.13719827990417027, 0.11937185506223688, 0.09968670899986165, 0.07825990831739421, 0.05528095770522729, 0.031016232090896562, 0.0058103924762656495, -0.019915691575644292, -0.045670869380806056, -0.07090368426500879, -0.0950164022704569, -0.11738288358628372, -0.13736985507049018, -0.1543609103022869, -0.16778234479339135, -0.17712974307464055, -0.18199408570471504, -0.18208605074549258, -0.17725715646546372, -0.16751643729146143, -0.15304146672549196, -0.13418273806183595, -0.1114606806231028, -0.08555491563889543, -0.0572857273340844, -0.027588123185645037, 0.0025207381574719806, 0.03197958453286062], [0.08069235790121831, 0.05570574218106777, 0.028270310898122826, -0.0006409754282528475, -0.03002807965783915, -0.05890402451081101, -0.08633239590937543, -0.1114606806231028, -0.13354819579908725, -0.15198770280837584, -0.16632015713858264, -0.17624240938958516, -0.18160802037610754, -0.18242166855756492, -0.1788278960809016, -0.17109514979541934, -0.15959621882048483, -0.14478624788034108, -0.1271795169340972, -0.10732612754693129, -0.0857896329957062, -0.0631265026963309, -0.039868134180728126, -0.016505930263581485, 0.0065202421682302655, 0.02883009042098063, 0.05010748884225075, 0.07010183827093616, 0.08862652853638416, 0.10555493165712146, 0.12081441070397907, 0.13437885433763305, 0.14626024334832619, 0.15649972810645998, 0.16515865057394133, 0.17230988766358785, 0.17802983029511174, 0.18239124981424537, 0.18545724476618586, 0.18727640924644018, 0.18787932061729182, 0.18727640924644018, 0.18545724476618586, 0.18239124981424537, 0.17802983029511174, 0.17230988766358785, 0.16515865057394133, 0.15649972810645998, 0.14626024334832619, 0.13437885433763305, 0.12081441070397907, 0.10555493165712146, 0.08862652853638416, 0.07010183827093616, 0.05010748884225075, 0.02883009042098063, 0.0065202421682302655, -0.016505930263581485, -0.039868134180728126, -0.0631265026963309, -0.0857896329957062, -0.10732612754693129, -0.1271795169340972, -0.14478624788034108, -0.15959621882048483, -0.17109514979541934, -0.1788278960809016, -0.18242166855756492, -0.18160802037610754, -0.17624240938958516, -0.16632015713858264, -0.15198770280837584, -0.13354819579908725, -0.1114606806231028, -0.08633239590937543, -0.05890402451081101, -0.03002807965783915, -0.0006409754282528475, 0.028270310898122826, 0.05570574218106777], [0.0993958462307399, 0.07773008237271903, 0.05298490441364873, 0.026026147564044762, -0.0022274559793407315, -0.030841885736018544, -0.05890402451081101, -0.08555491563889543, -0.11001880232017779, -0.1316269478872783, -0.14983554931501694, -0.1642373823959323, -0.17456713788189782, -0.1807007071005138, -0.18264893898060253, -0.18054660691367944, -0.17463748569481502, -0.16525654180237792, -0.1528102839666787, -0.1377563081818195, -0.12058300781296416, -0.10179031338845618, -0.08187218787401292, -0.061301442485772274, -0.040517266401149735, -0.019915691575644292, 0.0001569493213448689, 0.019407660252202565, 0.03759772656874239, 0.054541276561040686, 0.07010183827093616, 0.08418731130237875, 0.09674378883254962, 0.10774865812501504, 0.11720338291232232, 0.12512633286074154, 0.13154597877649798, 0.13649472168344115, 0.14000357308347133, 0.14209785531573388, 0.14279404657238684, 0.14209785531573388, 0.14000357308347133, 0.13649472168344115, 0.13154597877649798, 0.12512633286074154, 0.11720338291232232, 0.10774865812501504, 0.09674378883254962, 0.08418731130237875, 0.07010183827093616, 0.054541276561040686, 0.03759772656874239, 0.019407660252202565, 0.0001569493213448689, -0.019915691575644292, -0.040517266401149735, -0.061301442485772274, -0.08187218787401292, -0.10179031338845618, -0.12058300781296416, -0.1377563081818195, -0.1528102839666787, -0.16525654180237792, -0.17463748569481502, -0.18054660691367944, -0.18264893898060253, -0.1807007071005138, -0.17456713788189782, -0.1642373823959323, -0.14983554931501694, -0.1316269478872783, -0.11001880232017779, -0.08555491563889543, -0.05890402451081101, -0.030841885736018544, -0.0022274559793407315, 0.026026147564044762, 0.05298490441364873, 0.07773008237271903], [0.11526115097856117, 0.09738828403656238, 0.0759235678781371, 0.05161237775613617, 0.025275083284098894, -0.0022274559793407315, -0.03002807965783915, -0.0572857273340844, -0.08321475815193494, -0.10711012813756442, -0.1283676319466868, -0.1464987033293174, -0.16113955966514656, -0.17205475511311313, -0.17913546063850083, -0.18239300622958532, -0.18194839266053625, -0.17801860199902664, -0.17090060569317098, -0.1609539875623888, -0.14858307017251748, -0.13421936300715656, -0.11830504740258321, -0.10127808535368477, -0.08355939645450051, -0.06554239869174844, -0.04758506314163741, -0.030004497243790427, -0.013073952151520388, 0.0029779491154211806, 0.017966041941118966, 0.031745840459068614, 0.044209509361482956, 0.05528095770522729, 0.0649104168254659, 0.07306884206017318, 0.07974244535617742, 0.08492762656935865, 0.08862652853638416, 0.09084339726921295, 0.09158188560927924, 0.09084339726921295, 0.08862652853638416, 0.08492762656935865, 0.07974244535617742, 0.07306884206017318, 0.0649104168254659, 0.05528095770522729, 0.044209509361482956, 0.031745840459068614, 0.017966041941118966, 0.0029779491154211806, -0.013073952151520388, -0.030004497243790427, -0.04758506314163741, -0.06554239869174844, -0.08355939645450051, -0.10127808535368477, -0.11830504740258321, -0.13421936300715656, -0.14858307017251748, -0.1609539875623888, -0.17090060569317098, -0.17801860199902664, -0.18194839266053625, -0.18239300622958532, -0.17913546063850083, -0.17205475511311313, -0.16113955966514656, -0.1464987033293174, -0.1283676319466868, -0.10711012813756442, -0.08321475815193494, -0.0572857273340844, -0.03002807965783915, -0.0022274559793407315, 0.025275083284098894, 0.05161237775613617, 0.0759235678781371, 0.09738828403656238], [0.12777380562398274, 0.11405907878471819, 0.09636827159298987, 0.07531659368730659, 0.05161237775613617, 0.026026147564044762, -0.0006409754282528475, -0.027588123185645037, -0.054043516875550875, -0.07929019757294747, -0.10268778525178764, -0.12368964794720452, -0.14185512230149663, -0.15685668268767797, -0.16848219583369567, -0.17663261032673944, -0.18131560690315682, -0.1826358700412797, -0.18078273088932142, -0.1760159755489718, -0.16865061331126227, -0.15904136091487175, -0.14756752732225356, -0.13461888616197776, -0.12058300781296416, -0.10583439818051152, -0.0907256642328181, -0.07558080422426758, -0.060690608986011814, -0.046310064114579955, -0.032657564269347995, -0.019915691575644292, -0.00823327044894154, 0.0022716100207446164, 0.011507919583092052, 0.019407660252202565, 0.025921773001301992, 0.031016232090896562, 0.03466854669458865, 0.03686485131708162, 0.03759772656874239, 0.03686485131708162, 0.03466854669458865, 0.031016232090896562, 0.025921773001301992, 0.019407660252202565, 0.011507919583092052, 0.0022716100207446164, -0.00823327044894154, -0.019915691575644292, -0.032657564269347995, -0.046310064114579955, -0.060690608986011814, -0.07558080422426758, -0.0907256642328181, -0.10583439818051152, -0.12058300781296416, -0.13461888616197776, -0.14756752732225356, -0.15904136091487175, -0.16865061331126227, -0.1760159755489718, -0.18078273088932142, -0.1826358700412797, -0.18131560690315682, -0.17663261032673944, -0.16848219583369567, -0.15685668268767797, -0.14185512230149663, -0.12368964794720452, -0.10268778525178764, -0.07929019757294747, -0.054043516875550875, -0.027588123185645037, -0.0006409754282528475, 0.026026147564044762, 0.05161237775613617, 0.07531659368730659, 0.09636827159298987, 0.11405907878471819], [0.13650222610828716, 0.12719030582037316, 0.1136526088802527, 0.09636827159298987, 0.0759235678781371, 0.05298490441364873, 0.028270310898122826, 0.0025207381574719806, -0.023527608249201665, -0.04916880920228074, -0.07374973820785838, -0.09668883252747353, -0.11749065565570795, -0.13575600794040762, -0.1511875643863488, -0.163591222139663, -0.17287351607260817, -0.17903560277058095, -0.1821644169794075, -0.18242166855756492, -0.1800313728705813, -0.1752665961050691, -0.16843605361995675, -0.15987112992755653, -0.1499137997580331, -0.13890582780165694, -0.1271795169340972, -0.11505016730310495, -0.10281030706494565, -0.0907256642328181, -0.07903277128303789, -0.06793803188546253, -0.05761803324395176, -0.04822085787410071, -0.039868134180728126, -0.032657564269347995, -0.026665677985416577, -0.021950582012676394, -0.01855449981019833, -0.016505930263581485, -0.015821288518275644, -0.016505930263581485, -0.01855449981019833, -0.021950582012676394, -0.026665677985416577, -0.032657564269347995, -0.039868134180728126, -0.04822085787410071, -0.05761803324395176, -0.06793803188546253, -0.07903277128303789, -0.0907256642328181, -0.10281030706494565, -0.11505016730310495, -0.1271795169340972, -0.13890582780165694, -0.1499137997580331, -0.15987112992755653, -0.16843605361995675, -0.1752665961050691, -0.1800313728705813, -0.18242166855756492, -0.1821644169794075, -0.17903560277058095, -0.17287351607260817, -0.163591222139663, -0.1511875643863488, -0.13575600794040762, -0.11749065565570795, -0.09668883252747353, -0.07374973820785838, -0.04916880920228074, -0.023527608249201665, 0.0025207381574719806, 0.028270310898122826, 0.05298490441364873, 0.0759235678781371, 0.09636827159298987, 0.1136526088802527, 0.12719030582037316], [0.14111903500315878, 0.13632396086944565, 0.12719030582037316, 0.11405907878471819, 0.09738828403656238, 0.07773008237271903, 0.05570574218106777, 0.03197958453286062, 0.007233082355737275, -0.017859822184363938, -0.042655257000177006, -0.06655906279410359, -0.08904297911487404, -0.10965701691843574, -0.12803786284735597, -0.14391335124448024, -0.15710321083861073, -0.16751643729146143, -0.1751457556394694, -0.1800597155006458, -0.18239300622958532, -0.18233559039097344, -0.18012123502583363, -0.1760159755489718, -0.17030698199702413, -0.16329221750830802, -0.15527119023634722, -0.14653700801271363, -0.13736985507049018, -0.12803192632998142, -0.11876378051842666, -0.10978201113265723, -0.10127808535368477, -0.09341816596346665, -0.08634370978474622, -0.08017262722723162, -0.0750007897964791, -0.07090368426500879, -0.06793803188546253, -0.06614321685638791, -0.06554239869174844, -0.06614321685638791, -0.06793803188546253, -0.07090368426500879, -0.0750007897964791, -0.08017262722723162, -0.08634370978474622, -0.09341816596346665, -0.10127808535368477, -0.10978201113265723, -0.11876378051842666, -0.12803192632998142, -0.13736985507049018, -0.14653700801271363, -0.15527119023634722, -0.16329221750830802, -0.17030698199702413, -0.1760159755489718, -0.18012123502583363, -0.18233559039097344, -0.18239300622958532, -0.1800597155006458, -0.1751457556394694, -0.16751643729146143, -0.15710321083861073, -0.14391335124448024, -0.12803786284735597, -0.10965701691843574, -0.08904297911487404, -0.06655906279410359, -0.042655257000177006, -0.017859822184363938, 0.007233082355737275, 0.03197958453286062, 0.05570574218106777, 0.07773008237271903, 0.09738828403656238, 0.11405907878471819, 0.12719030582037316, 0.13632396086944565]], \"x\": [-10.0, -9.75, -9.5, -9.25, -9.0, -8.75, -8.5, -8.25, -8.0, -7.75, -7.5, -7.25, -7.0, -6.75, -6.5, -6.25, -6.0, -5.75, -5.5, -5.25, -5.0, -4.75, -4.5, -4.25, -4.0, -3.75, -3.5, -3.25, -3.0, -2.75, -2.5, -2.25, -2.0, -1.75, -1.5, -1.25, -1.0, -0.75, -0.5, -0.25, 0.0, 0.25, 0.5, 0.75, 1.0, 1.25, 1.5, 1.75, 2.0, 2.25, 2.5, 2.75, 3.0, 3.25, 3.5, 3.75, 4.0, 4.25, 4.5, 4.75, 5.0, 5.25, 5.5, 5.75, 6.0, 6.25, 6.5, 6.75, 7.0, 7.25, 7.5, 7.75, 8.0, 8.25, 8.5, 8.75, 9.0, 9.25, 9.5, 9.75], \"y\": [-10.0, -9.75, -9.5, -9.25, -9.0, -8.75, -8.5, -8.25, -8.0, -7.75, -7.5, -7.25, -7.0, -6.75, -6.5, -6.25, -6.0, -5.75, -5.5, -5.25, -5.0, -4.75, -4.5, -4.25, -4.0, -3.75, -3.5, -3.25, -3.0, -2.75, -2.5, -2.25, -2.0, -1.75, -1.5, -1.25, -1.0, -0.75, -0.5, -0.25, 0.0, 0.25, 0.5, 0.75, 1.0, 1.25, 1.5, 1.75, 2.0, 2.25, 2.5, 2.75, 3.0, 3.25, 3.5, 3.75, 4.0, 4.25, 4.5, 4.75, 5.0, 5.25, 5.5, 5.75, 6.0, 6.25, 6.5, 6.75, 7.0, 7.25, 7.5, 7.75, 8.0, 8.25, 8.5, 8.75, 9.0, 9.25, 9.5, 9.75], \"zmin\": null, \"zmax\": null, \"colorscale\": [[0.0, \"rgb(255, 153, 51)\"], [0.1111111111111111, \"rgb(55, 128, 191)\"], [0.2222222222222222, \"rgb(50, 171, 96)\"], [0.3333333333333333, \"rgb(128, 0, 128)\"], [0.4444444444444444, \"rgb(219, 64, 82)\"], [0.5555555555555556, \"rgb(0, 128, 128)\"], [0.6666666666666666, \"rgb(255, 255, 51)\"], [0.7777777777777778, \"rgb(128, 128, 0)\"], [0.8888888888888888, \"rgb(251, 128, 114)\"], [1.0, \"rgb(128, 177, 211)\"]]}], {\"legend\": {\"bgcolor\": \"#F5F6F9\", \"font\": {\"color\": \"#4D5663\"}}, \"paper_bgcolor\": \"#F5F6F9\", \"plot_bgcolor\": \"#F5F6F9\", \"yaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"xaxis1\": {\"tickfont\": {\"color\": \"#4D5663\"}, \"gridcolor\": \"#E1E5ED\", \"titlefont\": {\"color\": \"#4D5663\"}, \"zerolinecolor\": \"#E1E5ED\", \"showgrid\": true, \"title\": \"\"}, \"titlefont\": {\"color\": \"#4D5663\"}}, {\"showLink\": true, \"linkText\": \"Export to plot.ly\"})});</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "x = cf.datagen.sinwave(10,.25)\n",
    "x.iplot(kind=\"surface\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## iplotで他に作れるグラフ\n"
   ]
  },
  {
   "cell_type": "raw",
   "metadata": {},
   "source": [
    " kind : string\n",
    "                           Kind of chart\n",
    "                                   scatter\n",
    "                                   bar\n",
    "                                   box\n",
    "                                   spread\n",
    "                                   ratio\n",
    "                                   heatmap\n",
    "                                   surface\n",
    "                                   histogram\n",
    "                                   bubble\n",
    "                                   bubble3d\n",
    "                                   scatter3d       \n",
    "                                   scattergeo\n",
    "                                   ohlc\n",
    "                                   candle\n",
    "                                   pie\n",
    "                                   choroplet       "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.8"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
